/* eslint-disable no-console */
const Base = require('./base.js');
const uuid = require('node-uuid');
const util = require('../handle/util.js')
const uploadFile = require('../handle/uploadFile.js')
const moment = require('moment');
const path = require('path')
const fs = require('fs')
module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  // 活动添加
  /**
   * showdoc
   * @catalog 活动信息
   * @title 活动信息添加
   * @description 活动信息添加接口
   * @method post
   * @url http://127.0.0.1:8360/activity/add
   * @param id 必选 int 活动ID 0或''为新增
   * @param url 必选 array 附件地址
   * @param personID 必选 array 人员ID
   * @param matterID 必选 array 事项ID
   * @return {"errno": 0, "errmsg":"", "data":"活动ID"}
   */
  async addAction() {
    const data = this.post();
    data.url = data.url.join(',');// 将url数组转成string
    data.personID = data.personID.join(',');// 将personID数组转成string
    data.matterID = data.matterID.join(',');// 将matterID数组转成string
    data.abnormalID = data.abnormalID.join(',');// 将abnormalID数组转成string
    if (typeof data.id === 'undefined'){
      // 新增
      const userInfo = await this.getUserInfo(data.userId)
      const addData = data;
      addData['id'] = uuid.v1();
      if(Object.keys(userInfo).length !== 0) {
        // ********* 活动编号改为在提交审批时生成
        // const activityNum = await util.getActivityNo({description: userInfo.description, regionAdminNo: userInfo.regionAdminNo})
        // if (activityNum == 0 || activityNum == "") {
        //   return this.fail(2002, '获取活动编号失败');
        // }
        // addData['activityNum'] = activityNum;
        addData['createPerson'] = userInfo.name;
        addData['createAccount'] = userInfo.user_name;
        addData['createOrgID'] = userInfo.orgID;//创建机构ID
        addData['createOrg'] = userInfo.orgName;//创建机构
      }
      if (data.isMeeting === 0){
        if (data.registerTypeID === '002'){ // 大会来信
          addData['registerPlaceID'] = 6;
          addData['registerPlace'] = '来信';
        }
        if (data.registerTypeID === '003'){ // 大会来电
          addData['registerPlaceID'] = 7;
            addData['registerPlace'] = '来电';
        }
        if (data.registerTypeID === '004'){ // 大会网上
          addData['registerPlaceID'] = 8;
            addData['registerPlace'] = '网上';
        }
      }
      const back = await this.model('activity').add(addData);
      if (data.hasOwnProperty("ocr") && data.ocr.length > 0){
        //绑定ocr
        data.ocr.forEach(async function(item) {
          await think.model("ocr").where({"url":item}).update({"activityID":addData.id});
        });
      }
      // 如果为网上信访，需要修改online表状态registerState 并管理online表
      if (data.xfSourceID === "004001") {
        await this.model("online").where({"id":data.onlineID}).update({"registerState":0,"activityID":addData.id})//登记状态改为，0已登记
      }
      return this.success(addData.id)
    } else {
      // 更新
      const back = await this.model('activity').update(data,{'id':data.id});
      return this.success(data.id)
    }
  };
  // 活动列表
  async listAction() {
    const data = this.post();
    let personWhere = {}
    //主信访人名称
    if(data.mainPersonName) {
      personWhere['name'] = ['like', '%' + data.mainPersonName + '%'];
    }
    //住信访人身份证
    if(data.personIDNumber) {
      personWhere['IDNumber'] = data.personIDNumber;
    }
    let whereParam = {}
    if(!think.isEmpty(personWhere)) {
      let personIDS = await this.model('person').field('id').where(personWhere).select();
      if(!think.isEmpty(personIDS)){
        let personID = [];
        personIDS.forEach((item) => {
          personID.push(item.id)
        })
        whereParam.mainPerson = ['IN',personID]
      }
    }
    //活动编号
    if (data.activityNum) {
      whereParam['activityNum'] = data.activityNum;
    }
    //信访类型
    if(data.xfSourceID) {
      whereParam['xfSourceID'] = data.xfSourceID;
    }

    if (data.startTime) {
      whereParam['createTime'] = ['>=', data.startTime];
    }
    if (data.endTime) {
      whereParam['createTime'] = ['<=', data.endTime + " 23:59:59"]
    }
    const back = await this.model('activity').where(whereParam).page(data.page, data.limit).order('createTime DESC').countSelect();// 时间倒序
    back.data.forEach(function(item) {
      item.personID = item.personID === null || item.personID === '' ? [] : item.personID.split(',');
      item.matterID = item.matterID === null || item.matterID === '' ? [] : item.matterID.split(',');
      item.url = item.url === null || item.url === '' ? [] : item.url.split(',');
    });
    return this.success(back);

  }
  // 活动详情
  async findAction() {
    const data = this.post();
    const back = await this.model('activity').where({'id': data.id}).find();
    if (think.isEmpty(back)) {
      return this.fail("查询失败！")
    } else {
      let matter = [];
      back.personID = ((back.personID === null || back.personID === '') ? [] : back.personID.split(','));
      back.matterID = ((back.matterID === null || back.matterID === '') ? [] : back.matterID.split(','));
      back.url = ((back.url === null || back.url === '') ? [] : back.url.split(','));
      if (back.matterID.length > 0 ){
        matter = await this.model('matter').where({'id': ['IN', back.matterID]}).select();
      }
      let file = [];//附件详细信息
      if (back.url.length > 0 ) {
        file = await this.model('file_log').where({"url":["IN",back.url]}).select();
      }
      back["file"] = file;//附件详细信息
      back['matter'] = matter;
      if (!think.isEmpty(back.person)) {
        const mainContact = await this.model('person_activity').field('isMainContact').where({personID:back['person']['id'], activityID:data.id}).find();
        back['person']['isMainContact'] = mainContact['isMainContact'];
      }
      return this.success(back)
    }
  }

  /**
   * showdoc
   * @catalog 活动信息/领导或代表活动信息
   * @title 添加领导或代表活动信息
   * @description 添加领导或代表活动信息接口
   * @method post
   * @url http://127.0.0.1:8360/activity/addLeadingPerson
   * @param name 必选 string  姓名
   * @param IDcard 必选 string 身份证号
   * @param sex 必选 array 性别
   * @param activityID 必选 int 活动ID
   * @param unit 选填 string 单位
   * @param position 选填 string 职位
   * @param grade 选填 string 层级
   * @param due 选填 string 届次
   * @param zone 选填 string 地区
   * @param isLeading 必填 int 0是代表，1是领导
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  async addLeadingPersonAction() {
    const param = this.post();

    let insertID = await this.model('delegate_leading').add(param)
    if (insertID) {
      let leading_activity = {leadingID: insertID, activityID: param.activityID}
      let leadActivity = await this.model('activity_leading').add(leading_activity).catch((err) => {
        return think.isError(err) ? err : new Error(err);
      });
      if (think.isError(leadActivity)) {
        return this.fail(1008, '添加失败')
      }
      return this.success();
    }
  }

  // 关联活动和领导代表
  async relationAction(){
    //传参 activityID
    //传参 leadingID 领导或代表的id ，int
    const data = this.post();
    if (!data.hasOwnProperty("activityID") && !data.hasOwnProperty("leadingID")){
      return this.fail(1009, '字段缺失')
    }
    let find = await this.model('activity_leading').where({"activityID":data.activityID,"leadingID":data.leadingID}).find();
    if (think.isEmpty(find)){
      let insert = await this.model('activity_leading').add({"activityID":data.activityID,"leadingID":data.leadingID}).catch((err) => {
        return think.isError(err) ? err : new Error(err);
      });
      if (think.isError(insert)) {
        return this.fail(10091, '添加失败')
      }
      return this.success('绑定成功');
    } else {
      return this.fail(10092, '绑定失败')
    }

  }
  // 解除活动与领导代表关联
  async relieveAction(){
    const data = this.post();
    if (!data.hasOwnProperty("activityID") && !data.hasOwnProperty("leadingID")){
      return this.fail(1010, '字段缺失')
    }
    let insert = await this.model('activity_leading').where({"activityID":data.activityID,"leadingID":data.leadingID}).delete().catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(insert)) {
      return this.fail(1010, '解除失败')
    }
    return this.success();
  }
  //领导代表搜索列表
  async leaderFindAction(){
    // 传参 name 代表或领导姓名，没有传空字符串
    // 传参 isLeading 1领导，0代表，int
    // 传参 page，limit 分页
    const data = this.post();
    let time = moment().format('YYYY-MM-DD');
    let where = {
      "isLeading":data.isLeading,//1领导，0代表
      "name":['LIKE','%'+ data.name +'%'],
      "serveStartTime":['<=', time],
      "serveEndTime": ['>=', time]
    };
    const leader = await this.model('delegate_leading').where(where).page(data.page, data.limit).countSelect();
    return this.success(leader)
  }
  /**
   * showdoc
   * @catalog 领导或代表活动信息
   * @title 获取领导或代表活动信息列表
   * @description 获取领导或代表活动信息列表接口
   * @method post
   * @url http://127.0.0.1:8360/activity/getPersonList
   * @param page 必选 int 页码
   * @param pageSize 必选 int 每页显示条数
   * @param activityID 必选 string 活动id
   * @param isLeading 必选 int 0代表，1领导
   * @return {"errno": 0, "errmsg":"", "data":{"count": 1,"totalPages": 1,"pageSize": 15,"currentPage": 1,"data":[{"name":"zhang","IDcard":"","sex":"男","activityID":1,"unit":"河北","position":"组长","grade":"","due":"","zone":"","isLeading":1}]}}
   * @return_param count  int 总条数
   * @return_param totalPages  int 总页数
   * @return_param currentPage  int 当前页
   * @return_param name  string  姓名
   * @return_param IDcard string 身份证号
   * @return_param sex  string 性别
   * @return_param activityID int 活动ID
   * @return_param unit string 单位
   * @return_param position string 职位
   * @return_param grade string 层级
   * @return_param due string 届次
   * @return_param zone string 地区
   * @return_param isLeading int 0是代表，1是领导
   */
  async getPersonListAction() {
    const param = this.post();
    const list = await this.model('delegate_leading').alias('le').join({table:'activity_leading',on:['id','leadingID'],join:'right',as:'al'}).where('al.activityID="' + param.activityID + '" and le.isLeading=' + param.isLeading).page(param.page, param.pageSize).countSelect();
    this.success(list)
  }

  /**
   * showdoc
   * @catalog 领导或代表活动信息
   * @title 删除领导或代表活动信息
   * @description 删除领导或代表活动信息接口
   * @method post
   * @url http://127.0.0.1:8360/activity/delLeadingPerson
   * @param leadingID 必选 int  领导或代表id
   * @return {"errno": 0, "errmsg":"", "data":"活动ID"}
   */
  async delLeadingPersonAction() {
    const param = this.post();
    const sql = " delete delegate_leading,activity_leading from delegate_leading LEFT JOIN activity_leading on activity_leading.leadingID=delegate_leading.id where delegate_leading.id=" + param.leadingID;
    let delRes = await this.model('delegate_leading').query(sql).catch((err) => {
      return think.isError(err) ? err : new Error(err);
    })
    if (think.isError(delRes)) {
      return this.fail(1010, '删除失败');
    }
    return this.success();
  }

  /**
   * showdoc
   * @catalog 领导或代表活动信息
   * @title 修改领导或代表活动信息
   * @description 修改领导或代表活动信息接口
   * @method post
   * @url http://127.0.0.1:8360/activity/editLeadingPerson
   * @param name 必选 string  姓名
   * @param IDcard 必选 string 身份证号
   * @param sex 必选 array 性别
   * @param unit 选填 string 单位
   * @param position 选填 string 职位
   * @param grade 选填 string 层级
   * @param due 选填 string 届次
   * @param zone 选填 string 地区
   * @param isLeading 必填 int 0是代表，1是领导
   * @param leadingID 必填 int 领导或代表id
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  async editLeadingPersonAction() {
    const param = this.post();
    const editRes = await this.model('delegate_leading').where({id:param.leadingID}).update(param).catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(editRes)) {
      return this.fail(1011, '修改失败');
    }
    return this.success();
  }
  /**
   * showdoc
   * @catalog 活动信息
   * @title 删除活动信息
   * @description 删除活动信息接口
   * @method post
   * @url http://127.0.0.1:8360/activity/delActivity
   * @param activityID 必选 string  活动id
   * @return {"errno": 0, "errmsg":"", "data":"活动ID"}
   */
  async delActivityAction() {
    const param = this.post();
    // 删除活动表
    const delActivity = await this.model('activity').setRelation(false).where({id:param.activityID}).delete().catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    // 删除事项表
    const delMatter = await this.model('matter').where({activityID:param.activityID}).delete().catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    // 删除人员活动关联表
    const delPerson = await this.model('person_activity').setRelation(false).where({activityID:param.activityID}).delete().catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(delActivity) & think.isError(delMatter) & think.isError(delPerson)) {
      return this.fail(1011, '删除失败');
    }
    return this.success();
  }
  /**
   * showdoc
   * @catalog 活动信息
   * @title ocr文件上传
   * @description ocr文件上传formData接口
   * @method post
   * @url http://127.0.0.1:8360/activity/uploadOcr
   * @param activityID 必选 string  活动id
   * @param userId 必选 string userId
   * @param file 必选 string  图片名称
   * @param str 必选 string  ocr识别内容
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  // ocr上传
  async uploadOcrAction(){
    const data = this.ctx;
    const body = data.request.body;
    let req = data.req;
    let file = data.request.files.file;
    const userInfo = await this.getUserInfo(body.userId);
    //请求体格式不对 直接返回
    if (!/multipart\/form-data/i.test(req.headers['content-type'])) {
      return
    }
    //创建路径
    let filePath = path.join(
      think.ROOT_PATH,
      // '/www/static', 'OCR',
      '/www/static', moment().format('YYYY年')+'/'+moment().format('M月') + '/' + 'OCR',
    );
    uploadFile.mkdirsSync(filePath); // 创建文件夹（如果需要）
    let fileName = Math.random().toString(16).substr(2) + '.' + file.name.substr( file.name.lastIndexOf(".") + 1)
    let _uploadFilePath = path.join(filePath, fileName)
    let saveTo = path.join(_uploadFilePath);
    const reader = fs.createReadStream(file.path);
    // 文件保存到制定路径
    reader.pipe(fs.createWriteStream(saveTo))
    // 在表中插入数据
    const ocrAdd = {
      'activityID':body.activityID,
      // 'url':'/static/OCR/'+ fileName,
      'url':'/static/'+ moment().format('YYYY年')+'/'+moment().format('M月')  + '/OCR/' + fileName,
      'str':body.str,
      'createAccount':userInfo.user_name,
      'createPerson':data.name,
    };
    const ocr = await this.model('ocr').add(ocrAdd);
    // 在文件上传日志中保存记录
    let log = {
      "name":file.name,
      "random":fileName,
      // "url":'/static/OCR/' + fileName,
      "url":ocrAdd.url,
      "fileType":file.name.substr( file.name.lastIndexOf(".") + 1),
      "userId":body.userId
    };
    await this.model('file_log').add(log);
    // return this.success({"id":ocr,"path":'/static/OCR/' + fileName})
    return this.success({"id":ocr,"path":ocrAdd.url})
  }

  // ocr文件删除
  async delOcrAction(){
    const data = this.post();
    let path = think.ROOT_PATH + '\\www'+ data.url;

    // let a = await fsPromise.stat('html');
    // console.log(a)
    function unlink(path) {
     return new Promise(function (resolve, reject) {
        fs.unlink(path,function(err){
          if (err) {
            resolve(0);
          }
          resolve(1)
        })
      })
    }
    let p = await unlink(path)
    if (p == 1){
      await think.model('file_log').where({"url":data.url}).delete();
      await think.model('ocr').where({"url":data.url}).delete();
      return this.success('删除文件成功')
    } else {
      return this.fail('文件不存在')
    }

    // console.log(a)
    // let a = fsPromise.stat('./hehe.js',(err,stats)=>{
    //   if(err){
    //     // reject('文件不存在'
    //     return 1
    //   }else{
    //     // resolve('文件存在')
    //     return 2
    //   }
    // })
    // console.log(a)
    // return new Promise((resolve,reject)=>{
    //   fs.stat('./hehe.js',(err,stats)=>{
    //     if(err){
    //       reject(1,'文件不存在')
    //       // return this.fail()
    //     }else{
    //       resolve('文件存在')
    //     }
    //   })
    // })

    // fs.unlink(path,async function(error){
    //   if(error){
    //     console.log(error);
    //   }
    //   console.log('删除文件成功');
    //   await think.model('file_log').where({"url":data.url}).delete();
    // });
    // return this.success()
  }

  /**
   * showdoc
   * @catalog 活动信息
   * @title ocr列表
   * @description ocr列表接口
   * @method post
   * @url http://127.0.0.1:8360/activity/ocrList
   * @param activityID 必选 string  活动id
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  //ocr列表
  async ocrListAction(){
    const data = this.post();
    const ocr = await this.model('ocr').join('file_log on file_log.url = ocr.url').where({'activityID':data.activityID})
      .field('ocr.*,file_log.name').page(data.page, data.limit).order('createTime ASC').countSelect();// 时间倒序
    this.success(ocr)
  }

  /**
   * showdoc
   * @catalog 活动信息
   * @title  登记列表，带搜索，区分登记类型
   * @description  登记列表，带搜索，区分登记类型接口
   * @method post
   * @url http://127.0.0.1:8360/activity/registerList
   * @param userId 必选 string  userId
   * @param name 必选 string  搜索信访人名字,可以空字符串
   * @param type 必选 int  0全部，1未提交，2已完成
   * @param registerTypeID 必选 string  登记类型
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  // 登记列表，带搜索，区分登记类型
  async registerListAction(){
    const data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    let person_activityID = [];
    let name = typeof data.name === 'undefined' ? "" :data.name;
    let where = {
      'registerTypeID':data.registerTypeID,
      'createAccount':userInfo.user_name,
      'meetingID': typeof data.meetingID === 'undefined' ? null : data.meetingID
    };
    // 进行搜索
    const person = await this.model('person_activity').join('person ON person.id = person_activity.personID').where({'name':['LIKE', '%' + name + '%']}).group('activityID').select()
    person.forEach(function(item) {
          person_activityID.push(item.activityID)
    });
    // type: 0全部，1未提交，2已完成
    if (data.type !==0) {
      where['submit'] = (data.type === 1 ? 0 : 1);// submit 0未提交，1已提交
    }
    if (data.name.length > 0){
      //  带搜索
      // where['id'] = (data.type === 0 ? ['IN', person_activityID] : ['IN',activityID]);
      if (person_activityID.length === 0){
        // 姓名没有搜索到人，所以应该查不到，所以id给设置成null
        where['id'] = null;
      } else {
        where['id'] = ['IN', person_activityID];
      }
    } else {
      // 不带搜索
      // where['id'] = ((data.type === 0 || matter_activityID.length === 0 )? ['!=', null] : ['IN',matter_activityID]);
      where['id'] = ['!=', null];
    }
    // // 大会届次筛选
    // if (data.hasOwnProperty('meetingID') && data.meetingID !== ''){
    //   where['meetingID'] = data.meetingID
    // }
    // if (!data.hasOwnProperty('meetingID')){
    //   where['meetingID'] = null
    // }
    // 时间
    if ((!data.hasOwnProperty('startTime') && !data.hasOwnProperty('endTime')) || (data.startTime === '' && data.endTime === '')){
      where['createTime'] = ['!=', null] //全选
      // 默认当天
    } else if (data.startTime === ''){
      // 未设定开始时间
      where['createTime'] = ['between', '1900-01-01' + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    } else if (data.endTime === ''){
      // 未设定结束时间
      where['createTime'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + '2099-01-01']
    } else {
      where['createTime'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    }
    const activity = await this.model('activity').where(where).page(data.page, data.limit).order('createTime DESC').countSelect();
    return this.success(activity)
  }
  // app录入锁定和解锁
  async lockAPPAction(){
    // activityID
    // lockAPP 0锁定1位锁定
    const data = this.post();
    if (data.hasOwnProperty("activityID") && data.hasOwnProperty("lockAPP") && (data.lockAPP === 0 || data.lockAPP === 1)){
      let lock = await this.model('activity').where({"id":data.activityID}).update({"lockAPP":data.lockAPP}).catch((err) => {
        return think.isError(err) ? err : new Error(err);
      });
      if (think.isError(lock)) {
        return this.fail(1011, '修改失败')
      }
      return this.success('修改成功');
    } else {
      return this.fail(1011,"参数错误")
    }
  }
  // 根据条件查询当前部门信访活动
  //activityNum:"信访编号",
  //xfSourceID:"信访形式",array
  //mainPersonName:"访人姓名",
  //isMeeting 大会标识 0是1不是
  //xfTypeID:"信访性质",
  //startTime:
  //endTime
  //xfNumMin: 信访人数
  //xfNumMax: 信访人数
  //createPerson: 登记人
  //abnormalID: 异常访
  //deptID: 数据选择范围array
  //page
  //pageSize
  //userId
  async getActivityAction(){
    let data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    // let orgAccount = await this.model('sys_organization').join('sys_user on sys_user.orgID = sys_organization.id')
    //   .where({"sys_organization.id":userInfo.orgID}).field("sys_user.user_name").select();
    // let createAccount = [];
    // orgAccount.forEach(function(item) {
    //   createAccount.push(item.user_name);
    // });
    let where = {
      'activity.xfSourceID':data.xfSourceID === undefined || data.xfSourceID === ''|| data.xfSourceID.length ===0 ? ['!=',null] :['IN',data.xfSourceID],//信访形式 逐级可查
      'activity.activityNum':data.activityNum === undefined || data.activityNum === '' ? ['!=',null] :['LIKE', '%' + data.activityNum + '%'],
      'activity.xfTypeID':data.xfTypeID === undefined || data.xfTypeID === '' || data.xfTypeID.length ===0 ? ['!=',null] :['IN',data.xfTypeID],//信访性质
      // 'activity.createAccount':['IN',createAccount],
      'matter.taskid':['!=',null],
      // 'person.name':data.mainPersonName === undefined || data.mainPersonName === '' ? ['!=',''] :['LIKE', '%' + data.mainPersonName + '%'],
      // 'fw_task_act.c_user':data.userId // 过手单位人员
    };
      if (data.hasOwnProperty('mainPersonName') && data.mainPersonName !== ""){
        where["person.name"] = ['LIKE', '%' + data.mainPersonName + '%']
      }
    if (data.hasOwnProperty('deptID') && Array.isArray(data.deptID) && data.deptID.length > 0){
      // 对查询的数据范围进行选择
      let dept = await this.model('sys_dept').where({'id':userInfo.dictValue}).find();
      if (!think.isEmpty(dept) && data.deptID.includes(dept.parentID)) { // 选择了上级，即上级登记，本级经手
        where['fw_task_act.deptID_now'] = userInfo.dictValue;//本级经手
        data.deptID.concat(dept.parentID);//加入上级
        data.deptID.push(2);// 和 上上级
      }
      let org = await this.model('sys_organization').where({'deptID':['IN',data.deptID],'agent':1}).select();
      if (!think.isEmpty(org)){
        let co = [];
        org.forEach(function(item) {
          co.push(item.id)
        });
        where['activity.createOrgID'] = ['IN',co];
      }
    }
    // 登记人
    if (data.hasOwnProperty('createPerson')){
      where['activity.createPerson'] = ['LIKE', '%' + data.createPerson + '%']
    }
    // 信访活动初重标识 100初次200重复
    if (data.hasOwnProperty('visitID') && data.visitID !== ""){
      if (data.visitID === "100"){
        where['activity.visit'] = "初次"
      }
      if (data.visitID === "200"){
        where['activity.visit'] = "重复"
      }

    }
    // 来访人数 xfNumber
    if (data.hasOwnProperty('xfNumMin') && data.hasOwnProperty('xfNumMax')) {
      where['activity.xfNumber'] = ['BETWEEN', data.xfNumMin, data.xfNumMax]
    } else if (data.xfNumMin) {
      where['activity.xfNumber'] = {'>': data.xfNumMin}
    } else if (data.xfNumMax){
      where['activity.xfNumber'] = {'<': data.xfNumMax}
    }
    // 登记单位
    if (data.hasOwnProperty('createOrgID')) {
      where['activity.createOrgID'] = data.createOrgID
    }
    // 登记人
    if (data.hasOwnProperty('createPerson')) {
      where['activity.createPerson'] = ['LIKE', '%' + data.createPerson + '%']
    }
    // 大会标识
    if (data.hasOwnProperty('isMeeting')) {
      where['activity.isMeeting'] = data.isMeeting
    }
    // 异常访标识
    if (data.hasOwnProperty('abnormalID') && Array.isArray(data.abnormalID) && data.abnormalID.length > 0) {
      where['activity.abnormalID'] = ['IN', data.abnormalID]
    }
    // 时间
    if (data.startTime === '' && data.endTime === ''){
      where['activity.createTime'] = ['!=', null] //全选
      // 默认当天
    } else if (data.startTime === ''){
      // 未设定开始时间
      where['activity.createTime'] = ['between', '1900-01-01' + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    } else if (data.endTime === ''){
      // 未设定结束时间
      where['activity.createTime'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + '2099-01-01']
    } else {
      where['activity.createTime'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    }
    // // 多次反映问题的信访人
    // if (data.hasOwnProperty('visit') && data.visit === 0){
    //   let sql = 'SELECT COUNT(*),activityID FROM person_activity GROUP BY personID HAVING COUNT(*) > 1'
    //   let pa = await this.model('person_activity').query(sql);
    //   if (pa.length > 0) {
    //     let activityID = [];
    //     pa.forEach(function(item) {
    //       activityID.push(item.activityID);
    //     });
    //     if (activityID.length > 0){
    //       where['activity.id'] = ['IN',activityID];
    //     }
    //   }else {
    //     //因为是与条件，此处不满足，则返回空数据
    //     return this.success({
    //       "count": 0,
    //       "totalPages": 0,
    //       "pageSize": 10,
    //       "currentPage": 1,
    //       "data": []
    //     })
    //   }
    // }
    // 领导代表
    if (data.hasOwnProperty('xfTypeID') && Array.isArray(data.xfTypeID) && data.xfTypeID.length > 0){
      where["activity.xfTypeID"] =['IN',data.xfTypeID];
      let leaderWhere = {};
      // 领导代表姓名
      if (data.hasOwnProperty('leaderName') && data.leaderName !== '') {
        leaderWhere["dl.name"] = ['like', '%' + data.leaderName + '%']
      }
      // 届次
      if (data.hasOwnProperty('due') && data.due !== '') {
        leaderWhere["dl.due"] = ['like', '%' + data.due + '%']
      }
      // 层级
      if (data.hasOwnProperty('grade') && data.grade !== '') {
        leaderWhere["dl.grade"] = ['like', '%' + data.grade + '%']
      }
      // 地区编号
      if (data.hasOwnProperty('zoneID') && data.zoneID !== '') {
        leaderWhere["dl.zoneID"] = data.zoneID
      }
      if (JSON.stringify(leaderWhere) !== '{}') {
        let la = await this.model('activity_leading').alias('al').join('delegate_leading as dl on dl.id = al.leadingID').where(leaderWhere).select();
        if (!think.isEmpty('la')){
          let acID = [];
          la.forEach(function(item) {
            acID.push(item.activityID);
          });
          if (acID.length > 0){
            if (where.hasOwnProperty('activity.id') && where["activity.id"].length > 0){
              where["activity.id"][1] = acID.concat(where["activity.id"][1]);
            } else {
              where["activity.id"] = ['IN',acID]
            }
          }
        }else {
          //因为是与条件，此处不满足，则返回空数据
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        }
      }
    }
    // 诉求主体 事项属地 问题所属系统 摘要 三跨三分离 被反映人姓名
    if ((data.hasOwnProperty('objectName')  && data.objectName !== '')|| (data.hasOwnProperty('happenRegionID') && param.happenRegionID !== '')
      // || (data.hasOwnProperty('belongsID') && Array.isArray(data.belongsID) && data.belongsID.length > 0 )
      || (data.hasOwnProperty('belongsID') && data.belongsID !== "" )
      || (data.hasOwnProperty('abstract') && data.abstract !== '' ) || (data.hasOwnProperty('SKSFL') && Array.isArray(data.SKSFL) && data.SKSFL.length > 0 )
      || (data.hasOwnProperty('identityName') && data.identityName !== '')){
      let whereM = {};
      if (data.hasOwnProperty('objectName') && data.objectName !== '' ) {
        whereM['pa.objectName'] = ['LIKE','%' + data.objectName + '%'];
      }
      if (data.hasOwnProperty('happenRegionID') && param.happenRegionID !== '' ) {
        whereM['m.happenRegionID'] = data.happenRegionID;
      }
      // if (data.hasOwnProperty('belongsID') && Array.isArray(data.belongsID) && data.belongsID.length > 0 ) {
      if (data.hasOwnProperty('belongsID') && data.belongsID !== "" ) {
        whereM['m.belongsID'] = ['IN',data.belongsID];
      }
      if (data.hasOwnProperty('abstract') && data.abstract !== '' ) {
        whereM['m.abstract'] = ['LIKE','%' + data.abstract + '%'];
      }
      if (data.hasOwnProperty('SKSFL') && Array.isArray(data.SKSFL) && data.SKSFL.length > 0 ) {
        whereM['m.SKSFL'] = ['IN',data.SKSFL];
      }
      if (data.hasOwnProperty('identityName') && data.identityName !== '' ) {
        whereM['m.identityName'] = ['LIKE','%' + data.identityName + '%'];
      }
      let ma = await this.model('activity').alias('a').join('matter as m on m.activityID = a.id').join('person_activity as pa on a.id = pa.activityID').where(whereM).field('a.id').select();
      if (!think.isEmpty(ma)) {
        let activityID = [];
        ma.forEach(function(item) {
          activityID.push(item.id);
        });
        if (activityID.length > 0){
          if (where.hasOwnProperty('activity.id') && where["activity.id"].length > 0){
            where["activity.id"][1] = activityID.concat(where["activity.id"][1]);
          } else {
            where["activity.id"] = ['IN',activityID]
          }
        }
      }else {
        //因为是与条件，此处不满足，则返回空数据
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    let count = await this.model('activity').setRelation(false).join('person on person.id = activity.mainPerson')
      .join('matter on matter.activityID = activity.id').join('fw_task_act on fw_task_act.c_task = matter.taskid')
      .where(where).distinct('activity.id').select();
    const activity = await this.model('activity').join('person on person.id = activity.mainPerson')
      .join('matter on matter.activityID = activity.id').join('fw_task_act on fw_task_act.c_task = matter.taskid')
      .where(where).page(data.page, data.pageSize)
      .field("activity.id,activity.mainPerson,activity.createTime,activity.xfType,activity.xfNumber,activity.createPerson,activity.registerPlace,activity.activityNum")
      .distinct('activity.id,activity.mainPerson,activity.createTime,activity.xfType,activity.xfNumber,activity.createPerson,activity.registerPlace,activity.activityNum')
      .order('activity.createTime DESC').countSelect(count.length);
    return this.success(activity)
  }

  /**
   * showdoc
   * @catalog 活动信息
   * @title  集体访录入列表和搜索
   * @description  集体访录入列表和搜索接口
   * @method post
   * @url http://127.0.0.1:8360/activity/jtList
   * @param userId 必选 string  userId
   * @param type 必选 int  0全部，1未提交，2已完成
   * @param page 必选 int 页码
   * @param pageSize 必选 int 每页显示条数
   * @param name 选填 string  搜索信访人名字,可以空字符串
   * @param meetingID 选填 int  大会届次id
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  // 集体访录入列表和搜索
  async jtListAction(){
    let data = this.post();
    let userInfo = await this.getUserInfo(data.userId);
    let person_activityID = [];
    let name = typeof data.name === 'undefined' ? "" :data.name;
    let where = {
      'xfTypeID':'001002',//集体访
      'createOrgID':userInfo.orgID,
      'submit':(data.type === 1 ? 0 : 1),// type: 0全部，1未提交，2已完成
      'meetingID': !data.hasOwnProperty('meetingID') || data.meetingID === '' ? null : data.meetingID
    };
    // 进行搜索
    let person = await this.model('person_activity').join('person ON person.id = person_activity.personID').where({'name':['LIKE', '%' + name + '%']}).group('activityID').select()
    person.forEach(function(item) {
      person_activityID.push(item.activityID)
    });
    const back = await this.model('activity').where(where).page(data.page, data.pageSize).order('createTime DESC').countSelect();// 时间倒序
    return this.success(back);
  }
};
