const Base = require('./base.js');
const moment = require('moment');
const util = require('../handle/util.js')
const Check = require('./../handle/check');
const MSG = require('../handle/msg.js')
const request = require('request');
module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  // 待提交登记列表，返回的是活动列表
  async waitListAction() {
    const data = this.post();
    //判断该用户是否是领导
    const account = await this.getUserJurisdiction(data.userId);
    let acc = account.nextAccount;
    let inParam = "("
    if (acc.length > 0) {
      acc.forEach((it => {
        inParam += "'" + it + "',"
      }))
    }
    inParam += "'" + account.selfAccount + "')"
    let where = "a.createAccount in " + inParam + " and (m.state=1 or m.state is null)"
    const activity = await this.model('activity').alias('a').field('a.*,m.state as mState').join('left join matter as m on m.activityID=a.id').where(where).page(data.page, data.limit).order('a.createTime DESC').group('a.id').select();
    const count = await this.model('activity').alias('a').join('left join matter as m on m.activityID=a.id').where(where).count('distinct a.id')
    activity.forEach((item) => {
      item.isMatter = 0
      if (item.mState) {
        item.isMatter = 1
      }
    })
    const res = {
      count: count,
      data: activity
    }
    return this.success(res);
  }

  /**
   * showdoc
   * @catalog 审核信息
   * @title 登记审批一键提交
   * @description 登记审批一键提交接口
   * @method post
   * @url http://127.0.0.1:8360/approval/djSubmitKey
   * @param activityID 必选 string 活动ID
   * @param userId 必选 string userId
   * @return {"errno": 0, "errmsg":"",}}
   */
  // 登记审批一键提交
  async djSubmitKeyAction() {
    const data = this.post();
    const activity = await this.model('activity').where({
      'id': data.activityID
    }).find();
    // if (think.isEmpty(activity) || activity.matterID.length === 0 || activity.personID.length === 0) {
    if (think.isEmpty(activity) || activity.matterID.length === 0 || activity.mainPerson === null) {
      //活动不存在或者事项不存在或者信访人缺失
      return this.fail("信访信息不完整")
    } else {
      const matterID = await this.model('matter_state').where({
        'activityID': data.activityID
      }).field('matterID, state').select();
      // 分组方法
      // noinspection JSAnnotator
      function groupBy(array, f) {
        debugger;
        const groups = {};
        array.forEach(function (o) { //注意这里必须是forEach 大写
          const group = JSON.stringify(f(o));
          groups[group] = groups[group] || [];
          groups[group].push(o);
        });
        return Object.keys(groups).map(function (group) {
          return groups[group];
        });
      }
      const sorted = groupBy(JSON.parse(JSON.stringify(matterID)), function (item) {
        return [item.matterID]; //按照matterID进行分组
      });
      let matterArr = [];
      // 过滤掉非待提交状态的事项
      sorted.forEach(function (items) {
        if (items.length === 1 && items[0].state === 1) {
          matterArr.push(items[0].matterID)
        }
      });
      if (matterArr.length === 0) {
        return this.fail("没有符合条件的待提交事项！")
      } else {
        // 提交
        const userInfo = await this.getUserInfo(data.userId);
        // 先给活动编号
        // isDH 是否大会版，1是，0不是
        // code 大会代字，默认''
        let code = '';
        if (activity.isMeeting === 0) {
          // 判断为大会版，去获取大会代字
          if(activity.registerTypeID === '001'){
            // 大会来访
            let DHCode = await this.model('meeting_reception').where({'type':1,'codeName':activity.registerPlace}).find();
            code = DHCode.code;
          }else {
            let DHCode = await this.model('meeting_reception').where({'type':2,'codeName':activity.registerType}).find();
            code = DHCode.code;
          }
        }
        // await util.getActivityNum(userInfo.regionAdminNo,data.isDH,data.code)
        // 先检查活动有没有编号，以保证不会跳号
        let activityNum;
        if (activity.activityNum === null || activity.activityNum === ''){
          activityNum = await util.getActivityNum(userInfo.regionAdminNo,(activity.isMeeting === 0 ? 1 : 0),code);
        } else {
          activityNum = activity.activityNum;
        }
        // 更新活动编号 和 活动初重状态
        let acVisit = await util.isActivityVisit(activity);
        let acUpData = {'activityNum':activityNum,'visit':acVisit};

        await this.model("activity").where({'id':data.activityID}).update(acUpData);
        // 再给事项编号
        let matterUp = await util.getMatterNo(data.activityID);
        await this.model("matter").updateMany(matterUp);
        for (let item of matterArr) {
          // // 如果是互联网登记，生成查询码
          // if (activity.xfSourceID === '004001'){
          //   await MSG.createInquiryCode(data.matterID)
          // }
          await this.djSubmit(item, data.userId, activity.mainPerson);
          // 初始化流程
          let matter = await think.model('matter').setRelation(false).alias('m').field('m.*, sd.type as deptType')
            .join({table:'sys_dept', join:'left', on:['finalZoneID', 'id'],as:'sd'}).where({'m.id':item}).find();
          // 更新事项提交状态
          await think.model('matter_state').where({'matterID':item}).update({'state':0});
          let param = {
            "userId":data.userId,
            "regionLevel":matter.isMeeting === 0 && activity.registerPlaceID === "1" ? "大会" : (userInfo.deptLevel === 0 ? '省级' : (userInfo.deptLevel === 1 ? '市级': '县级')) ,
            "deptID":userInfo.orgID, // 创建部门id
            "deptName":userInfo.orgName, //创建部门名称
            "dealType_pre":matter.handleModel === "转送" ? (matter.isAnswer === 1 ? "转交" :(matter.isOut === 1 ? "域外": "转送")) : matter.handleModel, //预办理方式
            "regionLevel_pre":matter.deptType === 2 ? '省级' : (matter.deptType === 3 ? '市级': '县级'), //预转送行政级别
            "deptID_pre":matter.finalDisposalID, //预流转部门ID
            "deptName_pre":matter.finalDisposal, //预流转部门名称
          };
          // 2登记信访件
          // await Check.addPoints(2,data.userId);
          let startTask = await httpRequest('post','http://localhost:8360/flow/service/initTask',param);
          let taskid = await think.model('matter').where({'id':item}).update({'taskid':startTask.data.taskid});
          // 生成查询码
          await MSG.createInquiryCode(item);
          // 发送"已收悉"短信或者插入告知单
          await MSG.received(item,data.userId);
          // 插入节点表
          let nodeAdd = {
              'taskId':startTask.data.taskid,
              'actID':startTask.data.nextActid,
              'nextActID':null,
              'userId':data.userId,
              'businessID':data.businessID,
              'time':moment().format('YYYY-MM-DD HH:mm:ss'),
              'account':userInfo.user_name,
              'deptName':userInfo.orgName,
              'deptID':userInfo.orgID,
              'info':data.info,
              // 'solveCode':data.solveCode,
          };
          await think.model('node_record').add(nodeAdd);// 节点表
          await think.model('history').add(nodeAdd);// 历史表
        }
        // //判断 当person_activity<activity时更新来访人数
        // const personNumData = await util.getPersonNum(data.activityID);
        // const editActXfNum = await util.perActLessAct(personNumData, data.activityID);
        // 更新活动提交状态
        await this.model('activity').where({'id': data.activityID}).update({'submit':1});
        // 更新信访人历史居住地址
        await util.addressHistory(data.activityID, userInfo.orgID, userInfo.orgName);
        // 更新大会登记大屏状态
        if (activity.isMeeting === 0 && activity.registerPlaceID === '1' && activity.registerTypeID === '001'){
          // 大会，统一接待点，来访
          await util.DH_window_up(data.userId);
        }
        return this.success("提交成功")
      }
    }
  }
  /**
   * showdoc
   * @catalog 审核信息
   * @title 登记审批单独事件提交
   * @description 登记审批单独事件接口
   * @method post
   * @url http://127.0.0.1:8360/approval/djSubmitOne
   * @param matterID 必选 string 事项ID
   * @param activityID 必选 string 活动ID
   * @param userId 必选 string userId
   * @return {"errno": 0, "errmsg":"",}}
   */
  // 登记审批单独事件
  async djSubmitOneAction() {
    const data = this.post();
    const activity = await this.model('activity').where({
      'id': data.activityID
    }).find();
    // if (think.isEmpty(activity) || activity.personID.length === 0) {
    if (think.isEmpty(activity) || activity.mainPerson === null) {
      //活动不存在或者事项不存在或者信访人缺失
      return this.fail("信访信息不完整")
    } else {
      // 验证是否为待提交状态
      const matterID = await this.model('matter_state').where({
        'matterID': data.matterID,
        'state': 1
      }).order('submitTime DESC').limit(1).select();
      if (think.isEmpty(matterID)) {
        return this.fail("请勿重复提交!");
      } else {
        // 提交
        const userInfo = await this.getUserInfo(data.userId);
        // 先给活动编号
        // isDH 是否大会版，1是，0不是
        // code 大会代字，默认''
        let code = '';
        if (activity.isMeeting === 0) {
          // 判断为大会版，去获取大会代字
          if(activity.registerTypeID === '001'){
            // 大会来访
            let DHCode = await this.model('meeting_reception').where({'type':1,'codeName':activity.registerPlace}).find();
            code = DHCode.code;
          }else {
            let DHCode = await this.model('meeting_reception').where({'type':2,'codeName':activity.registerType}).find();
            code = DHCode.code;
          }
        }
        // await util.getActivityNum(userInfo.regionAdminNo,data.isDH,data.code)
        // 先检查活动有没有编号
        let activityNum
        if (activity.activityNum === null || activity.activityNum === ''){
          activityNum = await util.getActivityNum(userInfo.regionAdminNo,(activity.isMeeting === 0 ? 1 : 0),code);
        } else {
          activityNum = activity.activityNum;
        }
        // 更新活动编号 和 活动初重状态
        let acVisit = await util.isActivityVisit(activity);
        let acUpData = {'activityNum':activityNum,'visit':acVisit};

        await this.model("activity").where({'id':data.activityID}).update(acUpData);
        // 再给事项编号
        let matterUp = await util.getMatterNo(data.activityID,data.matterID);// 第二个参数为选填，仅针对单独提交
        await this.model("matter").updateMany(matterUp);
        // // 如果是互联网登记，生成查询码
        // if (activity.xfSourceID === '004001'){
        //   await MSG.createInquiryCode(data.matterID)
        // }
        let back = await this.djSubmit(matterID[0].matterID, data.userId, activity.mainPerson);
        // //判断 当person_activity<activity时更新来访人数
        // const personNumData = await util.getPersonNum(data.activityID);
        // const editActXfNum = await util.perActLessAct(personNumData, data.activityID);
        // 初始化流程
        const matter = await this.model('matter').setRelation(false).alias('m').field('m.*, sd.type as deptType')
          .join({table:'sys_dept', join:'left', on:['finalZoneID', 'id'],as:'sd'}).where({'m.id':data.matterID}).find();
        // 更新事项提交状态
        await this.model('matter_state').where({'matterID':data.matterID}).update({'state':0});
        let param = {
          "userId":data.userId,
          "regionLevel":matter.isMeeting === 0 && activity.registerPlaceID === "1" ? "大会" : (userInfo.deptLevel === 0 ? '省级' : (userInfo.deptLevel === 1 ? '市级': '县级')) ,
          "deptID":userInfo.orgID, // 创建部门id
          "deptName":userInfo.orgName, //创建部门名称
          "dealType_pre":matter.handleModel === "转送" ? (matter.isAnswer === 1 ? "转交" :(matter.isOut === 1 ? "域外": "转送")) : matter.handleModel, //预办理方式
          "regionLevel_pre":matter.deptType === 2 ? '省级' : (matter.deptType === 3 ? '市级': '县级') , //预转送行政级别
          "deptID_pre":matter.finalDisposalID, //预流转部门ID
          "deptName_pre":matter.finalDisposal, //预流转部门名称
        };
        // 2登记信访件
        // await Check.addPoints(2,data.userId);
        const startTask = await httpRequest('post','http://localhost:8360/flow/service/initTask',param);
        const taskid = await this.model('matter').where({'id':data.matterID}).update({'taskid':startTask.data.taskid});
        // 生成查询码
        await MSG.createInquiryCode(data.matterID)
        // 插入节点表
        let nodeAdd = {
          'taskId':startTask.data.taskid,
          'actID':startTask.data.nextActid,
          'nextActID':null,
          'userId':data.userId,
          'businessID':data.businessID,
          'time':moment().format('YYYY-MM-DD HH:mm:ss'),
          'account':userInfo.user_name,
          'deptName':userInfo.orgName,
          'deptID':userInfo.orgID,
          'info':data.info,
          // 'solveCode':data.solveCode,
        };
        await this.model('node_record').add(nodeAdd);// 节点表
        await this.model('history').add(nodeAdd);// 历史表
        // 更新信访人历史居住地址
        await util.addressHistory(data.activityID, userInfo.orgID, userInfo.orgName);
        // 更新大会登记大屏状态
        if (activity.isMeeting === 0 && activity.registerPlaceID === '1' && activity.registerTypeID === '001'){
          // 大会，统一接待点，来访
          await util.DH_window_up(data.userId);
        }
        return this.success("提交成功")
      }
    }
  }
  // 待审批列表
  async listAction() {
    // 传参handleModelID处理类型  发函 转交
    // 应该判断当前单位
    const data = this.post();
    const account = await this.getUserJurisdiction(data.userId);
    let acc = account.nextAccount;
    acc.push(account.selfAccount);
    let where = {
      'handleModelID': data.handleModelID,
      'state': 2,
      'createAccount': ['IN', acc]
    };

    const matter = await this.model('matter')
      .where(where).page(data.page, data.limit).order('createTime DESC').countSelect();
    return this.success(matter);
  }
  /**
   * showdoc
   * @catalog 审核信息
   * @title 登记审批
   * @description 登记审批接口
   * @method post
   * @url http://127.0.0.1:8360/approval/djPass
   * @param matterID 必选 string 事项ID
   * @param activityID 必选 string 活动ID
   * @param handleModelID 必选 string 办理方式ID
   * @param userId 必选 string userId
   * @param taskid 必选 string 流程id
   * @param opinion 必选 int 审批意见，0通过，1不通过
   * @param content 必选 string 审批意见
   * @return {"errno": 0, "errmsg":""}
   */
  // 登记审批
  async djPassAction() {
    const data = this.post();
    // 判断处理意见，插入审批记录，修改matter状态
    let userInfo = await this.getUserInfo(data.userId); // 获取用户信息
    // 账号信息
    const account = await this.getUserJurisdiction(data.userId);
    const acc = account.nextAccount;
    acc.push(account.selfAccount); //本人账号和下属账号
    const approvalUp = {
      'auditor': userInfo.name, // 审核人
      'auditorAccount': userInfo.user_name,
      'opinion': data.opinion, //审核操作0同意，1拒绝，2其他
      'remark': data.content, //审核意见
      'state': 1, //审核状态
      'auditTime': moment().format('YYYY-MM-DD HH:mm:ss'), //审核时间
    };
    const approval = await this.model('approval').where({
      'state': 0,
      'typeID': 1,
      'eventID': data.matterID,
      'auditeeAccount': ["IN", acc]
    }).update(approvalUp);
    const activity = await this.model('activity').where({
      'id': data.activityID
    }).find();
    const stateAdd = {
      'matterID': data.matterID,
      'activityID': data.activityID,
      'mainPersonID': activity.mainPerson, //主信访人
      'state': (data.opinion === 0 ? util.judgeState(data.handleModelID).state : 3), // 审批是否通过？通过：不通过
      'stateName': (data.opinion === 0 ? util.judgeState(data.handleModelID).stateName : '登记待修改'),
      'nextState': util.judgeState(data.handleModelID).state, // 判断办理方式
      'nextStateName': util.judgeState(data.handleModelID).stateName,
      'departmentID': userInfo.orgID,
      'department': userInfo.orgName, // 机构
      'description': userInfo.description, // 地区
      'dictValue': userInfo.dictValue,
      'handlePerson': userInfo.name,
      'handlePersonID': userInfo.user_name,
      'nextDepartment': userInfo.orgID, // 去向单位 （下一步操作还是本单位）
      'nextDepartmentID': userInfo.orgName
    };
    // 插入新状态
    const state = await this.model('matter_state').add(stateAdd);
    // 更新matter最新状态
    const matter = await this.model('matter').where({
      'id': data.matterID
    }).update({
      'state': (data.opinion === 0 ? util.judgeState(data.handleModelID).state : 3)
    });
    // 推进流程
    // if(data.opinion === 0){
      //同意，下一步
      const param = {
        "taskId":data.taskid,
        "userId":data.userId,
        "regionLevel":userInfo.deptLevel === 0 ? '省级' : (userInfo.deptLevel === 1 ? '市级': '县级'),
        "deptID":userInfo.orgID, // 去向单位id
        "deptName":userInfo.orgName, // 去向单位名称
        "dealtype":data.opinion === 0 ? data.handleModel : "修改" // 下一步办理方式  opinion=0同意，进入正常流程；1拒绝，进入修改
      };
      if (data.hasOwnProperty('businessId')){
        param['businessId'] = data.businessID
      }
      await httpRequest('post','http://localhost:8360/flow/service/taskForward',param);
    // }else {
    //   //拒绝，退回到上一步
    //   const param = {
    //     "taskId":data.taskid,
    //     "userId":data.userId,
    //   };
    //   await httpRequest('post','http://localhost:8360/flow/service/taskBackward',param);
    // }
    return this.success('审核成功！')
  }
  /**
   * showdoc
   * @catalog 审核信息
   * @title 已审核列表
   * @description 已审核列表接口
   * @method post
   * @url http://127.0.0.1:8360/approval/passList
   * @param userId 必选 string userId
   * @param handleModelID 必选 string 办理方式ID
   * @param typeID 必选 int 已审核类型。1登记、2修改、 3拟函、4转交、5回报
   * @return {"errno": 0, "errmsg":""}
   */
  // 已审核列表
  async passListAction() {
    const data = this.post();
    let userInfo = await this.getUserInfo(data.userId); // 获取用户信息
    const list = await this.model('approval').join('matter ON approval.eventID = matter.id')
      .where({
        'auditorAccount': userInfo.user_name,
        'approval.state': 1,
        'typeID': data.typeID,
        'matter.handleModelID': data.handleModelID
      })
      .page(data.page, data.limit).order('createTime DESC').field('approval.auditTime,matter.*').countSelect();
    this.success(list);
  }

  // 审批操作
  async updateAction() {
    const data = this.post();
    let up = {
      'state': 1,
      'auditTime': moment()
    };
    const update = await this.model('approval').where({
      'id': data.id
    }).update(up);
    return this.success(update);
  }
  // // 推动流程
  // async promoteAction(){
  //   const data = this.post();
  //   // 判断流程前进还是后退
  //   if (data.opinion === 0){
  //     // 审批，签收通过
  //     const param = {
  //       "taskId":data.taskid,
  //       "userId":data.userId,
  //       "regionLevel":userInfo.deptLevel === 0 ? '省级' : (userInfo.deptLevel === 1 ? '市级': '县级'),
  //       "deptID":userInfo.orgID, // 去向单位id
  //       "deptName":userInfo.orgName, // 去向单位名称
  //       "dealtype":'' // 下一步办理方式
  //     };
  //     if (data.hasOwnProperty('businessId')){
  //       param['businessId'] = data.businessID
  //     }
  //     await httpRequest('post','http://localhost:8360/flow/service/taskForward',param);
  //   }else if(data.opinion === 1){
  //     // 不通过，拒签，退回
  //
  //   }
  // }
  /**
   * showdoc
   * @catalog 审核信息
   * @title 登记完成列表
   * @description 登记完成列表接口
   * @method post
   * @url http://127.0.0.1:8360/approval/djCompleteList
   * @param userId 必选 string userId
   * @param page 必选 int
   * @param limit 必选 int
   * @param startTime 可选 string 登记提交开始时间
   * @param endTime 可选 string 登记提交结束时间
   * @param xfSourceID 可选 string 信访来源
   * @param xfName 可选 string 信访事项名称
   * @param deptID 可选 int 去向单位id
   * @param name 可选 string 首登记人姓名
   * @param handleModelID 可选 string 办理方式ID
   * @param registerTypeID 可选 string 信访登记类型
   * @return {"errno": 0, "errmsg":""}
   */
  // 登记完成列表
  async djCompleteListAction(){
    // 本人已提交的登记，但是未审批
    const data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    let where = {
      'fw.businessID':['IN',2],// 办理32
      'm.createAccount':userInfo.user_name,
    };
    // 设置查询条件
    // 提交时间
    if (data.hasOwnProperty('startTime') && data.startTime !== '') {
      where['fw.c_time'] = ['>=',moment(data.startTime).format('YYYY-MM-DD HH:mm:ss')]
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== '') {
      where['FW.c_time'] = ['<=',moment(data.endTime).add(1, 'day').format('YYYY-MM-DD HH:mm:ss')]
    }
    // 信访来源 ac.xfSourceID
    if (data.hasOwnProperty('xfSourceID') && data.xfSourceID !== '') {
      where['ac.xfSourceID'] = ['like',data.xfSourceID + '%']
    }
    // 信访登记类型 ac.registerTypeID
    if (data.hasOwnProperty('registerTypeID') && data.registerTypeID !== '') {
      where['ac.registerTypeID'] = data.registerTypeID
    }
    // 信访事项名称
    if (data.hasOwnProperty('xfName') && data.xfName !== '') {
      where['m.xfName'] = ['like','%' + data.xfName + '%']
    }
    // 首登记人姓名
    if (data.hasOwnProperty('name') && data.name !== '') {
      where['p.name'] = ['like','%' + data.name + '%']
    }
    // 去向单位
    if (data.hasOwnProperty('deptID') && data.deptID !== '') {
      where['fw.deptID_pre'] =  data.deptID
    }
    // 办理方式
    if (data.hasOwnProperty('handleModelID') && data.handleModelID !== '') {
      where['m.handleModelID'] =  data.handleModelID
    }
    // 事项编号
    if (data.hasOwnProperty('matterNum') && data.matterNum !== '') {
      where['m.matterNum'] =  data.matterNum
    }
    // 活动编号
    if (data.hasOwnProperty('activityNum') && data.activityNum !== '') {
      where['ac.activityNum'] =  data.activityNum
    }
    let matter = await this.model('matter').alias('m')
      .join({table: 'fw_task', join: 'left', as: 'fw', on: ['taskid', 'id']
      }).join({table: 'activity', join: 'left', as: 'ac', on: ['activityID', 'id']
      }).join({table: 'person', join: 'left', as: 'p', on: ['ac.mainPerson','p.id']
      }).where(where).order(['fw.c_time desc']).field('m.*,fw.businessID,fw.dealType_pre,fw.c_time')
      .page(data.page,data.limit).countSelect().catch((err) => {
        return think.isError(err) ? err : new Error(err);
      });
    if (think.isError(matter)) {
      return this.fail('Get review query fail');
    }
    matter.data.forEach(function(item) {
      if (item.dealType_pre === "转交") {
        item.dealType_pre = "转送"
      }
    });
    return this.success(matter);
  }

  /**
   * showdoc
   * @catalog 审核信息
   * @title 交办转送已发送列表
   * @description 交办转送已发送列表接口
   * @method post
   * @url http://127.0.0.1:8360/approval/jbzsSendList
   * @param userId 必选 string userId
   * @param page 必选 int
   * @param limit 必选 int
   * @param handelType 必选 int 办理方式 1交办 2转交转送
   * @param startTime 可选 string 发送开始时间
   * @param endTime 可选 string 发送结束时间
   * @param xfSourceID 可选 string 信访来源
   * @param xfName 可选 string 信访事项名称
   * @param deptID 可选 int 去向单位id
   * @param createOrg 可选 int 登记单位级别0 上上级 1上级 2本级
   * @param name 可选 string 首登记人姓名
   * @param matterNum 可选 string 事项编号
   * @param activityNum 可选 string 活动编号
   * @param registerTypeID 可选 string 信访登记类型
   * @return {"errno": 0, "errmsg":""}
   */
  // 交办转送 已发送列表
  // handelType 1交办 2转交转送
  async jbzsSendListAction(){
    // 本人已发送，但是下级未签收
    const data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    let where = {
      'fw.businessID':['IN',15,22],// 22人大签收 15职能单位签收
      'fw.c_user':data.userId,
      'fw.dealType_pre':data.handelType === 1 ? "交办" : ['IN',['转交','转送']],
    };
    // 设置查询条件
    // 提交时间
    if (data.hasOwnProperty('startTime') && data.startTime !== '') {
      where['fw.c_time'] = ['>=',moment(data.startTime).format('YYYY-MM-DD')]
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== '') {
      where['FW.c_time'] = ['<=',moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    }
    // 信访来源 ac.xfSourceID
    if (data.hasOwnProperty('xfSourceID') && data.xfSourceID !== '') {
      where['ac.xfSourceID'] = ['like',data.xfSourceID + '%']
    }
    // 信访登记类型 ac.registerTypeID
    if (data.hasOwnProperty('registerTypeID') && data.registerTypeID !== '') {
      where['ac.registerTypeID'] = data.registerTypeID
    }
    // 信访事项名称
    if (data.hasOwnProperty('xfName') && data.xfName !== '') {
      where['m.xfName'] = ['like','%' + data.xfName + '%']
    }
    // 首登记人姓名
    if (data.hasOwnProperty('name') && data.name !== '') {
      where['p.name'] = ['like','%' + data.name + '%']
    }
    // 去向单位
    if (data.hasOwnProperty('deptID') && data.deptID !== '') {
      where['fw.deptID_pre'] =  data.deptID
    }
    // 事项编号
    if (data.hasOwnProperty('matterNum') && data.matterNum !== '') {
      where['m.matterNum'] =  data.matterNum
    }
    // 活动编号
    if (data.hasOwnProperty('activityNum') && data.activityNum !== '') {
      where['fw.activityNum'] =  data.activityNum
    }
    // 登记单位
    if (data.hasOwnProperty('createOrg') && data.createOrg !== ''){
      // 0 上上级 1上级 2本级
      let createOrgID = 0;
      if (parseInt(data.createOrg) === 0){
        let sql = 'SELECT * FROM sys_organization WHERE deptID = (SELECT id FROM sys_dept WHERE id = (SELECT parentID ' +
          'FROM sys_dept WHERE id = (SELECT parentID FROM sys_dept WHERE id = '+ userInfo.dictValue +'))) AND agent = 1';
        let ssj = await this.model('sys_organization').query(sql);
        if (!think.isEmpty(ssj)){
          createOrgID = ssj.id
        }
      }else if (parseInt(data.createOrg) === 1) {
        let sql = 'SELECT * FROM sys_organization WHERE deptID = (SELECT id FROM sys_dept WHERE id = ' +
          '(SELECT parentID FROM sys_dept WHERE id = '+ userInfo.dictValue +'))) AND agent = 1';
        let sj = await this.model('sys_organization').query(sql);
        if (!think.isEmpty(sj)){
          createOrgID = sj.id
        }else if (parseInt(data.createOrg) === 2) {
          createOrgID = userInfo.orgID
        }
      }
      where['m.createOrgID'] = createOrgID;
    }
    let matter = await this.model('matter').alias('m')
      .join({table: 'fw_task', join: 'left', as: 'fw', on: ['taskid', 'id']
      }).join({table: 'activity', join: 'left', as: 'ac', on: ['activityID', 'id']
      }).join({table: 'person', join: 'left', as: 'p', on: ['ac.mainPerson','p.id']
      }).where(where).order(['fw.c_time desc']).field('m.*,fw.businessID,fw.dealType_pre,fw.c_time')
      .page(data.page,data.limit).countSelect().catch((err) => {
        return think.isError(err) ? err : new Error(err);
      });
    if (think.isError(matter)) {
      return this.fail('Get review query fail');
    }
    matter.data.forEach(function(item) {
      if (item.dealType_pre === "转交") {
        item.dealType_pre = "转送"
      }
    });
    return this.success(matter);
  }
  /**
   * showdoc
   * @catalog 审核信息
   * @title  已签收上级信访件列表
   * @description  已签收上级信访件列表接口
   * @method post
   * @url http://127.0.0.1:8360/approval/signedList
   * @param userId 必选 string userId
   * @param page 必选 int
   * @param limit 必选 int
   * @param handelType 可选 int 上级办理方式 1交办 2转交转送
   * @param startTime 可选 string 签收开始时间
   * @param endTime 可选 string 签收结束时间
   * @param sendStartTime 可选 string 发送开始时间
   * @param sendEndTime 可选 string 发送结束时间
   * @param createOrg 可选 int 登记单位级别0 上上级 1上级 2本级
   * @param xfSourceID 可选 string 信访来源
   * @param xfName 可选 string 信访事项名称
   * @param name 可选 string 首登记人姓名
   * @param matterNum 可选 string 事项编号
   * @param activityNum 可选 string 活动编号
   * @param registerTypeID 可选 string 信访登记类型
   * @return {"errno": 0, "errmsg":""}
   */
  // 已签收上级信访件
  async signedListAction(){
    // 本人已签收，但领导未审批
    const data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    let where = {
      'fw.businessID':['IN',23],//
      'fw.c_user':data.userId,
    };
    // 设置查询条件
    // 提交时间
    if (data.hasOwnProperty('startTime') && data.startTime !== '') {
      where['fw.c_time'] = ['>=',moment(data.startTime).format('YYYY-MM-DD')]
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== '') {
      where['FW.c_time'] = ['<=',moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    }
    // 信访来源 ac.xfSourceID
    if (data.hasOwnProperty('xfSourceID') && data.xfSourceID !== '') {
      where['ac.xfSourceID'] = ['like',data.xfSourceID + '%']
    }
    // 信访登记类型 ac.registerTypeID
    if (data.hasOwnProperty('registerTypeID') && data.registerTypeID !== '') {
      where['ac.registerTypeID'] = data.registerTypeID
    }
    // 信访事项名称
    if (data.hasOwnProperty('xfName') && data.xfName !== '') {
      where['m.xfName'] = ['like','%' + data.xfName + '%']
    }
    // 首登记人姓名
    if (data.hasOwnProperty('name') && data.name !== '') {
      where['p.name'] = ['like','%' + data.name + '%']
    }
    // 事项编号
    if (data.hasOwnProperty('matterNum') && data.matterNum !== '') {
      where['m.matterNum'] =  data.matterNum
    }
    // 活动编号
    if (data.hasOwnProperty('activityNum') && data.activityNum !== '') {
      where['fw.activityNum'] =  data.activityNum
    }
    // 办理方式
    if (data.hasOwnProperty('handelType') && data.handelType !== '') {
      where['fw.dealType_pre'] =  data.handelType === 1 ? "交办" : ['IN',['转交','转送']]
    }
    // 登记单位
    if (data.hasOwnProperty('createOrg') && data.createOrg !== ''){
      // 0 上上级 1上级 2本级
      let createOrgID = 0;
      if (parseInt(data.createOrg) === 0){
        let sql = 'SELECT * FROM sys_organization WHERE deptID = (SELECT id FROM sys_dept WHERE id = (SELECT parentID ' +
          'FROM sys_dept WHERE id = (SELECT parentID FROM sys_dept WHERE id = '+ userInfo.dictValue +'))) AND agent = 1';
        let ssj = await this.model('sys_organization').query(sql);
        if (!think.isEmpty(ssj)){
          createOrgID = ssj.id
        }
      }else if (parseInt(data.createOrg) === 1) {
        let sql = 'SELECT * FROM sys_organization WHERE deptID = (SELECT id FROM sys_dept WHERE id = ' +
          '(SELECT parentID FROM sys_dept WHERE id = '+ userInfo.dictValue +'))) AND agent = 1';
        let sj = await this.model('sys_organization').query(sql);
        if (!think.isEmpty(sj)){
          createOrgID = sj.id
        }else if (parseInt(data.createOrg) === 2) {
          createOrgID = userInfo.orgID
        }
      }
      where['m.createOrgID'] = createOrgID;
    }
    // 转交时间（上级发送时间）
    if (data.hasOwnProperty('sendStartTime') || data.hasOwnProperty('sendEndTime')){
      let sql = 'SELECT c_task FROM (SELECT * FROM fw_task_act WHERE businessID IN (15,22))t GROUP BY c_task ORDER BY c_time DESC';
      // fw_task_act      15去往职能单位的发送 22去往人大的发送
      if (data.hasOwnProperty('sendStartTime') && data.sendStartTime !== '' && data.hasOwnProperty('sendEndTime') && data.sendEndTime !== ''){
        sql = 'SELECT c_task FROM (SELECT * FROM fw_task_act WHERE businessID IN (15,22))t WHERE c_time BETWEEN "' + moment(data.sendStartTime).format('YYYY-MM-DD')
          + '" AND "' + moment(data.sendEndTime).add(1,'day').format('YYYY-MM-DD') + '" GROUP BY c_task ORDER BY c_time DESC';
      }else if (data.hasOwnProperty('sendStartTime') && data.sendStartTime !== '') { // 只传开始时间
        sql = 'SELECT c_task FROM (SELECT * FROM fw_task_act WHERE businessID IN (15,22))t WHERE c_time > "' + moment(data.sendStartTime).format('YYYY-MM-DD')
          + '" GROUP BY c_task ORDER BY c_time DESC';
      }else if (data.hasOwnProperty('sendEndTime') && data.sendEndTime !== '') {
        sql = 'SELECT c_task FROM (SELECT * FROM fw_task_act WHERE businessID IN (15,22))t WHERE c_time < "' +
          moment(data.sendEndTime).add(1,'day').format('YYYY-MM-DD') + '" GROUP BY c_task ORDER BY c_time DESC';
      }
      let task = await this.model('fw_task_act').query(sql);
      let taskList = [];
      if (!think.isEmpty(task)) {
        task.forEach(function(item) {
          taskList.push(item.c_task);
        });
        if (taskList.length>0){
          where['m.taskid'] = ['IN',taskList]
        }else {
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        }
      }
    }
    let matter = await this.model('matter').alias('m')
      .join({table: 'fw_task', join: 'left', as: 'fw', on: ['taskid', 'id']
      }).join({table: 'activity', join: 'left', as: 'ac', on: ['activityID', 'id']
      }).join({table: 'person', join: 'left', as: 'p', on: ['ac.mainPerson','p.id']
      }).where(where).order(['fw.c_time desc']).field('m.*,fw.businessID,fw.dealType_pre,fw.c_time')
      .page(data.page,data.limit).countSelect().catch((err) => {
        return think.isError(err) ? err : new Error(err);
      });
    if (think.isError(matter)) {
      return this.fail('Get review query fail');
    }
    matter.data.forEach(function(item) {
      if (item.dealType_pre === "转交") {
        item.dealType_pre = "转送"
      }
    });
    return this.success(matter);
  }
  //
  __after(){
    // if (this.ctx.url === '/approval/djSubmitOne' || this.ctx.url === '/approval/djSubmitKey'){
    //   // 单独提交 或者 一键提交 初始化流程
    //   const data = {
    //     "userId":this.ctx.response.body.userId,
    //     "regionLevel":"省级",
    //     "deptID":111,
    //     "deptName":"测试部门"
    //   }
    //   const back = httpRequest('post','http://127.0.0.1:8361/flow/service/initTask',data)
    //   console.log(122121);
    //   console.log(this.ctx.response.body);//返回值
    //   console.log(this.post());
    // }
  }
};
