/*
考核规则接口
*/
const Base = require('./../base.js');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }

  /**
   * showdoc
   * @catalog 后台管理-考核规则列表
   * @title 后台管理-考核规则列表
   * @description 后台管理-考核规则列表
   * @method post
   * @param page 必选 int 第几页
   * @param limit 必选 int 每页条数
   * @url http://127.0.0.1:8360/check/rules/list
   * @return {"errno": 0, "errmsg":""}
   */
  async listAction() {
    const data = this.post();
    data.page = data.page === undefined ? 0 : data.page;
    data.limit = data.limit === undefined ? 0 : data.limit;

    const rules = this.model('kh_point_rules'); // controller 里实例化模型
    const back = await rules.order('id').page(data.page, data.limit).countSelect();

    this.success(back);
  }

  /**
   * showdoc
   * @catalog 后台管理-考核日志列表
   * @title 后台管理-考核日志列表
   * @description 后台管理-考核日志列表
   * @method post
   * @param page 必选 int 第几页
   * @param limit 必选 int 每页条数
   * @param orgName 必选 string 部门名称
   * @param creatorName 必选 string 人员姓名
   * @url http://127.0.0.1:8360/check/rules/loglist
   * @return {"errno": 0, "errmsg":""}
   */
  async loglistAction() {
    const data = this.post();
    data.page = data.page === undefined ? 0 : data.page;
    data.limit = data.limit === undefined ? 0 : data.limit;
    data.orgName = data.orgName === undefined ? '' : data.orgName;
    data.creatorName = data.creatorName === undefined ? '' : data.creatorName;

    const rules = this.model('kh_point_detail'); // controller 里实例化模型
    const back = await rules.where({
      creatorName: ['like', '%' + data.creatorName + '%'], orgName: ['like', '%' + data.orgName + '%']
    }).order('id desc').page(data.page, data.limit).countSelect();

    this.success(back);
  }

  /**
   * showdoc
   * @catalog 后台管理-考核规则修改
   * @title 后台管理-考核规则修改
   * @description 后台管理-考核规则修改
   * @method post
   * @param id 必选 int 编辑考核类别id
   * @param typeName 必选 string 类别名称
   * @param point 必选 int 得分
   * @param memo 必选 string 备注
   * @url http://127.0.0.1:8360/check/rules/save
   * @return {"errno": 0, "errmsg":""}
   */
  async saveAction() {
    const data = this.post();
    if (think.isEmpty(data.id)) {
      this.fail();
    } else {
      const res = await this.model('kh_point_rules').update(data);
      if (res) {
        this.success();
      } else {
        this.fail();
      }
    }
  }
};
