/*
考核统计接口
首先创建视图
create view v_kh_person as
select u.user_id,u.`name`,d.point from sys_user u
LEFT JOIN (select creatorID, sum(point) point from kh_point_detail GROUP BY creatorID) d on u.user_id = d.creatorID

create view v_kh_org as
select o.id,o.orgName,d.point from sys_organization o
LEFT JOIN (select orgID, sum(point) point from kh_point_detail GROUP BY orgID) d on o.id = d.orgID;
*/
/*
考核规则接口
*/
const Base = require('./../base.js');
const moment = require('moment');
const check = require('../../handle/check');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }

  /**
   * showdoc
   * @catalog 用户积分列表
   * @title 用户积分列表
   * @description 用户积分列表
   * @method post
   * @param page 必选 int 第几页
   * @param limit 必选 int 每页条数
   * @param deptId 可选 int 行政区划ID
   * @param name 可选 string 考核人姓名
   * @param startTime 可选 string 考核开始统计时间 2020-11-11
   * @param endTime 可选 string 考核结束统计时间 2020-11-11
   * @url http://127.0.0.1:8360/check/statistic/personRank
   * @return {"errno": 0, "errmsg":""}
   */
  async personRankAction() {
    try {
      const data = this.post();
      data.page = data.page === undefined ? 0 : data.page;
      data.limit = data.limit === undefined ? 0 : data.limit;
      data.deptId = data.deptId === undefined ? 0 : data.deptId;
      data.name = data.name === undefined ? '' : data.name;
      data.startTime = data.startTime === undefined ? undefined : data.startTime;
      data.endTime = data.endTime === undefined ? undefined : data.endTime;

      let timeWhere = '';
      if (!think.isEmpty(data.startTime)) {
        timeWhere += ' and time >= "' + data.startTime + ' "';
      }
      if (!think.isEmpty(data.endTime)) {
        timeWhere += ' and time <= "' + moment(data.endTime).subtract(-1, 'days').format('YYYY-MM-DD') + ' "';
      }
      const nameWhere = ' and name like "%' + data.name + '%"';

      const afterSql = ' from sys_user u ' +
        'LEFT JOIN (select creatorID, sum(point) point from kh_point_detail where 1=1 ' + timeWhere + ' GROUP BY creatorID ) d on u.user_id = d.creatorID ' +
        'where u.orgID in (select id from sys_organization where orgName not like "%工作委员会%" and agent = 1 and deptID in (SELECT id FROM sys_dept where  FIND_IN_SET(' + data.deptId + ',ancestors) or id = ' + data.deptId + '))' +
        nameWhere + ' order by d.point desc, u.user_id ';

      const countBeforeSql = 'select count(1) as count ';
      const detailBeforeSql = 'select (select orgName from sys_organization where id = u.orgID) orgName ,(select deptName from sys_organization where id = u.orgID) deptName,' +
        'u.user_id id,u.user_id,u.`name`, IFNULL(d.point,0) point ';

      const count = await this.model('sys_organization').query(countBeforeSql + afterSql);
      const returnData = await this.model('sys_organization').query(detailBeforeSql + afterSql + 'limit ' + (data.page - 1) * data.limit + ',' + data.limit);

      const JsonData = {
        count: count[0].count,
        totalPages: Math.ceil(count[0].count / data.limit),
        pageSize: data.limit,
        currentPage: data.page,
        data: returnData
      };

      this.success(JsonData);
    } catch (e) {
      this.fail(e.sqlMessage);
    }
  }

  /**
   * showdoc
   * @catalog 部门积分列表
   * @title 部门积分列表
   * @description 部门积分列表
   * @method post
   * @param page 必选 int 第几页
   * @param limit 必选 int 每页条数
   * @param deptId 可选 int 行政区划ID
   * @param name 可选 string 考核部门名称
   * @param startTime 可选 string 考核开始统计时间 2020-11-11
   * @param endTime 可选 string 考核结束统计时间 2020-11-11
   * @url http://127.0.0.1:8360/check/statistic/orgRank
   * @return {"errno": 0, "errmsg":""}
   */
  async orgRankAction() {
    try {
      const data = this.post();
      data.page = data.page === undefined ? 0 : data.page;
      data.limit = data.limit === undefined ? 0 : data.limit;
      data.deptId = data.deptId === undefined ? 0 : data.deptId;
      data.name = data.name === undefined ? '' : data.name;
      data.startTime = data.startTime === undefined ? undefined : data.startTime;
      data.endTime = data.endTime === undefined ? undefined : data.endTime;

      let timeWhere = '';
      if (!think.isEmpty(data.startTime)) {
        timeWhere += ' and time >= "' + data.startTime + '"';
      }
      if (!think.isEmpty(data.endTime)) {
        timeWhere += ' and time <= "' + moment(data.endTime).subtract(-1, 'days').format('YYYY-MM-DD') + '"';
      }
      const nameWhere = ' and o.orgName like "%' + data.name + '%"';

      const afterSql = ' from sys_organization o ' +
        'LEFT JOIN (select orgID, sum(point) point from kh_point_detail where 1=1 ' + timeWhere + ' GROUP BY orgID ) d on o.id = d.orgID ' +
        'where o.orgName not like "%工作委员会%" and o.agent = 1 and o.deptID in (SELECT id FROM sys_dept where  FIND_IN_SET(' + data.deptId + ',ancestors) or id = ' + data.deptId + ')' +
        nameWhere + ' order by d.point desc, o.id ';

      const countBeforeSql = 'select count(1) as count ';
      const detailBeforeSql = 'select o.id,o.deptName,o.orgName,IFNULL(d.point,0) point  ';

      const count = await this.model('sys_organization').query(countBeforeSql + afterSql);
      const returnData = await this.model('sys_organization').query(detailBeforeSql + afterSql + 'limit ' + (data.page - 1) * data.limit + ',' + data.limit);

      const JsonData = {
        count: count[0].count,
        totalPages: Math.ceil(count[0].count / data.limit),
        pageSize: data.limit,
        currentPage: data.page,
        data: returnData
      };
      this.success(JsonData);
    } catch (e) {
      this.fail(e.sqlMessage);
    }
  }

  /**
   * showdoc
   * @catalog 人员积分详情
   * @title 人员积分详情
   * @description 人员积分详情
   * @method post
   * @param creatorID 必选 string 人员的userID 测试数据有"4e360e0030147bba67424qazx4523ws"
   * @url http://127.0.0.1:8360/check/statistic/personDetail
   * @return {"errno": 0, "errmsg":""}
   */
  async personDetailAction() {
    try {
      const data = this.post();
      data.creatorID = data.creatorID === undefined ? '' : data.creatorID;
      const sql = 'select d.creatorID,d.pointID,r.typeName,d.totolpoint from (SELECT creatorID, pointID ,sum(point) totolpoint ' +
        'from kh_point_detail where creatorID = "' + data.creatorID + '" GROUP BY pointID) d LEFT JOIN kh_point_rules r on d.pointID = r.id order by d.pointID';
      const returnData = await this.model('kh_point_detail').query(sql);
      this.success(returnData);
    } catch (e) {
      this.fail(e);
    }
  }

  /**
   * showdoc
   * @catalog 业务工作完成率
   * @title 业务工作完成率
   * @description 用户积分列表
   * @method post
   * @param ratioType 必选 int 1人员2部门
   * @param uuid 可选 string 考核人uuid或者部门uuid
   * @param startTime 可选 string 考核开始统计时间 2020-11-11
   * @param endTime 可选 string 考核结束统计时间 2020-11-11
   * @url http://127.0.0.1:8360/check/statistic/completeRatio
   * @return {"errno": 0, "errmsg":""}
   */
  async completeRatioAction() {
    const data = this.post();
    const ratioType = data.ratioType === undefined ? 2 : data.ratioType;
    const uuid = data.uuid === undefined ? 40 : data.uuid;
    const t1 = think.isEmpty(data.startTime) || !moment(data.startTime).isValid() ? new Date().getFullYear() + '-01-01' : data.startTime;
    const t2 = think.isEmpty(data.endTime) || !moment(data.endTime).isValid() ? new Date().getFullYear() + '-12-31' : data.endTime;
    const returnValue = {
      param1: 0,
      param2: 0,
      param3: 0,
      param4: 0,
      param5: 0,
      param6: 0
    };

    // 计算日期差
    const durationDays = moment(t2).diff(moment(t1), 'days') + 1;
    console.log(durationDays);
    // 判断类别是人还是部门
    let users;
    if (ratioType === 1) {
      users = await think.model('sys_user').where({'user_id': uuid}).select();
    }
    if (ratioType === 2) {
      const sql = 'select * from sys_user where orgID in (select id from sys_organization where id  = ' + uuid + ')';
      users = await think.model('sys_organization').query(sql);
    }
    console.log(users.length);
    if (users.length === 0) {
      return this.fail();
    }
    // 1.计算系统登录率
    // 分母：人数*天数
    const param1denominator = users.length * durationDays;
    // 分子：这些人签到的次数
    const userUUids = [];
    const userAccounts = [];
    for (let index = 0; index < users.length; index++) {
      userUUids.push(users[index].user_id);
      userAccounts.push(users[index].user_name);
    }
    const param1numerator = await think.model('kh_point_detail').where({
      creatorID: ['IN', userUUids],
      pointID: 1,
      time: {'>=': moment(t1).format('YYYY-MM-DD'), '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'), _logic: 'AND'}

    }).count('*');
    const param1 = param1numerator / param1denominator;
    returnValue.param1 = param1;

    // 2.按期办理率
    // 如果是单位
    if (ratioType === 2) {
      // 分母是这周期内转到本单位的事件
      const matters = await this.model('fw_task_act').where({
        c_time: {
          '>=': moment(t1).format('YYYY-MM-DD'),
          '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
          _logic: 'AND'
        },
        deptID_now: uuid
      }).field('max(id) as id,c_task,businessID,deptID_now').group('c_task').select();
      const param2denominator = matters.length;
      console.log(param2denominator);
      // 分子是这周期内转出单位的事件
      let dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id],
          _complex: {
            deptID_now: ['!=', uuid],
            businessID: 99,
            _logic: 'or'
          }
        }).select();
        // console.log(dealnum.length);
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param2numerator = dealsum;
      let param2 = 0;
      if (param2denominator === 0) {
        param2 = 0;
      } else {
        param2 = param2numerator / param2denominator;
      }
      returnValue.param2 = param2;
    }
    // 如果是个人
    if (ratioType === 1) {
      // 分母是这周期内转到本人的事件
      const matters = await this.model('fw_task_act').where({
        c_time: {
          '>=': moment(t1).format('YYYY-MM-DD'),
          '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
          _logic: 'AND'
        },
        charger: uuid
      }).field('max(id) as id,c_task,businessID,deptID_now').group('c_task').select();
      const param2denominator = matters.length;
      console.log(param2denominator);
      // 分子是这周期内本人处理的事件
      let dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id],
          _complex: {
            charger: ['!=', uuid],
            businessID: 99,
            _logic: 'or'
          }
        }).select();
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param2numerator = dealsum;
      let param2 = 0;
      if (param2denominator === 0) {
        param2 = 0;
      } else {
        param2 = param2numerator / param2denominator;
      }
      returnValue.param2 = param2;
    }

    // 3.按期回报率
    // 如果是单位
    if (ratioType === 2) {
      // 分母是这周期内本单位需要交办的事件
      const sql = 'select max(id) as id,c_task,businessID,deptID_now from fw_task_act where businessID in (select businessID from fw_act where dealType = \'交办\') ' +
        ' and deptID_now = "' + uuid + '"' +
        ' and ( `c_time` >= \'' + moment(t1).format('YYYY-MM-DD') +
        '\' AND `c_time` <= \'' + moment(t2).add(1, 'days').format('YYYY-MM-DD') + '\' ) GROUP BY c_task';
      const matters = await this.model('fw_task_act').query(sql);
      const param3denominator = matters.length;
      console.log(param3denominator);
      // 分子是这周期内转处理的事件
      let dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id]
          // _complex: {
          //   deptID_now: ['!=', uuid],
          //   businessID: 99,
          //   _logic: 'or'
          // }
        }).select();
        // console.log(dealnum.length);
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param3numerator = dealsum;
      let param3 = 0;
      if (param3denominator === 0) {
        param3 = 0;
      } else {
        param3 = param3numerator / param3denominator;
      }
      returnValue.param3 = param3;
    }
    // 如果是个人
    if (ratioType === 1) {
      // 分母是这周期内本单位需要交办的事件
      const orgID = users[0].orgID;
      const sql = 'select max(id) as id,c_task,businessID,deptID_now from fw_task_act where businessID in (select businessID from fw_act where dealType = \'交办\') ' +
        ' and deptID_now = "' + orgID + '"' +
        ' and ( `c_time` >= \'' + moment(t1).format('YYYY-MM-DD') +
        '\' AND `c_time` <= \'' + moment(t2).add(1, 'days').format('YYYY-MM-DD') + '\' ) GROUP BY c_task';
      const matters = await this.model('fw_task_act').query(sql);
      const param3denominator = matters.length;
      console.log(param3denominator);
      // 分子是这周期内转处理的事件
      let dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id]
        }).select();
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param3numerator = dealsum;
      let param3 = 0;
      if (param3denominator === 0) {
        param3 = 0;
      } else {
        param3 = param3numerator / param3denominator;
      }
      returnValue.param3 = param3;
    }
    // 4.按期反馈率
    // 如果是单位
    if (ratioType === 2) {
      // 分母是这周期内本单位需要交办的事件
      const sql = 'select max(id) as id,c_task,businessID,deptID_now from fw_task_act where businessID in (select businessID from fw_act where dealType = \'转交\') ' +
        ' and deptID_now = "' + uuid + '"' +
        ' and ( `c_time` >= \'' + moment(t1).format('YYYY-MM-DD') +
        '\' AND `c_time` <= \'' + moment(t2).add(1, 'days').format('YYYY-MM-DD') + '\' ) GROUP BY c_task';
      const matters = await this.model('fw_task_act').query(sql);
      const param4denominator = matters.length;
      console.log(param4denominator);
      // 分子是这周期内转处理的事件
      let dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id]
          // _complex: {
          //   deptID_now: ['!=', uuid],
          //   businessID: 99,
          //   _logic: 'or'
          // }
        }).select();
        // console.log(dealnum.length);
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param4numerator = dealsum;
      let param4 = 0;
      if (param4denominator === 0) {
        param4 = 0;
      } else {
        param4 = param4numerator / param4denominator;
      }
      returnValue.param4 = param4;
    }
    // 如果是个人
    if (ratioType === 1) {
      // 分母是这周期内本单位需要交办的事件
      const orgID = users[0].orgID;
      const sql = 'select max(id) as id,c_task,businessID,deptID_now from fw_task_act where businessID in (select businessID from fw_act where dealType = \'转交\') ' +
        ' and deptID_now = "' + orgID + '"' +
        ' and ( `c_time` >= \'' + moment(t1).format('YYYY-MM-DD') +
        '\' AND `c_time` <= \'' + moment(t2).add(1, 'days').format('YYYY-MM-DD') + '\' ) GROUP BY c_task';
      const matters = await this.model('fw_task_act').query(sql);
      const param4denominator = matters.length;
      console.log(param4denominator);
      // 分子是这周期内转处理的事件
      let dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id]
        }).select();
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param4numerator = dealsum;
      let param4 = 0;
      if (param4denominator === 0) {
        param4 = 0;
      } else {
        param4 = param4numerator / param4denominator;
      }
      returnValue.param4 = param4;
    }

    // 5.处理情况告知率：统计时间段内，向信访群众实际发送短信、出具告知书的实际数量与可发送出具数量的比值；
    if (ratioType === 2) {
      const matters = await this.model('matter').where({
        createAccount: ['IN', userAccounts],
        createTime: {
          '>=': moment(t1).format('YYYY-MM-DD'),
          '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
          _logic: 'AND'
        }
      }).select();
      let dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('tell_log').where({
          matterID: matters[index].id,
          sendType: ['in', (1, 2)]
        }).select();
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param5denominator = matters.length;
      const param5numerator = dealsum;
      let param5 = 0;
      if (param5denominator === 0) {
        param5 = 0;
      } else {
        param5 = param5numerator / param5denominator;
      }
      returnValue.param5 = param5;
    }
    if (ratioType === 1) {
      const matters = await this.model('matter').where({
        createAccount: ['IN', userAccounts],
        createTime: {
          '>=': moment(t1).format('YYYY-MM-DD'),
          '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
          _logic: 'AND'
        }
      }).select();
      let dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('tell_log').where({
          matterID: matters[index].id,
          sendType: ['in', (1, 2)]
        }).select();
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param5denominator = matters.length;
      const param5numerator = dealsum;
      let param5 = 0;
      if (param5denominator === 0) {
        param5 = 0;
      } else {
        param5 = param5numerator / param5denominator;
      }
      returnValue.param5 = param5;
    }

    // 6. 登记信息完整率：统计时间段内，所登记的信访件登记信息完整率的平均值。 就是人的信息项
    if (ratioType === 1) {
      let accountsStr = '';
      for (let index = 0; index < userAccounts.length; index++) {
        accountsStr = '"' + userAccounts[index] + '",';
      }
      accountsStr = accountsStr.substring(0, accountsStr.length - 1);
      const sql = 'select * from person where id in (select personID from person_activity ' +
        'where id in (select id from activity \n' +
        'where createTime >= \'' + moment(t1).format('YYYY-MM-DD') +
        '\' AND createTime <= \'' + moment(t2).add(1, 'days').format('YYYY-MM-DD') + '\'' +
        ' and createAccount in ' + '(' + accountsStr + ')' +
        ' ))';
      const person = await this.model('person').query(sql);
      let totallength = 0;
      let nullnum = 0;
      for (let index = 0; index < person.length; index++) {
        for (var key in person[index]) {
          // console.log(key+':'+person[index][key]);
          if (!key.endsWith('ID') && !key.startsWith('create')) {
            console.log(key);
            totallength = totallength + 1;
            if (person[index][key] == null || person[index][key].length === 0) {
              nullnum = nullnum + 1;
            }
          }
        }
      }
      if (totallength !== 0) {
        totallength = person.length * (totallength / person.length - 5);
      }
      const param6denominator = totallength;
      const param6numerator = totallength - nullnum;
      let param6 = 0;
      if (param6denominator === 0) {
        param6 = 0;
      } else {
        param6 = param6numerator / param6denominator;
      }
      returnValue.param6 = param6;
    }
    return this.success(returnValue);
  }

  /**
   * showdoc
   * @catalog 定时任务计算人员积分
   * @title 人员积分详情
   * @description 人员积分详情
   * @method 无法外部调用
   * @url http://127.0.0.1:8360/check/statistic/calculatePoints
   * @return {"errno": 0, "errmsg":""}
   */
  async calculatePointsAction() {
    if (!this.isCli) return this.fail(1000, 'deny');
    const where = ' and c_time >= "' + moment().format('YYYY-MM-DD') + '" and c_time <= "' + moment().add(1, 'days').format('YYYY-MM-DD') + '"';
    // where = ' and c_time >= "' + moment().add(-1000, 'days').format('YYYY-MM-DD') + '" and c_time <= "' + moment().add(1, 'days').format('YYYY-MM-DD') + '"';

    const sql = 'select * from fw_task_act where c_task in (select c_task from fw_task_act where businessID = 99 ' + where + ') ORDER BY c_task';
    const rule2 = await think.model('kh_point_rules').where({'id': 2}).select();
    const rule3 = await think.model('kh_point_rules').where({'id': 3}).select();

    if (rule2.length !== 1 || rule3.length !== 1) {
      return this.fail();
    }

    const taskData = await this.model('fw_task_act').query(sql);
    // console.log(taskData);
    let c_task = 0;
    let regionLevel = '';
    const writerlist = [];
    const writerTime = [];
    const downerlist = [];
    for (let count = 0; count < taskData.length; count++) {
      // console.log(taskData[count].c_task);
      if (taskData[count].businessID === 99) {
        writerTime.push(taskData[count].c_time);
      }
      if (taskData[count].c_task != c_task) {
        c_task = taskData[count].c_task;
        // 把登记人的信息拿下来
        // console.log('登记人信息:' + taskData[count].c_user);
        writerlist.push(taskData[count].c_user);
        regionLevel = taskData[count].regionLevel_now;
      } else {
        if ((regionLevel == '省级' && taskData[count].regionLevel_now == '市级') || (regionLevel == '市级' && taskData[count].regionLevel_now == '县级')) {
          // 把下级记录下来
          // console.log('下级用户：' + taskData[count].c_user);
          downerlist.push(taskData[count].c_user);
        }
        if (regionLevel != taskData[count].regionLevel_now) {
          regionLevel = taskData[count].regionLevel_now;
        }
      }
    }
    for (let count = 0; count < writerlist.length; count++) {
      const user = await think.model('sys_user').where({'user_id': writerlist[count]}).select();
      const org = await think.model('sys_organization').where({'id': user[0].orgID}).select();
      const insertPoint = {
        creatorID: user[0].user_id,
        creatorName: user[0].name,
        orgName: org[0].orgName || '',
        orgID: user[0].orgID,
        pointID: rule2[0].id,
        pointName: rule2[0].typeName,
        point: rule2[0].point,
        time: writerTime[count]
      };
      await think.model('kh_point_detail').add(insertPoint);
    }
    for (let count = 0; count < downerlist.length; count++) {
      const user = await think.model('sys_user').where({'user_id': downerlist[count]}).select();
      const org = await think.model('sys_organization').where({'id': user[0].orgID}).select();
      const insertPoint = {
        creatorID: user[0].user_id,
        creatorName: user[0].name,
        orgName: org[0].orgName || '',
        orgID: user[0].orgID,
        pointID: rule3[0].id,
        pointName: rule3[0].typeName,
        point: rule3[0].point
      };
      await think.model('kh_point_detail').add(insertPoint);
    }
    await this.success();
  }

  /**
   * showdoc
   * @catalog 业务工作完成率
   * @title 业务工作完成率
   * @description 业务工作完成率排行榜
   * @method post
   * @param orgID 可选 int 部门id 比如40
   * @param startTime 可选 string 考核开始统计时间 2020-11-11
   * @param endTime 可选 string 考核结束统计时间 2020-11-11
   * @url http://127.0.0.1:8360/check/statistic/completeRatioTop10
   * @return {"errno": 0, "errmsg":""}
   */
  async completeRatioTop10Action() {
    const data = this.post();
    const orgID = think.isEmpty(data.orgID) ? 40 : data.orgID;
    const t1 = think.isEmpty(data.startTime) || !moment(data.startTime).isValid() ? new Date().getFullYear() + '-01-01' : data.startTime;
    const t2 = think.isEmpty(data.endTime) || !moment(data.endTime).isValid() ? new Date().getFullYear() + '-12-31' : data.endTime;

    const orgSql = 'select id,orgName from sys_organization where jc = "人常" and agent = 1 and  (deptID in (\n' +
      'select id from  sys_dept where parentID in \n' +
      '(select deptID from sys_organization where id = ' + orgID + ') )  or id = ' + orgID + ')';
    const orgData = await this.model('sys_dept').query(orgSql);

    const returnValue = {
      param1org: [],
      param2org: [],
      param3org: [],
      param4org: [],
      param5org: [],
      param6org: [],
      param1per: [],
      param2per: [],
      param3per: [],
      param4per: [],
      param5per: [],
      param6per: []
    };
    // 计算日期差
    const durationDays = moment(t2).diff(moment(t1), 'days') + 1;

    for (let index = 0; index < orgData.length; index++) {
      const uuid = orgData[index].id;
      const orgName = orgData[index].orgName;
      // 1.计算系统登录率

      let sql = 'select * from sys_user where orgID in (select id from sys_organization where id  = ' + uuid + ')';
      const users = await think.model('sys_organization').query(sql);
      // 分母：人数*天数
      let param1numerator = 0;
      const param1denominator = users.length * durationDays;
      let userUUids = [];
      let userAccounts = [];
      for (let index = 0; index < users.length; index++) {
        userUUids.push(users[index].user_id);
        userAccounts.push(users[index].user_name);
      }
      if (users.length > 0) {
        param1numerator = await think.model('kh_point_detail').where({
          creatorID: ['IN', userUUids],
          pointID: 1,
          time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          }
        }).count('*');
      }
      const param1 = param1numerator / param1denominator || 0;
      returnValue.param1org.push({
        orgName: orgName,
        param: param1
      });

      // 2.按期办理率
      // 分母是这周期内转到本单位的事件
      let matters = await this.model('fw_task_act').where({
        c_time: {
          '>=': moment(t1).format('YYYY-MM-DD'),
          '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
          _logic: 'AND'
        },
        deptID_now: uuid
      }).field('max(id) as id,c_task,businessID,deptID_now').group('c_task').select();
      const param2denominator = matters.length;
      // 分子是这周期内转出单位的事件
      let dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id],
          _complex: {
            deptID_now: ['!=', uuid],
            businessID: 99,
            _logic: 'or'
          }
        }).select();
        // console.log(dealnum.length);
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param2numerator = dealsum;
      let param2 = 0;
      if (param2denominator === 0) {
        param2 = 0;
      } else {
        param2 = param2numerator / param2denominator;
      }

      returnValue.param2org.push({
        orgName: orgName,
        param: param2
      });

      // 3.按期回报率
      // 分母是这周期内本单位需要交办的事件
      sql = 'select max(id) as id,c_task,businessID,deptID_now from fw_task_act where businessID in (select businessID from fw_act where dealType = \'交办\') ' +
        ' and deptID_now = "' + uuid + '"' +
        ' and ( `c_time` >= \'' + moment(t1).format('YYYY-MM-DD') +
        '\' AND `c_time` <= \'' + moment(t2).add(1, 'days').format('YYYY-MM-DD') + '\' ) GROUP BY c_task';
      matters = await this.model('fw_task_act').query(sql);
      const param3denominator = matters.length;
      // 分子是这周期内转处理的事件
      dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id]
          // _complex: {
          //   deptID_now: ['!=', uuid],
          //   businessID: 99,
          //   _logic: 'or'
          // }
        }).select();
        // console.log(dealnum.length);
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param3numerator = dealsum;
      let param3 = 0;
      if (param3denominator === 0) {
        param3 = 0;
      } else {
        param3 = param3numerator / param3denominator;
      }
      returnValue.param3org.push({
        orgName: orgName,
        param: param3
      });

      // 4.按期反馈率
      // 分母是这周期内本单位需要交办的事件
      sql = 'select max(id) as id,c_task,businessID,deptID_now from fw_task_act where businessID in (select businessID from fw_act where dealType = \'转交\') ' +
        ' and deptID_now = "' + uuid + '"' +
        ' and ( `c_time` >= \'' + moment(t1).format('YYYY-MM-DD') +
        '\' AND `c_time` <= \'' + moment(t2).add(1, 'days').format('YYYY-MM-DD') + '\' ) GROUP BY c_task';
      matters = await this.model('fw_task_act').query(sql);
      const param4denominator = matters.length;
      // 分子是这周期内转处理的事件
      dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id]
          // _complex: {
          //   deptID_now: ['!=', uuid],
          //   businessID: 99,
          //   _logic: 'or'
          // }
        }).select();
        // console.log(dealnum.length);
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param4numerator = dealsum;
      let param4 = 0;
      if (param4denominator === 0) {
        param4 = 0;
      } else {
        param4 = param4numerator / param4denominator;
      }
      returnValue.param4org.push({
        orgName: orgName,
        param: param4
      });

      // 5.处理情况告知率：统计时间段内，向信访群众实际发送短信、出具告知书的实际数量与可发送出具数量的比值；

      if (userAccounts.length > 0) {
        matters = await this.model('matter').where({
          createAccount: ['IN', userAccounts],
          createTime: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          }
        }).select();
      }

      dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('tell_log').where({
          matterID: matters[index].id,
          sendType: ['in', (1, 2)]
        }).select();
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      let param5denominator = 0;
      if (userAccounts.length > 0) {
        param5denominator = matters.length;
      }
      const param5numerator = dealsum;
      let param5 = 0;
      if (param5denominator === 0) {
        param5 = 0;
      } else {
        param5 = param5numerator / param5denominator;
      }
      returnValue.param5org.push({
        orgName: orgName,
        param: param5
      });
      // 6. 登记信息完整率：统计时间段内，所登记的信访件登记信息完整率的平均值。 就是人的信息项
      if (userAccounts.length > 0) {
        let accountsStr = '';
        for (let index = 0; index < userAccounts.length; index++) {
          accountsStr = '"' + userAccounts[index] + '",';
        }
        accountsStr = accountsStr.substring(0, accountsStr.length - 1);
        sql = 'select * from person where id in (select personID from person_activity ' +
          'where id in (select id from activity \n' +
          'where createTime >= \'' + moment(t1).format('YYYY-MM-DD') +
          '\' AND createTime <= \'' + moment(t2).add(1, 'days').format('YYYY-MM-DD') + '\'' +
          ' and createAccount in ' + '(' + accountsStr + ')' +
          ' ))';
        const person = await this.model('person').query(sql);
        let totallength = 0;
        let nullnum = 0;
        for (let index = 0; index < person.length; index++) {
          for (var key in person[index]) {
            // console.log(key+':'+person[index][key]);
            if (!key.endsWith('ID') && !key.startsWith('create')) {
              totallength = totallength + 1;
              if (person[index][key] == null || person[index][key].length === 0) {
                nullnum = nullnum + 1;
              }
            }
          }
        }
        if (totallength !== 0) {
          totallength = person.length * (totallength / person.length - 5);
        }
        const param6denominator = totallength;
        const param6numerator = totallength - nullnum;
        let param6 = 0;
        if (param6denominator === 0) {
          param6 = 0;
        } else {
          param6 = param6numerator / param6denominator;
        }
        returnValue.param6org.push({
          orgName: orgName,
          param: param6
        });
      } else {
        returnValue.param6org.push({
          orgName: orgName,
          param: 0
        });
      }
    }

    const allusersSql = 'select sys_user.*,sys_organization.orgName from sys_user LEFT JOIN sys_organization on sys_user.orgID = sys_organization.id where user_name not REGEXP "[A-Z]+" and orgID in (\n' +
      ' select id from sys_organization where jc = "人常" and agent = 1 and  (deptID in (\n' +
      'select id from  sys_dept where parentID in \n' +
      '(select deptID from sys_organization where id = ' + orgID + ') )  or id = ' + orgID + '))';
    const allusers = await this.model('sys_user').query(allusersSql);

    for (let index = 0; index < allusers.length; index++) {
      const userUUids = [];
      const userAccounts = [];
      const personID = allusers[index].user_id;
      const personName = allusers[index].name;
      userUUids.push(personID);
      userAccounts.push(personName);
      // 1.计算系统登录率
      const param1numerator = await think.model('kh_point_detail').where({
        creatorID: ['IN', userUUids],
        pointID: 1,
        time: {
          '>=': moment(t1).format('YYYY-MM-DD'),
          '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
          _logic: 'AND'
        }

      }).count('*');
      const param1denominator = durationDays;
      const param1 = param1numerator / param1denominator;

      returnValue.param1per.push({
        personName: personName,
        orgName: allusers[index].orgName,
        param: param1
      });
      // 2.按期办理率
      // 分母是这周期内转到本人的事件
      let matters = await this.model('fw_task_act').where({
        c_time: {
          '>=': moment(t1).format('YYYY-MM-DD'),
          '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
          _logic: 'AND'
        },
        charger: personID
      }).field('max(id) as id,c_task,businessID,deptID_now').group('c_task').select();
      const param2denominator = matters.length;
      // 分子是这周期内本人处理的事件
      let dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id],
          _complex: {
            charger: ['!=', personID],
            businessID: 99,
            _logic: 'or'
          }
        }).select();
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param2numerator = dealsum;
      let param2 = 0;
      if (param2denominator === 0) {
        param2 = 0;
      } else {
        param2 = param2numerator / param2denominator;
      }
      returnValue.param2per.push({
        personName: personName,
        orgName: allusers[index].orgName,
        param: param2
      });
      // 3.按期回报率
      // 分母是这周期内本单位需要交办的事件
      let orgID = allusers[index].orgID;
      let sql = 'select max(id) as id,c_task,businessID,deptID_now from fw_task_act where businessID in (select businessID from fw_act where dealType = \'交办\') ' +
        ' and deptID_now = "' + orgID + '"' +
        ' and ( `c_time` >= \'' + moment(t1).format('YYYY-MM-DD') +
        '\' AND `c_time` <= \'' + moment(t2).add(1, 'days').format('YYYY-MM-DD') + '\' ) GROUP BY c_task';
      matters = await this.model('fw_task_act').query(sql);
      const param3denominator = matters.length;
      // 分子是这周期内转处理的事件
      dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id]
        }).select();
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param3numerator = dealsum;
      let param3 = 0;
      if (param3denominator === 0) {
        param3 = 0;
      } else {
        param3 = param3numerator / param3denominator;
      }
      returnValue.param3per.push({
        personName: personName,
        orgName: allusers[index].orgName,
        param: param3
      });
      // 4.按期反馈率
      // 分母是这周期内本单位需要交办的事件
      sql = 'select max(id) as id,c_task,businessID,deptID_now from fw_task_act where businessID in (select businessID from fw_act where dealType = \'转交\') ' +
        ' and deptID_now = "' + orgID + '"' +
        ' and ( `c_time` >= \'' + moment(t1).format('YYYY-MM-DD') +
        '\' AND `c_time` <= \'' + moment(t2).add(1, 'days').format('YYYY-MM-DD') + '\' ) GROUP BY c_task';
      matters = await this.model('fw_task_act').query(sql);
      const param4denominator = matters.length;
      // 分子是这周期内转处理的事件
      dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('fw_task_act').where({
          c_time: {
            '>=': moment(t1).format('YYYY-MM-DD'),
            '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
            _logic: 'AND'
          },
          c_task: matters[index].c_task,
          id: ['>', matters[index].id]
        }).select();
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param4numerator = dealsum;
      let param4 = 0;
      if (param4denominator === 0) {
        param4 = 0;
      } else {
        param4 = param4numerator / param4denominator;
      }
      returnValue.param4per.push({
        personName: personName,
        orgName: allusers[index].orgName,
        param: param4
      });
      // 5.处理情况告知率：统计时间段内，向信访群众实际发送短信、出具告知书的实际数量与可发送出具数量的比值；
      matters = await this.model('matter').where({
        createAccount: ['IN', userAccounts],
        createTime: {
          '>=': moment(t1).format('YYYY-MM-DD'),
          '<=': moment(t2).add(1, 'days').format('YYYY-MM-DD'),
          _logic: 'AND'
        }
      }).select();
      dealsum = 0;
      for (let index = 0; index < matters.length; index++) {
        const dealnum = await this.model('tell_log').where({
          matterID: matters[index].id,
          sendType: ['in', (1, 2)]
        }).select();
        if (dealnum.length > 0) {
          dealsum = dealsum + 1;
        }
      }
      const param5denominator = matters.length;
      const param5numerator = dealsum;
      let param5 = 0;
      if (param5denominator === 0) {
        param5 = 0;
      } else {
        param5 = param5numerator / param5denominator;
      }
      returnValue.param5per.push({
        personName: personName,
        orgName: allusers[index].orgName,
        param: param5
      });
      // 6. 登记信息完整率：统计时间段内，所登记的信访件登记信息完整率的平均值。 就是人的信息项
      let accountsStr = '';
      for (let index = 0; index < userAccounts.length; index++) {
        accountsStr = '"' + userAccounts[index] + '",';
      }
      accountsStr = accountsStr.substring(0, accountsStr.length - 1);
      sql = 'select * from person where id in (select personID from person_activity ' +
        'where id in (select id from activity \n' +
        'where createTime >= \'' + moment(t1).format('YYYY-MM-DD') +
        '\' AND createTime <= \'' + moment(t2).add(1, 'days').format('YYYY-MM-DD') + '\'' +
        ' and createAccount in ' + '(' + accountsStr + ')' +
        ' ))';
      const person = await this.model('person').query(sql);
      let totallength = 0;
      let nullnum = 0;
      for (let index = 0; index < person.length; index++) {
        for (var key in person[index]) {
          // console.log(key+':'+person[index][key]);
          if (!key.endsWith('ID') && !key.startsWith('create')) {
            totallength = totallength + 1;
            if (person[index][key] == null || person[index][key].length === 0) {
              nullnum = nullnum + 1;
            }
          }
        }
      }
      if (totallength !== 0) {
        totallength = person.length * (totallength / person.length - 5);
      }
      const param6denominator = totallength;
      const param6numerator = totallength - nullnum;
      let param6 = 0;
      if (param6denominator === 0) {
        param6 = 0;
      } else {
        param6 = param6numerator / param6denominator;
      }
      returnValue.param6per.push({
        personName: personName,
        orgName: allusers[index].orgName,
        param: param6
      });
    }

    for (let key in returnValue) {
      const list = returnValue[key];
      for (let index = 0; index < list.length; index++) {
        for (let count = 0; count < list.length - 1 - index; count++) {
          if (list[count].param < list[count + 1].param) {
            let tmp = list[count + 1];
            list[count + 1] = list[count];
            list[count] = tmp;
          }
        }
      }
    }

    return this.success(returnValue);
  }

  /**
   * showdoc
   * @catalog 异常信访的预警
   * @title 异常信访的预警
   * @description 异常信访的预警
   * @method get
   * @url http://127.0.0.1:8360/check/statistic/abnormalMsg
   * @return {"errno": 0, "errmsg":""}
   */
  async abnormalMsgAction() {
    const startDate = moment().add(-7, 'days').format('YYYY-MM-DD');
    const endDate = moment().add(1, 'days').format('YYYY-MM-DD');

    //   ①集体访登记信息即时推送；
    const param1 = await this.model('activity').where({
      xfTypeID: ['in', ['001002', '001003']],
      createTime: {
        '>=': moment(startDate).format('YYYY-MM-DD'),
        '<=': moment(endDate).format('YYYY-MM-DD'),
        _logic: 'AND'
      }
    }).count('*');
    //   ②联名信登记信息即时推送；
    const param2 = await this.model('activity').where({
      xfTypeID: '002002',
      createTime: {
        '>=': moment(startDate).format('YYYY-MM-DD'),
        '<=': moment(endDate).format('YYYY-MM-DD'),
        _logic: 'AND'
      }
    }).count('*');
    //   ③异常访登记信息即时推送；
    const param3 = await this.model('activity').where({
      registerTypeID: '001',
      isAbnormal: 1,
      createTime: {
        '>=': moment(startDate).format('YYYY-MM-DD'),
        '<=': moment(endDate).format('YYYY-MM-DD'),
        _logic: 'AND'
      }
    }).count('*');
    //   ④扬言信登记信息即时推送
    const param4 = await this.model('activity').where({
      registerTypeID: '002',
      isAbnormal: 1,
      abnormalID: ['like', '%002001%'],
      createTime: {
        '>=': moment(startDate).format('YYYY-MM-DD'),
        '<=': moment(endDate).format('YYYY-MM-DD'),
        _logic: 'AND'
      }
    }).count('*');
    let msg = '';
    if (param1 > 0) {
      msg = '集体访' + param1 + '次,';
    }
    if (param2 > 0) {
      msg += '联名信' + param2 + '件,';
    }
    if (param3 > 0) {
      msg += '异常访' + param3 + '次,';
    }
    if (param4 > 0) {
      msg += '扬言信' + param4 + '件,';
    }
    if (msg.length > 0) {
      msg = '近7日内,有' + msg;
      msg = msg.substring(0, msg.length - 1);
    }
    return this.success(msg);

  }

  /**
   * showdoc
   * @catalog 信息研判
   * @title 信息研判
   * @description 信息研判
   * @method post
   * @param orgID 可选 int 部门id 比如40
   * @param startTime 可选 string 开始统计时间 2020-11-11
   * @param endTime 可选 string 结束统计时间 2020-11-11
   * @url http://127.0.0.1:8360/check/statistic/infoDiagResearch
   * @return {"errno": 0, "errmsg":""}
   */
  async infoDiagResearchAction() {
    const data = this.post();
    const orgID = think.isEmpty(data.orgID) ? 40 : data.orgID;
    const startTime = think.isEmpty(data.startTime) || !moment(data.startTime).isValid() ? moment().format('YYYY-MM') + '-01' : data.startTime;
    const endTime = think.isEmpty(data.endTime) || !moment(data.endTime).isValid() ? moment().add('month', 1).format('YYYY-MM') + '-01' : data.endTime;

    const returnvalue = {};

    const totalSql = '-- 总数\n' +
      'select "总信访数" as name, count(1) as count from activity where  createOrgID in (\n' +
      'select id as orgID from sys_organization where deptID in (\n' +
      'select id from sys_dept where parentID = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ') or id = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ')) and jc = "人常") and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'union all\n' +
      '-- 001002 场所异常\n' +
      'select "场所异常" as name, count(1) as count from activity where  createOrgID in (\n' +
      'select id as orgID from sys_organization where deptID in (\n' +
      'select id from sys_dept where parentID = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ') or id = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ')) and jc = "人常") and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'00100200%\' )\n' +
      'union all\n' +
      '-- 001003 行为异常\n' +
      'select "行为异常" as name, count(1) as count from activity where  createOrgID in (\n' +
      'select id as orgID from sys_organization where deptID in (\n' +
      'select id from sys_dept where parentID = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ') or id = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ')) and jc = "人常") and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'0010030%\' )\n' +
      'union all\n' +
      '-- 002001 扬言信\n' +
      'select "扬言信" as name, count(1) as count from activity where  createOrgID in (\n' +
      'select id as orgID from sys_organization where deptID in (\n' +
      'select id from sys_dept where parentID = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ') or id = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ')) and jc = "人常") and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'00200100%\' )\n' +
      'union all\n' +
      '-- 003001 扬言投诉\n' +
      '-- 004001 扬言投诉\n' +
      'select "扬言投诉" as name, count(1) as count from activity where  createOrgID in (\n' +
      'select id as orgID from sys_organization where deptID in (\n' +
      'select id from sys_dept where parentID = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ') or id = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ')) and jc = "人常") and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'00300100%\' or abnormalID like \'00400100%\')\n' +
      'union all\n' +
      '-- 002004 夹带钱、物\n' +
      'select "夹带钱、物" as name, count(1) as count from activity where  createOrgID in (\n' +
      'select id as orgID from sys_organization where deptID in (\n' +
      'select id from sys_dept where parentID = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ') or id = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ')) and jc = "人常") and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'00200400%\' )\n' +
      'union all\n' +
      '-- 003002 违法上传违禁电子信息\n' +
      'select "上传违禁电子信息" as name, count(1) as count from activity where  createOrgID in (\n' +
      'select id as orgID from sys_organization where deptID in (\n' +
      'select id from sys_dept where parentID = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ') or id = (\n' +
      'select deptID from sys_organization where id = ' + orgID + ')) and jc = "人常") and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'003002%\' )';

    const totalNum = await this.model('activity').query(totalSql);

    returnvalue.total = totalNum;

    const provinceSql = '-- 总数\n' +
      'select "总信访数" as name, count(1) as count from activity where createOrgID = ' + orgID +
      ' and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'union all\n' +
      '-- 001002 场所异常\n' +
      'select "场所异常" as name, count(1) as count from activity where  createOrgID  = ' + orgID +
      ' and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'00100200%\' )\n' +
      'union all\n' +
      '-- 001003 行为异常\n' +
      'select "行为异常" as name, count(1) as count from activity where  createOrgID = ' + orgID +
      ' and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'0010030%\' )\n' +
      'union all\n' +
      '-- 002001 扬言信\n' +
      'select "扬言信" as name, count(1) as count from activity where  createOrgID = ' + orgID +
      ' and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'00200100%\' )\n' +
      'union all\n' +
      '-- 003001 扬言投诉\n' +
      '-- 004001 扬言投诉\n' +
      'select "扬言投诉" as name, count(1) as count from activity where  createOrgID = ' + orgID +
      ' and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'00300100%\' or abnormalID like \'00400100%\')\n' +
      'union all\n' +
      '-- 002004 夹带钱、物\n' +
      'select "夹带钱、物" as name, count(1) as count from activity where  createOrgID  = ' + orgID +
      ' and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'00200400%\' )\n' +
      'union all\n' +
      '-- 003002 违法上传违禁电子信息\n' +
      'select "上传违禁电子信息" as name, count(1) as count from activity where  createOrgID = ' + orgID +
      ' and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
      'and isAbnormal = 1 and (abnormalID like \'003002%\' )';

    const proviceNum = await this.model('activity').query(provinceSql);

    returnvalue.provice = proviceNum;

    const regionlistSql = 'select sys_dept.deptName,sys_organization.id,sys_organization.orgName from sys_dept\n' +
      'left join sys_organization on sys_dept.id = sys_organization.deptID  ' +
      'where sys_dept.parentID = (select deptID from sys_organization where id = ' + orgID + ') and  sys_organization.jc = "人常"';
    const regionlist = await this.model('sys_organization').query(regionlistSql);

    for (let index = 0; index < regionlist.length; index++) {
      const orgID = regionlist[index].id;
      // console.log(orgID)
      const regionNumSql = 'select count(1) as count from activity where  createOrgID = ' + orgID +
        ' and createTime >= \'' + startTime + '\' and createTime <= \'' + endTime + '\'\n' +
        'and isAbnormal = 1';
      const regionNum = await this.model('activity').query(regionNumSql);

      regionlist[index].count = regionNum[0].count;
      delete regionlist[index].id;
      delete regionlist[index].orgName;
    }
    returnvalue.region = regionlist;

    return this.success(returnvalue);
  }

};
