const Base = require('./base.js');
const moment = require('moment');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }

  /**
   * showdoc
   * @catalog 系统管理/字典管理
   * @title 字典分类
   * @description 字典分类
   * @method post
   * @url http://127.0.0.1:8360/dictionary/group
   * @return {"errno": 0, "errmsg":"", "data":[{"dictName":1,"dictID":1,"dictValue":10,"description":1,"shortDesc":"admin","parentValue":1,"isExistchild":0,"descSpell":"jash"}]}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param dictName  string 字典名称
   * @return_param dictID  string 字典类型
   */
  // group分组列表
  async groupAction() {
    const list = await this.model('dictionary').field('dictID,dictName').group('dictID').select();
    return this.success(list);
  }

  //获取字典值的所有父级
  async ancestorAction() {
    let param = this.post();
    let dictLen = param.dictValue.length;
    //字典前面有几级
    let dictFornt = dictLen / 3 - 1;
    let dictParam = [];
    for (let i = 1; i <= dictFornt; i++) {
      dictParam.push(param.dictValue.substring(0, i * 3));
    }
    dictParam.push(param.dictValue);
    const whereParam = {
      dictValue: ['IN', dictParam],
      dictID: param.dictID
    };
    let res = await this.model('dictionary').field('description').where(whereParam).select();
    let dictName = [];
    res.forEach((item) => {
      dictName.push(item.description);
    });
    //将名字串联起来
    dictName = dictName.join('/');
    return this.success(dictName);

  }

  // 通过dictID查询对应字典
  async selectAction() {
    const param = this.post();
    const back = await this.model('dictionary').where({'dictID': param.dictID, 'flag': 1}).order('IFNULL(orderNum, 9999) ASC').select();
    // const gettree = () => {
    let tree = [];
    let data = {};
    for (const i in back) {
      const dataKey = back[i]['dictValue'];
      data[dataKey] = back[i];
    }
    for (const j in back) {
      const bval = back[j];
      const dataP = data[bval['parentValue']];
      if (dataP) {
        if (!dataP.children) {
          dataP.children = [];
        }
        dataP.children.push(bval);
      } else {
        tree.push(bval);
      }
    }
    return this.success(tree);
  }

  // 部门系统表字典查询
  async bmxtListAction() {
    //传参 问题分类 contentClassifyID
    const param = this.post();
    let dictValue = '';
    if (param.hasOwnProperty('contentClassifyID')) {
      dictValue = param.contentClassifyID.toString().substring(0, 3);
    }
    const back = await this.model('bmxt').where({'belongs': ['like', '%' + dictValue + '%']}).order('IFNULL(orderNum, 9999) ASC').select();
    let tree = [];
    let data = {};
    for (let i in back) {
      data[back[i]['dictValue']] = back[i];
    }
    for (let j in back) {
      let bval = back[j];
      let dataP = data[bval['parentValue']];
      if (dataP) {
        (!dataP.children) && (dataP.children = []);
        dataP.children.push(bval);
      } else {
        tree.push(bval);
      }
    }
    return this.success(tree);
  }

  // 通过userId，判断问题属地，问题属地只能是本级和下一级
  async getRegionAction(){
    const data = this.post();
    if (data.hasOwnProperty('isMeeting') && data.isMeeting === 0){
      let sql = 'select * from dictionary where dictID = "AB" AND flag = 1 AND length(dictValue) <= 6 order by IFNULL(orderNum, 9999) ASC';
      let dictionary = await this.model('dictionary').query(sql);
      let tree = [];
      let data = {};
      for (let i in dictionary) {
        data[dictionary[i]['dictValue']] = dictionary[i];
      }
      for (let j in dictionary) {
        let bval = dictionary[j];
        let dataP = data[bval['parentValue']];
        if (dataP) {
          (!dataP.children) && (dataP.children = []);
          dataP.children.push(bval);
        } else {
          tree.push(bval);
        }
      }
      return this.success(tree);
    }
    let userInfo = await this.getUserInfo(data.userId); // 获取用户信息
    let where = {
      "dictID":"AB",
      "flag":1,
      // "dictValue":userInfo.deptValue,
      "parentValue":userInfo.deptValue
    }
    let dictionary = await this.model('dictionary').where(where).order("orderNum").select();
    let back = [{
      "dictValue":userInfo.deptValue,
      "description":userInfo.description,
      "children":[]
    }];
    if (userInfo.deptValue === '001'){
      // 安徽省人员，问题属地可选外地
      let out = await this.model('dictionary').where({'dictID':'AB','flag':1,'parentValue':null,'dictValue':['!=','001']}).select();
      out.forEach(function(item) {
        back.push(item)
      })
    }
    dictionary.forEach(function(item) {
      back[0].children.push(item)
    })
    return this.success(back)
  }
  // 获取当前流转状态名称，不包括businessID
  async getBusinessNameAction(){
    let businessName = await this.model('fw_act').field('businessName').distinct('businessName').order('businessID').select();
    return this.success(businessName)
  }
  //分别获取领导代表登记类型
  async getLeaderXftypeAction(){
    const param = this.post();
    if (param.hasOwnProperty('leaderType')){
      let sql = '';
      if (param.leaderType === 0){// 领导
        sql = 'select * from dictionary where dictID = "LY" AND flag = 1 AND description LIKE "%领导%" order by IFNULL(orderNum, 9999) ASC';
      }else {//代表
        sql = 'select * from dictionary where dictID = "LY" AND flag = 1 AND description LIKE "%代表%" order by IFNULL(orderNum, 9999) ASC';
      }
      let dictionary = await this.model('dictionary').query(sql);
      let tree = [];
      let data = {};
      for (let i in dictionary) {
        data[dictionary[i]['dictValue']] = dictionary[i];
      }
      for (let j in dictionary) {
        let bval = dictionary[j];
        let dataP = data[bval['parentValue']];
        if (dataP) {
          (!dataP.children) && (dataP.children = []);
          dataP.children.push(bval);
        } else {
          tree.push(bval);
        }
      }
      return this.success(tree);
    }
  }
};
