const Base = require('./base.js');
const fs = require('fs');
module.exports = class extends Base {
  /**
   * showdoc
   * @catalog 查重
   * @title 信访人查重
   * @description 信访人查重接口
   * @method post
   * @url http://127.0.0.1:8360/duplicateCheck/personDuplicateCheck
   * @param name 选填 string 姓名
   * @param IDNumber 选填 string 身份证号
   * @return {"errno": 0, "errmsg":"", "data":""} datatype 来区分1期2期数据,1为一期,2为二期
   */
  async personDuplicateCheckAction() {
    const param = this.post();
    param.page = param.page === undefined ? 1 : param.page;
    param.pageSize = param.pageSize === undefined ? 10 : param.pageSize;
    let whereParam = {};
    if ((param.IDNumber && param.name) || (param.IDNumber && !param.name)) {
      whereParam.IDNumber = param.IDNumber;
    } else if (param.name && !param.IDNumber) {
      if (param.name.length < 2) {
        return this.fail(1000, 'name should be length more 2');
      }
      whereParam.name = ['like', '%' + param.name + '%'];
    } else {
      return this.fail(1002, '请传需要查询人员的信息');
    }
    let res = await this.model('v_total_person').page(param.page, param.pageSize).where(whereParam).countSelect();
    return this.success(res);
  }

  /**
   * showdoc
   * @catalog 查重
   * @title 事项查重
   * @description 事项查重接口
   * @method post
   * @url http://127.0.0.1:8360/duplicateCheck/matterDuplicateCheck
   * @param personID 选填 string  信访人id
   * @param datatype 非必填 int 默认2 2期新数据 如果传1，则查1期老数据
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  async matterDuplicateCheckAction() {
    const param = this.post();

    param.datatype = param.datatype === undefined ? 2 : param.datatype;
    let res;
    if (param.datatype === 2) {
      res = await this.model('matter').alias('m').field('m.*').join(['activity as a on a.id=m.activityID', 'person_activity as pa on pa.activityID=a.id']).where('pa.personID=' + param.personID).page(param.page, param.pageSize).countSelect();
      if (res.data.length >= 1) {
        for (let count = 0; count < res.data.length; count++) {
          res.data[count].addTime = res.data[count].activity.createTime;
          const createAccount = res.data[count].activity.createAccount;
          const userinfo = await this.model('sys_user').where({user_name: createAccount}).select();
          let orgName = '';
          if (userinfo.length === 1) {
            const orgInfo = await this.model('sys_organization').where({id: userinfo[0].orgID}).select();
            if (orgInfo.length === 1) {
              orgName = orgInfo[0].orgName;
            }
          }
          res.data[count].addUnit = orgName;
          res.data[count].addType = getAddType(res.data[count].activity.registerType);
          // res.data[count].addUnit = res.data[count].AA020W;
          // res.data[count].addType = res.data[count].AA0214.indexOf('信') !== -1 ? '信' : '访';
        }
      }
    }
    if (param.datatype === 1) {
      res = await this.model('AA02').field('AA02.ID,CONCAT("关于",(select ZA0101 from aa01 where `ZA0100` = "' + param.personID + '"),IFNULL((SELECT  DI.DESCRIPTION AS NAME FROM GS_DICTITEM_old DI WHERE DI.FLAG = 1 AND DI.DICTID = \'FY\'  and DI.DICTVALUE = AA020A),"其他问题"),"的信访事项")  xfName,' +
        '1 as datatype,' +
        'AA02.AA0214,\n' +
        '(SELECT  DI.DESCRIPTION AS NAME FROM GS_DICTITEM_old DI WHERE DI.FLAG = 1 AND DI.DICTID = \'FX\'  and DI.DICTVALUE = AA0203) AA0203,\n' +
        'AA02.AA0206,\n' +
        '(SELECT  DI.DESCRIPTION AS NAME FROM GS_DICTITEM_old DI WHERE DI.FLAG = 1 AND DI.DICTID = \'MD\'  and DI.DICTVALUE = AA0209) AA0209,\n' +
        '(SELECT  DI.DESCRIPTION AS NAME FROM GS_DICTITEM_old DI WHERE DI.FLAG = 1 AND DI.DICTID = \'FY\'  and DI.DICTVALUE = AA020A) AA020A,\n' +
        '(SELECT  DI.DESCRIPTION AS NAME FROM GS_DICTITEM_old DI WHERE DI.FLAG = 1 AND DI.DICTID = \'GK\'  and DI.DICTVALUE = AA020M) AA020M, \n' +
        '(SELECT  DI.DESCRIPTION AS NAME FROM GS_DICTITEM_old DI WHERE DI.FLAG = 1 AND DI.DICTID = \'GK\'  and DI.DICTVALUE = AA020N) AA020N,\n' +
        'AA02.AA0228,\n' +
        'AA02.AA020B,\n' +
        '(SELECT  DI.DESCRIPTION AS NAME FROM GS_DICTITEM_old DI WHERE DI.FLAG = 1 AND DI.DICTID = \'SS\'  and DI.DICTVALUE = AA020C) AA020C,\n' +
        'AA02.AA020G,\n' +
        'AA02.AA0200,\n' +
        'AA02.AA020O,\n' +
        'AA02.AA020Y,\n' +
        'AA02.AA020W,\n' +
        '(SELECT  DI.DESCRIPTION AS NAME FROM GS_DICTITEM_old DI WHERE DI.FLAG = 1 AND DI.DICTID = \'LX\'  and DI.DICTVALUE = AA0208) AA0208').where({ZA0100: param.personID}).page(param.page, param.pageSize).countSelect();

      if (res.data.length >= 1) {
        for (let count = 0; count < res.data.length; count++) {
          const matterID = res.data[count].ID;
          // console.log(matterID);
          const attachmentlist = await this.model('cp_xf_news').field('ID,TITLE,TYPES,PHOTO_EXT').where({
            AA02ID: matterID,
            TITLE: ['!=', null]
          }).order('TITLE').select();
          // ID,TITLE,TYPES,PHOTO_EXT
          //文件ID,文件标题,文件类型,文件保存下来的文件名称
          res.data[count].attachmentlist = attachmentlist;
          res.data[count].addTime = res.data[count].AA020Y;
          res.data[count].addUnit = res.data[count].AA020W;
          res.data[count].addType = getAddType(res.data[count].AA0214);
        }
      }
    }
    // AA02.AA0214	信访标识
    // AA02.AA0203	来访类型	FX
    // AA02.AA0206	人数
    // AA02.AA0204
    // AA02.AA0207
    // AA02.AA0217
    // AA02.AA0216
    // AA02.AA022D
    // AA02.AA0209	来访目的	MD
    // AA02.AA020A	反映问题分类	FY
    // AA02.AA021N
    // AA02.AA020M	归口单位	GK
    // AA02.AA020N	最后处理机关	GK
    // AA02.AA020D
    // AA02.AA020E
    // AA02.AA020F
    // AA02.AA0228	申诉理由
    // AA02.AA020B	法律文书号
    // AA02.AA020C	诉讼程序阶段	SS
    // AA02.AA020H
    // AA02.AA021T
    // AA02.AA020G	来访内容摘要
    // AA02.AA0200	案件编号
    // AA02.AA020O	登记人
    // AA02.AA020Y	登记时间
    // AA02.AA020W	登记单位
    // AA02.AA021K
    // AA02.AA0208	来访类型	LX
    // AA02.AA020L	转交去向
    // AA02.AA022C	登记日期
    return this.success(res);
  }

  /**
   * showdoc
   * @catalog 查重
   * @title 家庭成员查重
   * @description 家庭成员查重接口
   * @method post
   * @url http://127.0.0.1:8360/duplicateCheck/familyDuplicateCheck
   * @param IDcard 必填 string  家庭成员身份证
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  async familyDuplicateCheckAction() {
    const param = this.post();
    let res = [];
    //根据身份证查看本人是否是首访人
    let person = await this.model('person').where({IDNumber: param.IDcard}).find();
    if (!think.isEmpty(person)) {
      res.push(person);
    }
    let family = await this.model('family').where({IDcard: param.IDcard}).select();
    if (family.length > 0) {
      for (let i = 0; i < family.length; i++) {
        let newPerson = await this.model('person').where({id: family[i].personID}).find();
        res.push(newPerson);
      }
    }
    return this.success(res);
  }

  /**
   * showdoc
   * @catalog 老系统文件下载
   * @title 老系统文件下载
   * @description 老系统文件下载接口
   * @method post
   * @url http://127.0.0.1:8360/duplicateCheck/downloadOldAttch
   * @param ID 必填 string  文件ID
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  async downloadOldAttchAction() {
    const downloadPath = '/www/static/image/';
    const urlPrePath = '/static/image/';
    const param = this.post();
    const attachment = await this.model('cp_xf_news').field('ID,TITLE,TYPES,PHOTO_EXT,PHOTO').where({ID: param.ID}).select();
    if (attachment.length === 1) {
      if (attachment[0].PHOTO !== undefined) {
        const originBuffer = attachment[0].PHOTO;
        if (Buffer.isBuffer(originBuffer)) {
          // 生成图片2(把buffer写入到图片文件)
          const filepath = downloadPath + attachment[0].PHOTO_EXT;

          fs.writeFileSync(think.ROOT_PATH + filepath, originBuffer);
          attachment[0].url = urlPrePath + attachment[0].PHOTO_EXT;
          attachment[0].PHOTO = '';
        } else {
          attachment[0].url = '';
          attachment[0].PHOTO = '';
        }
        return this.success(attachment[0]);
      }
    } else {
      return this.fail();
    }
  }
};

//获取登记类型，统一
function getAddType(addType) {
  if (addType.indexOf('信') !== -1) {
    return '信';
  }
  if (addType.indexOf('访') !== -1) {
    return '访';
  }
  if (addType.indexOf('网') !== -1) {
    return '网';
  }
  if (addType.indexOf('电') !== -1) {
    return '电';
  }
}

// 视图
// create view v_total_person as
// (select id,
//   name,
//   sex,
//   sexID,
//   birthday,
//   IDType,
//   IDTypeID,
//   IDNumber,
//   identity,
//   identityID,
//   nationality,
//   nationalityID,
//   nation,
//   nationID,
//   idCardRegion,
//   idCardRegionID,
//   idCardAddress,
//   domicile,
//   domicileID,
//   addressRegion,
//   addressRegionID,
//   address,
//   political,
//   politicalID,
//   education,
//   educationID,
//   professionID,
//   profession,
//   company,
//   mobilePhone,
//   telephone,
//   weChat,
//   qq,
//   postCode,
//   email,
//   postalRegion,
//   postalRegionID,
//   postal,
//   remark,
//   isRepresent,
//   isPoor,
//   isEXserviceman,
//   isFocusGroup,
//   isFocusPerson,
//   isNormal,
//   createTime,
//   createPerson,
//   createAccount,
//   unit,
//   position,
//   grade,
//   due,
//   zone,
//   isAnonymous,
//   identification,
//   2 as datatype
// from person)
// union
// (select
// ZA0100 as id,
//   ZA0101 as name,
//   '' as sex,
//   '' as sexID,
//   '' as birthday,
//   '居民身份证' as IDType,
//   '001' as IDTypeID,
//   AA0177 as IDNumber,
//   '' as identity,
//   '' as identityID,
//   '' as nationality,
//   '' as nationalityID,
//   '' as nation,
//   '' as nationID,
//   '' as idCardRegion,
//   '' as idCardRegionID,
//   '' as idCardAddress,
//   '' as domicile,
//   '' as domicileID,
//   AA0104 as addressRegion,
//   '' as addressRegionID,
//   AA0109 as address,
//   '' as political,
//   '' as politicalID,
//   '' as education,
//   '' as educationID,
//   '' as professionID,
//   '' as profession,
//   '' as company,
//   AA0106 as mobilePhone,
//   '' as telephone,
//   '' as weChat,
//   '' as qq,
//   '' as postCode,
//   '' as email,
//   '' as postalRegion,
//   '' as postalRegionID,
//   '' as postal,
//   '' as remark,
//   '' as isRepresent,
//   '' as isPoor,
//   '' as isEXserviceman,
//   '' as isFocusGroup,
//   '' as isFocusPerson,
//   '' as isNormal,
//   '' as createTime,
//   '' as createPerson,
//   '' as createAccount,
//   '' as unit,
//   '' as position,
//   '' as grade,
//   '' as due,
//   '' as zone,
//   '' as isAnonymous,
//   '' as identification,
//   1 as datatype
// from aa01 where ZA0100 in (select ZA0100 from aa02 where (aa02.AA020P is null or aa02.AA020P != 'fianlCase')
// AND aa02.AA0214 IS NOT NULL AND ( aa02.AA021K='来访' or aa02.AA021K='来信' ) ))
