const Base = require('./base.js');
const moment = require('moment');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  // 新增或者修改终结库
  async addAction(){
    let data = this.post();
    //传id是更新，不传是插入
    let update = {
      "personName":data.personName,
      "personCard":(typeof data.personName === 'undefined' || data.personName === "") ? "" : data.personCard,
      "region":data.region,
      "regionID":data.regionID,
      "address":(typeof data.personName === 'undefined' || data.personName === "") ? "" : data.address,
      "endingOrg":data.endingOrg,
      "endingOrgID":(typeof data.personName === 'undefined' || data.personName === null) ? "" : data.endingOrgID,
      "contentClassify":data.contentClassify,
      "contentClassifyID":data.contentClassifyID,
      "content":(typeof data.content === 'undefined' || data.content === null) ? "" : data.content,
      "endingTime":moment(data.endingTime).format('YYYY-MM-DD')
    };
    if (data.hasOwnProperty('id') && data.id !== "" && data.id !== null){
      let back = await this.model('ending_case').where({"id":data.id}).update(update);
      return this.success(back);
    }else {
      let back = await this.model('ending_case').add(update);
      return this.success(back);
    }
  }
  // 终结案件列表 带搜索
  /**
   * showdoc
   * @catalog 终结案件
   * @title 终结案件查询
   * @description 终结案件查询接口
   * @method post
   * @url http://127.0.0.1:8360/endingCase/select
   * @param page 必选 int
   * @param limit 必选 int
   * @param personName 可选 string 人员姓名
   * @param contentClassifyID 可选 string 问题分类id
   * @param endingOrg 可选 string 终结单位
   * @param startTime 可选 string 终结开始时间YYYY-MM-DD
   * @param endTime 可选 string 终结结束时间YYYY-MM-DD
   * @return {"errno": 0, "errmsg":""}
   */
  async selectAction(){
    let data = this.post();
    let where = {
      "personName":(typeof data.personName === 'undefined' || data.personName === "") ? ["!=",null] : data.personName,
    };
    if (data.hasOwnProperty("contentClassifyID") && data.contentClassifyID !== "" && data.contentClassifyID !== null){
      where['contentClassifyID'] = ['like',[data.contentClassifyID + '%']]
    }
    if (data.hasOwnProperty("endingOrg") && data.endingOrg !== "" && data.endingOrg !== null){
      where['endingOrg'] = ['like',['%' + data.endingOrg + '%']]
    }
    if (data.hasOwnProperty("startTime") && data.startTime !== "" && data.startTime !== null){
      where['endingTime'] = ['>=',moment(data.startTime).format('YYYY-MM-DD')]
    }
    if (data.hasOwnProperty("endTime") && data.endTime !== "" && data.endTime !== null){
      where['ENDINGTime'] = ['<',moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    }
    let back = await this.model('ending_case').where(where).order('endingTime DESC').page(data.page, data.limit).countSelect();
    return this.success(back)
  }
  // 删除终结案件
  async deleteAction(){
    let data = this.post();
    let back = await this.model('ending_case').where({"id":data.id}).delete();
    return this.success(back)
  }
  // 终结案件详情
  async detailAction(){
    let data = this.post();
    let back = await this.model('ending_case').where({"id":data.id}).find();
    return this.success(back)
  }
};
