'use strict';
// const Base = require('../base.js');
/**
 * 提供工作流模板设计的URL接口
 * @class flow.controller.proc
 */

const Base = require('./../base.js');
const moment = require('moment');

module.exports = class extends Base {

  /**
   * showdoc
   * @catalog 流程信息
   * @title 流程信息列表
   * @description 流程信息列表
   * @method post
   * @url /proc/list
   * @param page 必选 int 第几页
   * @param limit 必选 int 每页多少条数据
   * @param c_name 可选 string 名称搜索条件
   * @return {
   * "errno": 0,
   * "errmsg":"",
   * "data":{
   * "count": 1,
   *   "totalPages": 1,
   *   "pageSize": 1,
   *   "currentPage": 1,
   *   "data": [
   *       {
   *           "id": 10,
   *           "c_name": "VIP申请",
   *           "c_desc": "VIP客户的审核流程",
   *           "c_type": 8,
   *           "c_class": "flow/task",
   *           "c_no_format": "",
   *           "c_way_create": 1,
   *           "c_time_from": "2020-06-18 08:00:00",
   *           "c_time_to": "2099-12-31 00:00:00",
   *           "c_can_terminate": 1,
   *           "c_can_suspend": 1,
   *          "c_status": 0,
   *           "c_user": 1,
   *           "c_time": "2017-01-01 22:22:29",
   *           "c_memo": "demo",
   *           "c_group": 2,
   *           "c_map": "{states:{rect1:{type:'start', text:{text:'开始'}, attr:{x:660, y:212, width:50, height:50}, data_id:18, props:{}}, rect2:{type:'state', text:{text:'递交申请'}, attr:{x:247, y:119, width:100, height:50}, data_id:19, props:{}}, rect3:{type:'state', text:{text:'主管审核'}, attr:{x:246, y:217, width:100, height:50}, data_id:20, props:{}}, rect4:{type:'state', text:{text:'经理审核'}, attr:{x:249, y:321, width:100, height:50}, data_id:21, props:{}}, rect5:{type:'task', text:{text:'财务审核'}, attr:{x:248, y:429, width:100, height:50}, data_id:22, props:{}}, rect6:{type:'end', text:{text:'结束6'}, attr:{x:273, y:524, width:50, height:50}, data_id:24, props:{}}, rect7:{type:'state', text:{text:'主管驳回'}, attr:{x:378, y:218, width:100, height:50}, data_id:23, props:{}}, rect8:{type:'state', text:{text:'经理驳回'}, attr:{x:384, y:327, width:100, height:50}, data_id:25, props:{}}, rect9:{type:'start', text:{text:'开始18'}, attr:{x:23, y:116, width:50, height:50}, data_id:27, props:{}}, rect10:{type:'state', text:{text:'财务驳回'}, attr:{x:390, y:435, width:100, height:50}, data_id:26, props:{}}}, paths:{path11:{from:'rect1', to:'rect2', dots:[], text:{text:'TO 递交申请'}, textPos:{x:0, y:-10}, data_id:765, props:{}}, path12:{from:'rect2', to:'rect3', dots:[], text:{text:'TO 主管审核'}, textPos:{x:0, y:-10}, data_id:766, props:{}}, path13:{from:'rect3', to:'rect4', dots:[], text:{text:'TO 经理审核'}, textPos:{x:0, y:-10}, data_id:767, props:{}}, path14:{from:'rect4', to:'rect5', dots:[], text:{text:'TO 财务审核'}, textPos:{x:0, y:-10}, data_id:768, props:{}}, path15:{from:'rect5', to:'rect6', dots:[], text:{text:'TO 结束'}, textPos:{x:0, y:-10}, data_id:769, props:{}}, path16:{from:'rect2', to:'rect7', dots:[], text:{text:'TO 驳回申请'}, textPos:{x:0, y:-10}, data_id:770, props:{}}, path17:{from:'rect7', to:'rect1', dots:[], text:{text:'TO 开始'}, textPos:{x:0, y:-10}, data_id:771, props:{}}, path18:{from:'rect3', to:'rect8', dots:[], text:{text:'TO 经理驳回'}, textPos:{x:0, y:-10}, data_id:772, props:{}}, path19:{from:'rect4', to:'rect10', dots:[], text:{text:'TO 财务驳回'}, textPos:{x:0, y:-10}, data_id:773, props:{}}, path20:{from:'rect10', to:'rect1', dots:[], text:{text:'TO 开始'}, textPos:{x:0, y:-10}, data_id:774, props:{}}, path21:{from:'rect8', to:'rect1', dots:[], text:{text:'TO 开始'}, textPos:{x:0, y:-10}, data_id:775, props:{}}}, props:{props:{}}}",
   *           "c_link_model": "demo/customer_appr",
   *           "c_link_type": "t_customer",
   *           "c_act_start": 18
   *       }
   *   ]
   * }
   * }
   */
  async listAction() {
    const data = this.post();
    const c_name = data.c_name == undefined ? '' : data.c_name;

    const back = await this.model('fw_proc').page(data.page, data.limit).order('id DESC').where({
      c_name: ['like', '%' + c_name + '%'],
      c_status: 0
    }).countSelect();// 时间倒序
    this.success(back);
  }

  /**
   * showdoc
   * @catalog 流程信息
   * @title 流程信息新增
   * @description 流程信息新增
   * @method post
   * @url /proc/add
   * @param c_name 必选 string 流程名称
   * @param c_desc 必选 string 流程描述
   * @param c_type 必选 string 流程类型 1.常规类型 2.审核类型 8.状态流转
   * @param c_class 必选 string 实现类
   * @param c_time_from 必选 string 开始启用时间 2020-01-01
   * @param c_time_to 必选 string 结束启用时间 2020-12-31
   * @param c_user 必选 string 创建者ID
   * @param c_memo 必选 string 流程备注
   * @return {
   * "errno": 0,
   * "errmsg":"",
   * "data":{
   *     "id": 22
   *   ]
   * }
   * }
   */
  async addAction() {
    const data = this.post();
    const addData = {
      id: 0,
      //名称
      c_name: data.c_name || '',
      //描述
      c_desc: data.c_desc || '',
      //类型 1.常规类型 2.审核类型 8.状态流转
      c_type: data.c_type || 1,
      //实现类
      c_class: data.c_class || '',
      //编号格式
      c_no_format: data.c_no_format || '',
      //创建方式 1手动 2自动 9自定义
      c_way_create: data.c_way_create || 1,
      //有效期从
      c_time_from: data.c_time_from || moment().format('YYYY-MM-DD'),
      //有效期到
      c_time_to: data.c_time_to || '2099-12-31',
      c_status: 0,
      //创建者ID
      c_user: data.c_user || 1,
      //创建时间
      c_time: moment().format('YYYY-MM-DD HH:mm:ss'),
      //备注
      c_memo: data.c_memo,
      c_group: 2
    };
    if (think.isEmpty(data.id)) {
      const res = await this.model('fw_proc').add(addData);
      if (res) {
        this.success({id: res});
      } else {
        this.fail();
      }
    }
  }

  /**
   * showdoc
   * @catalog 流程信息
   * @title 流程信息修改
   * @description 流程信息修改
   * @method post
   * @url /proc/modify
   * @param id 必选 int id
   * @param c_name 必选 string 流程名称
   * @param c_desc 必选 string 流程描述
   * @param c_type 必选 string 流程类型 1.常规类型 2.审核类型 8.状态流转
   * @param c_class 必选 string 实现类
   * @param c_time_from 必选 string 开始启用时间 2020-01-01
   * @param c_time_to 必选 string 结束启用时间 2020-12-31
   * @param c_user 必选 string 创建者ID
   * @param c_memo 必选 string 流程备注
   * @return {
   * "errno": 0,
   * "errmsg":""
   * }
   * }
   */
  async modifyAction() {
    const data = this.post();
    const updateData = {
      // id: data.id,
      //名称
      c_name: data.c_name || '',
      //描述
      c_desc: data.c_desc || '',
      //类型 1.常规类型 2.审核类型 8.状态流转
      c_type: data.c_type || 1,
      //实现类
      c_class: data.c_class || '',
      //编号格式
      c_no_format: data.c_no_format || '',
      //创建方式 1手动 2自动 9自定义
      c_way_create: data.c_way_create || 1,
      //有效期从
      c_time_from: data.c_time_from || moment().format('YYYY-MM-DD'),
      //有效期到
      c_time_to: data.c_time_to || '2099-12-31',
      c_status: 0,
      //创建者ID
      c_user: data.c_user || 1,
      //创建时间
      c_time: moment().format('YYYY-MM-DD HH:mm:ss'),
      //备注
      c_memo: data.c_memo,
      c_group: 2
    };
    if (!think.isEmpty(data.id)) {
      const res = await this.model('fw_proc').where({id: data.id}).update(updateData);
      if (res) {
        this.success();
      } else {
        this.fail();
      }
    }
  }

  /**
   * showdoc
   * @catalog 流程信息
   * @title 流程删除
   * @description 流程删除
   * @method post
   * @url /proc/del
   * @param id 必选 int
   * @return {
   * "errno": 0,
   * "errmsg":""
   * }
   */
  async delAction() {
    const get = this.post();
    const id = get.id;
    const where = {id: id};
    const data = {c_status: -1};
    const res = await this.model('fw_proc').where(where).update(data);
    if (res) {
      this.success();
    } else {
      this.fail();
    }
  }

  //1.流程指派列表
  /**
   * showdoc
   * @catalog 流程指派信息
   * @title 流程指派信息列表
   * @description 流程指派信息列表
   * @method post
   * @url /proc/assignList
   * @param page 必选 int 第几页
   * @param limit 必选 int 每页多少条数据
   * @param procID 必选 int 主流程ID
   * @return {
   * "errno": 0,
   * "errmsg":"",
   * "data":{
   * "count": 1,
   *   "totalPages": 1,
   *   "pageSize": 1,
   *   "currentPage": 1,
   *   "data": [
   *       {
   *           "id": 10,
   *           "c_proc": 10, //主流程ID
   *           "c_type": 1, 指派类别 1所有人2部门3角色4团队5用户6发起人9自定义
   *           "c_link": 8, 指派类别对应人员的ID
   *           "c_is_begin": 1,是否能发起 0不能1能
   *           "c_is_suspend": 1,是否能挂起 0不能1能
   *           "c_is_terminate": 1,是否能终止 0不能1能
   *           "c_is_track": 1,是否能轨迹 0不能1能
   *           "c_memo": "备注" 备注
   *       }
   *   ]
   * }
   * }
   */
  async assignListAction() {
    const data = this.post();

    const back = await this.model('fw_proc_assign').page(data.page, data.limit).order('id').where({
      c_proc: data.procID
    }).countSelect();// 时间倒序
    this.success(back);
  }

  //2.流程指派新增
  /**
   * showdoc
   * @catalog 流程指派信息
   * @title 流程指派增加
   * @description 流程指派增加
   * @method post
   * @url /proc/assignAdd
   * @param c_proc 必选 int 主流程ID
   * @param c_type 必选 int 指派类别 1所有人2部门3角色4团队5用户6发起人9自定义
   * @param c_link 必选 int 指派类别对应人员的ID
   * @param c_is_begin 必选 int 是否能发起 0不能1能
   * @param c_is_suspend 必选 int 是否能挂起 0不能1能
   * @param c_is_terminate 必选 int 是否能终止 0不能1能
   * @param c_is_track 必选 int 是否能轨迹 0不能1能
   * @param c_memo 必选 string 备注
   * @return {
   * "errno": 0,
   * "errmsg":""
   * }
   * }
   */
  async assignAddAction() {
    const addData = this.post();
    if (think.isEmpty(addData.id)) {
      const res = await this.model('fw_proc_assign').add(addData);
      if (res) {
        this.success({id: res});
      } else {
        this.fail();
      }
    }
  }
  /**
   * showdoc
   * @catalog 流程指派信息
   * @title 流程指派修改
   * @description 流程指派修改
   * @method post
   * @url /proc/assignModify
   * @param id 必选 string 流程模板ID
   * @param c_type 必选 int 指派类别 1所有人2部门3角色4团队5用户6发起人9自定义
   * @param c_link 必选 int 指派类别对应人员的ID
   * @param c_is_begin 必选 int 是否能发起 0不能1能
   * @param c_is_suspend 必选 int 是否能挂起 0不能1能
   * @param c_is_terminate 必选 int 是否能终止 0不能1能
   * @param c_is_track 必选 int 是否能轨迹 0不能1能
   * @param c_memo 必选 string 备注
   * @return {
   * "errno": 0,
   * "errmsg":""
   * }
   * }
   */
  //3.流程指派修改
  async assignModifyAction() {
    const updateData = this.post();
    if (!think.isEmpty(updateData.id)) {
      const res = await this.model('fw_proc_assign').where({id: updateData.id}).update(updateData);
      if (res) {
        this.success();
      } else {
        this.fail();
      }
    }
  }
  /**
   * showdoc
   * @catalog 流程节点信息
   * @title 流程指派删除
   * @description 流程指派删除
   * @method post
   * @url /proc/assignDel
   * @param id 必选 int
   * @return {
   * "errno": 0,
   * "errmsg":""
   * }
   */
  //4.流程指派删除
  async assignDelAction() {
    const get = this.post();
    const id = get.id;
    const where = {id: id};
    const res = await this.model('fw_act_path').where(where).delete();
    if (res) {
      this.success();
    } else {
      this.fail();
    }
  }

  /**
   * showdoc
   * @catalog 流程节点信息
   * @title 流程人员类别列表
   * @description 流程人员类别列表
   * @method post
   * @url /proc/c_typeList
   * @return {
   * "errno": 0,
   * "errmsg":""
   * “data”:[
   *   {
   *    id:1, id值
   *    value:'所有人' 值
   *   }
   * ]
   * }
   */
  //人员类别列表 1所有人2部门3角色4团队5用户6发起人9自定义
  async c_typeListAction() {
    const data = [
      {id:1,value:'所有人'},
      {id:2,value:'部门'},
      {id:3,value:'角色'},
      // {id:4,value:'团队'},
      {id:5,value:'用户'},
      // {id:6,value:'发起人'},
      // {id:9,value:'自定义'}
    ];
    this.success(data);
  }


  /**
   * showdoc
   * @catalog 流程节点信息
   * @title 流程人员类别列表
   * @description 流程人员类别列表
   * @method post
   * @url /proc/c_typeList
   * @return {
   * "errno": 0,
   * "errmsg":""
   * “data”:[
   *   {
   *    id:1, id值
   *    value:'所有人' 值
   *   }
   * ]
   * }
   */
  // async memberListAction() {
  //   const data = this.post();
  //   // switch (data.c_type)
  //
  //
  //   this.success(data);
  // }

  /**
   * 图形化设置流程模板， 调用： /flow/proc/desing?id=xxx
   * @method  design
   * @return {promise}
   */
  async designAction() {
    let module = cmpage.service('cmpage/module');
    let parms = await module.getModuleByName('FwProcList');
    parms.parmsUrl = JSON.stringify(this.get());
    parms.editID = this.get('id');
    parms.user = await this.session('user');
    //cmpage.debug(page);
    let pageModel = cmpage.service('flow/proc_list');
    pageModel.mod = parms;
    await pageModel.initPage();
    pageModel.modEdits = await module.getModuleEdit(parms.id);

    let procEditHtml = await pageModel.htmlGetEdit();
    this.assign('procEditHtml', procEditHtml);
    this.assign('parms', pageModel.mod);

    let parmsAct = await module.getModuleByName('FwAct');
    parmsAct.parmsUrl = '{}';
    parmsAct.editID = 0;
    parmsAct.user = parms.user;
    let pageAct = cmpage.service('cmpage/page');
    pageAct.mod = parmsAct;
    await pageAct.initPage();
    pageAct.modEdits = await module.getModuleEdit(parmsAct.id);

    let actEditHtml = await pageAct.htmlGetEdit();
    //cmpage.debug(actEditHtml,'flow.controller.proc - actEditHtml');
    this.assign('actEditHtml', '<tbody>' + actEditHtml + '</tbody>');

    let flowMap = await pageModel.getFlowMap(parms.editID);
    this.assign('flowMap', flowMap);

    return this.display();
  }

  /**
   * 取流程模板的图形信息 调用： /flow/proc/flow_map?proc_id=xxx
   * @method  flowMap
   * @return {promise}
   */
  async flow_mapAction() {
    let procID = this.get('proc_id');
    let flowMap = await cmpage.service('flow/proc_list').getFlowMap(procID);
    this.assign('flowMap', flowMap);
    this.assign('procID', procID);

    return this.display();
  }

  /**
   * 保存流程模板的图形信息，如果某个节点和路径的data_id==0，则增加相应记录 POST调用： /flow/proc/save_map
   * @method  saveMap
   * @return {json}
   */
  async save_mapAction() {
    let parms = this.post();
    await cmpage.service('flow/proc_list').saveFlowMap(parms);

    return this.json({
      statusCode: 200,
      message: '保存图形成功!'
    });
  }

  async clear_cacheAction() {
    let ret = {
      statusCode: 200,
      message: '已成功清除了流程模板的缓存!',
      tabid: '',
      data: {}
    };

    await cmpage.service('flow/proc').clearCache();

    return this.json(ret);
  }

};
