/**
 * 提供工作流引擎服务接口
 * @class flow.controller.service
 */
// 测试

const Base = require('./../base.js');
const moment = require('moment');
// const sleepTime = require('sleep-promise');

module.exports = class extends Base {
  /**
   * showdoc
   * @catalog 流程引擎服务
   * @title 流程实例初始化
   * @description 初始化一个新的流程实例
   * @method post
   * @url /flow/service/initTask
   * @param procId 可选 int 流程ID 默认为1
   * @param userId 必选 int 用户ID
   * @param regionLevel 必选 string 地区类别 省级 市级 县级
   * @param deptID 必选 int 创建部门id
   * @param deptName 必选 int 创建部门名称
   * @param dealType_pre 必选 string 预办理方式 接谈 存件 存信 自办 交办  转交（须反馈的转送） 转送（无须反馈的转送） 域外（行政区域外转送） 修改
   * @param regionLevel_pre 必选 string 预转送行政级别 省级 市级 县级
   * @param deptID_pre 必选 string 预流转部门ID
   * @param deptName_pre 必选 string 预流转部门名称
   */
  async initTaskAction() {
    const data = this.post();
    if (data.regionLevel === '大会' && (think.isEmpty(data.userId) || think.isEmpty(data.regionLevel) || think.isEmpty(data.deptID) || think.isEmpty(data.deptName))) {
      return this.fail();
    } else if (data.regionLevel !== '大会' && (think.isEmpty(data.userId) || think.isEmpty(data.regionLevel) || think.isEmpty(data.deptID) || think.isEmpty(data.deptName)
      || think.isEmpty(data.dealType_pre) || think.isEmpty(data.regionLevel_pre) || think.isEmpty(data.deptID_pre) || think.isEmpty(data.deptName_pre))) {
      return this.fail();
    } else {
      const procId = data.procId !== undefined ? data.procId : 1;
      const sql = 'select * from fw_act where id in ' +
        '(select  c_to from fw_act_path where c_from in ( SELECT id from fw_act where c_type = 3 and c_proc = ' + procId + ')) ' +
        'and regionLevel = \'' + data.regionLevel + '\'';
      const taskDetail = await this.model('fw_act_path').query(sql);
      if (taskDetail.length !== 1) {
        return this.fail();
      } else {
        const detail = taskDetail[0];
        const task = {
          c_proc: procId,
          actno: detail.id,
          businessID: detail.businessID,
          businessName: detail.businessName,
          c_status: 1,
          c_creater: data.userId,
          c_user: data.userId,
          regionLevel_create: data.regionLevel,
          deptID_create: data.deptID,
          deptName_create: data.deptName,
          regionLevel_now: data.regionLevel,
          deptID_now: data.deptID,
          deptName_now: data.deptName,
          dealType_pre: data.dealType_pre,
          regionLevel_pre: data.regionLevel_pre,
          deptID_pre: data.deptID_pre,
          deptName_pre: data.deptName_pre,
          deptType_now: detail.deptType,
          deptType_create: detail.deptType,
          charger: data.userId
        };
        const taskid = await this.model('fw_task').add(task);
        const taskAct = {
          c_task: taskid,
          actno: detail.id,
          c_type: detail.c_type,
          c_user: data.userId,
          businessID: detail.businessID,
          businessName: detail.businessName,
          regionLevel_now: data.regionLevel,
          deptID_now: data.deptID,
          deptName_now: data.deptName,
          deptType_now: detail.deptType,
          charger: data.userId
        };
        const actid = await this.model('fw_task_act').add(taskAct);
        return this.success({taskid: taskid, nextActid: actid});
      }
    }
  }

  /**
   * showdoc
   * @catalog 流程引擎服务
   * @title 流程实例进入下一步
   * @description 流程实例进入下一步
   * @method post
   * @url /flow/service/taskForward
   * @param taskId 必选 int 流程实例ID
   * @param businessId 必选 int 流程业务ID
   * @param userId 必选 int 用户ID
   * @param dealType_pre 可选 string 预办理方式 接谈 存件 存信 自办 交办  转交（须反馈的转送） 转送（无须反馈的转送） 域外（行政区域外转送）修改
   * @param regionLevel_pre 可选 string 预转送行政级别
   * @param deptID_pre 可选 string 预流转部门ID
   * @param deptName_pre 可选 string 预流转部门名称
   * @param charger 可选 string 指定信访负责人
   */
  async taskForwardAction() {
    const data = this.post();
    const taskModel = this.model('fw_task');
    const actModel = this.model('fw_task_act').db(taskModel.db());
    try {
      if (think.isEmpty(data.taskId) || think.isEmpty(data.userId)) {
        return this.fail();
      } else {
        let where = {};
        if (think.isEmpty(data.businessId)) {
          where = {
            id: data.taskId,
            c_status: 1
          };
        } else {
          where = {
            id: data.taskId,
            c_status: 1,
            businessID: data.businessId
          };
        }
        //事务开始
        await taskModel.startTrans();

        // 查询是否存在该实例，或实例是否已关闭
        // let taskDetail = await taskModel.lock(true).where(where).select();
        let taskDetail = await taskModel.lock(true).where(where).select();
        // const sleepPromise = sleepTime(20000);
        // // clock.tick(2000);
        // await sleepPromise;

        if (taskDetail.length !== 1) {
          //如果不存在该流程
          console.log('如果不存在该流程');
          await taskModel.rollback();
          return this.fail('请勿重复提交');
        } else {
          console.log('存在该流程');
          // 如果传了这四个值，则先更新主task表中的值
          if (!think.isEmpty(data.dealType_pre) || !think.isEmpty(data.regionLevel_pre) || !think.isEmpty(data.deptID_pre) || !think.isEmpty(data.deptName_pre) || !think.isEmpty(data.charger)) {
            let updateTaskData = {};
            if (!think.isEmpty(data.dealType_pre)) {
              updateTaskData.dealType_pre = data.dealType_pre;
            }
            if (!think.isEmpty(data.regionLevel_pre)) {
              updateTaskData.regionLevel_pre = data.regionLevel_pre;
            }
            if (!think.isEmpty(data.deptID_pre)) {
              updateTaskData.deptID_pre = data.deptID_pre;
            }
            if (!think.isEmpty(data.deptName_pre)) {
              updateTaskData.deptName_pre = data.deptName_pre;
            }
            if (!think.isEmpty(data.charger)) {
              updateTaskData.charger = data.charger;
            }
            await taskModel.where({id: data.taskId}).update(updateTaskData);
            taskDetail = await taskModel.where({id: data.taskId, c_status: 1}).select();
          }
          // 1.先确定是否能拿到唯一路由；
          // 1.1有且只有一条
          // 1.2如果有多条
          // 1.2.1 如果有关闭节点，
          // 1.如果是多条 含有关闭节点
          //
          // 1.1判断是职能部门 无须判断是否同级别
          // 本级处理方式转送 ——》 关闭
          // 本级处理方式非转送 ———》 不关闭
          //
          // 1.2判断是人大部门 无须判断是否同级别
          // 上级处理方式转送——》 关闭
          // 与登记单位同级别——》 关闭
          // 上级处理方式非转送 ———》 不关闭
          //
          // 1.5加上办理方式与行政级别能否过滤出一条
          // 2.再确定下步路由和本步路由行政级别上有没有变化，单位类别上有没有变化；
          // 2.1如果没变化，沿用之前的部门id与部门名称；
          // 2.2如果单位属性上发生变化
          // 2.2.1人大转职能
          // 2.2.2职能转人大
          // 3.3如果单位属性上没有发生变化
          // 3.3.1下发 调用 现存 办理部门与办理部门id
          // 3.3.2回报 调用 历史 办理部门与办理部门id

          let route;
          const routeSql = 'select * from fw_act where id in (' +
            'select c_to from fw_act_path where c_from in ' +
            '(select actno from (select actno from fw_task_act where c_task = ' +
            data.taskId +
            ' order by id desc LIMIT  1 ) a1 ))';

          const routeData = await actModel.query(routeSql);

          let ids = [];
          let deptTypes = [];
          let regionLevels = [];
          let c_types = [];
          let dealTypes = [];
          //把常用的值放入数组
          for (var value of routeData) {
            ids.push(value.id);
            deptTypes.push(value.deptType);
            regionLevels.push(value.regionLevel);
            c_types.push(value.c_type);
            if (!think.isEmpty(value.dealType)) {
              dealTypes.push(value.dealType);
            }
          }
          console.log(dealTypes);
          console.log(ids)
          if (ids.length === 0) {
            await taskModel.rollback();
            return this.fail();
          } else if (ids.length === 1) {
            //如果有且只有一条，那就选这条
            console.log("如果有且只有一条，那就选这条")
            route = routeData[0];
          } else {
            // 如果有多条，其中含有关闭节点
            // 2020-9-10 增加如果含有关闭节点或即将关闭的节点（类型为8）
            // if (c_types.indexOf(9) > -1 || c_types.indexOf(8) > -1) {
            if (c_types.indexOf(9) > -1) {
              //查找本级的办理方式
              //如果本机办理方式为转送，则关闭
              const levelNowDealtypeSql = 'SELECT dealType from fw_task_act LEFT JOIN fw_act on fw_task_act.actno = fw_act.id where fw_task_act.c_task = ' + data.taskId +
                ' and fw_task_act.regionLevel_now in (select regionLevel_now from fw_task where id = ' + data.taskId + ') ' +
                'and fw_act.dealType is not NULL and fw_act.dealType != "" order by fw_task_act.id desc limit 1';

              const dealtypedata = await actModel.query(levelNowDealtypeSql);
              // 1.1判断是职能部门 无须判断是否同级别
              // 本级处理方式转送 ——》 关闭
              // 本级处理方式非转送 ———》 不关闭
              if (taskDetail[0].deptType_now === '职能') {
                if (dealtypedata[0].dealType === '转送') {
                  route = routeData[c_types.indexOf(9)] || routeData[c_types.indexOf(8)];
                } else {
                  if (c_types.indexOf(9) > -1) {
                    routeData.splice(c_types.indexOf(9), 1);
                    c_types.splice(c_types.indexOf(9), 1);
                  }
                  if (c_types.indexOf(8) > -1) {
                    routeData.splice(c_types.indexOf(8), 1);
                    c_types.splice(c_types.indexOf(8), 1);
                  }
                  if (routeData.length === 1) {
                    route = routeData[0];
                  }
                }
              }
              // 1.2判断是人大部门 无须判断是否同级别
              // 上级处理方式转送——》 关闭
              // 与登记单位同级别——》 关闭
              // 上级处理方式非转送 ———》 不关闭
              if (taskDetail[0].deptType_now === '人大') {
                //如果登记与回报处理同一级别，则关闭
                if (taskDetail[0].regionLevel_create === taskDetail[0].regionLevel_now || (taskDetail[0].regionLevel_create === '安徽省人大常委会' && taskDetail[0].regionLevel_now === '省级')) {
                  route = routeData[c_types.indexOf(9)] || routeData[c_types.indexOf(8)];
                } else {
                  // 如果不是同一级别，判断上级单位的办理方式
                  let upperLevel = '';
                  if (taskDetail[0].regionLevel_now === '市级') {
                    upperLevel = '省级';
                  }
                  if (taskDetail[0].regionLevel_now === '县级') {
                    upperLevel = '市级';
                  }
                  const levelNowDealtypeSql = 'SELECT dealType from fw_task_act LEFT JOIN fw_act on fw_task_act.actno = fw_act.id where fw_task_act.c_task = ' + data.taskId +
                    ' and fw_task_act.regionLevel_now  = "' + upperLevel + '" ' +
                    'and fw_act.dealType is not NULL and fw_act.dealType != "" order by fw_task_act.id desc limit 1';
                  const dealtypedata = await actModel.query(levelNowDealtypeSql);
                  // 如果是转送（无须反馈）则关闭
                  // 如果不是转送（无须反馈）则不
                  if (dealtypedata[0].dealType === '转送') {
                    route = routeData[c_types.indexOf(9)] || routeData[c_types.indexOf(8)];
                  } else {
                    if (c_types.indexOf(9) > -1) {
                      routeData.splice(c_types.indexOf(9), 1);
                      c_types.splice(c_types.indexOf(9), 1);
                    }
                    if (c_types.indexOf(8) > -1) {
                      routeData.splice(c_types.indexOf(8), 1);
                      c_types.splice(c_types.indexOf(8), 1);
                    }
                    if (routeData.length === 1) {
                      route = routeData[0];
                    }
                  }
                }
              }
            } else {
              //如果办理方式为自办的情况下：
              //1.如果同一级别，就选择走关闭路由；
              //2.如果不是同一级别，就选择走向上回报路由；
              if (taskDetail[0].businessID === 37 && routeData.length >= 2) {
                console.log("所有自办的流程进入")
                if (taskDetail[0].regionLevel_now === '市级' || taskDetail[0].regionLevel_now === '县级') {
                  console.log("所有市级和县级自办的流程进入");
                  //如果同一级别，就选择走即将关闭路由；
                  if (taskDetail[0].regionLevel_create === taskDetail[0].regionLevel_now) {
                    console.log("所有市级和县级自己的自办的流程进入");
                    route = routeData[c_types.indexOf(8)];
                  }else {
                    // 如果不是同一级别，判断上级单位的办理方式
                    let upperLevel = '';
                    if (taskDetail[0].regionLevel_now === '市级') {
                      upperLevel = '省级';
                    }
                    if (taskDetail[0].regionLevel_now === '县级') {
                      upperLevel = '市级';
                    }
                    const levelNowDealtypeSql = 'SELECT dealType from fw_task_act LEFT JOIN fw_act on fw_task_act.actno = fw_act.id where fw_task_act.c_task = ' + data.taskId +
                      ' and fw_task_act.regionLevel_now  = "' + upperLevel + '" ' +
                      'and fw_act.dealType is not NULL and fw_act.dealType != "" order by fw_task_act.id desc limit 1';
                    const dealtypedata = await actModel.query(levelNowDealtypeSql);
                    // 如果是转送（无须反馈）则关闭
                    // 如果不是转送（无须反馈）则不
                    if (dealtypedata[0].dealType === '转送') {
                      console.log("所有市级和县级不是自办的流程进入");
                      //如果无须上报，就关闭流程
                      route = routeData[c_types.indexOf(8)];
                    }else{
                      console.log("所有市级和县级上级的自办的流程进入，且需要回报的流程");
                      route = routeData[c_types.indexOf(1)];
                    }
                  }
                }
              }
              //无关闭节点 且总路由大于1
              //如果属于办理方式的分支
              else if (dealTypes.length > 0) {
                console.log('办理方式的分支');
                if (dealTypes.indexOf(taskDetail[0].dealType_pre) !== -1) {
                  route = routeData[dealTypes.indexOf(taskDetail[0].dealType_pre)];
                } else if (routeData.length > dealTypes.length) {
                  routeData.forEach((val) => {
                    if (think.isEmpty(val.dealType)) {
                      route = val;
                    }
                  });
                }
              } else {
                console.log('行政级别的分支');
                route = routeData[regionLevels.indexOf(taskDetail[0].regionLevel_pre)];
              }
            }
          }
          if (route === undefined) {
            await taskModel.rollback();
            return this.fail();
          } else {
            //如果下一个路由为关闭 直接关闭
            //如果行政级别和单位类别都一致 沿用之前的部门id和部门名称 不用下一步部门
            let currentValue = 0;
            let nextValue = 0;
            switch (taskDetail[0].regionLevel_now) {
              case '大会':
                currentValue += 3;
                break;
              case '省级':
                currentValue += 3;
                break;
              case '市级':
                currentValue += 2;
                break;
              case '县级':
                currentValue += 1;
                break;
            }
            switch (route.regionLevel) {
              case '大会':
                nextValue += 3;
                break;
              case '省级':
                nextValue += 3;
                break;
              case '市级':
                nextValue += 2;
                break;
              case '县级':
                nextValue += 1;
                break;
            }
            switch (taskDetail[0].deptType_now) {
              case '人大':
                currentValue += 1;
                break;
              case '职能':
                currentValue += 0.5;
                break;
            }
            switch (route.deptType) {
              case '人大':
                nextValue += 1;
                break;
              case '职能':
                nextValue += 0.5;
                break;
            }
            let agent = '';
            let deptID;
            let deptName;
            let charger;
            if (taskDetail[0].deptType_now === '人大' && route.deptType === '职能') {
              agent = taskDetail[0].charger;
            }
            if (taskDetail[0].deptType_now === '职能' && route.deptType === '职能') {
              agent = taskDetail[0].agent;
            }


            if (route.c_type === 9 || route.c_type === 8) {
              //平级沿用
              deptID = taskDetail[0].deptID_now;
              deptName = taskDetail[0].deptName_now;
              charger = taskDetail[0].charger;
            } else {
              if (currentValue === nextValue) {
                //平级沿用
                deptID = taskDetail[0].deptID_now;
                deptName = taskDetail[0].deptName_now;
                // 如果charger传了就传charger，没传就沿用
                if (!think.isEmpty(data.charger)) {
                  charger = data.charger;
                } else {
                  if (taskDetail[0].charger !== '') {
                    charger = taskDetail[0].charger;
                  } else {
                    charger = data.userId;
                  }
                }
              }
              if (currentValue > nextValue) {
                //下放 用pre参数
                deptID = taskDetail[0].deptID_pre;
                deptName = taskDetail[0].deptName_pre;
                charger = '';
              }
              if (currentValue < nextValue) {
                //上报 参考历史值 遵循同级别本单位的负责人
                console.log(taskDetail[0]);
                let querylastDeptSql = '';
                if (taskDetail[0].regionLevel_now === '大会') {
                  querylastDeptSql = ' select  deptID_now,deptName_now,charger from fw_task_act where c_task = ' + data.taskId
                    // + ' and deptID_now != ' + taskDetail[0].deptID_now
                    // +' and regionLevel_now = "' + route.regionLevel
                    + ' and deptType_Now = "' + route.deptType
                    + '" ORDER BY id desc LIMIT 1';
                } else {
                  querylastDeptSql = ' select  deptID_now,deptName_now,charger from fw_task_act where c_task = ' + data.taskId
                    + ' and deptID_now != ' + taskDetail[0].deptID_now
                    + ' and regionLevel_now = "' + route.regionLevel + '" ORDER BY id desc LIMIT 1';
                }
                let deptData = await actModel.query(querylastDeptSql);

                if(deptData.length === 0) {

                  const tmpSql = ' select  charger,agent from fw_task_act where c_task = ' + data.taskId
                    + ' ORDER BY id desc LIMIT 1';
                  const actData = await actModel.query(tmpSql);
                  if (actData.length === 1 && actData[0].charger === actData[0].agent){
                    //如果是代办，regionLevel_now就不需要这个条件:最后一条详情记录中charger和agent相同
                    querylastDeptSql = ' select  deptID_now,deptName_now,charger from fw_task_act where c_task = ' + data.taskId
                      + ' and regionLevel_now = "' + route.regionLevel + '" ORDER BY id desc LIMIT 1';
                    deptData = await actModel.query(querylastDeptSql);
                  }
                }
                if (deptData.length === 1) {
                  deptID = deptData[0].deptID_now;
                  deptName = deptData[0].deptName_now;
                  charger = deptData[0].charger;
                } else {
                  await taskModel.rollback();
                  return this.fail();
                }
              }
            }
            if (deptID !== undefined && deptName !== undefined) {
              const task = {
                actno: route.id,
                businessID: route.businessID,
                businessName: route.businessName,
                // 考虑1和8两种情况
                c_status: route.c_type === 1 || route.c_type === 8 ? 1 : 2,
                c_user: data.userId,
                c_time: moment().format('YYYY-MM-DD HH:mm:ss'),
                regionLevel_now: route.regionLevel,
                deptID_now: deptID,
                deptName_now: deptName,
                deptType_now: route.deptType,
                charger: charger,
                agent: agent,
                isBack: 0
              };
              await taskModel.where({id: data.taskId}).update(task);
              // console.log(task);
              const taskAct = {
                c_task: data.taskId,
                actno: route.id,
                c_type: route.c_type,
                c_user: data.userId,
                businessID: route.businessID,
                businessName: route.businessName,
                regionLevel_now: route.regionLevel,
                deptID_now: deptID,
                deptName_now: deptName,
                deptType_now: route.deptType,
                charger: charger,
                agent: agent,
                isBack: 0
              };
              const actid = await actModel.add(taskAct);
              // console.log(taskAct);
              await taskModel.commit();
              return this.success({nextActid: actid});
            } else {
              await taskModel.rollback();
              return this.fail();
            }
          }
        }
      }
    } catch (e) {
      await taskModel.rollback();
      return this.fail();
    }
  }

  /**
   * showdoc
   * @catalog 流程引擎服务
   * @title 某单位某节点流程实例列表
   * @description 某单位某节点流程实例列表
   * @method post
   * @url /flow/service/tasklist
   * @param deptID 必选 int 部门id
   * @param businessID 必选 int 业务id
   * @param page 必选 int 第几页
   * @param limit 必选 int 每页多少条
   */
  async tasklistAction() {
    const data = this.post();
    if (think.isEmpty(data.deptID) || think.isEmpty(data.businessID) || think.isEmpty(data.page) || think.isEmpty(data.limit)) {
      return this.fail();
    } else {
      const listdata = await this.model('fw_task').where({
        deptID_now: data.deptID,
        businessID: data.businessID
      }).order('id DESC').page(data.page, data.limit).countSelect();
      return this.success(listdata);
    }
  }

  /**
   * 回退至前一个节点或前一个单位, GET调用：/flow/proc/backword?taskActID=xxx
   * @method  /flow/service/taskBackward
   * @param taskId 必选 int 流程实例ID
   * @param backtype 可选 int 1回退至上一个节点，2回退至上一个单位
   * @param userId 必选 int 用户ID
   * @return {json}  流程实例对象
   */
  async taskBackwardAction() {
    const data = this.post();
    if (think.isEmpty(data.taskId) || think.isEmpty(data.userId)) {
      return this.fail();
    }
    //不存在或者已经关闭的节点无法回退
    const taskdetail = await this.model('fw_task').where({id: data.taskId, c_status: 1}).select();
    if (taskdetail.length !== 1) {
      return this.fail();
    }
    //只存在一个流程节点的，也无法回退
    const taskActDetail = await this.model('fw_task_act').where({
      c_task: data.taskId
    }).order('id desc').select();
    if (taskActDetail.length === 1) {
      return this.fail();
    }
    const actno = taskdetail[0].actno;
    let lastindex = -1;
    for (let index = 0; index < taskActDetail.length; index += 1) {
      if (taskActDetail[index].actno === actno && taskActDetail[index].isBack === 0) {
        lastindex = index + 1;
        break;
      }
    }
    if (lastindex === -1 || taskActDetail[lastindex] === undefined) {
      return this.fail();
    }
    const detail = taskActDetail[lastindex];

    const task = {
      actno: detail.actno,
      businessID: detail.businessID,
      businessName: detail.businessName,
      c_user: data.userId,
      c_time: moment().format('YYYY-MM-DD HH:mm:ss'),
      regionLevel_now: detail.regionLevel_now,
      deptID_now: detail.deptID_now,
      deptName_now: detail.deptName_now,
      deptType_now: detail.deptType_now,
      charger: detail.charger,
      agent: detail.agent,
      isBack: 1
    };
    await this.model('fw_task').where({id: data.taskId}).update(task);
    const taskAct = {
      c_task: data.taskId,
      actno: detail.actno,
      c_type: detail.c_type,
      c_user: data.userId,
      businessID: detail.businessID,
      businessName: detail.businessName,
      regionLevel_now: detail.regionLevel_now,
      deptID_now: detail.deptID_now,
      deptName_now: detail.deptName_now,
      deptType_now: detail.deptType_now,
      charger: detail.charger,
      agent: detail.agent,
      isBack: 1
    };
    const actid = await this.model('fw_task_act').add(taskAct);
    return this.success({nextActid: actid});

  }

  /**
   * showdoc
   * @catalog 流程引擎服务
   * @title 查询某个流程实例下一个活动列表
   * @description 查询某个流程实例下一个活动列表
   * @method post
   * @url /service/queryNextAct
   * @param taskId 必选 int 任务id
   */
  // async queryNextActAction() {
  //   const model = this.model('affiliation');
  //   try {
  //     await model.startTrans();
  //     await model.lock(true).where({dicValue: 'xxx'}).select();
  //     const sleepPromise = sleepTime(20000);
  //     // clock.tick(2000);
  //     await sleepPromise;
  //     await model.add({dicValue: 'xxx'});
  //     //那如果一个事务中涉及到多个model会怎么处理呢?如下：
  //     let model2 = this.model('authorize').db(model.db());
  //     await model2.add({authorizeUser: 'yyyy'});
  //     await model.commit();
  //   } catch (e) {
  //     console.log(e);
  //     await model.rollback();
  //   }
  // }

};
