const Base = require('./base.js');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  // 通过反映内容判断是否在受理范围
  // 传参 userId 用于判断登记单位层级、行政区域
  // 传参 departmentID 工作部门
  // 传参 contentClassifyID 问题分类
  // 传参 deptZoneID 工作部门属地
  // 传参 deptLevel 工作部门层级2省，3市，4县
  // 传参 happenRegion 问题属地
  // 传参 identityTypeID 被反映人身份类型
  // 传参 identityBelongsID 被反映人所属系统
  // 传参 judge ①本机关或所属单位工作人员；②本行政区划所辖下级人大机关其所属单位工作人员。
  async isAcceptAction(){
    // 字典表FYN
    const data = this.post();
    let back = {
      "isAccept":1,// 是否受理范围 0受理1不受理
      "disposal":"",// 去向单位推荐
    };
    if (!data.hasOwnProperty("contentClassifyID")) {
      return this.fail(102)//传参缺失
    }
    let userInfo = await this.getUserInfo(data.userId); // 获取用户信息
    let classify = data.contentClassifyID.toString().substring(0,3); // 内容分类前3位，即大类 // 有可能是数组，所以先toString
    //“反映建议”001、“行政诉求”002、“纪检监察”003、“涉法涉诉”005、“其他”004
    if (classify === "001"){ // 反映建议类
      if ( !data.hasOwnProperty("deptZoneID")|| !data.hasOwnProperty("happenRegion")) {
        return this.fail(102)//传参缺失
      }
      let region = data.happenRegion.replace(/\s+/g,""); // 问题属地（去除空格
      region = (region.substr(-1) === "直" ? region.substr(0,region.length-1) : region); // 去掉最后一个“直”字；
      const dept = await this.model('sys_dept').where({"deptName":region}).find();
      const deptParent = await this.model('sys_dept').where({"id":data.deptZoneID}).find();
      if (data.contentClassifyID.substring(0,6) === "001001"){ // 涉及人大机关 001001
        if (think.isEmpty(dept) || think.deptParent){
          // 属地没有匹配上？？？？？
          return this.fail(102)
        }else {
          if (data.contentClassifyID.substring(0,9) === "001001001"){ // 依法履职方面的工作 001001001
            //问题属地在登记单位行政区域内，且工作部门层级在登记单位本级或者下级（不包含下下级），属于范围内
            // 问题属地的ancestor中，是否包含登记单位id，包含，则在行政区域内，注意id先转字符串
            // 工作部门属地deptZoneID或者工作部门属地的parentID，与登记部门属地相同，范围内
            if ((dept.ancestors.split(",").indexOf(userInfo.dictValue.toString()) !== -1 || dept.id === userInfo.dictValue) &&
              (data.deptZoneID === userInfo.dictValue || deptParent.parentID === userInfo.dictValue)){
              // 受理范围内
              back.isAccept = 0;
            }else {
              // 受理范围外
              back.isAccept = 1;
            }
          }else if (data.contentClassifyID.substring(0,9) === "001001003"){ //对人大选举任命人大机关工作人员的批评、建议、意见 001001003
            // 信访问题属地为本行政区划内，且涉及工作部门的机构层级为登记单位本级时
            // 问题属地的ancestor中，是否包含登记单位id，包含，则在行政区域内，注意id先转字符串
            // 工作部门属地deptZoneID与登记部门属地相同，范围内
            if ((dept.ancestors.split(",").indexOf(userInfo.dictValue.toString()) !== -1 || dept.id === userInfo.dictValue) &&
              (data.deptZoneID === userInfo.dictValue)) {
              //受理范围内
              back.isAccept = 0;
            }else {
              // 受理范围外
              back.isAccept = 1;
            }
          }else { // 涉及人大机关的其他工作
            // 信访问题属地为本行政区划内，且涉及工作部门的机构层级为登记单位本级时
            // 问题属地的ancestor中，是否包含登记单位id，包含，则在行政区域内，注意id先转字符串
            // 工作部门属地deptZoneID与登记部门属地相同，范围内
            if ((dept.ancestors.split(",").indexOf(userInfo.dictValue.toString()) !== -1 || dept.id === userInfo.dictValue) &&
              (data.deptZoneID === userInfo.dictValue)) {
              //受理范围内
              back.isAccept = 0;
            }else {
              // 受理范围外
              back.isAccept = 1;
            }
          }
        }
      }else if(data.contentClassifyID.substring(0,9) === "001002001"||data.contentClassifyID.substring(0,9) === "001002002"
        ||data.contentClassifyID.substring(0,9) === "001003001"||data.contentClassifyID.substring(0,9) === "001003002"
        ||data.contentClassifyID.substring(0,9) === "001004001"||data.contentClassifyID.substring(0,9) === "001004002"){
        //涉及 "行政机关"、"审判机关"、"检察机关"的  依法履职方面的工作”和 对人大选任命行政（或审判、检察）机关工作人员的批评、建议、意见”
        // 信访问题属地为本行政区划内，且涉及工作部门的机构层级为登记单位本级时
        // 问题属地的ancestor中，是否包含登记单位id，包含，则在行政区域内，注意id先转字符串
        // 工作部门属地deptZoneID与登记部门属地相同，范围内
        if ((dept.ancestors.split(",").indexOf(userInfo.dictValue.toString()) !== -1 || dept.id === userInfo.dictValue) &&
          (data.deptZoneID === userInfo.dictValue)) {
          //受理范围内
          back.isAccept = 0;
        }else {
          // 受理范围外
          back.isAccept = 1;
        }
      }else {//此处包括 “行政机关”、“审判机关”、“检察机关”类中二级分类的“其他工作”以及“监察机关”、“其他方面”类
        // 受理范围外
        back.isAccept = 1;
      }
    }else if(classify === "003"){ // 纪检检察
      // 被反映人身份类型为“个人”003001 中的“国家机关工作人员”  identityTypeID取值为字典表BSF前6位为200100
      // 被反映人所属系统为“人大”101 为 本机关或所属单位工作人员judge===1
      if (data.contentClassifyID.toString().substring(0,6) === "003001" && data.hasOwnProperty("identityTypeID")
        && data.identityTypeID.toString().substring(0,6) === "200100" && data.hasOwnProperty("identityBelongsID")
        && data.identityBelongsID === "101"  && data.hasOwnProperty("judge") && data.judge === 1) {
        //受理范围内
        back.isAccept = 0;
      }else {
        //受理范围外
        back.isAccept = 1;
      }
    }else {
      //行政诉求”002、“涉法涉诉”005、“其他”004，必然为受理范围外
      // 受理范围外
      back.isAccept = 1;
    }
    return this.success(back)
  }
  // 信访目的
  async lfReasonAction(){
    // 传参 contentClassifyID 问题分类
    const data = this.post();
    let classify = data.contentClassifyID.toString().substring(0,3); // 内容分类前3位，即大类 // 有可能是数组，所以先toString
    //“反映建议”001、“行政诉求”002、“纪检监察”003、“涉法涉诉”005、“其他”004
    switch (classify) {
      case "001":
        return this.success({"lfReasonID":"003","lfReason":"反映建议"})
        break;
      case "002":
      case "005":
        return this.success({"lfReasonID":"001","lfReason":"申诉求决"})
        break;
      case "003":
        return this.success({"lfReasonID":"004","lfReason":"控告检举"})
        break;
      case "004":
        return this.success({"lfReasonID":"005","lfReason":"其他"})
        break;
      default:
        return this.fail(101);
    }
  }
  // 通过问题分类，判断所属系统
  async belongsAction(){
    // 传参 contentClassifyID 问题分类
    const data = this.post();
    let back = {
      "belongsID":""
    };
    let classify = data.contentClassifyID.toString().substring(0,3); // 内容分类FYN 前3位，即大类 // 有可能是数组，所以先toString
    //“反映建议”001、“行政诉求”002、“纪检监察”003、“涉法涉诉”005、“其他”004
    if (classify === "001"){
      //反映建议类，手选工作部门，反映建议类没有所属系统
      return this.fail(105)
    }else if (classify === "002") {// 行政诉求类
      // 根据下级分类判断
      switch (data.contentClassifyID.substring(0,6)) {
        case "002001"://农村农业
          back.belongsID = "002019";//农村农业
          break;
        case "002002"://自然资源
          back.belongsID = "002015";//自然资源
          break;
        case "002003"://林业
          back.belongsID = "002035";//林业
          break;
        case "002004"://城乡建设
          back.belongsID = "002017";//住房和城乡建设
          break;
        case "002005"://劳动和社会保障
          back.belongsID = "002014";//人力资源和社会保障
          break;
        case "002006"://卫生健康
          back.belongsID = "002024";//卫生健康
          break;
        case "002008"://公安行政管理服务
          back.belongsID = "007";//公安行政
          break;
        case "002009"://民政
          back.belongsID = "002011";//民政
          break;
        case "002011"://交通运输
          back.belongsID = "002018";//交通运输
          break;
        case "002012"://市场监管
          back.belongsID = "002031";//市场监管
          break;
        case "002013"://水利
          back.belongsID = "002020";//水利
          break;
        case "002014"://扶贫开发
          back.belongsID = "002041";//扶贫开发
          break;
        case "002015"://科技
          back.belongsID = "002007";//科技
          break;
        case "002016"://经济和信息化
          back.belongsID = "002008";//经济和信息化
          break;
        case "002017"://生态环保
          back.belongsID = "002016";//生态环境
          break;
        case "002020"://应急管理
          back.belongsID = "002026";//应急管理
          break;
        case "002021"://海关
          back.belongsID = "006019";//海关
          break;
        case "002022"://退役军人
          back.belongsID = "002025";//退役军人事务
          break;
      }
      switch (data.contentClassifyID.substring(0,9)) {
        case "002007001":
        case "002007002":
        case "002007003":
        case "002007004":
        case "002007006":
        case "002007006":
          back.belongsID = "002006";//教育
          break;
        case "002007007":
        case "002007008":
          back.belongsID = "002022";//文化
          break;
        case "002007009":
          back.belongsID = "002033";//体育
          break;
        case "002007010":
          back.belongsID = "002023";//旅游
          break;
        case "002010001"://宏观调控
          back.belongsID = "002002";//发展和改革
          break;
        case "002010004":
        case "002010006":
          back.belongsID = "002030";//国有资产监管
          break;
        case "002010005":
          back.belongsID = "002005";//能源
          break;
        case "002010007":
          back.belongsID = "002021";//商务
          break;
        case "002010008":
          back.belongsID = "002027";//审计
          break;
        case "002010009":
          back.belongsID = "006014";//银行
          break;
        case "002011005"://邮政管理
          back.belongsID = "006018";//邮政
          break;
        case "002018001":
        case "002018002":
          back.belongsID = "002040";//信访
          break;
        case "002018003":
          back.belongsID = "002009";//民族宗教
          break;
        case "002018007":
          back.belongsID = "006003";//宣传
          break;
        case "002019001"://选拔任用
        case "002019002"://招录辞退
        case "002019003"://编制职位
        case "002019006"://离休
        case "002019007"://其他
          back.belongsID = "006002";//组织
          break;
        case "002019004":
          back.belongsID = "002014";//人力资源和社会保障
          break;
        case "002019005":
          back.belongsID = "006004";//机构编制
          break;
      }
      switch (data.contentClassifyID.substring(0,12)) {
        case "002001003003"://粮食储备
          back.belongsID = "002003";//粮食
          break;
        case "002010002001"://金融管理（含融资租凭、典当、商业保理监管）
        case "002010002002"://集资融资
          back.belongsID = "002038";//金融监管
          break;
        case "002010002003"://财政收支
          back.belongsID = "002013";//财政
          break;
        case "002010002004"://税收征管
          back.belongsID = "006020";//税收
          break;
        case "002010003001"://保险业监管
          back.belongsID = "006016";//保险
          break;
        case "002010003002"://证券业监管
        case "002010003003"://期货基金
          back.belongsID = "006015";//证券
          break;
        case "002018004001"://港澳事务
          back.belongsID = "002028";//港澳事务
          break;
        case "002018004002"://侨务
        case "002018005001"://外交外事
          back.belongsID = "002029";//外事
          break;
        case "002018004003"://台湾事务
          back.belongsID = "006007";//台湾事务
          break;
        case "002018006001"://工会工作
          back.belongsID = "006010";//工会
          break;
        case "002018006002"://共青团工作
          back.belongsID = "006012";//共青团
          break;
        case "002018006003"://妇联工作
          back.belongsID = "006011";//妇女
          break;
      }
      return this.success(back)
    }else if (classify === "003") {// 纪检监察类
      // 所属系统为 监察委
      back.belongsID = "003";
      return this.success(back)
    }else if (classify === "005") {// 涉法涉诉类
      //根据二级分类判断
      switch (data.contentClassifyID.substring(0,6)) {
        case "005001":
          //公安
          back.belongsID = "008";
          break;
        case "005002":
          //检察院
          back.belongsID = "005";
          break;
        case "005003":
          //司法
          back.belongsID = "009";
          break;
        case "005004":
          //法院
          back.belongsID = "004";
          break;
      }
      return this.success(back)
    }else {
      //classify === "004" 其他类，自选所属系统且非必填
      //所以返回空
      return this.fail(105)
    }

  }
  async isDeptAction(){
    // 传参 userId 用于判断登记单位层级、行政区域
    // 传参 happenRegion 问题属地
    const data = this.post();
    let region = data.happenRegion.replace(/\s+/g,""); // 问题属地（去除空格
    region = (region.substr(-1) === "直" ? region.substr(0,region.length-1) : region); // 去掉最后一个“直”字；
    const dept = await this.model('sys_dept').where({"deptName":region}).find();
    let userInfo = await this.getUserInfo(data.userId); // 获取用户信息
    if (think.isEmpty(dept)){
      return this.success(1)//区域外
    }
    // 问题属地的ancestor中，是否包含登记单位id，包含，则在行政区域内，注意id先转字符串
    if (dept.ancestors.split(",").indexOf(userInfo.dictValue.toString()) !== -1 || dept.id === userInfo.dictValue){
      return this.success(0)//区域内
    }else {
      return this.success(1)//区域外
    }
  }

  // "对人大选举任命XXX工作人员的批评、建议、意见"的"职务类型"联动
  async getGZWAction(){
    // 传参 contentClassifyID 问题分类
    const data = this.post();
    if (!data.hasOwnProperty("contentClassifyID")) {
      return this.fail(106);
    }
    let where = {
      "dictID":"GZW",
      "flag":"1",
      "dictValue":['LIKE',data.contentClassifyID.substring(2,3)+'%']
    };
    switch (data.contentClassifyID) {
      case "001001002":
        where.dictValue = ['LIKE','100%'];
        break;
      case "001002002":
        where.dictValue = ['LIKE','200%'];
        break;
      case "001003002":
        where.dictValue = ['LIKE','300%'];
        break;
      case "001004002":
        where.dictValue = ['LIKE','400%'];
        break;
      case "001005002":
        where.dictValue = ['LIKE','500%'];
        break;
      default:
        return this.fail(106)
    }
    let back = await this.model("dictionary").where(where).select();
    let gzw ={"children":[]};
    let gzwChild =[];
    back.forEach(function(item) {
      if (item.isExistchild === 1){
        gzw = item
      }else {
        gzwChild.push(item)
      }
    });
    gzw.children = gzwChild;
    return this.success(gzw)
  }
  // 根据信访类型，给出所有可能的办理方式
  async handlemodelAllAction() {
    const param = this.post();
    const back = await this.model('dictionary').where({'dictID': 'FS', 'flag': 1,'dictValue':['like',param.registerTypeID + '%'],'parentValue':['!=',null]}).order('IFNULL(orderNum, 9999) ASC').select();
    let tree = [];
    let data = {};
    for (const i in back) {
      const dataKey = back[i]['dictValue'];
      data[dataKey] = back[i];
    }
    for (const j in back) {
      const bval = back[j];
      const dataP = data[bval['parentValue']];
      if (dataP) {
        if (!dataP.children) {
          dataP.children = [];
        }
        dataP.children.push(bval);
      } else {
        tree.push(bval);
      }
    }
    return this.success(tree);
  }

  // 根据受理范围，判断办理方式
  async handlemodelAction(){
    const param = this.post();
    // isAcceptPerson 人工判断是否受理0受理，1不受理
    // isAccept 系统判断是否受理0受理，1不受理
    // xfSourceID 信访来源 001001为群众
    // contentClassifyID 问题分类
    // registerTypeID 001来信 002来访 003来电 004网上信访 005其他
    let where = {
      'dictID': 'FS',
      'flag': 1
    };
    if (param.hasOwnProperty('contentClassifyID') && param.contentClassifyID.toString().substring(0,3) === "003") {
      // 纪检监察类
      where['dictValue'] = {'like':param.registerTypeID + '%','NOT LIKE':param.registerTypeID + '006' + '%','NOTLIKE':'%003001'}// 剔除自办和交办
    }else {
      if (param.registerTypeID !== '005'){
        // where["dictValue"] = ['like', activity.registerTypeID + '%']
        // 自动判断为受理范围内 且 手选受理范围
        if (param.isAccept === 0 && param.hasOwnProperty("isAcceptPerson") && param.isAcceptPerson === 0){
          // 自办和转办
          where['dictValue'] = ['like',[param.registerTypeID ,param.registerTypeID + '003'+'%',param.registerTypeID + '006'+'%'] ]
        }else {
          // 自动判断为受理范围外
          if (param.xfSourceID.substr(3,3) !== "001"){
            // 受理范围外，但是是领导代表件，可以转办
            where['dictValue'] = ['like',[param.registerTypeID ,param.registerTypeID + '003'+'%',param.registerTypeID + '006'+'%'] ]
          } else {
            // 存信存件接谈，转送
            where['dictValue'] = {'like':param.registerTypeID + '%','NOT LIKE':param.registerTypeID + '006' + '%','NOTLIKE':'%003001'}// 剔除自办和交办
          }
        }
      }
    }

    const back = await this.model('dictionary').where(where).order('IFNULL(orderNum, 9999) ASC').select();
    let tree = [];
    let data = {};
    for (const i in back) {
      const dataKey = back[i]['dictValue'];
      data[dataKey] = back[i];
    }
    for (const j in back) {
      const bval = back[j];
      const dataP = data[bval['parentValue']];
      if (dataP) {
        if (!dataP.children) {
          dataP.children = [];
        }
        dataP.children.push(bval);
      } else {
        tree.push(bval);
      }
    }
    return this.success(tree);
  }
  // 传参 departmentID 工作部门
  // 传参 contentClassifyID 问题分类
  // 传参 deptZoneID 工作部门属地
  // 传参 happenRegionID 问题属地ID
  // 传参 userId
  // 传参 identityBelongsID 被反映人所属系统
  // 传参 judge ①本机关或所属单位工作人员；②本行政区划所辖下级人大机关其所属单位工作人员
  // 传参 judgeDept ①本机关及所属单位；②本行政区所辖下级人大机关及所属单位
  async disposalAction(){
    const param = this.post();
    let userInfo = await this.getUserInfo(param.userId); // 获取用户信息
    let disposal = []; // 去向单位
    let errmsg = ""; // 提示消息
    if (param.happenRegionID.length < userInfo.deptLevel * 3){
      // 问题属地层级 高于 当前登记单位，重新选择
      // return this.fail(6401,"问题属地层级高于当前登记单位，重新选择!")
      return this.success([])
    } else {
      if (param.contentClassifyID.toString().substring(0,3) === "001"){ // 问题分类为  反映建议
        let dictValue = param.happenRegionID.substr(0,userInfo.type * 3); // 下级地区
        if (dictValue.substr(-3) !== "000"){ // 非本级“直”，可选下级人大
          // 下级人大
          let rd = await this.model('sys_organization').join('sys_dept ON sys_dept.id = sys_organization.deptID')
            .where({"sys_dept.dictValue":dictValue,"agent":1}).field("sys_organization.*").find();
          if (!think.isEmpty(rd)){
            // push下级人大
            disposal.push({
              "id":rd.id,
              "orgName":rd.orgName,
              "deptID":rd.deptID,
              "deptName":rd.deptName
            })
          }
        } else {
          // push本级人大
          disposal.push({
            "id":userInfo.orgID,
            "orgName":userInfo.orgName,
            "deptID":userInfo.dictValue,
            "deptName":userInfo.deptName
            }
          );
        }
        // 本级职能单位
        let org = await this.model('disposal_role').where({"deptID":userInfo.dictValue,"bmxtValue":param.departmentID}).group('orgID').select();
        org.forEach(function(item) {
          disposal.push({
            "id":item.orgID,
            "orgName":item.orgName,
            "deptID":item.deptID,
            "deptName":item.deptName
          })
        })
      } else if (param.contentClassifyID.toString().substr(0,3) === "002"){
        // 问题分类为  行政诉求
        let dictValue = param.happenRegionID.substr(0,userInfo.type * 3); // 下级地区
        if (dictValue.substr(-3) !== "000"){ // 非本级“直”，可选下级人大
          // 下级人大
          let rd = await this.model('sys_organization').join('sys_dept ON sys_dept.id = sys_organization.deptID')
            .where({"sys_dept.dictValue":dictValue,"agent":1}).field("sys_organization.*").find();
          if (!think.isEmpty(rd)){
            // push下级人大
            disposal.push({
              "id":rd.id,
              "orgName":rd.orgName,
              "deptID":rd.deptID,
              "deptName":rd.deptName
            })
          }
        } else {
          // push本级人大
          disposal.push({
            "id":userInfo.orgID,
            "orgName":userInfo.orgName,
            "deptID":userInfo.dictValue,
            "deptName":userInfo.deptName

            }
          );
        }
        // 本级职能单位
        let org = await this.model('disposal_role').where({"deptID":userInfo.dictValue,"FYN":param.contentClassifyID}).group('orgID').select();
        org.forEach(function(item) {
          disposal.push({
            "id":item.orgID,
            "orgName":item.orgName,
            "deptID":item.deptID,
            "deptName":item.deptName
          })
        })
      } else if (param.contentClassifyID.toString().substring(0,3) === "003" && param.hasOwnProperty("identityBelongsID")){
        // 问题分类为  纪检监察
        if (param.identityBelongsID === "101") { // 被反映人所属系统为  人大
          if (param.happenRegionID.substr(0,userInfo.deptValue.length) === userInfo.deptValue) {
            // 判断为区域内
            if (param.hasOwnProperty("judgeDept") && param.judgeDept === 1){ // 本级所属机关
              // 去向单位为登记单位办公厅或办公室
              let org = await this.model("disposal_role").where({"deptID":userInfo.dictValue,"bmxtValue":["IN",["001001001","001002001","001003001"]]}).group('orgID').select();
              org.forEach(function(item) {
                disposal.push({
                  "id":item.orgID,
                  "orgName":item.orgName,
                  "deptID":item.deptID,
                  "deptName":item.deptName
                })
              })
            }else {
              // 去向单位为下级人大
              let dictValue = param.happenRegionID.substr(0, userInfo.type * 3); // 下级地区
              let rd = await this.model('sys_organization').join('sys_dept ON sys_dept.id = sys_organization.deptID')
                .where({"sys_dept.dictValue": dictValue, "agent": 1}).field("sys_organization.*").find();
              if (!think.isEmpty(rd)) {
                // push下级人大
                disposal.push({
                  "id": rd.id,
                  "orgName": rd.orgName,
                  "deptID":rd.deptID,
                  "deptName":rd.deptName
                })
              }
            }
          }else {
            // 判断为区域外
            // 去向单位为 本单位，并推存信存件接谈
            disposal.push({
              "id":userInfo.orgID,
              "orgName":userInfo.orgName,
              "deptID":userInfo.dictValue,
              "deptName":userInfo.deptName
            });
            errmsg = "推荐办理方式为存信存件或接谈";
          }
        }else {// 被反映人所属系统为  非人大
          if (param.happenRegionID.substr(0,userInfo.deptValue.length) === userInfo.deptValue) {
            // 判断为区域内
            // 去向单位为 同级监察委
            let org = await this.model("disposal_role").where({"deptID":userInfo.dictValue,"bmxtValue":"003"}).group('orgID').select()
            org.forEach(function(item) {
              disposal.push({
                "id":item.orgID,
                "orgName":item.orgName,
                "deptID":item.deptID,
                "deptName":item.deptName
              })
            })
          }else {
            // 判断为区域外
            // 去向单位为 本单位，并推存信存件接谈
            disposal.push({
              "id":userInfo.orgID,
              "orgName":userInfo.orgName,
              "deptID":userInfo.dictValue,
              "deptName":userInfo.deptName
            });
            errmsg = "推荐办理方式为存信存件或接谈";
          }
        }
      } else if (param.contentClassifyID.toString().substring(0,3) === "004"){
        // 问题分类为  其他
        errmsg = "去向单位自选"
      }else if (param.contentClassifyID.toString().substring(0,3) === "005"){
        // 问题分类为  渉法涉诉
        // 去向单位为本级职能
        let where = {
          "deptID":userInfo.dictValue
        };
        switch (param.contentClassifyID.toString().substr(0,6)) {
          case "005001":
            //公安
            where["bmxtValue"] = "002010";
            break;
          case "005002":
            //检察院
            where["bmxtValue"] = "005";
            break;
          case "005003":
            //司法
            where["bmxtValue"] = "002012";
            break;
          case "005004":
            // 法院
            where["bmxtValue"] = "004";
            break;
        }
        let org = await this.model("disposal_role").where(where).group('orgID').select();
        org.forEach(function(item) {
          disposal.push({
            "id":item.orgID,
            "orgName":item.orgName,
            "deptID":item.deptID,
            "deptName":item.deptName
          })
        })
      }else {
        // 问题分类有问题，或者有字段没传
        errmsg = "问题分类有问题，或者有字段没传";
        return this.fail(6404,errmsg)
      }
    }
    return this.success(disposal,errmsg)
  }
};
