const Base = require('./base.js');
const Check = require('./../handle/check');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }

  /**
   * showdoc
   * @catalog 系统管理/登录
   * @title 后台登录
   * @description 后台登录接口
   * @method post
   * @url http://127.0.0.1:8360/login/loginAdmin
   * @param username 必选 string 用户名
   * @param password 必选 string 密码
   * @return {"errno": 0, "errmsg":"", "data":{"user_id":"dddddddddddddfsfsf","email":"123@163.com"}}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param user_id 必选 string 用户id
   * @return_param email 必选 string 邮箱
   */
  async loginAdminAction() {
      if (this.isPost) {
        const param = this.post();
        const user = this.model('sys_user');
        let login_return = await user.setRelation(false).where({user_name:param.username,del_flag:1,status:1,isAdmin:1}).find().catch((err) => {
          return think.isError(err) ? err : new Error(err);
        });
        if (think.isError(login_return)) {
          return this.fail(1000, 'get userInfo fail');
        }
        if (!login_return) {
          return this.fail(1001, "Sorry,the count does not exist")
        }
        if (login_return.password !== think.md5(param.password)) {
            return this.fail(1002, "Sorry, your password is not correct");
        }
        const token = this.updateAuth(login_return.user_id)
        const data= {
          token: token,
          user_id: login_return.user_id
        }
        user.where({user_id: login_return.user_id}).update({last_login_time:think.datetime(new Date()),token:token})
        this.cookie('data',token)
        return this.success(data);
      }
  }

  /**
   * showdoc
   * @catalog 系统管理/登录
   * @title 登录
   * @description 登录接口
   * @method post
   * @url http://127.0.0.1:8360/login/login
   * @param username 必选 string 用户名
   * @param password 必选 string 密码
   * @return {"errno": 0, "errmsg":"", "data":{"user_id":"dddddddddddddfsfsf","email":"123@163.com"}}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param user_id 必选 string 用户id
   * @return_param email 必选 string 邮箱
   */
  async loginAction() {
    if (this.isPost) {
      const param = this.post();
      const user = this.model('sys_user');
      let login_return = await user.setRelation(false).where({user_name:param.username,del_flag:1,status:1}).find().catch((err) => {
        return think.isError(err) ? err : new Error(err);
      });
      if (think.isError(login_return)) {
        return this.fail(1000, '数据库连接失败，请联系管理员');
      }
      if (!login_return) {
        return this.fail(1001, "对不起，您输入的账号有误")
      }
      if (login_return.password !== think.md5(param.password)) {
          return this.fail(1002, "对不起，您输入的密码有误");
      }
      const token = this.updateAuth(login_return.user_id)
      const data= {
        token: token,
        user_id: login_return.user_id,
        user_name:login_return.user_name,
        name:login_return.name
      }
      user.where({user_id: login_return.user_id}).update({last_login_time:think.datetime(new Date()),token:token})
      this.cookie('data',token)
      // 增加考勤积分
      await Check.addPoints(1,login_return.user_id);
      return this.success(data);
    }
  }

  /**
   * showdoc
   * @catalog 系统管理/登录
   * @title 获取登录用户授权信息
   * @description 获取登录用户授权信息接口
   * @method post
   * @url http://127.0.0.1:8360/login/getUserAuthorize
   * @param userid 必选 string 用户名uuid
   * @return {"errno": 0, "errmsg":"", "data":{"user_id":"dddddddddddddfsfsf","email":"123@163.com"}}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param user_id 必选 string 用户id
   * @return_param email 必选 string 邮箱
   */
  async getUserAuthorizeAction() {
    const userId = this.post().userid;
    let nowTime = think.datetime(new Date());
    const result = await this.model('authorize').where({authorityObject:userId,startTime:['<',nowTime], endTIme:['>=', nowTime]}).select().catch((err) => {
      console.log(err)
      return think.isError(err) ? err : new Error(err)
    })
    if (think.isError(result)) {
      return this.fail(5002, '获取登录用户被授权账号失败')
    }
    return this.success(result)
  }


  /**
   * showdoc
   * @catalog 系统管理/登录
   * @title 获取用户权限
   * @description 获取用户权限接口
   * @method get
   * @url http://127.0.0.1:8360/login/getUserMenu
   * @param userid 必选 string 用户名id
   * @return {"errno": 0, "errmsg":"", "data":{"menu_id":1,"menu_name":"系统管理","parent_id":0,"perms":"sys/menu/getMenuList","visible":0,"menu_type":1,"order_num":3}}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param menu_id  int 菜单权限id
   * @return_param menu_name  string 菜单权限名称
   * @return_param parent_id  int 父级id
   * @return_param perms string 权限接口地址
   * @return_param visible int 0显示，1隐藏
   * @return_param menu_type int 0目录 1菜单 2按钮
   * @return_param order_num int 排序顺序
   */
  async getUserMenuAction() {
    const userid = this.get().userid;
    //获取用户的角色
    let userRole = await this.model('sys_role').alias('r').join('sys_user_role as sur on sur.role_id=r.role_id').where('sur.user_id="'+userid+'"').select();
    if (think.isEmpty(userRole)){
      return this.success([])
    }
    let roleids = []
    userRole.forEach((item) => {
      roleids.push(item.role_id);
    })
    // roleids = "(" + roleids.join(',') + ")"
    let whereParam = ""
    //角色id不含有1，0为普通管理员，1是超级管理员
    if (roleids.indexOf(1) !== -1) {
      roleids = "(" + roleids.join(',') + ")"
      this.cookie('isSuper','1')
    } else {
      roleids = "(" + roleids.join(',') + ")"
      whereParam += "srm.role_id in "  + roleids;
      this.cookie('isSuper', '0')
    }

    let return_data = await this.model('sys_menu').alias('sm')
      .field('sm.menu_id,sm.menu_name,sm.parent_id,sm.perms,sm.visible,sm.menu_type,sm.order_num,sm.path')
      .join('sys_role_menu as srm on srm.menu_id=sm.menu_id').where(whereParam).select();
    let perm = [];
    if(return_data) {
      return_data.forEach((item) => {
        perm.push(item.perm);
      })
    }
    let permStr = perm.join();
    this.cookie('perm', permStr)
    let menu_data = this.getDictTree(return_data, 'id', 'parent_id')
    return this.success(menu_data);
  }

  /**
   * showdoc
   * @catalog 系统管理/登录
   * @title 退出
   * @description 退出接口
   * @method get
   * @url http://127.0.0.1:8360/login/logout
   * @return {"errno": 0, "errmsg":"", "data":}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   */
  logoutAction() {
    this.updateAuth(null);
    this.cookie('data', null)
    this.cookie('perm', null)
    return this.success();
  }

  /**
   * showdoc
   * @catalog 系统管理/登录
   * @title 获取用户信息
   * @description 获取用户信息接口
   * @method post
   * @url http://127.0.0.1:8360/login/getUserInfo
   * @param userid 必选 string 用户名id
   * @return {"errno": 0, "errmsg":"", "data":{"userid":"ffffddddsssffdee","email":"123@163.com","name":"zhang","phone":"15333599951","role_name":"管理员"}}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param userid  string 用户id
   * @return_param email  string 邮箱
   * @return_param name  string 真实姓名
   * @return_param phone string 手机号
   * @return_param role_name string 角色名称
   */
  async getUserInfoAction() {
    const user_id = this.post().userid;
    const result = await this.getUserInfo(user_id);
    if(result === 0) {
      this.success(1004, "Get userInfo failed");
    }
    if(result.meetingID !== null && result.meetingID !== ''&& typeof result.meetingID !== 'undefined'){
      let room = await this.model('meeting_room').where({'meetingID':result.meetingID,'roomOrgID':result.orgID}).find();
      JSON.parse(JSON.stringify(result));
      result['meeting_room'] = room;
    }
    return this.success(result);
  }

  //根据token解析userid
  async getUseridByTokenAction() {
    const user_id = this.get().userId;
    return this.success(user_id);
  }

  // 当前用户修改密码
  async changePwdAction(){
    let data = this.post();
    if (!data.hasOwnProperty('userId') || !data.hasOwnProperty('oldPwd') || !data.hasOwnProperty('newPwd')){
      return this.fail("字段传入缺失！")
    }
    let user = await this.model('sys_user').where({'user_id':data.userId,'status':1,'del_flag':1}).find();
    if (think.isEmpty(user)){
      return this.fail('账号未启用')
    } else {
      if (think.md5(data.oldPwd) === user.password){
        await this.model('sys_user').where({'user_id':data.userId,'status':1,'del_flag':1}).update({'password':think.md5(data.newPwd)});;
        return this.success('修改成功！')
      } else {
        return this.fail('原密码错误！')
      }
    }
  }

};
