/* eslint-disable no-unused-vars */
const Base = require('./base.js');
const uuid = require('node-uuid');
const moment = require('moment');
const util = require('../handle/util.js');
module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  /**
   * showdoc
   * @catalog 事项信息
   * @title 事项信息添加
   * @description 事项信息添加接口
   * @method post
   * @url http://127.0.0.1:8360/matter/add
   * @param activityID 必选 int 活动ID
   * @param userid 必选 string 登录人userid
   * @param xfType 必选 string 信访类型
   * @param xfTypeID 必选 string 信访类型ID
   * @param matter 必选 array 修改事项
   * @param delMatter 必选 array 删除事项ID
   * @param addMatter 必选 array 新增事项关系
   * @return {"errno": 0, "errmsg":"", "data":{"matterID":,"activityID":}}
   */
  async addAction() {
    const data = this.post();
    let matter = [];
    let userInfo = await this.getUserInfo(data.userid);
    // 已经存在活动ID
    let matterID = []; // 活动表中，新matterID
    if (data.matter.length > 0) {
      // 修改更新matter
      let label = []; // 要插入的标签列表
      let handleLog = []; // 要插入的办事方式记录
      data.matter.forEach(function(it) {
        // it.hotspot = typeof it.hotspot === 'object' ? it.hotspot : JSON.parse(it.hotspot);
        // let hotV = [];
        it.hotspot.forEach(function(hotS) {
          label.push({
            "labelName":hotS.name,
            "labelID":hotS.id,
            "type":1,
            "matterID":it.id,
            "userId":data.userid,
            "orgID":userInfo.orgID,
            "orgName":userInfo.orgName,
          });
          // hotV.push(hotS.name);
        });
        // it.hotspot = (hotV.length === 0 ? '':hotV.join(","));// 热点问题标签  还是改回去改成存json
        // it.personspot = typeof it.personspot === 'object' ? it.personspot : JSON.parse(it.personspot);
        // let personV = [];
        it.personspot.forEach(function(personS) {
          label.push({
            "labelName":personS.name,
            "labelID":personS.id,
            "type":2,
            "matterID":it.id,
            "userId":data.userid,
            "orgID":userInfo.orgID,
            "orgName":userInfo.orgName,
          })
          // personV.push(personS.name);
        });
        // it.personspot = (personV.length === 0 ? '':personV.join(","));// 个人标签  还是改回去改成存json
        it['activityID'] = data.activityID;
        it['contraband'] = it['contraband'] ?it['contraband'].join(',') : "";
        it['SKSFL'] = it['SKSFL'] ? it['SKSFL'].join(',') : "";
        it['hotspot'] = it['hotspot'] ? JSON.stringify(it['hotspot']) : ""; // 热点问题标签
        it['personspot'] = it['personspot'] ? JSON.stringify(it['personspot']) : ""; // 个人标签
        it['url'] = it['url'] ? it['url'].join(',') : "";
        it['contentClassify'] = it['contentClassify'].toString();
        it['contentClassifyID'] = it['contentClassifyID'].toString(); // 问题分类可能多选，多选的话是数组，所以转字符串，单选依旧是字符串
        it['ccmID'] = it.contentClassifyID.substr(0,3) === "003" ?
          (it.contentClassifyMainID === null ? it.contentClassifyID.split(",")[0] : it.contentClassifyMainID) : it.contentClassifyID; // 用于统计的问题分类字段，纪检监察类取主要分类，其他取contentClassifyID

        // it['isMeeting'] = userInfo.meetingID === null ? 1 : 0;//是否大会 0大会 1不是大会
        // it['meetingID'] = userInfo.meetingID;//大会届次
        // 办理方式记录
        handleLog.push({
          "matterID":it.id,
          "belongs":it.belongs,
          "belongsID":it.belongsID,
          "finalDisposal":it.finalDisposal,
          "finalDisposalID":it.finalDisposalID,
          "createUserID":data.userId,
          "createUserName":userInfo.name,
          "createOrgID":userInfo.orgID,
          "createOrgName":userInfo.orgName,
          "finalZone":it.finalZone,
          "finalZoneID":it.finalZoneID,
          "handleModel":it.handleModel,
          "handleModelID":it.handleModelID,
          "departmentID":it.departmentID,
          "department":it.department,
          "deptZone":it.deptZone,
          "deptZoneID":it.deptZoneID,
          "deptLevel":it.deptLevel,
          "happenRegion":it.happenRegion,
          "happenRegionID":it.happenRegionID,
          "happenAddress":it.happenAddress,
          "isAccept":it.isAccept,
          "isAcceptPerson":it.isAcceptPerson,
          "isAnswer":it.isAnswer
        })
      });
      const upMatter = await this.model('matter').setRelation(false).updateMany(data.matter);
      data.matter.forEach(function(item) {
        matterID.push(item.id);
      });

      if (matterID.length>0){
        // 先删除标签统计表中数据
        await this.model('label_count').where({'matterID': ['IN', matterID]}).delete();
        //删除办理方式记录
        await this.model('handle_log').where({'matterID': ['IN', matterID]}).delete();
      }
      // 再插入标签统计数据
      if (label.length > 0){
        await this.model('label_count').addMany(label);
      }
      // 再插入办理方式记录数据
      if (handleLog.length > 0){
        await this.model('handle_log').addMany(handleLog);
      }
      // // 将事项id加到返回值中
      // data.matter.forEach(function(item) {
      //   matter.push(item.id);
      // });
    }
    if (data.delMatter.length > 0) {
      // 删除事项
      const delMatter = await this.model('matter').setRelation(false).where({'id': ['IN', data.delMatter]}).delete();
      // 删除matter_state表中状态
      const delState = await this.model('matter_state').setRelation(false).where({'matterID': ['IN', data.delMatter]}).delete();
      //更新活动表中matterID字段
      let activity = await this.model('activity').setRelation(false).where({'id':data.activityID}).find();
      let matterOld = activity.matterID.split(",");
      let matterNew = matterOld.filter(el => !data.delMatter.includes(el)).toString();
      await this.model('activity').setRelation(false).where({'id':data.activityID}).update({'matterID':matterNew});
      // 删除标签统计表中数据
      await this.model('label_count').where({'matterID': ['IN', data.delMatter]}).delete()
      // 删除办理方式记录表中数据
      await this.model('handle_log').where({'matterID': ['IN', data.delMatter]}).delete()
    }
    if (data.addMatter.length > 0) {
      // 新增事项
      let label = []; // 要插入的标签列表
      let handleLog = []; // 要插入的办事方式记录
      data.addMatter.forEach(async function(it) {
        it['id'] = uuid.v1();
        // it.hotspot = typeof it.hotspot === 'object' ? it.hotspot : JSON.parse(it.hotspot);
        // let hotV = [];
        it.hotspot.forEach(function(hotS) {
          label.push({
            "labelName":hotS.name,
            "labelID":hotS.id,
            "type":1,
            "matterID":it.id,
            "userId":data.userid,
            "orgID":userInfo.orgID,
            "orgName":userInfo.orgName,
          })
          // hotV.push(hotS.name);
        });
        // it.hotspot = (hotV.length === 0 ? '': hotV.join(","));// 热点问题标签  还是改回去改成存json
        // it.personspot = typeof it.personspot === 'object' ? it.personspot : JSON.parse(it.personspot);
        // let personV = [];
        it.personspot.forEach(function(personS) {
          label.push({
            "labelName":personS.name,
            "labelID":personS.id,
            "type":2,
            "matterID":it.id,
            "userId":data.userid,
            "orgID":userInfo.orgID,
            "orgName":userInfo.orgName,
          })
          // personV.push(personS.name);
        });
        // it.personspot = (personV.length === 0 ? '': personV.join(","));// 个人标签  还是改回去改成存json
        it['activityID'] = data.activityID;
        it['contraband'] = it['contraband'] ?it['contraband'].join(',') : "";
        it['SKSFL'] = it['SKSFL'] ? it['SKSFL'].join(',') : "";
        it['url'] = it['url'] ? it['url'].join(',') : "";
        it['hotspot'] = it['hotspot'] ? JSON.stringify(it['hotspot']) : ""; // 热点问题标签
        it['personspot'] = it['personspot'] ? JSON.stringify(it['personspot']) : ""; // 个人标签
        it['contentClassify'] = it['contentClassify'].toString(); // 问题分类可能多选，多选的话是数组，所以转字符串，单选依旧是字符串
        it['contentClassifyID'] = it['contentClassifyID'].toString(); // 问题分类可能多选，多选的话是数组，所以转字符串，单选依旧是字符串
        it['ccmID'] = it.contentClassifyID.substr(0,3) === "003" ?
          (it.contentClassifyMainID === null ? it.contentClassifyID.split(",")[0] : it.contentClassifyMainID) : it.contentClassifyID; // 用于统计的问题分类字段，纪检监察类取主要分类，其他取contentClassifyID
        it['createPerson'] = userInfo.name;
        it['createAccount'] = userInfo.user_name;
        it['createOrgID'] = userInfo.orgID;//创建机构ID
        it['createOrg'] = userInfo.orgName;//创建机构

        // it['isMeeting'] = userInfo.meetingID === null ? 1 : 0;//是否大会 0大会 1不是大会
        // it['meetingID'] = userInfo.meetingID;//大会届次
        // 办理方式记录
        handleLog.push({
          "matterID":it.id,
          "belongs":it.belongs,
          "belongsID":it.belongsID,
          "finalDisposal":it.finalDisposal,
          "finalDisposalID":it.finalDisposalID,
          "createUserID":data.userId,
          "createUserName":userInfo.name,
          "createOrgID":userInfo.orgID,
          "createOrgName":userInfo.orgName,
          "finalZone":it.finalZone,
          "finalZoneID":it.finalZoneID,
          "handleModel":it.handleModel,
          "handleModelID":it.handleModelID,
          "departmentID":it.departmentID,
          "department":it.department,
          "deptZone":it.deptZone,
          "deptZoneID":it.deptZoneID,
          "deptLevel":it.deptLevel,
          "happenRegion":it.happenRegion,
          "happenRegionID":it.happenRegionID,
          "happenAddress":it.happenAddress,
          "isAccept":it.isAccept,
          "isAcceptPerson":it.isAcceptPerson,
          "isAnswer":it.isAnswer
        })
        // 新增事项id
        matter.push(it.id);
      });
      // const matterAdd = await this.model('matter').addMany(data.addMatter);
      for (let ma of data.addMatter){
        await this.model('matter').setRelation(false).add(ma);
      }
      // 插入标签统计数据
      if (label.length > 0){
        await this.model('label_count').addMany(label);
      }
      // 插入办理方式记录数据
      if (handleLog.length > 0){
        await this.model('handle_log').addMany(handleLog);
      }
      // // 在插入新的信访事项之后，给信访事项编号
      // let matterUp = await util.getMatterNo(data.activityID);
      // await this.model("matter").updateMany(matterUp);

      let state = [];
      matter.forEach(function(item) {
        matterID.push(item); // 更新活动表中matterID
        // 在matter_state中插入新状态
        state.push({
          'matterID': item,
          'activityID': data.activityID,
          'state': 1,
          'stateName': '待提交登记审批',
          'nextState': 2,
          'nextStateName': '登记待审批/已提交登记审批',
          'departmentID': userInfo.orgID,
          'department': userInfo.orgName, // 机构
          'description': userInfo.description, // 地区
          'dictValue': userInfo.dictValue,
          'handlePerson': userInfo.name,
          'handlePersonID': userInfo.user_name,
          // 'nextDepartment': '', // 去向单位 （下一步操作还是本单位）
        })
      });
      // 在matter_state中插入新状态
      const addState = await this.model('matter_state').addMany(state);
    }
    // 更新活动表matterID
    const upActivity = await this.model('activity').setRelation(false).where({'id':data.activityID}).update({'matterID': matterID.join(',')})
    return this.json({
      'errno': 0,
      'errmsg': '',
      'data': {
        'matterID': matter,
        'activityID': data.activityID // 因为活动不会在这里插入了，只有更新
        // 'activityID': data.activityID === '' ? activity : data.activityID // 活动更新返回0，活动插入返回ID
      }
    });
  }
  async getPersonByMatterAction() {
    const param = this.post();
    let whereParam = {"m.matterNum":['!=','']};
    whereParam['m.id'] = param.matterID;
    //获取活动id
    const activity = await this.model('matter').alias('m').field('a.*').join('left join activity as a on a.id=m.activityID').where(whereParam).find();
    //根据活动查找人员
    // const res = await this.model('person_activity').where({activityID:activity.id}).page(param.page,param.pageSize).countSelect();
    let res = await this.model('person').setRelation(false).join('person_activity on person_activity.personID = person.id')
      .where({"person_activity.activityID":activity.id}).field('person.*').page(param.page, param.pageSize).countSelect();
    let finaRes = {
      count:res.count,
      totalPages:res.totalPages,
      pageSize:res.pageSize,
      currentPage:res.currentPage,
      activity: activity,
      // person: res
      person: res.data
    }
    return this.success(finaRes);
  }
  //查询事项详细信息
  async findAction() {
    const param = this.post();
    const res = await this.model('matter').where({id: param.id}).find();
    this.success(res);
  }
  // 根据活动ID查询对应的事项
  async listAction() {
    const data = this.post();
    // let userInfo = await this.getUserInfo(userid);// 获取用户信息
    // const back = await this.model('matter').where({'matter.activityID': data.activityID,'createAccount':userInfo.username}).select();
    let where = {
      'matter.activityID': data.activityID
    };
    if (data.hasOwnProperty("matterID")){
      where["matter.id"] = data.matterID
    }
    let back = await this.model('matter').where(where).select();
    if (!think.isEmpty(back)){
      for (let i in back){
        let lead = await this.model('delegate_leading').alias('dl').join('activity_leading as al on al.leadingID = dl.id')
          .where({"al.activityID":back[i].activityID}).field('dl.*').find();
        if (!think.isEmpty(lead)) {
          back[i]["leading"] = lead;
        }else {
          back[i]["leading"] = {}
        }
        if (back[i].url === null || back[i].url.length === 0){
          back[i].url = [];
          back[i]["file"] = [];
        }else {
          back[i].url = back[i].url.split(',');
          let file = await this.model("file_log").where({"url":["IN", back[i].url]}).select();
          back[i]["file"] = file;
        }
        if (back[i].tellLog === null || back[i].tellLog === ""){
          back[i]["tell_log"] = "";
        }else {
          let sql = 'select * from tell_log where (id = ' + back[i].tellLog + ') or (isSend = 1 and isRepresent =1 and matterID = "'+back[i].id+'")';
          let logs = await this.model("tell_log").query(sql)
          // let logs = await this.model("tell_log").where({"id":back[i].tellLog}).select();
          back[i]["tell_log"] = logs;
        }
        if (back[i].tellLogRepresent !== null){
          back[i]["tell_log_represent"] = "";
        }else {
          if (back[i].tell_log !== ""){
            let sql = 'select * from tell_log where (id = ' + back[i].tellLog + ') or (isSend = 1 and isRepresent = 0 and matterID = "'+back[i].id+'")';
            let log_represent = await this.model("tell_log").query(sql)
            // let log_represent = await this.model("tell_log").where({"id":back[i].tellLogRepresent}).select();
            back[i]["tell_log_represent"] = log_represent;
          }
        }
      }
    }
    return this.success(back)
  }
  /**
   * showdoc
   * @catalog 事项信息
   * @title 流程引擎事件列表
   * @description 流程引擎事件列表接口
   * @method post
   * @url http://127.0.0.1:8360/matter/taskMatterList
   * @param userId 必选 string 登录人userId
   * @param businessID 必选 int 业务序号
   * @param activityNum 必选 string 活动编号
   * @param matterNum 必选 string 事项编号
   * @param contentClassifyID 必选 string 问题分类编号
   * @param startTime 必选 string 登记开始时间
   * @param endTime 必选 string 登记结束时间
   * @param finalDisposalID 必选 int 去向单位id
   * @param name 必选 string 首登记人
   * @param sendStartTime 必选 string 发送开始时间
   * @param sendEndTime 必选 string 发送结束时间
   * @param submitStartTime 必选 string 送审开始时间
   * @param submitEndTime 必选 string 送审结束时间
   * @param submitUserID 必选 string 送审人id
   * @param agent 选 string 代办人userId
   * @return {"errno": 0, "errmsg":"", "data":{}}
   */
  // 流程引擎事件列表
  async taskMatterListAction(){
    const data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    // 取交集
    let intersection = (nums1, nums2) => {
      return [...new Set(nums1)].filter((item) => {
        return nums2.includes(item);
      });
    };
    let where = {
      'fw.businessID':['IN',data.businessID],
      // 'fw.deptID_now':userInfo.orgID
    };
    if (data.hasOwnProperty("activityNum")){
      where["ac.activityNum"] = ['LIKE','%' + data.activityNum + '%'];
    }
    if (data.hasOwnProperty("matterNum")){
      where["m.matterNum"] = ['LIKE','%' + data.matterNum + '%'];
    }
    if (data.hasOwnProperty("contentClassifyID") && data.contentClassifyID !==""){
      if (data.contentClassifyID.substr(0,3) === '003'){
        // 纪检监察类
        where["m.contentClassifyMainID"] = ['LIKE',data.contentClassifyMainID + '%'];
      } else {
        where["m.contentClassifyID"] = ['LIKE',data.contentClassifyID + '%'];
      }
    }
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      where["m.createTime"] = ['>',moment(data.startTime).format('YYYY-MM-DD HH:mm:ss')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      where["m.CreateTime"] = ['<',moment(data.endTime).add(1,'day').format('YYYY-MM-DD HH:mm:ss')];
    }
    if (data.hasOwnProperty('name') && data.name !== ''){
      // 首登记人，这操作有点骚，去模糊查询信访事项名称
      where["m.xfName"] = ['LIKE','%' + data.name + '%'];
    }
    if (data.hasOwnProperty('finalDisposalID') && data.finalDisposalID !== ''){
      //去向单位
      where["fw.deptID_pre"] = data.finalDisposalID;
    }
    // 转交时间（上级发送时间）
    if (data.hasOwnProperty('sendStartTime') || data.hasOwnProperty('sendEndTime')){
      let sql = 'SELECT c_task FROM (SELECT * FROM fw_task_act WHERE businessID IN (15,22))t GROUP BY c_task ORDER BY c_time DESC';
      // fw_task_act      15去往职能单位的发送 22去往人大的发送
      if (data.hasOwnProperty('sendStartTime') && data.sendStartTime !== '' && data.hasOwnProperty('sendEndTime') && data.sendEndTime !== ''){
        sql = 'SELECT c_task FROM (SELECT * FROM fw_task_act WHERE businessID IN (15,22))t WHERE c_time BETWEEN "' + moment(data.sendStartTime).format('YYYY-MM-DD')
        + '" AND "' + moment(data.sendEndTime).add(1,'day').format('YYYY-MM-DD') + '" GROUP BY c_task ORDER BY c_time DESC';
      }else if (data.hasOwnProperty('sendStartTime') && data.sendStartTime !== '') { // 只传开始时间
        sql = 'SELECT c_task FROM (SELECT * FROM fw_task_act WHERE businessID IN (15,22))t WHERE c_time > "' + moment(data.sendStartTime).format('YYYY-MM-DD')
        + '" GROUP BY c_task ORDER BY c_time DESC';
      }else if (data.hasOwnProperty('sendEndTime') && data.sendEndTime !== '') {
        sql = 'SELECT c_task FROM (SELECT * FROM fw_task_act WHERE businessID IN (15,22))t WHERE c_time < "' +
          moment(data.sendEndTime).add(1,'day').format('YYYY-MM-DD') + '" GROUP BY c_task ORDER BY c_time DESC';
      }
      let task = await this.model('fw_task_act').query(sql);
      let taskList = [];
      if (!think.isEmpty(task)) {
        task.forEach(function(item) {
          taskList.push(item.c_task);
        });
        if (taskList.length>0){
          where['m.taskid'] = ['IN',taskList]
        }
      }else {
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    // 登记单位
    if (data.hasOwnProperty('createOrg') && data.createOrg !== ''){
      // 0 上上级 1上级 2本级
      let createOrgID = 0;
      if (parseInt(data.createOrg) === 0){
        let sql = 'SELECT * FROM sys_organization WHERE deptID = (SELECT id FROM sys_dept WHERE id = (SELECT parentID ' +
          'FROM sys_dept WHERE id = (SELECT parentID FROM sys_dept WHERE id = '+ userInfo.dictValue +'))) AND agent = 1';
        let ssj = await this.model('sys_organization').query(sql);
        if (!think.isEmpty(ssj)){
          createOrgID = ssj.id
        }
      }else if (parseInt(data.createOrg) === 1) {
        let sql = 'SELECT * FROM sys_organization WHERE deptID = (SELECT id FROM sys_dept WHERE id = ' +
          '(SELECT parentID FROM sys_dept WHERE id = '+ userInfo.dictValue +'))) AND agent = 1';
        let sj = await this.model('sys_organization').query(sql);
        if (!think.isEmpty(sj)){
          createOrgID = sj.id
        }else if (parseInt(data.createOrg) === 2) {
          createOrgID = userInfo.orgID
        }
      }
      where['m.createOrgID'] = createOrgID;
    }
    // 办理方式
    if (data.hasOwnProperty('handleModelID') && data.handleModelID !== '') { // 逐级可查
      let sql = 'SELECT * FROM history t WHERE JSON_EXTRACT( t.info,"$.handleModelID") LIKE "'+ data.handleModelID +'"%';
      let history = await this.model('history').query(sql);
      let taskID = [];
      if (!think.isEmpty(history)){
        history.forEach(function(item) {
          taskID.push(item.taskId);
        });
        if (where.hasOwnProperty('m.taskid') && where['m.taskid'][1].length > 0) {
          // 取taskid交集
          where['m.taskid'][1] = intersection(taskID,where['m.taskid'][1])
          // where['m.taskid'][1] = taskID.concat(where['m.taskid'][1]);
        }else {
          where['m.taskid'] = ['IN',taskID]
        }
      }
    }
    // 送审时间和送审人
    if (data.hasOwnProperty('submitStartTime') || data.hasOwnProperty('submitEndTime') || data.hasOwnProperty('submitUserID')){
      let submitWhere = {
        'businessID':['IN',data.businessID]
      };
      if (data.hasOwnProperty('submitStartTime') && data.submitStartTime !== ''){
        submitWhere["c_time"] = ['>',moment(data.submitStartTime).format('YYYY-MM-DD')];
      }
      if (data.hasOwnProperty('submitEndTime') && data.submitEndTime !== ''){
        submitWhere["C_TIME"] = ['<',moment(data.submitEndTime).add(1,'day').format('YYYY-MM-DD')];
      }
      if (data.hasOwnProperty('submitUserID') && data.submitUserID.length > 0) {// 送审人userID
        submitWhere["c_user"] = ['IN',data.submitUserID];
      }
      let submit = await this.model('fw_task_act').where(submitWhere).select();
      if (!think.isEmpty(submit)) {
        let taskID = [];
        submit.forEach(function(item) {
          taskID.push(item.c_task);
        });
        if (taskID.length > 0 ){
          if (where.hasOwnProperty('m.taskid') && where['m.taskid'][1].length > 0) {
            // 取taskid交集
            where['m.taskid'][1] = intersection(taskID,where['m.taskid'][1])
            // where['m.taskid'][1] = taskID.concat(where['m.taskid'][1]);
          }else {
            // 前面传了参数，但是没有符合条件
            if (data.hasOwnProperty('handleModelID') && data.handleModelID !== ''){
              return this.success({
                "count": 0,
                "totalPages": 0,
                "pageSize": 10,
                "currentPage": 1,
                "data": []
              })
            } else {
              where['m.taskid'] = ['IN',taskID]
            }
          }
        }
      }else {// 未命中，因为是and条件，此条件未命中，则结果应为空
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    // 回报反馈审批部分 办理结果solveCode/FK 拟办意见auditOpinionID/JA
    if ((data.hasOwnProperty('solveCode') && data.solveCode !== null) || (data.hasOwnProperty('auditOpinionID') && data.auditOpinionID !== null)) {
      let taskList = [];
      if (data.hasOwnProperty('solveCode') && data.solveCode !== ''){
        let sql = 'SELECT taskId FROM (SELECT * FROM history WHERE businessID = 17 GROUP BY taskId ORDER BY time DESC)t WHERE solveCode = "' + data.solveCode +'"';
        let history = await this.model('history').query(sql);
        history.forEach(function(item) {
          taskList.push(item.taskId);
        })
      }
      if (data.hasOwnProperty('auditOpinionID') && data.auditOpinionID !== '') {
        // let sql = 'SELECT taskId FROM (SELECT * FROM history WHERE businessID = 19 AND info LIKE "%auditOpinionID%" GROUP BY taskId ORDER BY time DESC)t WHERE info LIKE \'%auditOpinionID": "' + data.auditOpinionID +'"%\'';
        let sql = 'SELECT taskId FROM (SELECT * FROM history WHERE businessID = 19 AND info LIKE "%auditOpinionID%" GROUP BY taskId ORDER BY time DESC)t WHERE JSON_EXTRACT(t.info,"$.auditOpinionID") LIKE "%' + data.auditOpinionID +'%"';
        let history = await this.model('history').query(sql);
        let hisTask = [];
        history.forEach(function(item) {
          hisTask.push(item.taskId);
        });
        taskList = intersection(taskList,hisTask);
      }
      if (taskList.length > 0 ){
        if (where.hasOwnProperty('m.taskid') && where['m.taskid'][1].length > 0) {//已经给where['m.taskid'] 赋过值了
          // where['m.taskid'][1] = taskList.concat(where['m.taskid'][1])
          where['m.taskid'][1] = intersection(taskList,where['m.taskid'][1])
        }else {
          where['m.taskid'] = ['IN',taskList];
        }
      }else { // 未命中，因为是and条件，此条件未命中，则结果应为空
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    switch (data.businessID[0]) {
      case 21://办理
      case 22://签收
      case 13://自办填报
      case 2://信访登记审批
      case 23:
      case 32:
      case 4://交办函审批
      case 8://转送单审批
      case 29:
      case 26:
      case 37:// 自办审批
      case 20://下级回报反馈
      case 34:// 大会接谈室等候列表
      case 35:// 大会省直机关接谈接谈中
      case 36:// 大会分类处理
      // case 1://大会领导审核
      case 10:// 待接谈
      case 11:// 已存件
      case 12:// 已存信
      case 14:// 已自办待关闭
        where["fw.deptID_now"] = userInfo.orgID;
        break;
      case 24://登记
      case 3://拟函审批
      case 5://交办打印
      case 7://转交打印
      case 25:
      case 28:
      case 6://转送
      case 9:
      case 27:
      case 30:
      case 19://向上签收
        where["fw.charger"] = data.userId;
        break;
      case 15://反馈签收
      case 16://回报审核
      case 17://向上回报
      case 18://向上回报反馈
        if (data.hasOwnProperty('agent') && data.agent !== ''){
          //仅仅查询代理
          where['fw.agent'] = data.agent
        } else {
          where["fw.deptID_now"] = userInfo.orgID;
        }
        // where["_complex"] = {
        //   "fw.deptID_now": userInfo.orgID,
        //   "fw.agent": data.userId,
        //   _logic: 'or'
        // };
        break;
      case 33://大会版分配接谈
        where['m.createAccount'] = userInfo.user_name
    }
    if (data.businessID[0] === 1){
      //大会版领导审核
      where["fw.deptID_now"] = userInfo.orgID;
      where['fw.businessID'] = ['IN',[1,2]];// 1 大会流程的领导审核 2大会普通流程的登记审核
      where['m.isMeeting'] = 0;
    }
    if (data.hasOwnProperty("registerTypeID") && data.registerTypeID !== ""){
      where['ac.registerTypeID'] = data.registerTypeID
    }
    let matter = await this.model('matter').alias('m')
      .field('m.*,fw.businessID,fw.dealType_pre,fw.deptID_create,fw.deptName_create,fw.isBack').join({
      table: 'fw_task',
      join: 'left',
      as: 'fw',
      on: ['taskid', 'id']
    }).join({
      table: 'activity',
      join: 'left',
      as: 'ac',
      on: ['activityID', 'id']
    }).where(where).order(['m.createTime desc']).page(data.page,data.limit).countSelect().catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(matter)) {
      return this.fail('Get review query fail');
    }
    for (let item of matter.data){
      if (item.dealType_pre === "转交") {
        item.dealType_pre = "转送"
      }
      if (item.url.length > 0){
        let file = await this.model("file_log").where({"url":["IN", item.url]}).select();
        if (think.isEmpty(file)){
          item["file"] = [];
        } else {
          item["file"] = file
        }
      }
      let queue = await this.model('queue').where({'matterID':item.id}).order('createTime desc').find();
      if (!think.isEmpty(queue)){
        item['queueID'] = queue.id;
        item['roomCode'] = queue.roomCode;
        item['roomCodeNum'] = queue.roomCodeNum;
      }
    }
    if (data.businessID[0] === 34) {
      matter.data = matter.data.reverse()
    }
    return this.success(matter);
  }

  // 根据条件查询当前部门信访事项
  //matterNum:"信访事项编号",
  //xfSourceID:"信访形式",
  //xfName:"信访名称",
  //name:"信访人姓名",
  //objectName:"信访主体名称",
  //contentClassifyID:"问题分类",
  //happenRegionID:"问题属地",
  //objectName:"信访主体名称",
  //deptID_now:"最近承办部门ID",
  //operator:"最近承办人"（模糊搜索）,
  //businessName:"当前流转状态",
  //solveCode:"办理结果",
  //auditOpinionID:"审核签收结果",
  //hotspot:"热点标签",
  //personspot:"个人标签",
  //isMeeting 大会标识 0是1不是
  //talkingOrgID 大会接谈单位ID
  //handleModelID 办理方式
  //belongsID 所属系统编号
  //startTime:
  //endTime
  //page
  //pageSize
  //userId
  //deptID: 数据选择范围array
  async getMatterListAction(){
    const data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    // 取交集
    let intersection = (nums1, nums2) => {
      return [...new Set(nums1)].filter((item) => {
        return nums2.includes(item);
      });
    };
    // let orgAccount = await this.model('sys_organization').join('sys_user on sys_user.orgID = sys_organization.id')
    //   .where({"sys_organization.id":['IN',[userInfo.orgID]]}).field("sys_user.user_name").select();
    // let createAccount = [];
    // orgAccount.forEach(function(item) {
    //   createAccount.push(item.user_name);
    // });
    let activityList = [];
    if ((data.hasOwnProperty('name') && data.name !== '')||(data.hasOwnProperty('objectName') && data.objectName !== '')) {
      let personWhere ={};
      if (data.hasOwnProperty('name')){
        personWhere['person.name'] = ['LIKE', '%' + data.name + '%']
      }
      if (data.hasOwnProperty('objectName')){//信访主体名称
        personWhere['person_activity.objectName'] = ['LIKE', '%' + data.objectName + '%']
      }
      let activity = await this.model('person').join('person_activity on person_activity.personID = person.id')
        .where(personWhere).field("person_activity.activityID").select();
      if (think.isEmpty(activity)){
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      } else {
        activity.forEach(function(item) {
          activityList.push(item.activityID);
        })
      }
    }
    let where = {
      'activity.xfTypeID':data.xfTypeID === undefined || data.xfTypeID === ''|| data.xfTypeID.length ===0 ? ['!=',null] :['IN',data.xfTypeID],// 信访类型 逐级
      'matter.matterNum':data.matterNum === undefined || data.matterNum === '' ? ['!=',null] :['LIKE', '%' + data.matterNum + '%'],// 事项编号
      'matter.xfName':data.xfName === undefined || data.xfName === '' ? ['!=',null] :['LIKE', '%' + data.xfName + '%'],// 事项名称
      'matter.happenRegionID':data.happenRegionID === undefined || data.happenRegionID === '' || data.happenRegionID.length === 0 ? ['!=',null] :['IN',data.happenRegionID ],// 问题属地 逐级
      // 'matter.createAccount':['IN',createAccount],// 当前用户所在部门的所有账号
      'matter.activityID':activityList.length === 0 ? ['!=',null] : ['IN',activityList],
      'matter.taskid':['!=',null],
      'matter.SKSFL':!data.hasOwnProperty('SKSFL') || data.SKSFL.length === 0 ? ['!=',null] : ["IN",data.SKSFL],// 三跨三分离
      'matter.abstract':!data.hasOwnProperty('abstract') || data.abstract === '' ? ['!=',null] :['LIKE', '%' + data.abstract + '%'],// 信访摘要
    };
    if (data.hasOwnProperty('visit') && data.visit !== ''){
      if (data.visit === 0) {
        where['matter.visitID'] = '200';
      }else if (data.visit === 1) {
        where['matter.visitID'] = '100';
      }
    }
    //异常
    if (data.hasOwnProperty('abnormalID') && Array.isArray(data.abnormalID) && data.abnormalID.length > 0){//异常
      where['activity.abnormalID'] =  ['IN',data.abnormalID]
    }
    //信访来源
    if (data.hasOwnProperty('xfSourceID') && Array.isArray(data.xfSourceID) && data.xfSourceID.length > 0){//信访来源
      where['activity.xfSourceID'] =  ['IN',data.xfSourceID]
    }
    // 领导代表
    if (data.hasOwnProperty('leader') && Array.isArray(data.leader) && data.leader.length > 0){
      where["activity.xfSourceID"] = ['IN',data.leader];
      let leaderWhere = {};
      // 领导代表姓名
      if (data.hasOwnProperty('leaderName')) {
        leaderWhere["dl.name"] = ['like', '%' + data.leaderName + '%']
      }
      // 届次
      if (data.hasOwnProperty('due')) {
        leaderWhere["dl.due"] = ['like', '%' + data.due + '%']
      }
      // 层级
      if (data.hasOwnProperty('grade')) {
        leaderWhere["dl.grade"] = ['like', '%' + data.grade + '%']
      }
      // 地区编号
      if (data.hasOwnProperty('zoneID')) {
        leaderWhere["dl.zoneID"] = data.zoneID
      }
      let la = await this.model('activity_leading').alias('al').join('delegate_leading as dl on dl.id = al.leadingID').where(leaderWhere).select();
      if (!think.isEmpty('la')){
        let acID = [];
        la.forEach(function(item) {
          acID.push(item.activityID);
        });
        if (acID.length > 0){
          where["activity.id"] = ['IN',acID];
        }
      }
    }
    // 被反映人姓名
    if (data.hasOwnProperty('identityName') && data.identityName !== '') {
      where['matter.identityName'] = ['LIKE', '%' + data.identityName + '%']
    }
    if (data.hasOwnProperty('deptID') && Array.isArray(data.deptID) && data.deptID.length > 0){
      // 对查询的数据范围进行选择
      let dept = await this.model('sys_dept').where({'id':userInfo.dictValue}).find();
      if (!think.isEmpty(dept) && data.deptID.includes(dept.parentID)) { // 选择了上级，即上级登记，本级经手
        where['fw_task_act.deptID_now'] = userInfo.dictValue;//本级经手
        data.deptID.concat(dept.parentID);//加入上级
        data.deptID.push(2);// 和 上上级
      }
      let org = await this.model('sys_organization').where({'deptID':['IN',data.deptID],'agent':1}).select();
      if (!think.isEmpty(org)){
        let co = [];
        org.forEach(function(item) {
          co.push(item.id)
        });
        where['matter.createOrgID'] = ['IN',co];
      }
    }
    // 当前流转状态
    if (data.hasOwnProperty('businessName') && data.businessName !== ''){
      where['fw_task.businessName'] = data.businessName
    }
    // 最近承办人（指的是最近操作人员）
    if (data.hasOwnProperty('operator') && data.operator !== ''){
      let user = await this.model('sys_user').where({'name':['LIKE','%'+data.operator+'%']}).select();
      if (!think.isEmpty(user)){
        let userList = [];
        user.forEach(function(item) {
          userList.push(item.user_id);
        });
        if (userList.length > 0){
          where['fw_task.c_user'] = ['IN',userList]
        }
      }else {// 未命中，因为是and条件，此条件未命中，则结果应为空
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    // 最近承办单位(现在部门id
    if (data.hasOwnProperty('deptID_now') && data.orgID !== ''){
      where['fw_task.deptID_now'] = data.deptID_now
    }
    // 热点问题标签 和 个人标签
    if ((data.hasOwnProperty('hotspot') && data.hotspot !== '') || (data.hasOwnProperty('personspot')  && data.personspot !== '')){
      let spotMatterID = []; // 通过标签筛选出matterID
      // 两个标签都是单选
      if (data.hasOwnProperty('hotspot') && data.hotspot !== ''){
        let label = await this.model('label_count').where({'labelName':['LIKE',['%'+ data.hotspot + '%']],'type':1}).select();
        label.forEach(function(item) {
          spotMatterID.push(item.matterID);
        })
      }
      if (data.hasOwnProperty('personspot') && data.personspot !== ''){
        let label = await this.model('label_count').where({'labelName':['LIKE',['%'+ data.personspot + '%']],'type':2}).select();
        label.forEach(function(item) {
          spotMatterID.push(item.matterID);
        })
      }
      if (spotMatterID.length > 0 ){
        where['matter.id'] = ['IN',spotMatterID];
      }else { // 未命中，因为是and条件，此条件未命中，则结果应为空
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    // 大会标识
    if (data.hasOwnProperty('isMeeting') ) {
      where['matter.isMeeting'] = data.isMeeting;
      if (data.isMeeting === 0 && data.hasOwnProperty('talkingOrgID') && data.talkingOrgID.length > 0){
        // 大会件
        let meetingMatter = await this.model('talking_record').where({'orgID':['IN',data.talkingOrgID]}).select();
        if (!think.isEmpty(meetingMatter)){
          let matterList = [];
          meetingMatter.forEach(function(item) {
            matterList.push(item.matterID)
          });
          if (where.hasOwnProperty('matter.id') && where['matter.id'][1].length > 0){
            // where['matter.id'][1] = meetingMatter.concat(where['matter.id'][1]);
            //应当取id交集
            where['matter.id'][1] = intersection(meetingMatter,where['matter.id'][1]);
          }
        }else { // 未命中，因为是and条件，此条件未命中，则结果应为空
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        }
      }
    }
    // 所属系统和办理方式 逐级
    if ((data.hasOwnProperty('belongsID') && data.belongsID !== ''&& data.belongsID.length > 0)
      || (data.hasOwnProperty('handleModelID') && data.handleModelID !== ''&& data.handleModelID.length > 0)){
      let taskIds = [];
      if (data.hasOwnProperty('belongsID') && data.belongsID !== ''&& data.belongsID.length > 0){
        // let history = await this.model('history').where({'info':['like','%belongsID": "' + data.belongsID +'%']}).select();
        let matter = await this.model('matter').setRelation(false).where({'belongsID':['IN',data.belongsID]}).select();
        let str = Array.isArray(data.belongsID) ? "'" + data.belongsID.join("','" ) + "'" :data.belongsID;
        let sql = "SELECT * FROM `history` WHERE info -> '$.belongsID' IN ("+ str +")";
        let history = await this.model('history').query(sql);
        history.forEach(function(item) {
          taskIds.push(item.taskId);
        });
        matter.forEach(function(item) {
          taskIds.push(item.taskid);
        })
      }

      if (data.hasOwnProperty('handleModelID') && data.handleModelID !== ''&& data.handleModelID.length > 0){
        // let history = await this.model('history').where({'info':['like','%handleModelID": "' + data.handleModelID +'%']}).select();

        let str = Array.isArray(data.handleModelID) ? "'" + data.handleModelID.join("','" ) + "'" :data.handleModelID;
        // let sql = "SELECT t.* FROM ( " +
        //   "SELECT * FROM `history` WHERE businessID IN (2,32) AND info -> '$.handleModelID' IN ("+ str +") AND info -> '$.dealType_pre' != '修改' ORDER BY id desc limit 99999" +
        //   ") t GROUP BY t.deptID,t.taskId";
        let sql = "SELECT * FROM(SELECT t.* FROM (SELECT * FROM `history` WHERE businessID IN (2,32)  ORDER BY id desc limit 99999) t GROUP BY t.taskId,t.deptID) b" +
          " WHERE b.info ->> '$.handleModelID' IN ("+ str +") AND b.info -> '$.dealType_pre' != '修改'";
        let history = await this.model('history').query(sql);
        let historyTask = [];
        history.forEach(function(item) {
          historyTask.push(item.taskId);
        });
        if (data.hasOwnProperty('belongsID') && data.belongsID !== ''&& data.belongsID.length > 0 ){
          // 条件之间，taskid相交
          taskIds = intersection(historyTask,taskIds);
        } else {
          taskIds = historyTask;
        }
      }
      if (taskIds.length > 0 ){
        where['matter.taskid'] = ['IN',taskIds]
      }else { // 未命中，因为是and条件，此条件未命中，则结果应为空
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    // 最近一次办理结果 FK 和 最近一次审核签收结果 JA
    if ((data.hasOwnProperty('solveCode') && data.solveCode.length > 0) || (data.hasOwnProperty('auditOpinionID')  && data.auditOpinionID !== '') ) {
      let taskList = [];
      if (data.hasOwnProperty('solveCode') && data.solveCode !== '' ){
        // let sql = 'SELECT taskId FROM (SELECT * FROM history WHERE businessID = 17 GROUP BY taskId ORDER BY time DESC)t WHERE solveCode = "' + data.solveCode +'"';
        let str = Array.isArray(data.solveCode) ? "'" + data.solveCode.join("','" ) + "'" :data.solveCode;
        let sql = 'SELECT taskId FROM (SELECT * FROM history WHERE businessID = 17 GROUP BY taskId ORDER BY time DESC)t WHERE solveCode IN (' + str +')';
        let history = await this.model('history').query(sql);
        history.forEach(function(item) {
          taskList.push(item.taskId);
        })
      }
      if (data.hasOwnProperty('auditOpinionID') && data.auditOpinionID !== '') {
        // let sql = 'SELECT taskId FROM (SELECT * FROM history WHERE businessID = 19 AND info LIKE "%auditOpinionID%" GROUP BY taskId ORDER BY time DESC)t WHERE info LIKE \'%auditOpinionID": "' + data.auditOpinionID +'"%\'';
        let sql = 'SELECT taskId FROM (SELECT * FROM history WHERE businessID = 19 AND info LIKE "%auditOpinionID%" GROUP BY taskId ORDER BY time DESC)t WHERE JSON_EXTRACT(t.info,"$.auditOpinionID") LIKE "%' + data.auditOpinionID +'%"';
        let history = await this.model('history').query(sql);
        let historyTask = [];
        history.forEach(function(item) {
          historyTask.push(item.taskId);
        });
        if (data.hasOwnProperty('solveCode') && data.solveCode !== '') {
          // 条件之间，taskid相交
          taskList = intersection(historyTask,taskList)
        }else {
          taskList = historyTask;
        }

      }
      if (taskList.length > 0 ){
        if (where['matter.taskid'][0] === '!=' && where['matter.taskid'][1] === null) {
          where['matter.taskid'] = ['IN',taskList]
        }else {//已经给where['matter.taskid'] 赋过值了
          where['matter.taskid'][1] = intersection(taskList,where['matter.taskid'][1])
        }
      }else { // 未命中，因为是and条件，此条件未命中，则结果应为空
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    // 问题分类
    if (data.hasOwnProperty('contentClassifyID')) {//逐级查询，单选
      if (data.contentClassifyID.substr(0,3) === "003") {
        // 纪检监察类，只查主要问题
        where['matter.contentClassifyMainID'] = ['LIKE',data.contentClassifyID + '%']
      }else {
        where['matter.contentClassifyID'] = ['LIKE',data.contentClassifyID + '%']
      }
    }
    // 时间
    if (data.startTime === '' && data.endTime === ''){
      where['matter.createTime'] = ['!=', null] //全选
      // 默认当天
    } else if (data.startTime === ''){
      // 未设定开始时间
      where['matter.createTime'] = ['between', '1900-01-01' + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    } else if (data.endTime === ''){
      // 未设定结束时间
      where['matter.createTime'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + '2099-01-01']
    } else {
      where['matter.createTime'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    }
    let count =  await this.model('matter').join('activity on activity.id = matter.activityID').join('fw_task on fw_task.id = matter.taskid')
      .join('fw_task_act on fw_task_act.c_task = matter.taskid').where(where).distinct('matter.id').select();
    const matter = await this.model('matter').join('activity on activity.id = matter.activityID').join('fw_task on fw_task.id = matter.taskid')
      .join('fw_task_act on fw_task_act.c_task = matter.taskid').where(where).page(data.page, data.pageSize)
      // .field("matter.*").distinct('matter.*').order('matter.createTime DESC').countSelect(count.length);
      .field("matter.id,matter.activityID,matter.xfName,matter.happenRegion,matter.createTime,matter.createPerson,matter.matterNum")
      .distinct('matter.id,matter.activityID,matter.xfName,matter.happenRegion,matter.createTime,matter.createPerson,matter.matterNum')
      .order('matter.createTime DESC').countSelect(count.length);
    return this.success(matter)
  }

  /**
   * showdoc
   * @catalog 事项信息
   * @title 流程引擎事件列表
   * @description 反馈回报详细列表
   * @method post
   * @url http://127.0.0.1:8360/matter/feedbackDetailList
   * @param taskId 必选 int taskId 流程ID
   * @return {"errno": 0, "errmsg":"", "data":{}}
   */
  // 流程引擎事件列表
  async feedbackDetailListAction() {
    const data = this.post();
    data.taskId = data.taskId === undefined ? 0 : data.taskId;

    // const Sql = 'select n.time,n.businessID,n.deptName,u.name,n.info from node_record n LEFT JOIN sys_user u on n.account = u.user_name ' +
    const Sql = 'select n.time,n.businessID,n.deptName,u.name,n.info from history n LEFT JOIN sys_user u on n.account = u.user_name ' +
      'where taskId = ' + data.taskId + ' and businessID in (17,18,19,20) ' +
      'order by id desc';
    const returnData = await this.model('sys_organization').query(Sql);
    for (const item of returnData){
      item.info = JSON.parse(item.info);
      if (item.info.hasOwnProperty('url')){
        if (item.info.url.length > 0) {
          item.info["url_file"] = await think.model('file_log').where({"url":['IN',item.info.url]}).select()
        }else {
          item.info["url_file"] = []
        }
      }
      if (item.info.hasOwnProperty('endingUrl')){
        if (item.info.endingUrl.length > 0) {
          item.info["endingUrl_file"] = await think.model('file_log').where({"url":['IN',item.info.endingUrl]}).select()
        }else {
          item.info["endingUrl_file"] = [];
        }
      }
      if (item.businessID === 17){
        let agent = await think.model('fw_task_act').where({"c_task":data.taskId,"businessID":17}).find();
        if (!think.isEmpty(agent) && agent.agent !== null && agent.agent !== ""){
          item.deptName = agent.deptName_now + "("+item.deptName+"代办)"
        }
      }
    }
    this.success(returnData);
  }
  /**
   * showdoc
   * @catalog 事项信息
   * @title 经手事件列表
   * @description 经手事件列表列表接口
   * @method post
   * @url http://127.0.0.1:8360/matter/passMatterList
   * @param userId 必选 string 操作人人userId
   * @param businessID 必选 int 业务序号
   * @return {"errno": 0, "errmsg":"", "data":{}}
   */



  // select DISTINCT c_task from fw_task_act where businessID in (
  //   select DISTINCT businessID from fw_act where id in
  // (select c_to from fw_act_path where c_from in (
  //   select id from fw_act where businessID = 0))) and c_user = '33e424d8250645faa9f1c61895748f08'
  async passMatterListAction() {
    let data = this.post();
    // let where = {
    //   'fta.c_user':data.userId,
    //   'fta.businessID':data.businessID
    // };
    let where = {};
    // businessID=0 已提交登记审批 l; businessID=2 登记已审批
    if (typeof data.registerTypeID !== 'undefined' && data.registerTypeID !== ''){
      where['a.registerTypeID'] = data.registerTypeID //信访类型
    };
    // 操作时间
    let startTime = typeof data.startTime === 'undefined' ? '' : data.startTime;
    let endTime = typeof data.endTime === 'undefined' ? '' : data.endTime;
    if (startTime === '' && endTime === ''){
      where['fta.c_time'] = ['!=', null] //全选
      // 默认当天
    } else if (startTime === ''){
      // 未设定开始时间
      where['fta.c_time'] = ['between', '1900-01-01' + ',' + moment(endTime).add(1, 'day').format('YYYY-MM-DD')]
    } else if (endTime === ''){
      // 未设定结束时间
      where['fta.c_time'] = ['between', moment(startTime).format('YYYY-MM-DD') + ',' + '2099-01-01']
    } else {
      where['fta.c_time'] = ['between', moment(startTime).format('YYYY-MM-DD') + ',' + moment(endTime).add(1, 'day').format('YYYY-MM-DD')]
    }
    let sql = 'select DISTINCT c_task from fw_task_act where businessID in (' +
      'select DISTINCT businessID from fw_act where id in' +
      '(select c_to from fw_act_path where c_from in (' +
      'select id from fw_act where businessID = '+ data.businessID +'))) and c_user = "' +data.userId+'"'
    let task = await this.model('fw_task_act').query(sql);
    if (!think.isEmpty(task)){
      let taskId = [];
      task.forEach(function(item) {
        taskId.push(item.c_task)
      });
      where['m.taskid'] = ['IN',taskId];
    }else {
      return this.success({
        "count": 0,
        "totalPages": 0,
        "pageSize": 10,
        "currentPage": 1,
        "data": []});
    }
    let matter = await this.model('matter').alias('m').join('fw_task_act as fta on fta.c_task = m.taskid')
      .join('activity as a on a.id = m.activityID').where(where).page(data.page, data.pageSize)
      .field("m.*").distinct('m.*').order('m.createTime DESC').countSelect();
    return this.success(matter)
  }
  // 获取最近一条handle_log
  async getHandleLogAction(){
    let data = this.post();
    let handle = await this.model('handle_log').where({'matterID':data.matterID}).order('createTime DESC').find();
    let tellLog = await this.model('tell_log').where({"isSend":1,'matterID':data.matterID}).select()// 未发送的告知或者短信
    JSON.parse(JSON.stringify(handle));
    JSON.parse(JSON.stringify(tellLog));
    handle['tellLog'] = tellLog;
    return this.success(handle)
  }

  /**
   * showdoc
   * @catalog 事项信息
   * @title 可打印告知单的事项列表
   * @description 可打印告知单的事项列表接口
   * @method post
   * @url http://127.0.0.1:8360/matter/tellMatterList
   * @param userId 必选 string 操作人人userId
   * @param page 必选 int 页码
   * @param pageSize 必选 int 每页显示条数
   * @param startTime 选填 string 操作开始时间
   * @param endTime 选填 string 操作结束时间
   * @param matterNum 选填 string 事项编号
   * @param name 选填 string 首登记人
   * @return {"errno": 0, "errmsg":"", "data":{}}
   */
  // 本级有可打印告知单的事项列表
  async tellMatterListAction(){
    let data = this.post();
    //1当前单位 2过手人和领导
    let userInfo = await this.getUserInfo(data.userId);
    // 本单位领导
    let leader = await this.model('sys_user').where({'isLead':1,'orgID':userInfo.orgID}).select();
    // 经手人和领导账号
    let userList = [data.userId];
    leader.forEach(function(item) {
      userList.push(item.user_id);
    });
    // 过手事项taskId
    let taskList = [];
    let taskWhere = {
      'userId':['IN',userList]
    };
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      taskWhere['time'] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      taskWhere['TIME'] = ['<',moment(data.endTime).add(1,'days').format('YYYY-MM-DD')];
    }
    let task = await this.model('history').where(taskWhere).distinct('taskId').select();
    if (think.isEmpty(task)){
      return this.success([]);
    }
    task.forEach(function(item) {
      taskList.push(item.taskId);
    });
    // 当前单位告知单
    let tell = await this.model('tell_log').where({"sendType":2,"content":['!=',''],"sendOrgID":userInfo.orgID}).select();
    let matterList = [];// 本级有告知单的事项id
    let findTellID = [];//需要查找matterID的告知单id
    tell.forEach(function(item) {
      if (item.matterID === null || item.matterID === ""){
        findTellID.push(item.id);
      } else {
        matterList.push(item.matterID);
      }
    });
    if (findTellID.length > 0 ){
      let findMatter = await this.model('matter').setRelation(false).where({'tellLog':['IN',findTellID],"content":['!=','']}).select();
      findMatter.forEach(function(item) {
        matterList.push(item.id);
      })
    }
    // 最终搜索条件
    let where = {};
    if (matterList.length > 0) {
      where['matter.id'] = ['IN',matterList];
    }
    if (taskList.length > 0) {
      where['matter.taskid'] = ['IN',taskList];
    }
    if (matterList.length === 0 && taskList.length === 0) {
      return this.success({
        "count": 0,
        "totalPages": 0,
        "pageSize": 10,
        "currentPage": 1,
        "data": []
      })
    }
    if (data.hasOwnProperty('matterNum') && data.matterNum !== ''){
      where['matter.matterNum'] = ['LIKE','%'+data.matterNum+'%']
    }
    if (data.hasOwnProperty('name') && data.name !== ''){
      where['person.name'] = ['LIKE','%'+data.name+'%']
    }
    let matter = await this.model('matter').where(where).field('matter.*').join('activity on activity.id = matter.activityID')
      .join('person_activity on person_activity.activityID = activity.id')
      .join('person on person.id = person_activity.personID')
      .distinct('matter.*').order('matter.createTime Desc').page(data.page, data.pageSize).countSelect();
    let count = await this.model('matter').where(where).field('matter.*').join('activity on activity.id = matter.activityID')
      .join('person_activity on person_activity.activityID = activity.id')
      .join('person on person.id = person_activity.personID')
      .distinct('matter.id').select();
    matter.count = count.length;
    matter.totalPages = Math.ceil(count.length/matter .pageSize);
    return this.success(matter);
  }

  // 当前用户办理事项
  // name 信访人姓名
  // type 1 本人登记件，type 2 本人办理或代办件
  // startTime endTime
  // xfSourceID 数组 信访来源
  // matterNum 信访事项编号
  async handledAction(){
    const data = this.post();
    let userInfo = await this.getUserInfo(data.userId);
    let where = {
      'm.taskid':['!=',null]
    };
    if (data.hasOwnProperty('type') && data.type !== ''){
      // type 1 本人登记件，type 2 本人办理或代办件
      if (data.type === 1){ // 本人登记件
        where['m.createAccount'] = userInfo.user_name;
      }
      if (data.type === 2 ){ //  本人办理或代办件
        where['_complex'] = {
          'fta.charger': data.userId,
          'fta.agent': data.userId,
          _logic: 'or'
        };
        where['m.createAccount'] = ['!=',userInfo.user_name]
      }
    }else {
      where['m.createAccount'] = userInfo.user_name;// 默认本人
    }
    // 时间区间
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      where["m.createTime"] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      where["m.CreateTime"] = ['<',moment(data.endTime).add(1,'day').format('YYYY-MM-DD')];
    }
    // 信访类型
    if (data.hasOwnProperty('xfSourceID') && Array.isArray(data.xfSourceID) && data.xfSourceID.length > 0){
      where["a.xfSourceID"] = ['IN',data.xfSourceID];
    }
    // 事项编号
    if (data.hasOwnProperty('matterNum') && data.matterNum !== ''){
      where["m.matterNum"] = ['LIKE','%' + data.matterNum + '%'];
    }
    // 信访人姓名
    if (data.hasOwnProperty('name') && data.name !== ''){
      let person = await this.model('person').alias('p').setRelation(false).join('person_activity as pa on pa.personID = p.id')
        .where({'p.name':['LIKE','%' + data.name + '%']}).field("p.*,pa.activityID").select();
      if (think.isEmpty(person)){
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      } else {
        let acID = [];
        person.forEach(function(item) {
          acID.push(item.activityID);
        });
        if (acID.length > 0){
          where['a.id'] = ['IN',acID];
        }
      }
    }
    // 查询当前用户登记或者过手事项
    let matter = await this.model('matter').alias('m').where(where)
      .join('fw_task_act as fta on m.taskid = fta.c_task')
      .join('activity as a on a.id = m.activityID')
      .distinct('m.*').order('m.createTime Desc').page(data.page, data.pageSize).countSelect();
    let count = await this.model('matter').setRelation(false).alias('m').where(where)
      .join('fw_task_act as fta on m.taskid = fta.c_task')
      .join('activity as a on a.id = m.activityID').distinct('m.id').select();
    if (!think.isEmpty(matter)){
      for (let item of matter.data){
        let fta = await this.model('fw_task_act').where({'c_task':item.taskid}).order('c_time DESC').find();
        item['nowBusinessName'] = fta.businessName;
        item['nowOrgName'] = fta.deptName_now;
      }
    }
    matter.count = count.length;
    matter.totalPages = Math.ceil(count.length/matter .pageSize);
    return this.success(matter)
  }

  //获取 流程节点
  // taskId
  async getTaskActAction(){
    const data = this.post();
    if (!data.hasOwnProperty('taskId') || data.taskId === ''){
      return this.fail("taskId有误")
    }
    let fta = await this.model('fw_task_act').where({"c_task":data.taskId}).order('c_time Desc').select();
    if (!think.isEmpty(fta)) {
      for (let item of fta){
        // 办理人
        if (item.charger !== '' && item.charger !== null){
          let chargerName = await this.model('sys_user').where({'user_id':item.charger}).find();
          item['chargerName'] = chargerName.user_name;
        } else {
          item['chargerName'] = '';
        }
        // 代理人
        if (item.agent !== '' && item.agent !== null){
          let agentName = await this.model('sys_user').where({'user_id':item.agent}).find();
          item['agentName'] = agentName.user_name;
        } else {
          item['agentName'] = '';
        }
      }
    }
    return this.success(fta)
  }
};
