const Base = require('./base.js');
const moment = require('moment');
const repeat = require('./../handle/repeat');
module.exports = class extends Base {

  //增加绑定关系
  async addAction(){
    const param = this.post();
    if (!param.hasOwnProperty('matter') || !param.hasOwnProperty('matterList')||!param.hasOwnProperty('userId')) {
      return this.fail("参数缺失")
    }
    if (!Array.isArray(param.matterList) || param.matterList.length === 0) {
      return this.fail("matterList参数异常")
    }
    let userInfo = await this.getUserInfo(param.userId);
    //新增时，matter 作为主事项id只有一个，matterList作为与之有关联的事项，可以有多个
    let relation = await this.model('dictionary').where({'dictID':'SGX','flag':1}).select();
    for (let ml of param.matterList){
      for (let r of relation){
        if (ml.relationID.toString() === r.dictValue && (relation.description !== "互不相关")){// 互不相关不绑定
          ml['relation'] = r.description;
          break;
        }
      }
    }
    let relationList = await this.model('matter_relation').where({'matter_a':param.matter, 'matter_b':param.matter, _logic: 'or'}).select();
    if (think.isEmpty(relationList)){
      // matter_a 没有绑定关系
      let addData = [];
      param.matterList.forEach(async function(item) {
        addData.push({
          'matter_a': param.matter,
          'matter_b': item.matterID,
          'relationID': item.relationID,
          'relation': item.relation,
          'createUserID': param.userId,
          'createUserName': userInfo.name,
          'createOrgID': userInfo.orgID,
          'createOrgName': userInfo.orgName
        });
        // 更新重复访事项关系表
        if (item.relationID === '102') {
          await repeat.upRepeat(param.matter, item.matterID);
        }
      });
      if (addData.length > 0 ) {
        await this.model('matter_relation').addMany(addData);
        return this.success()
      }else {
        return this.fail()
      }
    } else {
      let upData = [];
      let newData = [];
      for (let mb of param.matterList){
        let states = 0 ;
        for (let list of relationList){
          if (list.matter_a === mb.matterID || list.matter_b === mb.matterID) {
            // 匹配到记录，修改关系
            states = 1;
            upData.push({
              'id':list.id,
              'matter_a':param.matter,
              'matter_b':mb.matterID,
              'relationID':mb.relationID,
              'relation':mb.relation,
              'createUserID':param.userId,
              'createUserName':userInfo.name,
              'createOrgID':userInfo.orgID,
              'createOrgName':userInfo.orgName,
              'time':moment().format("YYYY-MM-DD HH:mm:ss"),
            });
            break;
          }
        }
        if (states === 0){
          // 没有匹配到任何记录
          newData.push({
            'matter_a':param.matter,
            'matter_b':mb.matterID,
            'relationID':mb.relationID,
            'relation':mb.relation,
            'createUserID':param.userId,
            'createUserName':userInfo.name,
            'createOrgID':userInfo.orgID,
            'createOrgName':userInfo.orgName
          })
        }
      }
      if (newData.length > 0 ) {
        await this.model('matter_relation').addMany(newData);
      }
      if (upData.length > 0 ) {
        await this.model('matter_relation').updateMany(upData);
      }
      return this.success();
    }
  }

  // 删除绑定关系
  async delAction(){
    const param = this.post();
    if (!param.hasOwnProperty('matter') || !param.hasOwnProperty('matterList')) {
      return this.fail("参数缺失")
    }
    if (!Array.isArray(param.matterList) || param.matterList.length === 0) {
      return this.fail("matterList参数异常")
    }
    if (param.matterList.indexOf(param.matter)!== -1){
      return this.fail("matterList参数异常包含matter参数")
    }
    let relationList = await this.model('matter_relation').where({'matter_a':param.matter, 'matter_b':param.matter, _logic: 'or'}).select();
    //
    if (think.isEmpty(relationList)){
      return this.fail("未删除绑定关系");
    }else {
      //有绑定关系
      let delList = [];
      for (let mb of param.matterList) {
        for (let item of relationList){
          if (item.matter_a === mb || item.matter_b === mb) {
            // 匹配到绑定记录
            delList.push(item.id);
          }
        }
        // 解除重复关系（如果是的话
        repeat.delRepeat(param.matter,delList);
      }
      if (delList.length > 0) {
        await this.model('matter_relation').where({'id':['IN',delList]}).delete();
      }
      return this.success();
    }
  }
  // 事项绑定关系详情
  async findAction(){
    const param = this.post();
    if (!param.hasOwnProperty('matter')) {
      return this.fail("参数缺失")
    }
    let where = {};
    if (param.hasOwnProperty('relationID') && param.relationID !== '') {
      where = {
        'relationID':param.relationID,
        _complex:{'matter_a':param.matter, 'matter_b':param.matter, _logic: 'or'}
      }
    } else {
      where = {'matter_a':param.matter, 'matter_b':param.matter, _logic: 'or'}
    }
    let back = await this.model('matter_relation').where(where).select();
    let matterID = [];
    back.forEach(function(item) {
      if (item.matter_a === param.matter){
        matterID.push(item.matter_b)
      } else {
        matterID.push(item.matter_a);
      }
    });
    let matter = [];
    let matterBack = {
      "relation_102":[],
      "relation_103":[],
      "relation_104":[],
    }
    if (matterID.length > 0) {
      matter = await this.model('matter').where({'id':['IN',matterID]}).select();
      for (let m of matter) {
        for (let b of back) {
          if (m.id === b.matter_a || m.id === b.matter_b) {
            switch (b.relationID) {
              case '102':matterBack.relation_102.push(m); break;
              case '103':matterBack.relation_103.push(m); break;
              case '104':matterBack.relation_104.push(m); break;
            }
            // m["relation"] = {
            //   'relationID':b.relationID,
            //   'relation':b.relation
            // };
            break;
          }
        }
      }
    }

    return this.success(matterBack)
  }
  // 事项关系数量列表，带查询，分页
  async queryAction(){
    const param = this.post();
    // 先搜索事项，事项条件
    let where = {
      'm.taskid':['!=',null]
    };
    if (param.hasOwnProperty('type') && param.type !== ''){
      let userInfo = await this.getUserInfo(param.userId);
      // type 1 本人登记件，type 2 本人办理或代办件
      if (param.type === 1){ // 本人登记件
        where['m.createAccount'] = userInfo.user_name;
      }
      if (param.type === 2 ){ //  本人办理或代办件
        where['_complex'] = {
          'fta.charger': param.userId,
          'fta.agent': param.userId,
          _logic: 'or'
        }
      }
    }
    // 时间区间
    if (param.hasOwnProperty('startTime') && param.startTime !== ''){
      where["m.createTime"] = ['>',moment(param.startTime).format('YYYY-MM-DD')];
    }
    if (param.hasOwnProperty('endTime') && param.endTime !== ''){
      where["m.CreateTime"] = ['<',moment(param.endTime).add(1,'day').format('YYYY-MM-DD')];
    }
    // 信访类型
    if (param.hasOwnProperty('xfSourceID') && Array.isArray(param.xfSourceID) && param.xfSourceID.length > 0){
      where["a.xfSourceID"] = ['IN',param.xfSourceID];
    }
    // 事项编号
    if (param.hasOwnProperty('matterNum') && param.matterNum !== ''){
      where["m.matterNum"] = ['LIKE','%' + param.matterNum + '%'];
    }
    // 事项摘要
    if (param.hasOwnProperty('abstract') && param.abstract !== ''){
      where["m.abstract"] = ['LIKE','%' + param.abstract + '%'];
    }
    // 事项初重情况
    if (param.hasOwnProperty('visit') && param.visit !== ''){
      if (param.visit === 0) {
        where['m.visitID'] = '200';
      }else if (param.visit === 1) {
        where['m.visitID'] = '100';
      }
    }

    // 信访人姓名
    if (param.hasOwnProperty('name') && param.name !== ''){
      let person = await this.model('person').alias('p').setRelation(false).join('person_activity as pa on pa.personID = p.id')
        .where({'p.name':['LIKE','%' + param.name + '%']}).field("p.*,pa.activityID").select();
      if (think.isEmpty(person)){
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      } else {
        let acID = [];
        person.forEach(function(item) {
          acID.push(item.activityID);
        });
        if (acID.length > 0){
          where['a.id'] = ['IN',acID];
        }
      }
    }
    // 查询信访事项
    let matter = await this.model('matter').alias('m').where(where)
      .join('activity as a on a.id = m.activityID')
      .distinct('m.*').order('m.createTime Desc').page(param.page, param.pageSize).countSelect();
    // 匹配事项对应关系
    for (let item of matter.data){
      let back = await this.model('matter_relation').where({'matter_a':item.id, 'matter_b':item.id, _logic: 'or'})
        .group('relationID').field('relation,relationID,COUNT(*) as count').select();
      item['relation'] = back
    }
    return this.success(matter)
  }

  // 事项关系度推荐
  async similarAction(){
    const param = this.post();
    let where ={
      'm.id':['!=',param.matterID]
    };
    let sql = 'select * from matter_repeat where find_in_set("'+ param.matterID +'",matter_list)';
    let find = await think.model().query(sql);
    if (!think.isEmpty(find)){
      where['m.id'] = ['NOT IN',find[0].matter_list.split(",")]
    }
    if (Array.isArray(param.personID) && param.personID.length > 0){
      where['p.id'] = ['IN',param.personID]
    }
    if (param.hasOwnProperty('name') && param.name !== ''){
      where['p.name'] = param.name
    }
    if (param.hasOwnProperty('matterNum') && param.matterNum !== ''){
      where['m.matterNum'] = param.matterNum
    }
    let matter = await this.model('activity').alias('a').join('person_activity as pa on a.id = pa.activityID')
      .join('person as p on p.id = pa.personID').join('matter as m on m.activityID = a.id').where(where).field('m.*').distinct('m.*').select();
    let mList = [];
    console.log(1111)
    console.log(matter)
    console.log(2222)
    for (let item of matter) {
      let mr = await this.model('matter_relation').where({
          'relationID':'102',
          _complex:{
            'matter_a': item.id,
            'matter_b': item.id,
            _logic: 'or'
          }}
        ).select();
      if (think.isEmpty(mr)){
        mList.push({
          'id':item.id,
          'abstract':item.abstract,
        })
      }else {
        for (let r of mr){
          if (r.matter_a !== param.matterID && r.matter_b !== param.matterID){
            mList.push({
              'id':item.id,
              'abstract':item.abstract,
            });
            break;
          }
        }
      }
    }
    let similar = {
      "id":param.matterID,
      "keyword":param.abstract,
      "list":[],
    };
    mList.forEach(function(m) {
      similar.list.push({
        'id':m.id,
        'keyword':m.abstract
      })
    });
    // let back = await httpRequest('post','http://115.238.142.158:2580/similarity/list',similar);
    let back = await httpRequest('post','http://192.9.200.52:2468/similarity/list',similar);
    let backList = back[1].list;
    for (let l of backList) {
      l.score = (l.score * 100).toFixed(2) + '%'
      for (let m of matter) {
        if (l.id === m.id){
          l['data'] = m;
          break;
        }
      }
    }
    return this.success(backList)
  }
};
