const Base = require('./../base.js');
const moment = require('moment');

module.exports = class extends Base {

  /**
   * showdoc
   * @catalog 大会接待点及信访形式列表获取
   * @title 大会接待点及信访形式列表获取
   * @description 大会接待点及信访形式列表获取接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/getReception
   * @param type 选填 int 类型1接待点，2信访形式
   * @return {"errno": 0, "errmsg":""}
   */
  //大会接待点及信访形式列表获取
  // type 1接待点，2信访形式
  async getReceptionAction(){
    let data = this.post();
    let where = {};
    if (data.hasOwnProperty('type') && data.type === 1){
      where['type'] = 1;
    }
    if (data.hasOwnProperty('type') && data.type === 2){
      where['type'] = 2;
    }
    let back = await this.model('meeting_reception').where(where).select();
    return this.success(back);
  };
  /**
   * showdoc
   * @catalog 获取大会届次
   * @title 获取大会届次
   * @description 获取大会届次接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/getSession
   * @param startTime 选填 string 开始时间YYYY-MM-DD
   * @param endTime 选填 string 结束时间YYYY-MM-DD
   * @param page 必选 int
   * @param limit 必选 int
   * @return {"errno": 0, "errmsg":""}
   */
  // 获取大会届次
  async getSessionAction(){
    let data = this.post();
    let where = {};
    // 时间
    if (data.hasOwnProperty('startTime') && data.startTime !== '' ){
      where['startTime'] = ['>=',moment(data.startTime).format('YYYY-MM-DD') ];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== '' ){
      where['endTime'] = ['<',moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')];
    }
    let back = await this.model('meeting_session').where(where).page(data.page, data.limit).order('createTime DESC').countSelect();
    return this.success(back);
  }
  /**
   * showdoc
   * @catalog 新增大会届次
   * @title 新增大会届次
   * @description 新增大会届次接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/addSession
   * @param id 必选 int 大会届次id
   * @param sessionName 必选 string 届次
   * @param startTime 必选 string 开始时间YYYY-MM-DD
   * @param endTime 必选 string 结束时间YYYY-MM-DD
   * @param remark 必选 string 备注
   * @return {"errno": 0, "errmsg":""}
   */
  // 新增大会届次
  async addSessionAction(){
    let data = this.post();
    let find = await this.model('meeting_session').where({'sessionName':data.sessionName}).find();
    if (think.isEmpty(find)){
      let add = {
        'sessionName':data.sessionName,// 届次名称
        'startTime':moment(data.startTime).format('YYYY-MM-DD'),
        'endTime':moment(data.endTime).format('YYYY-MM-DD'),
        'remark':data.remark,// 备注
      };
      let back = await this.model('meeting_session').add(add);
      return this.success(back);
    }else {
      // 已存在同名届次
      return this.fail('已存在同名届次');
    }
  }
  /**
   * showdoc
   * @catalog 删除大会届次
   * @title 删除大会届次
   * @description 删除大会届次接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/delSession
   * @param id 必选 int 大会届次id
   * @return {"errno": 0, "errmsg":""}
   */
  // 删除大会届次
  async delSessionAction(){
    let data = this.post();
    let back = await this.model('meeting_session').where({'id':data.id}).delete();
    return this.success(back)
  }
  /**
   * showdoc
   * @catalog 修改大会届次
   * @title 修改大会届次
   * @description 修改大会届次接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/updateSession
   * @param id 必选 int 大会届次id
   * @param sessionName 必选 string 届次
   * @param startTime 必选 string 开始时间YYYY-MM-DD
   * @param endTime 必选 string 结束时间YYYY-MM-DD
   * @param remark 必选 string 备注
   * @return {"errno": 0, "errmsg":""}
   */
  // 修改大会届次
  async updateSessionAction(){
    let data = this.post();
    let update = {
      'sessionName':data.sessionName,// 届次名称
      'startTime':moment(data.startTime).format('YYYY-MM-DD'),
      'endTime':moment(data.endTime).format('YYYY-MM-DD'),
      'remark':data.remark,// 备注
    }
    let back = await this.model('meeting_session').where({'id':data.id}).update(update);
    return this.success(back)
  }
  /**
   * showdoc
   * @catalog 新增大会接谈室
   * @title 新增大会接谈室
   * @description 新增大会接谈室接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/addMeetingRoom
   * @param meetingID 必选 int 大会届次id
   * @param room 必选 string 接谈室名称
   * @param roomShort 必选 string 接谈室简称
   * @param roomOrgID 必选 int 接谈室使用单位ID
   * @param roomOrg 必选 string 接谈室使用单位
   * @param roomCode 必选 string 接谈室叫号代字
   * @return {"errno": 0, "errmsg":""}
   */
  // 新增大会接谈室
  async addMeetingRoomAction(){
    let data = this.post();
    let session = await this.model('meeting_session').where({'id':data.meetingID}).find();
    if (think.isEmpty(session)){
      // 届次查询失败
      return this.fail('届次不存在，请重新选择届次')
    } else {
      // 本届次，是否有相同的接谈室、接谈室代字、接谈单位
      let room = await this.model('meeting_room').where({'meetingID': data.meetingID}).select();
      for (let item of room){
        if (item.roomOrgID === data.roomOrgID || data.roomOrgID === 0){
          return this.fail('本届该接谈单位已分配接谈室');
        }
        if (item.room === data.room){
          return this.fail('本届已使用该接谈室名称');
        }
        if (item.roomCode === data.roomCode){
          return this.fail('本届已使用该接谈室代字');
        }
      };
      let roomAdd = {
        'meetingID':data.meetingID,
        'meetingSession':session.sessionName,//大会届次
        'room':data.room,//接谈室名称
        'roomShort':data.roomShort,//接谈室简称
        'roomOrgID':data.roomOrgID,//接谈室使用单位ID
        'roomOrg':data.roomOrg,//接谈室使用单位
        'roomCode':data.roomCode,//接谈室叫号代字
      }
      let add = await this.model('meeting_room').add(roomAdd);
      return this.success(add);
    }
  }
  // 大会接谈室列表 及搜索
  /**
   * showdoc
   * @catalog 大会接谈室列表
   * @title 大会接谈室列表
   * @description 大会接谈室列表接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/searchMeetingRoom
   * @param meetingID 选填 string 届次ID
   * @param page 必选 int
   * @param limit 必选 int
   * @return {"errno": 0, "errmsg":""}
   */
  async searchMeetingRoomAction(){
    let data = this.post();
    let where = {
      'meetingID': (typeof data.meetingID === 'undefined' || data.meetingID === '') ? ['!=',null] : data.meetingID
    };
    let back = await this.model('meeting_room').where(where).page(data.page, data.limit).countSelect()
    return this.success(back);
  }
  /**
   * showdoc
   * @catalog 大会接谈室修改
   * @title 大会接谈室修改
   * @description 大会接谈室修改接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/updateMeetingRoom
   * @param id 必选 int 大会接谈室id
   * @param meetingID 必选 int 大会届次id
   * @param room 必选 string 接谈室名称
   * @param roomShort 必选 string 接谈室简称
   * @param roomOrgID 必选 int 接谈室使用单位ID
   * @param roomOrg 必选 string 接谈室使用单位
   * @param roomCode 必选 string 接谈室叫号代字
   * @return {"errno": 0, "errmsg":""}
   */
  // 大会接谈室修改
  async updateMeetingRoomAction(){
    let data = this.post();
    let session = await this.model('meeting_session').where({'id':data.meetingID}).find();
    if (think.isEmpty(session)){
      // 届次查询失败
      return this.fail('届次不存在，请重新选择届次')
    } else {
      let room = await this.model('meeting_room').where({'meetingID':data.meetingID,'id':['!=',data.id]}).select();
      // 本届次，是否有相同的接谈室、接谈室代字、接谈单位
      for (let item of room){
        if (item.roomOrgID === data.roomOrgID || data.roomOrgID === 0){ // 前端bug id不能为0
          return this.fail('本届该接谈单位已分配接谈室');
        }
        if (item.room === data.room){
          return this.fail('本届已使用该接谈室名称');
        }
        if (item.roomCode === data.roomCode){
          return this.fail('本届已使用该接谈室代字');
        }
      };
      let roomUp = {
        'meetingID':data.meetingID,
        'meetingSession':session.sessionName,//大会届次
        'room':data.room,//接谈室名称
        'roomShort':data.roomShort,//接谈室简称
        'roomOrgID':data.roomOrgID,//接谈室使用单位ID
        'roomOrg':data.roomOrg,//接谈室使用单位
        'roomCode':data.roomCode,//接谈室叫号代字
        'roomCodeNum':null,//每次修改，必然清空接谈当前叫号
      }
      let up = await this.model('meeting_room').where({'id':data.id}).update(roomUp);
      return this.success(up);
    }
  }
  /**
   * showdoc
   * @catalog 删除大会接谈室
   * @title 删除大会接谈室
   * @description 删除大会接谈室接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/delMeetingRoom
   * @param id 必选 int 大会接谈室id
   * @return {"errno": 0, "errmsg":""}
   */
  // 删除大会接谈室
  async delMeetingRoomAction(){
    let data = this.post();
    let back = await this.model('meeting_room').where({'id':data.id}).delete();
    return this.success(back)
  }
  // 获取接谈室使用单位
  async getRoomOrgAction(){
    // 仅获取省级，有账号的职能单位
    let back = await this.model('sys_user').join('sys_organization on sys_organization.id = sys_user.orgID')
      .where({'sys_organization.deptID':2,'isRenDa':0}).field('sys_organization.*').distinct('sys_organization.*').select();
    return this.success(back);
  }
  /**
   * showdoc
   * @catalog 绑定大会用户（大会用户新增）
   * @title 绑定大会用户（大会用户新增）
   * @description 绑定大会用户（大会用户新增）接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/addMeetingUser
   * @param meetingID 必选 int 大会接谈室id
   * @param person 必选 array 大会用户userId
   * @return {"errno": 0, "errmsg":""}
   */
  // 绑定大会用户（大会用户新增）
  async addMeetingUserAction(){
    let data = this.post();
    // meetingID 大会届次id
    // person [] 用户userId
    let meeting = await this.model('meeting_session').where({'id':data.meetingID}).find();
    if (think.isEmpty(meeting)){
      return this.fail('不存在该届次')
    }else {
      let up = [];
      data.person.forEach(function(item) {
        up.push({
          'user_id':item,
          'meetingSession':meeting.sessionName,
          'meetingID':data.meetingID
        });
      });
      const user = this.model('sys_user');
      user._pk = 'user_id';
      await user.updateMany(up);
      return this.success();
    }
  }
  /**
   * showdoc
   * @catalog 大会用户列表
   * @title 大会用户列表
   * @description 大会用户列表接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/meetingUserList
   * @param meetingID 选填 string 届次ID
   * @param page 必选 int
   * @param limit 必选 int
   * @return {"errno": 0, "errmsg":""}
   */
  // 大会用户列表
  async meetingUserListAction(){
    let data = this.post();
    let where = {
      'sys_user.meetingID':(typeof data.meetingID === 'undefined' || data.meetingID === '') ? ['!=',null] : data.meetingID,
      // 'meeting_room.meetingID':(typeof data.meetingID === 'undefined' || data.meetingID === '') ? ['!=',null] : data.meetingID,
    };
    const user = this.model('sys_user');
    user._pk = 'user_id';
    let back = await user.join('sys_organization on sys_organization.id = sys_user.orgID')
      .join('meeting_room on meeting_room.roomOrgID = sys_user.orgID').where(where)
      .page(data.page, data.limit).order('sys_user.meetingID DESC')
      .field('sys_user.*,sys_organization.orgName as orgName,meeting_room.room as roomName').countSelect();
    return this.success(back)
  }
  /**
   * showdoc
   * @catalog 大会用户删除
   * @title 大会用户删除
   * @description 大会用户删除接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/delMeetingUser
   * @param user_id 必选 string 需要删除的用户user_id
   * @return {"errno": 0, "errmsg":""}
   */
  // 大会用户删除（将用户从大会中取消绑定
  async delMeetingUserAction(){
    let data = this.post();
    let user = await this.model('sys_user').where({'user_id':data.user_id}).update({'meetingID':null,'meetingSession':null});
    return this.success(user);
  }
  /**
   * showdoc
   * @catalog 大会待绑定的用户列表
   * @title 大会待绑定的用户列表
   * @description 大会待绑定的用户列表接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/meetingSession/waitUser
   * @param meetingID 必选 string 大会届次id
   * @param page 必选 int
   * @param limit 必选 int
   * @return {"errno": 0, "errmsg":""}
   */
  // 大会待绑定的用户列表
  async waitUserAction(){
    let data = this.post();
    // 查出省级所有非本届的人员
    if (typeof data.meetingID === 'undefined' || data.meetingID === ''){
      return this.success([]);
    }else {
      const user = this.model('sys_user');
      user._pk = 'user_id';
      let where = {
        'meetingID':null,
        'meetingid':['!=',data.meetingID],
        _logic:'OR'
      }
      let back = await user.join('sys_organization on sys_organization.id = sys_user.orgID')
        .where(where).page(data.page, data.limit).countSelect();
      return this.success(back)
    }
  }
};
