const Base = require('./../base.js');
const moment = require('moment');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  /**
   * showdoc
   * @catalog 接谈记录表
   * @title 接谈记录表
   * @description 接谈记录表接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/talking/talkingRecordList
   * @param userId 必选 string userId
   * @param startTime 必选 string 开始时间
   * @param endTime 必选 string 开始时间
   * @param page 必选 int
   * @param limit 必选 int
   * @return {"errno": 0, "errmsg":""}
   */
  // 接谈记录表
  async talkingRecordListAction(){
    const data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    let where = {
      't.meetingID':userInfo.meetingID
    };
    // 时间
    if ((data.startTime === '' && data.endTime === '') || (typeof data.startTime === 'undefined' && typeof data.endTime === 'undefined')){
      // 默认当天
      where['createTime'] = ['between', moment().format('YYYY-MM-DD') + ',' + moment().add(1, 'day').format('YYYY-MM-DD')]
      // where['t.createTime'] = ['between', moment('2022-07-05').format('YYYY-MM-DD') + ',' + moment('2022-07-08').add(1, 'day').format('YYYY-MM-DD')]
    }
    if (typeof data.startTime !== 'undefined' && data.startTime !== ''){
      where['t.createTime'] = ['>',moment(data.startTime).format('YYYY-MM-DD HH:mm:ss')];
    }
    if (typeof data.endTime !== 'undefined' && data.endTime !== ''){
      where['t.CREATETime'] = ['<',moment(data.endTime).format('YYYY-MM-DD HH:mm:ss')];
    }
    // 先判断是否是职能单位账号，如果是职能单位，只返回本接谈室
    let org = await this.model('sys_organization').where({"id":userInfo.orgID}).find();
    if (think.isEmpty(org)){
      return this.fail()
    } else {
      let back = [];
      if (org.isRenDa !== 1){
        // 只能单位
        where['t.orgID'] = userInfo.orgID;
        back = await this.model('talking_record').alias('t').where(where).page(data.page, data.limit).order('createTime DESC').countSelect();
      }else {
        // 判断为人大，导出所有单位的接谈记录
        back = await this.model('talking_record').alias('t').where(where).page(data.page, data.limit).order('createTime DESC').countSelect();
      }
      // let back = await this.model('talking_record').alias('t').where(where).page(data.page, data.limit).order('createTime DESC').countSelect();
      let list = [];
      for (let r of back.data){
        let matter = await think.model('matter').where({'id':r.matterID}).find();
        let act = await think.model('fw_task_act').where({'businessID':35,'c_task':matter.taskid,'deptID_now':r.orgID})
          .order('c_time DESC').find();
        let queue = await think.model('queue').where({'id':r.queueID}).find();
        r = JSON.parse(JSON.stringify(r));
        r['callingTime'] = act.c_time;
        if (!think.isEmpty(queue)){
          r['roomName'] = queue.roomName;
          r['roomNum'] = queue.roomCode + queue.roomCodeNum;
        }
        matter = JSON.parse(JSON.stringify(matter));
        matter['record'] = r;
        list.push(matter)
      }
      back.data = list;
      return this.success(back)
    }
  };

  /**
   * showdoc
   * @catalog 获取排号单
   * @title 获取排号单
   * @description 获取排号单接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/talking/getQueue
   * @param queueID 必选 string 单号ID
   * @return {"errno": 0, "errmsg":""}
   */
  // 获取排号单
  async getQueueAction(){
    let data = this.post();
    let where = {};
    if (data.hasOwnProperty('queueID') && data.queueID !== ''){
      where['queue.id'] = data.queueID;
    } else {
      where['matterID'] = data.matterID;
    }
    let queue = await this.model('queue').join('meeting_room as mr on mr.id = queue.roomID').where(where)
      .field('queue.*,mr.roomShort').order('createTime Desc').find();
    return this.success(queue);
  }
  /**
   * showdoc
   * @catalog 获取排号单列表
   * @title 获取排号单列表
   * @description 获取排号单列表接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/talking/getQueueList
   * @param startTime 选填 string YYYY-MM-DD
   * @param endTime 选填 string YYYY-MM-DD
   * @param personName 选填 string 主信访人
   * @param roomOrgID 选填 int 接谈单位ID
   * @return {"errno": 0, "errmsg":""}
   */
  // 获取排号单列表
  async getQueueListAction(){
    let data = this.post();
    let startTime = moment().format('YYYY-MM-DD');
    let endTime = moment().add(1,'day').format('YYYY-MM-DD');
    if (typeof data.startTime !== 'undefined' && data.startTime !== ''){
      startTime = moment(data.startTime).format('YYYY-MM-DD HH:mm:ss');
    }
    if (typeof data.endTime !== 'undefined' && data.endTime !== ''){
      endTime = moment(data.endTime).format('YYYY-MM-DD HH:mm:ss');
    }
    let where = {
      'queue.createTime':['BETWEEN', startTime, endTime],
    };
    if (data.hasOwnProperty('personName') && data.personName !== ''){
      where['queue.personName'] = ['LIKE','%'+data.personName+'%']
    }
    if (data.hasOwnProperty('roomOrgID') && data.roomOrgID !== ''){
      where['queue.roomOrgID'] = data.roomOrgID
    }
    let back = await this.model('queue').join('matter on matter.id = queue.matterID').where(where).page(data.page, data.limit)
      .order('createTime DESC').field('queue.*,matter.activityID,matter.taskid').countSelect();
    return this.success(back)
  }
  /**
   * showdoc
   * @catalog 省人代会接谈单位输出接谈情况列表
   * @title 省人代会接谈单位输出接谈情况列表
   * @description 省人代会接谈单位输出接谈情况列表接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/talking/getTalkingHandle
   * @param orgID 选填 int 机构id，不传或者传40查询全部，否则查询对应接谈室
   * @param startTime 选填 string YYYY-MM-DD
   * @param endTime 选填 string YYYY-MM-DD
   * @return {"errno": 0, "errmsg":""}
   */
  //省人代会接谈单位输出接谈情况列表
  async getTalkingHandleAction(){
    // 时间筛选，默认当天
    // orgID不传默认全选
    let data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    let where = {
      'talking_record.meetingID':userInfo.meetingID,
      'talking_record.orgID':typeof data.orgID === 'undefined' || data.orgID === 40 ? ['!=',null] : data.orgID
    };
    // 时间
    if ((data.startTime === '' && data.endTime === '') || (typeof data.startTime === 'undefined' && typeof data.endTime === 'undefined')){
      // 默认当天
      where['talking_record.createTime'] = ['between', moment().format('YYYY-MM-DD') + ',' + moment().add(1, 'day').format('YYYY-MM-DD')]
    }
    if (typeof data.startTime !== 'undefined' && data.startTime !== ''){
      where['talking_record.createTime'] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (typeof data.endTime !== 'undefined' && data.endTime !== ''){
      where['talking_record.CREATETime'] = ['<',moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')];
    }
    let handle = await this.model('talking_record').join('queue on queue.id = talking_record.queueID')
      .where(where).field('talking_record.*,queue.roomCode,queue.contentClassifyAll,roomCodeNum,queue.personName,').order('talking_record.createTime')
      .page(data.page,data.limit).countSelect();
    // handle.data = JSON.parse(JSON.stringify(handle.data));
    handle.data.forEach(function(item) {
      item['queueNum'] = item.roomCode + item.roomCodeNum;
      // item['level1'] = item.contentClassifyAll.split('-')[0];
      // item['level2'] = item.contentClassifyAll.split('-')[1];
      // item['level3'] = item.contentClassifyAll.split('-')[2];
      // item['level4'] = item.contentClassifyAll.split('-')[3];
      // item['level5'] = item.contentClassifyAll.split('-')[4];
    });
    return this.success(handle)
  }

  // 当前用户登记，且领导已审核列表
  // businessID 为3,7,10,25,28
  async getLeaderPassAction(){
    const data = this.post();
    let where = {
      'fw.businessID':['IN',[3,7,10,25,28]],
      'm.isMeeting':0
    };
    if (data.hasOwnProperty("name") && data.name !== "" ){
      let person = await this.model('person').join({
        table: 'person_activity',
        join: 'left',
        on: ['id','personID']
      }).where({'name':['LIKE','%'+data.name+'%']}).select();
      let activityID = [];
      person.forEach(function(item){
        activityID.push(item.activityID);
      });
      if(activityID.length > 0) {
        where['m.activityID'] = ['IN',activityID];
      }
    }
    if (data.hasOwnProperty("matterNum") && data.matterNum !== "" ){
      where['m.matterNum'] = ['LIKE','%'+ data.matterNum + '%'];
    }
    let sql = await this.model('queue').order('createTime desc').limit(1).buildSelectSql();
    let matter = await this.model('matter').alias('m')
      .field('m.*,fw.businessID,fw.dealType_pre,fw.deptID_create,fw.deptName_create,q.id as queueID').join({
        table: 'fw_task',
        join: 'left',
        as: 'fw',
        on: ['taskid', 'id']
      }).join({
        table: sql,// 接谈室叫号id，表queue
        as: 'q',
        join: 'left',
        on: ['id', 'matterID']
      }).where(where).order(['m.createTime desc']).page(data.page,data.limit).countSelect().catch((err) => {
        return think.isError(err) ? err : new Error(err);
      });
    if (think.isError(matter)) {
      return this.fail('Get review query fail');
    }
    let list = []// 临时数组，只返回接谈
    for (let item of matter.data){
      if (item.dealType_pre === "转交") {
        item.dealType_pre = "转送"
      }
      let persuade = await think.model('history').where({'businessID':36,'taskId':item.taskid,'info':['LIKE','%"persuade"%']}).find();
      if (!think.isEmpty(persuade)){
        item['persuade'] = JSON.parse(persuade.info).persuade;
        list.push(item)// 临时数组
      }
    }
    matter.data = list;// 临时数组
    return this.success(matter);
  }
  /**
   * showdoc
   * @catalog 大会事项列表
   * @title 大会事项列表
   * @description 大会事项列表接口
   * @method post
   * @url http://127.0.0.1:8360/meeting/talking/getMeetingList
   * @param registerTypeID 选填 Array 信访活动类型，选填
   * @param startTime 选填 string YYYY-MM-DD
   * @param endTime 选填 string YYYY-MM-DD
   * @return {"errno": 0, "errmsg":""}
   */
  // 大会事项列表，大会期间的事项，作为部分表格导出的跳板
  async getMeetingListAction(){
    let data = this.post();
    let userInfo = await this.getUserInfo(data.userId);
    // 默认查询当天
    let startTime = moment().format('YYYY-MM-DD');
    let endTime = moment().add(1,'day').format('YYYY-MM-DD');
    // 如果能匹配到大会届次
    let session = await this.model('meeting_session').where({'id':userInfo.meetingID}).find();
    if (!think.isEmpty(session)) {
      startTime = moment(session.startTime).format('YYYY-MM-DD');
      endTime = moment(session.endTime).add(1,'day').format('YYYY-MM-DD');
    }
    // let startTime = moment('2022-07-05').format('YYYY-MM-DD');
    // let endTime = moment('2022-07-08').add(1,'day').format('YYYY-MM-DD');
    if (typeof data.startTime !== 'undefined' && data.startTime !== ''){
      startTime = moment(data.startTime).format('YYYY-MM-DD HH:mm:ss');
    }
    if (typeof data.endTime !== 'undefined' && data.endTime !== ''){
      endTime = moment(data.endTime).format('YYYY-MM-DD HH:mm:ss');
    }
    let where = {'m.createTime':['BETWEEN', startTime, endTime],'m.isMeeting':0,'m.meetingID':userInfo.meetingID};
    if (data.hasOwnProperty('registerTypeID') && Array.isArray(data.registerTypeID) && data.registerTypeID.length > 0) {
      where['a.registerTypeID'] = ['IN',data.registerTypeID];// 信访形式
    }
    let matter;
    if(userInfo.isRenDa !== 1){
      //非人大单位，即为职能单位，仅查询本单位接谈情况
      where['th.roomOrgID'] = userInfo.orgID;
      matter = await this.model('matter').alias('m').join('activity as a on a.id = m.activityID')
        .join('talking_handle as th on th.matterID = m.id')
        .where(where).page(data.page, data.limit).order('m.createTime DESC').field('m.*').countSelect();
      matter = JSON.parse(JSON.stringify(matter));
    }else {
      matter = await this.model('matter').alias('m').join('activity as a on a.id = m.activityID')
        .where(where).page(data.page, data.limit).order('m.createTime DESC').field('m.*').countSelect();
      matter = JSON.parse(JSON.stringify(matter));
    }
    for (let m of matter.data){
      let handle = await this.model('talking_handle').where({'matterID':m.id}).order('createTime DESC').find()
      m['handle'] = handle
    }
    return this.success(matter)
  }
  //获取大会接谈单位
  async getTalkingOrgAction(){
    // 如果传了届次，按届次查找
    // 如果没有届次，返回所有省级职能部门
    let data = this.post();
    if (data.hasOwnProperty('meetingID')){
      let back = await this.model('meeting_room').where({'meetingID':data.meetingID}).field('roomOrgID as id,roomOrg as orgName').select();
      return this.success(back)
    } else {
      let back = await this.model('meeting_room').field('roomOrgID as id,roomOrg as orgName').select();
      return this.success(back)
    }
  }
};
