const Base = require('./../base.js');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }

  /**
   * showdoc
   * @catalog 后台管理-平台标签列表
   * @title 后台管理-平台标签列表接口
   * @description 后台管理-平台标签列表
   * @method get
   * @param name 必选 string 标签名称 支持模糊查询
   * @param type 必选 int 标签类别 1个人标签，2热点标签
   * @param userid 必选 string 登录人userid
   * @param page 必选 int 第几页
   * @param limit 必选 int 每页条数
   * @url http://127.0.0.1:8360/msg/label/backLabelList
   * @return {"errno": 0, "errmsg":""}
   */
  async backLabelListAction() {
    let data = this.get();
    data.page = data.page === undefined ? 0 : data.page;
    data.limit = data.limit === undefined ? 0 : data.limit;
    data.type = data.type === undefined ? 0 : data.type;
    data.name = data.name === undefined ? '' : data.name;
    const userInfo = await this.getUserInfo(data.userid || '');
    data.orgID = userInfo.orgID === undefined ? 0 : userInfo.orgID;
    data.publisherID = data.userid;
    let where = {};
    if (data.type === '1') {
      where = {
        name: ['like', '%' + data.name + '%'],
        type: data.type,
        creatorID: data.publisherID,
        del: 0
      };
    }
    if (data.type === '2') {
      where = {
        name: ['like', '%' + data.name + '%'],
        type: data.type,
        orgID: data.orgID,
        del: 0
      };
    }

    const label = this.model('label'); // controller 里实例化模型
    const back = await label.where(where).order('updatetime DESC').page(data.page, data.limit).countSelect();

    this.success(back);
  }

  /**
   * showdoc
   * @catalog 后台管理-平台自有新闻新增或编辑接口
   * @title 后台管理-平台自有新闻新增或编辑接口
   * @description 后台管理-平台自有新闻新增或编辑接口
   * @method post
   * @param id 可选 int 新增的时候不传，编辑的时候传
   * @param name 必选 string 标签名称
   * @param userid 必选 string 登录人userid
   * @param type 必选 int 标签类别 1个人标签，2热点标签
   * @url http://127.0.0.1:8360/msg/label/backLabelSave
   * @return {"errno": 0, "errmsg":""}
   */
  async backLabelSaveAction() {
    let data = this.post();

    if (think.isEmpty(data.id)) {
      const userInfo = await this.getUserInfo(data.userid || '');
      data.orgID = userInfo.orgID === undefined ? 0 : userInfo.orgID;
      data.orgName = userInfo.orgName === undefined ? 0 : userInfo.orgName;
      data.creatorID = data.userid;
      data.creatorName = userInfo.name === undefined ? 0 : userInfo.name;
      //保存
      const res = await this.model('label').add(data);
      if (res) {
        this.success();
      } else {
        this.fail();
      }
    } else {
      //更新
      let res = await this.model('label').update(data);
      if (res) {
        this.success();
      } else {
        this.fail();
      }
    }
  }

  /**
   * showdoc
   * @catalog 后台管理-平台标签删除接口
   * @title 后台管理-平台标签删除接口
   * @description 后台管理-平台标签删除接口
   * @method post
   * @param id 必选 int 标签ID
   * @url http://127.0.0.1:8360/msg/label/backLabelDelete
   * @return {"errno": 0, "errmsg":""}
   */
  async backLabelDeleteAction() {
    const post = this.post();
    const id = post.id;
    const affectedRows = await this.model('label').where({id: id}).update({del: 1});
    if (affectedRows === 0) {
      this.fail();
    } else {
      this.success();
    }
  }

  /**
   * showdoc
   * @catalog 后台管理-平台标签列表
   * @title 后台管理-平台标签列表接口
   * @description 后台管理-平台标签列表
   * @method get
   * @param type 必选 int 标签类别 1个人标签，2热点标签
   * @param userid 必选 string 登录人userid
   * @url http://127.0.0.1:8360/msg/label/labelList
   * @return {"errno": 0, "errmsg":""}
   */
  async labelListAction() {
    let data = this.get();
    data.type = data.type === undefined ? 0 : data.type;
    const userInfo = await this.getUserInfo(data.userid || '');
    data.orgID = userInfo.orgID === undefined ? 0 : userInfo.orgID;
    data.publisherID = data.userid;
    let where = {};
    if (data.type === '1') {
      where = {
        type: data.type,
        creatorID: data.publisherID,
        del: 0
      };
    }
    if (data.type === '2') {
      where = {
        type: data.type,
        orgID: data.orgID,
        del: 0
      };
    }
    const label = this.model('label'); // controller 里实例化模型
    const back = await label.where(where).order('updatetime DESC').select();

    this.success(back);
  }

};
