const Base = require('./../base.js');
const MSG = require('./../../handle/msg');
const Template = require('./../../handle/template');
const util = require('./../../handle/util');
const moment = require('moment');
const sixtytwo = require('sixtytwo');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  /**
   * showdoc
   * @catalog 短信
   * @title 发送验证码
   * @description 发送验证码接口
   * @method post
   * @url http://127.0.0.1:8360/msg/msg/sendVerifyCode
   * @param phone 必选 string 手机号
   * @return {"errno": 0, "errmsg":""}
   */
  // 发送验证码
  async sendVerifyCodeAction(){
    const data = this.post();
    const reg = /^[1][3,4,5,6,7,8,9][0-9]{9}$/;
    // 验证手机号
    if (reg.test(data.phone)){
      // 验证通过
      // 生成一个验证码 插入数据库
      const verifyCode = Math.random().toString().slice(-6);
      const addData = {
        'verifyCode':verifyCode,
        'createTime':moment().format('YYYY-MM-DD HH:mm:ss'),
        'expirationTime':moment().add(15, 'm').format('YYYY-MM-DD HH:mm:ss'),// 有效期15分钟
        'phone':data.phone
      };
      const setCode = await this.model('msg_code').add(addData);
      const content = "您的验证码是:" + verifyCode + "。有效时间15分钟！" + "【人大网上信访】"
      // const content = "您的验证码是:" + verifyCode + "。有效时间15分钟！"
      // const back = await MSG.msg(data.phone,content );
      // 内网发起调用，访问外网发送短信接口
      console.log(content)
      // let back = await httpRequest('post','https://192.9.200.55:8360/msg/msg/sendMsg',{"phone":data.phone,"content":content});
      let back = await httpRequest('post','https://172.28.50.118/msg/msg/sendMsg',{"phone":data.phone,"content":content});
      // let back = await httpRequest('post','http://localhost:8360/msg/msg/sendMsg',{"phone":data.phone,"content":content});
      this.success(back)
    }else {
      this.fail("手机号有误")
    }
  }
  /**
   * showdoc
   * @catalog 短信
   * @title 验证验证码
   * @description 验证验证码接口
   * @method post
   * @url http://127.0.0.1:8360/msg/msg/checkCode
   * @param phone 必选 string 手机号
   * @param code 必选 string 验证码
   * @return {"errno": 0, "errmsg":""}
   */
  // 验证验证码
  async checkCodeAction(){
    const data = this.post();
    const time = moment().format('YYYY-MM-DD HH:mm:ss');// 当前时间
    const msg = await this.model('msg_code').where({'phone':data.phone,'verifyCode':data.code}).find();
    if (think.isEmpty(msg)){
      this.fail('验证码错误');
    } else if(time > msg.expirationTime) {
      this.fail('验证码过期，请重新获取');
    }else {
      const upMsg = await this.model('msg_code').where({'phone':data.phone,'verifyCode':data.code}).update({'verifyTime':time});
      this.success('验证成功');
    }
  }
  // 外网发送短信接口，由内网发起调用
  async sendMsgAction(){
    const data = this.post();
    let back = await MSG.msg(data.phone,data.content);
    return this.success(back);
  }

  /**
   * showdoc
   * @catalog 短信
   * @title 打印告知单
   * @description 打印告知单接口
   * @method post
   * @url http://127.0.0.1:8360/msg/msg/printMsg
   * @param userId 必选 string userId
   * @param matterID 必选 string 事项id
   * @return {"errno": 0, "errmsg":""}
   */
  // 打印告知单
  // matterID
  async printMsgAction(){
    const data = this.post();
    let userInfo = await this.getUserInfo(data.userId);
    let matter = await this.model('matter').where({'id':data.matterID}).find();
    let finalOrgID;
    let handleLog = await this.model('handle_log').where({"matterID":data.matterID}).order('createTime DESC').find();
    if (think.isEmpty(handleLog)){
      //没有办理记录，发送单位、去向单位取登记时那个
      finalOrgID = matter.finalDisposalID;
    } else {
      finalOrgID = handleLog.finalDisposalID;
    }
    let final = await this.model('sys_organization').where({'id':finalOrgID}).find();
    let where = {
      'sendType':2,//告知单
      'sendOrgID':userInfo.orgID,
      'content':['!=',''],
      _complex:{
        'id':matter.tellLog === null || matter.tellLog === '' ? ['!=',null] : ['IN', matter.tellLog],
        'matterID':data.matterID,
        _logic:matter.tellLog === null || matter.tellLog === ''  ? 'and' : 'or'
      }
    };
    let tell = await this.model('tell_log').where(where).select();
    for (let item of tell){
      if (item.isRepresent === 1){
        //发送给信访人
        item.mobilePhone =item.mobilePhone === null ? matter.activity.person.mobilePhone : item.mobilePhone;
        item.personName = item.personName === null ? matter.activity.person.name : item.personName;
        item.personID = item.personID === null ? matter.activity.person.id : item.personID;
      } else {
        //发送给代表 delegate_leading 表
        let leader = await think.model('delegate_leading').join('activity_leading on activity_leading.leadingID = delegate_leading.id')
          .where({"activity_leading.activityID":matter.activity.id}).field('delegate_leading.*').find();
        item.mobilePhone = item.mobilePhone === null ? leader.phone : item.mobilePhone;
        item.personID = item.personID === null ? leader.id : item.personID;
        item.personName = item.personName === null ? leader.name : item.personName;
      }
      item.matterID = item.matterID === '' || item.matterID === null ? data.matterID : item.matterID;
      item.sendTime = item.sendTime === null ? moment().format('YYYY-MM-DD HH:mm:ss') : item.sendTime;
      item.isSend = 0;
      item.tellCode = item.tellCode === '' || item.tellCode === null ? await util.getTellNum(userInfo.regionAdminNo) : item.tellCode;
      item.content = item.content.replace('[信访事项编号]', matter.matterNum);
      item.content = item.content.replace('[发送人电话]', userInfo.phone);
      item.content = item.content.replace('[发送单位]', userInfo.orgName);
      item.content = item.content.replace('[去向单位查询电话]', think.isEmpty(final) ? "" : final.searchPhone);
      item.content = item.content.replace('[去向单位]', think.isEmpty(final) ? "" : final.orgName);
      item.content = item.content.replace('[去向单位]', think.isEmpty(final) ? "" : final.orgName);//故意两遍
      await think.model('tell_log').update(item);
      item['title'] = userInfo.deptName + '人大常委会信访事项处理告知单';
    }
    return this.success(tell)
  }

  /**
   * showdoc
   * @catalog 短信
   * @title 获取本级短信和告知单
   * @description 获取本级短信和告知单接口
   * @method post
   * @url http://127.0.0.1:8360/msg/msg/getTellLog
   * @param userId 必选 string userId
   * @param matterID 必选 string 事项id
   * @param businessID 必选 int 流程号
   * @param sendType 选填 int 发送类型，1短信，2转交单
   * @param isSend 选填 int 是否发送0发送，1未发送
   * @return {"errno": 0, "errmsg":""}
   */
  //通过businessID获取本级短信和告知单
  async getTellLogAction(){
    let data = this.post();
    let userInfo = await this.getUserInfo(data.userId);
    let where = {
      'sendOrgID':userInfo.orgID,
      'businessID':data.businessID,
      'matterID':data.matterID
    };
    if (data.hasOwnProperty('sendType')){//发送类型，1短信，2转交单
      where['sendType'] = data.sendType
    }
    if (data.hasOwnProperty('isSend')){//是否发送0发送，1未发送
      where['isSend'] = data.isSend
    }
    let tell = await this.model('tell_log').where(where).select();
    return this.success(tell)
  }


  // 获取办理阶段告知单模板（不含“已收悉、已办结
  // finalDisposalID 去向单位ID
  // type 告知形式1短信，2告知单
  // isRepresent 是否代表，0是，1否
  // isAccept 是否受理范围0受理，1不受理(非登记时没有这个参
  // isAcceptPerson 是否受理范围人工判断0受理，1不受理
  // handleModelID 办理方式 通过ID和是否受理，判断handleModel
  // userId
  async getTellTemplateAction(){
    const data = this.post();
    let disposal = await this.model('sys_organization').where({"id":data.finalDisposalID}).find();
    let param = {
      "userId":data.userId,
      "finalDisposal":disposal.orgName,
      "disposalPhone":disposal.searchPhone === null || disposal.searchPhone === "" ? "" :disposal.searchPhone,
      "isRepresent":data.isRepresent === null || data.isRepresent === 1 ? 1 : 0, // 是否代表，0是，1否
    };
    if (data.hasOwnProperty('handleModelID') && data.handleModelID.substr(3,3) !== '003'){
      // 办理方式为存信存件接谈(自办
      param['handleModel'] = 2
    }else {
      param['handleModel'] = 1
    }
    if (data.hasOwnProperty('isAccept')) {
      // 系统受理，需要人工判断也为受理才受理
      param['isAccept'] = data.isAccept === 0 ? (data.isAcceptPerson === 0 ? 0 : 1) : 1;
    }
    if (!data.hasOwnProperty('isAccept')) {
      // 非登记单位获取模板
      param['isAccept'] = data.isAcceptPerson;
    }
    let template = await Template.getTellTemplate(data.type,data.stage,param);
    return this.success(template);
  }
  // 2021-03弃用该接口
  // // 分类处理阶段获取告知模板 阶段2
  // // isRepresent 是否代表，0是，1否
  // // isAccept 是否办理 0办理，1不办理
  // // matterID
  // // userId
  // // type 告知形式1短信，2告知单
  // async getHandleTemplateAction(){
  //   const data = this.post();
  //   let handleModel = [3];
  //   let finalDisposal = "";
  //   let disposalPhone = "";
  //   if (data.hasOwnProperty('matterID') && data.matterID !== ""){
  //     let matter = await this.model('matter').setRelation(false).join('fw_task on fw_task.id = matter.taskid')
  //       .where({"id":data.matterID}).find();
  //     let model1 = "交办,转送,转交";
  //     if (model1.indexOf(matter.dealType_pre) >= 0){
  //       handleModel.push(1)
  //     }else {
  //       handleModel.push(2)
  //     };
  //     let where = {"id":(matter.deptName_now === matter.deptName_pre ? matter.deptID_now : matter.deptID_pre)};
  //     let org = await this.model('sys_organization').where(where).find();
  //     if (!think.isEmpty(org)){
  //       finalDisposal = org.orgName;
  //       disposalPhone = org.searchPhone;
  //     }
  //   }
  //   // let disposal = await this.model('sys_organization').where({"id":data.finalDisposalID}).find();
  //   let param = {
  //     "userId":data.userId,
  //     "finalDisposal":finalDisposal,
  //     "disposalPhone":disposalPhone,
  //     "handleModel":['IN',handleModel],
  //     "isAccept":data.isAccept,
  //     "isRepresent":data.isRepresent === null || data.isRepresent === 1 ? 1 : 0, // 是否代表，0是，1否
  //   };
  //   let template = await Template.getTellTemplate(data.type,2,param);
  //   return this.success(template)
  // }
  // 登记时保存告知模板
  // 传id的话是更新
  async saveTellAction(){
    const data = this.post();
    let add = [];
    let up = [];
    let del = [];
    data.forEach(function(item) {
      if (typeof item.id !== 'undefined' && item.id !== ""){
        if (item.content === "" || (item.type !== 1 && item.type !== 2)){
          // 内容为空 或 类型不对，视为删除记录
          del.push(item.id);
        } else {
          up.push({
            "id":item.id,
            "matterID":typeof item.matterID === 'undefined' || item.matterID === "" ? "" :item.matterID,
            // "mobilePhone":item.mobilePhone,// 接收手机号
            // "personID":item.personID,// 接收人id
            // "personName":item.personName,// 接收人
            "sendType":item.type,// 发送类型，1短信，2转交单
            "sendPerson":item.userId,// 发送人userId
            "sendOrgID":item.orgId,// 发送单位id
            "content":item.content,// 发送内容
            "isSend":1, //是否发送 1未发送
            "isRepresent":item.isRepresent, //是否代表，0是，1否
            "businessID":item.businessID
          })
        }
      }else {
        add.push({
          "matterID":typeof item.matterID === 'undefined' || item.matterID === "" ? "" :item.matterID,
          // "mobilePhone":item.mobilePhone,// 接收手机号
          // "personID":item.personID,// 接收人id
          // "personName":item.personName,// 接收人
          "sendType":item.type,// 发送类型，1短信，2转交单
          "sendPerson":item.userId,// 发送人userId
          "sendOrgID":item.orgId,// 发送单位id
          "content":item.content,// 发送内容
          "isSend":1, //是否发送 1未发送
          "isRepresent":item.isRepresent, //是否代表，0是，1否
        })
      }
    });
    if (up.length > 0){
      await this.model("tell_log").updateMany(up);
    }
    if (del.length >0){
      await this.model("tell_log").where({'id':["IN",del]}).delete();
    }
    console.log(add)
    if (add.length > 0){
      let save = await this.model("tell_log").addMany(add);
      return this.success(save)
    }
    return this.success()
  }
  // 删除发送记录
  async delTellAction(){
    const data = this.post();
    let where = {
      "id":['IN',data.id],
      "isSend":1// 只能删除未发送
    }
    let del = await this.model("tell_log").where(where).delete();
    return this.success(del)
  }
  // 发送告知短信
  // matterID
  async sendTellMsgAction(){
    const data = this.post();
    // 在日志表中查询待发送的短信
    let matter = await this.model("matter").where({"id":data.matterID}).find();
    let finalOrgID;//去向单位id
    let handleLog = await this.model('handle_log').where({"matterID":data.matterID}).order('createTime DESC').find();
    if (think.isEmpty(handleLog)){
      //没有办理记录，发送单位、去向单位取登记时那个
      finalOrgID = matter.finalDisposalID;
    } else {
      finalOrgID = handleLog.finalDisposalID;
    }
    let final = await this.model('sys_organization').where({'id':finalOrgID}).find();
    let code = "";//查询码
    let inquiry = await think.model('inquiry_code').where({"matterID":data.matterID,"flag":0}).order("createTime DESC").find();
    if (!think.isEmpty(inquiry)){
      code = inquiry.inquiryCode;
    }
    let msg = await this.model("tell_log").where({"isSend":1,"sendType":1,"matterID":data.matterID}).select();
    if (think.isEmpty(msg)){
      // 可能是登记签收类短信
      let tellID = [];
      if (matter.tellLog !== null){
        tellID.push(matter.tellLog)
      }
      if (matter.tellLogRepresent !== null){
        tellID.push(matter.tellLogRepresent)
      }
      if (tellID.length === 0){
        return this.fail(4004,"未找到短信预发送记录！")
      } else {
        let msgDJ = await this.model("tell_log").where({"isSend":1,"sendType":1,"id":['IN',tellID]}).select();
        if (think.isEmpty(msgDJ)) {
          return this.fail(4004,"未找到短信预发送记录！")
        }else {
          // 发送登记签收类短信（需要替换matterNum）
          // let code = "";//查询码
          // if (matter.activity.registerTypeID === "004"){// 网上信访 去找查询码
          //   let inquiry = await think.model('inquiry_code').where({"matterID":data.matterID,"flag":0}).order("createTime DESC").find();
          //   code = inquiry.inquiryCode;
          // }
          // let inquiry = await think.model('inquiry_code').where({"matterID":data.matterID,"flag":0}).order("createTime DESC").find();
          // if (!think.isEmpty(inquiry)){
          //   code = inquiry.inquiryCode;
          // }
          let userInfo = await this.getUserInfo(msgDJ[0].sendPerson);
          msgDJ.forEach(async function(item) {
            if (item.content !== null && item.content.length > 10){
              // 有内容才发
              //判断是否发送给代表，0是，1否
              if (item.isRepresent === 1){
                //非代表，发送给主信访人，person表
                item.mobilePhone = matter.activity.person.mobilePhone;
                item.personID = matter.activity.person.id;
                item.personName = matter.activity.person.name;
              }else {
                //发送给代表 delegate_leading 表
                let leader = await think.model('delegate_leading').join('activity_leading on activity_leading.leadingID = delegate_leading.id')
                  .where({"activity_leading.activityID":matter.activity.id}).field('delegate_leading.*').find();
                item.mobilePhone = leader.phone;
                item.personID = leader.id;
                item.personName = leader.name;
              }
              item.content = item.content.replace('[信访事项编号]', matter.matterNum);
              item.content = item.content.replace('[查询码]', code);
              item.content = item.content.replace('[网址链接]', "");
              item.content = item.content.replace('[发送人电话]', userInfo.phone);
              item.content = item.content.replace('[发送单位]', userInfo.orgName);
              item.content = item.content.replace('[去向单位查询电话]', think.isEmpty(final) ? "" : final.searchPhone);
              item.content = item.content.replace('[去向单位]', think.isEmpty(final) ? "" : final.orgName);
              item.content = item.content.replace('[去向单位]', think.isEmpty(final) ? "" : final.orgName);//故意两遍
              item.content = item.content + "【" + userInfo.deptName + "人大信访】";
              // await MSG.msg(item.mobilePhone,item.content);//发送短信
              // await httpRequest('post','https://192.9.200.55:8360/msg/msg/sendMsg',{"phone":item.mobilePhone,"content":item.content});//发送短信
              await httpRequest('post','https://172.28.50.118/msg/msg/sendMsg',{"phone":item.mobilePhone,"content":item.content});//发送短信
              // await httpRequest('post','http://localhsot:8360/msg/msg/sendMsg',{"phone":item.mobilePhone,"content":item.content});//发送短信
              // 更新 发送日志
              let up = {
                "isSend":0,
                "matterID":data.matterID,
                "sendTime":moment().format('YYYY-MM-DD HH:mm:ss'),
                "content":item.content,
                "mobilePhone":item.mobilePhone,// 接收手机号
                "personID":item.personID,// 接收人id
                "personName":item.personName,// 接收人
              };
              await think.model("tell_log").where({"id":item.id}).update(up);
            }
          });
          return this.success()
        }
      }
    } else {
      // 发送非 登记签收类短信（短信模板中有事项编号）
      let userInfo = await this.getUserInfo(msg[0].sendPerson);
      msg.forEach(async function(item) {
        //判断是否发送给代表，0是，1否
        if (item.isRepresent === 1){
          //非代表，发送给主信访人，person表
          item.mobilePhone = matter.activity.person.mobilePhone;
          item.personID = matter.activity.person.id;
          item.personName = matter.activity.person.name;
        }else {
          //发送给代表 delegate_leading 表
          let leader = await think.model('activity_leading').join('delegate_leading on delegate_leading.id = activity_leading.activityID')
            .where({"activity_leading.activityID":matter.activity.id}).field('activity_leading.*').find();
          item.mobilePhone = leader.phone;
          item.personID = leader.id;
          item.personName = leader.name;
        }
        item.content = item.content.replace('[信访事项编号]', matter.matterNum);
        item.content = item.content.replace('[查询码]', code);
        item.content = item.content.replace('[发送人电话]', userInfo.phone);
        item.content = item.content.replace('[发送单位]', userInfo.orgName);
        item.content = item.content.replace('[网址链接]', "");
        item.content = item.content.replace('[去向单位查询电话]', think.isEmpty(final) ? "" : final.searchPhone);
        item.content = item.content.replace('[去向单位]', think.isEmpty(final) ? "" : final.orgName);
        item.content = item.content.replace('[去向单位]', think.isEmpty(final) ? "" : final.orgName);//故意两遍
        item.content = item.content + "【" + userInfo.deptName + "人大信访】";
        // await MSG.msg(item.mobilePhone,item.content);//发送短信
        // await httpRequest('post','https://192.9.200.55:8360/msg/msg/sendMsg',{"phone":item.mobilePhone,"content":item.content});//发送短信
        await httpRequest('post','https://172.28.50.118/msg/msg/sendMsg',{"phone":item.mobilePhone,"content":item.content});//发送短信
        // await httpRequest('post','http://localhost:8360/msg/msg/sendMsg',{"phone":item.mobilePhone,"content":item.content});//发送短信
        // 更新 发送日志
        let up = {
          "isSend":0,
          "sendTime":moment().format('YYYY-MM-DD HH:mm:ss'),
          "content":item.content,
          "mobilePhone":item.mobilePhone,// 接收手机号
          "personID":item.personID,// 接收人id
          "personName":item.personName,// 接收人
        };
        await think.model("tell_log").where({"id":item.id}).update(up);
      });
      return this.success()
    }
  }
  // 信访件流转，发送给下级人大办事员通知短信
  // 操作人userId
  // 事项id matterID
  // 接受收人userId  receivePerson 数组
  async sendOfficerAction(){
    let data = this.post();
    if (!data.hasOwnProperty('receivePerson') || data.receivePerson.length === 0){
      return this.fail();
    }
    let content = '您有新的业务(信访事项编号:[信访事项编号])待处理，请及时查收！【[发送单位]人大信访】';
    let matter = await this.model('matter').setRelation(false).where({"id":data.matterID}).find();
    let userInfo = await this.getUserInfo(data.userId);
    let receivePerson = await this.model('sys_user').where({"user_id":['IN',data.receivePerson]}).select();
    receivePerson.forEach(async function(item) {
      if (item.mobilePhone !== "" && item.mobilePhone !== null){
        content = content.replace('[信访事项编号]',matter.matterNum);
        content = content.replace('[发送单位]',userInfo.deptName);
        // await httpRequest('post','https://192.9.200.55:8360/msg/msg/sendMsg',{"phone":item.mobilePhone,"content":content});//发送短信
        await httpRequest('post','https://172.28.50.118/msg/msg/sendMsg',{"phone":item.mobilePhone,"content":content});//发送短信
        // await MSG.msg(item.mobilePhone,content);//发送短信
        // 保存内部发送日志
        let add = {
          "receiveName":item.user_name,
          "receiveOrgID":item.orgID,
          "receiveUserId":item.user_id,
          "receivePhone":item.mobilePhone,
          "content":content,
          "sendOrg":userInfo.orgName,
          "sendOrgID":userInfo.orgID,
          "sendUserId":data.userId,
          "matterID":data.matterID,
        };
        await think.model('office_msg_log').add(add);
      }
    })
    return this.success()
  }
  // 获取内部短信接收人列表
  // taskId
  async getReceivePersonAction(){
    let data = this.post();
    let person = await this.model('sys_user').alias('su').join('sys_organization as so on so.id = su.orgID')
      .join('fw_task as fw on fw.deptID_pre = so.id').where({"fw.id":data.taskId}).field('su.*').select()
    return this.success(person)
  }
  /**
   * showdoc
   * @catalog 短信
   * @title 短信发送记录
   * @description 短信发送记录接口
   * @method post
   * @url http://127.0.0.1:8360/msg/msg/smsList
   * @param userId 必选 string userId
   * @param personName 选填 string 接收人姓名
   * @param content 选填 string 发送内容
   * @param sendOrgID 选填 string 发送单位ID
   * @param mobilePhone 选填 string 接收手机号
   * @param tellCode 选填 string 告知单号
   * @param startTime 选填 string 发送开始时间YYYY-MM-DD
   * @param endTime 选填 string 发送结束时间YYYY-MM-DD
   * @return {"errno": 0, "errmsg":""}
   */
  // 短信发送记录
  async smsListAction(){
    let data = this.post();
    let where = {
      'tl.personName':data.personName === undefined || data.personName === '' ? ['!=',null] :['LIKE',"%" + data.personName + "%"],// 接收人姓名
      'tl.content':data.content === undefined || data.content === '' ? ['!=',null] :['LIKE',"%" + data.content + "%"],
      'tl.sendOrgID':data.orgID === undefined || data.orgID === '' ? ['!=',null] :data.orgID,
      'tl.mobilePhone':data.mobilePhone === undefined || data.mobilePhone === '' ? ['!=',null] :data.mobilePhone,// 接收手机号
      'tl.isSend':0,// 已发送
    };
    if (data.hasOwnProperty('tellCode') && data.tellCode !== ""){
      where['tl.tellCode'] = data.tellCode;// 告知单号
    }
    // 时间
    if ((!data.hasOwnProperty('startTime') && !data.hasOwnProperty('endTime')) || (data.startTime === '' && data.endTime === '')){
      where['tl.sendTime'] = ['!=', null] //全选
      // 默认当天
    } else if (data.startTime === ''){
      // 未设定开始时间
      where['tl.sendTime'] = ['between', '1900-01-01' + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    } else if (data.endTime === ''){
      // 未设定结束时间
      where['tl.sendTime'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + '2099-01-01']
    } else {
      where['tl.sendTime'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    }
    const sms = await this.model('tell_log').alias( 'tl').join('sys_organization as so on so.id = tl.sendOrgID')
      .join('sys_user on sys_user.user_id = tl.sendPerson').join('matter ON matter.id = tl.matterID').where(where)
      .page(data.page, data.limit).field('tl.*,so.orgName,sys_user.name as userName,matter.matterNum')
      .order('tl.sendTime DESC').countSelect();
    return this.success(sms)
  }
  async testAction(){
    // MSG.createInquiryCode(1);
    let t = moment().format('x');
    console.log(Math.random().toString(16).substr(2,1) + sixtytwo.toString(t))
    // console.log(Math.random().toString(16).substr(2,4) + parseInt(t).toString(16).substr(4,4))
    // let matter = await this.model('matter').setRelation(false).where({"taskid":this.post().taskId}).find();
    // await httpRequest('post','http://localhost:8360/msg/msg/sendTellMsg',{"matterID":matter.id})
  }
};
