const Base = require('../base.js');
const util = require('../../handle/util.js');
const idCard = require('../../handle/idCard');
let fs = require('fs');
const path = require('path');
let moment = require('moment');
const upload = require('../../handle/uploadFile.js');
var request = require('request');
module.exports = class extends Base {
  /**
   * showdoc
   * @catalog 互联网端
   * @title 互联网端提交
   * @description 互联网端提交接口
   * @method post
   * @url http://127.0.0.1:8360/online/add/add
   * @param name 必选 string 姓名
   * @param sex 必选 string 性别
   * @param sexID 必选 string 性别ID（为字典表dictValue字段）
   * @param IDType 必选 string 证件类型
   * @param IDTypeID 必选 string 证件类型ID（为字典表dictValue字段）
   * @param IDNumber 必选 string 证件号
   * @param mobilePhone 必选 string 手机号
   * @param addressRegion 必选 string 家庭所属地区
   * @param addressRegionID 必选 string 家庭所属地区编号（为字典表dictValue字段）
   * @param address 必选 string 详细地址
   * @param contentClassify 必选 string 所属分类
   * @param contentClassifyID 必选 string 所属分类编号（为字典表dictValue字段）
   * @param happenRegion 必选 string 问题所属地区
   * @param happenRegionID 必选 string 问题所属地区编号（为字典表dictValue字段）
   * @param content 必选 string 事项简述
   * @param appealContent 必选 string 诉求简述
   * @param host 必选 string 受理单位
   * @param hostID 必选 string 受理单位ID（为字典表dictValue字段）
   * @param url 必选 array 附件地址
   * @param type 必选 int 上传端，1手机，2微信，3网页
   * @return {"errno": 0, "errmsg":""}
   */
  async addAction() {
    const param = this.post();
    // 重复提交验证 当日手机号或者身份证号相同，提交单位(地区)相同，APP端默认向省人大提交
    let count;
    let where = {
      "time":['between', moment().format('YYYY-MM-DD') + ',' + moment().add(1, 'day').format('YYYY-MM-DD')],
      _complex:{
        "IDNumber":param.IDNumber,
        "mobilePhone":param.mobilePhone,
        _logic:'or'
      }
    }
    if (param.type === 1){ // app端
      //
    } else { // 互联网端和微信端
      // where["_complex"] = ;
    }
    count = await this.model("online").where(where).count();
    if (count > 0){
      return this.fail(4001,"您当日已向同一单位提交过信访资料，请勿重复提交！")
    }else {
      let addParam = {
        name: param.name, //姓名
        sex: param.sex, //性别
        sexID: param.sexID, //性别编号
        addressRegion: param.addressRegion,//家庭所属地区
        addressRegionID: param.addressRegionID,
        address: param.address,//详细地址
        IDType: param.IDType, //证件类型
        IDTypeID: param.IDTypeID, //证件类型编号
        IDNumber: param.IDNumber, //证件号
        idCardAdd: param.idCardAdd, //身份证地址
        mobilePhone: param.mobilePhone, //手机号
        happenRegion: param.happenRegion, //问题所属地区
        happenRegionID: param.happenRegionID, //问题所属地区id
        contentClassify: param.contentClassify, //所属分类
        contentClassifyID: param.contentClassifyID, //所属分类ID
        content: param.content, //信访简述
        appealContent: param.appealContent, //诉求内容
        host: param.host, //受理单位
        hostID: param.hostID, //受理单位
        djRegionID: param.djRegionID, //登记地区sys_dept表id
        djRegion: param.djRegion, //登记地区
        url: param.url.join(','),
        type: param.type, // 上传端，1手机，2微信，3网页
        time: moment().format('YYYY-MM-DD HH:mm:ss')
      };
      const res = await this.model('online').add(addParam);
      if (!think.isEmpty(res)){
        let content = '您的信访事项已提交，等待工作人员审核！【人大网上信访】';
        // await httpRequest('post','https://192.9.200.55:8360/msg/msg/sendMsg',{"phone":param.mobilePhone,"content":content });//发送短信
        await httpRequest('post','https://172.28.50.118/msg/msg/sendMsg',{"phone":param.mobilePhone,"content":content });//发送短信
      }
      return this.success(res);
    }
  }

  //互联网三端获取字典
  async getDictAction(){
    let param = this.post();
    let whereParam = {dictID: param.dictID,flag:1}
    if (param.dictID === 'AB') {
      whereParam.dictValue = ['notlike', '135%'] // 排除135开头国外代码
    }
    const res = await this.model('dictionary').where(whereParam).select();
    let treeRes = this.getDictTree(res, 'dictValue', 'parentValue') ;
    this.success(treeRes);
  }

  //获取问题列表
  async getQuestionAction() {
    const res = await this.model('question').limit(5).order('isTop desc,createTime desc').select();
    this.success(res);
  }
  async getQuestionListAction() {
    const param = this.post();
    const res = await this.model('question').page(param.page, param.pageSize).order('isTop desc,createTime desc').countSelect();
    this.success(res);
  }
  // async uploadPicAction()

  // 互联网数据列表
  async onlineListAction(){
    const data = this.post();
    let where = {};
    if (typeof data.type === 'number'){
      where['type'] = data.type;//数据端
      where["state"] = 0//状态0未筛选，1不采纳，2已采纳
    }
    // 时间
    if (data.startTime === '' && data.endTime === ''){
      where['time'] = ['!=', null] //全选
      // 默认当天
      // where['time'] = ['between', moment().format('YYYY-MM-DD') + ',' + moment().add(1, 'day').format('YYYY-MM-DD')]
    } else if (data.startTime === ''){
      // 未设定开始时间
      where['time'] = ['between', '1900-01-01' + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    } else if (data.endTime === ''){
      // 未设定结束时间
      where['time'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + '2099-01-01']
    } else {
      where['time'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    }
    const res = await this.model('online').page(data.page, data.limit).where(where).order('time desc').countSelect();
    if (!think.isEmpty(res)){
      for (let i in back){
        if (res[i].url === null || res[i].url.length === 0){
          res[i].url = [];
          res[i]["file"] = [];
        }else {
          res[i].url = res[i].url.split(',');
          let file = await this.model("file_log").where({"url":["IN", res[i].url]}).select();
          res[i]["file"] = file;
        }
      }
    }
    this.success(res);
  }
  // 互联网附件上传
  async uploadAction(){
    const file = this.file().file; // file 文件
    // const data = this.post(); // post其他参数
    // 上传文件
    //获取后缀
    let fileType = file.name.substr( file.name.lastIndexOf(".") + 1);
    // 认可的文件类型
    // let arr = ['doc','docx','jpg','png','jpeg','pdf','zip','rar','jpg'];
    // if(arr.toString().indexOf(fileType.toLowerCase()) === -1) { // 字符串转为小写比较
    let arr = ['application/msword',// doc
      'application/vnd.openxmlformats-officedocument.wordprocessingml.document',// docx
      'image/jpeg',// jpeg
      'image/png',//png
      'application/pdf',//pdf
      'aplication/zip',// zip
      'application/x-rar-compressed',// rar
      'application/octet-stream'// 其他不可识别
    ];
    if(arr.indexOf(file.type.toLowerCase()) === -1) { // 字符串转为小写比较
      return this.fail("文件类型不支持！")
    }
    if (file.size > 50*1024*1024) {
      return this.fail("文件大小超过限制！")
    }
    //创建路径
    // let filePath = path.join(think.ROOT_PATH, '/www/static/online', fileType);
    let filePath = path.join(think.ROOT_PATH, '/www/static/online', moment().format('YYYY年')+'/'+moment().format('M月')+'/'+fileType);
    upload.mkdirsSync(filePath);// 创建文件夹（如果需要）
    let fileName = Math.random().toString(16).substr(2) + '.' + fileType;// 文件名称
    let _uploadFilePath = path.join(filePath, fileName);
    let saveTo = path.join(_uploadFilePath);
    const reader = fs.createReadStream(file.path);// 读取文件
    // 文件保存到指定路径
    reader.pipe(fs.createWriteStream(saveTo));
    // 在文件上传日志中保存记录
    let log = {
      "name":file.name,
      "random":fileName,
      // "url":'/static/online/' + fileType + '/' + fileName,
      "url":'/static/online/' + moment().format('YYYY年')+'/'+moment().format('M月')+'/'+ fileType + '/' + fileName,
      "fileType":fileType,
      "userId":""
    };
    await this.model('file_log').add(log);
    // return this.success('/static/online/'+ fileType + '/' + fileName)
    return this.success(log.url)
  }
/**
 * showdoc
 * @catalog 互联网端
 * @title 互联网端提交
 * @description 互联网端提交接口
 * @method post
 * @url http://127.0.0.1:8360/online/add/checkID
 * @param name 必选 string 姓名
 * @param IDNumber 必选 string 身份证
 * @return {"errno": 0, "errmsg":""}
 */
  // 互联网端验证身份证
  async checkIDAction(){
    const data = this.post();
    // let back = await httpRequest('post','https://192.9.200.55:8360/online/add/checkID',{"name":data.name,"IDNumber":data.IDNumber});//内网调外网
    const back = await idCard.check(data.name,data.IDNumber);
    return this.success(back) // 2不通过，其他都通过
  }
}
