const Base = require('../base.js');
const util = require('../../handle/util.js');
const Check = require('../../handle/check.js');
let fs = require('fs');
const path = require('path');
let moment = require('moment');
module.exports = class extends Base {
  // 互联网三端列表，包括地区
  async getListAction(){
    const data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    let where = {
      "type":data.type === 0 || data.type === "" ? ['IN', [1,2,3]] : data.type,//1手机，2微信，3网页 0全选
      "state":data.state,//状态0未筛选，1已采纳，2不采纳
      "djRegionID":data.type === 1 ? ['!=',null] : userInfo.dictValue
    };
    if (data.state === 1){
      where["registerState"] = data.registerState ? data.registerState : ['!=',null] //登记状态，0已登记，1未登记
    }
    // 时间
    if (data.startTime === '' && data.endTime === ''){
      where['time'] = ['!=', null] //全选
    } else if (data.startTime === ''){
      // 未设定开始时间
      where['time'] = ['between', '1900-01-01' + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    } else if (data.endTime === ''){
      // 未设定结束时间
      where['time'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + '2099-01-01']
    } else {
      where['time'] = ['between', moment(data.startTime).format('YYYY-MM-DD') + ',' + moment(data.endTime).add(1, 'day').format('YYYY-MM-DD')]
    }
    const back = await this.model('online').page(data.page, data.limit).order('id DESC').where(where).countSelect();// 时间倒序
    return this.success(back)
  }
  // 互联网三端详情
  async getDetailAction(){
    const data = this.post();
    const back = await this.model('online').where({"id":data.id}).find();
    back.url = ((back.url === null || back.url === '' || back.url === undefined) ? [] : back.url.split(','));
    let file = [];//附件详细信息
    if (back.url.length > 0 ) {
      file = await this.model('file_log').where({"url":["IN",back.url]}).select();
    }
    back["file"] = file;//附件详细信息
    return this.success(back)
  }
  // 是否采纳互联网信息信访事项
  async isAdoptAction(){
    const data = this.post();
    let content = '';// 发送短信的内容
    let update = {
      "state":data.state,//1采纳，2不采纳
    };
    if (data.state === 1){ //如果采纳
      update["registerState"] = 1;//登记状态改为,1未登记
      // 如果采纳，增加考勤积分
      // 5人民意见转信访件（互联网加分）
      // await Check.addPoints(5,data.userId);//22年7月删除。没有type: 5
      // 短信内容
      content = '您提交的信访事项已能通过审核，工作人员正在登记。感谢您的支持！【人大网上信访】';
    }
    if (data.hasOwnProperty('reason') && data.reason !== '') {
      update['refuseReason'] = data.reason;// 不采纳理由
      // 发送短信内容
     content = '您提交的信访事项因' + data.reason + '等原因，未能通过审核。感谢您的支持。【人大网上信访】';
    }
    // 发送短信
    let online = await this.model('online').where({'id':data.id}).find();
    if (!think.isEmpty(online)){
      // await httpRequest('post','https://192.9.200.55:8360/msg/msg/sendMsg',{"phone":online.mobilePhone,"content":content });//发送短信
      await httpRequest('post','https://172.28.50.118/msg/msg/sendMsg',{"phone":online.mobilePhone,"content":content });//发送短信
      update['notice'] = 1
    }
    const back = await this.model('online').where({"id":data.id}).update(update);
    return this.success(back)
  }
  // 通过活动id查询互联网登记记录
  async byActivityAction(){
    const data = this.post();
    const back = await this.model('online').where({"activityID":data.activityID}).find();
    if (!think.isEmpty(back)){
      if (back.url === null || back.url.length === 0){
        back.url = [];
        back["file"] = [];
      }else {
        back.url = back.url.split(',');
        let file = await this.model("file_log").where({"url":["IN", back.url]}).select();
        back["file"] = file;
      }
    }
    return this.success(back)
  }
  // 通过查询码查询信访进度
  // code 查询码
  // idCard 身份证号
  async inquireAction(){
    const data = this.post();
    let endingUrl = [];
    let conclusion = "";
    let internetEndingUrl = [];//互联网办结
    let internetConclusion = "";
    let isEnding = 0;// 默认0未办结,1办结 与数据库设置相反
    let inquiry = await this.model('inquiry_code').where({"inquiryCode":data.code,"flag":0}).find();
    if (think.isEmpty(inquiry)){
      // 验证码错误或者验证码过期
      return this.fail(9404,"验证码错误或者验证码过期");
    } else {
      // 验证主信访人身份证
      let matter = await this.model('matter').where({"id":inquiry.matterID}).find();
      if (data.idCard !== matter.activity.person.IDNumber){
        //身份证不匹配
        return this.fail(9405,"查询人身份信息与主信访人身份信息不匹配");
      }
      //**********************
      // 重新修改的对外显示的node

      //**********************
      let nodeWhere = {"taskId":matter.taskid,"info":["!=",null]};
      let task = await this.model('fw_task').where({"id":matter.taskid,"businessID":99}).find();
      if (!think.isEmpty(task)){
        // 如果是闭环，查询职能单位，15,16，17 或者自办13
        nodeWhere["businessID"] = ['IN',[15,16,17]];
        if (matter.endingUrl !== null && matter.endingUrl.length > 0 ) {
          let file = await this.model('file_log').where({"url":["IN",matter.endingUrl.split(',')]}).select();
          endingUrl = file;
        }
        conclusion = matter.conclusion;
        isEnding = 1;
      }
      // 流程信息
      let node = await this.model('node_record').where(nodeWhere).limit(1).order("id DESC").select();
      if (!think.isEmpty(node)){
        let userId = [];
        let actID = [];
        node.forEach(function(item) {
          userId.push(item.userId);
          actID.push(item.actID);
          item.info = JSON.parse(item.info);
        });
        if (node[0].solveCode !== ""){
          let solveName = await this.model('dictionary').where({"dictID":"FK","flag":1,"dictValue":node[0].solveCode}).find();
          node[0]["solveName"] = solveName.description;
        }
        if (node[0].businessID === 13 && (conclusion === "" || conclusion === null)){
          conclusion = node[0].info.content;
        }
        if (node[0].info.hasOwnProperty('internetEndingUrl') && node[0].info.internetEndingUrl.length > 0) {
          let file = await this.model('file_log').where({"url":["IN",node[0].info.internetEndingUrl]}).select();
          internetEndingUrl = file;
        }
        if (node[0].info.hasOwnProperty('internetConclusion')) {
          internetConclusion = node[0].info.internetConclusion;
        }
        let userInfo = await this.model('sys_user').where({"user_id":['IN',userId]}).field('name,orgID,user_id').select();
        let actInfo = await this.model('fw_task_act').where({"id":['IN',actID]}).select();
        for (let n of node){
          for (let user of userInfo){
            if (n.userId === user.user_id){
              n["userInfo"] = user;
              break;
            }
          };
          for (let act of actInfo){
            if (parseInt(n.actID) === act.id){
              n["actInfo"] = act;
              break;
            }
          }
        }
      }else {
        // 流程信息未找到
        return this.fail(9406,"不符合查询环节");
      }
      // 网上提交信息
      let online = {};
      if (matter.activity.registerTypeID === "004"){
        online = await this.model('online').join('activity on activity.id = online.activityID')
          .join('matter on matter.activityID = activity.id').where({"matter.id":inquiry.matterID}).field('online.*').find();
        if (!think.isEmpty(online)){
          if (online.url === null || online.url.length === 0){
            online.url = [];
            online["file"] = [];
          }else {
            online.url = online.url.split(',');
            let file = await this.model("file_log").where({"url":["IN", online.url]}).select();
            online["file"] = file;
          }
        }
      }

      //更新查询次数
      await this.model('inquiry_code').where({"id":inquiry.id}).increment('number', 1);
      let nodeBack = [{
        actInfo:{
          businessName:node[0].actInfo.businessName,
          deptName_now:node[0].actInfo.deptName_now,
          c_time:node[0].actInfo.c_time
        },
        userInfo:{
          name:node[0].userInfo.name
        }
      }];
      let back = {
        // "node":node,
        "node":nodeBack,
        "online":Object.keys(online).length === 0 ? {"name":matter.activity.person.name,"content":matter.abstract,"time": matter.createTime} : {"name":online.name,"content":online.content,"time":online.time},
        "endingUrl":endingUrl,
        "conclusion":conclusion,
        "internetEndingUrl":internetEndingUrl,
        "internetConclusion":internetConclusion,
        "isEnding":isEnding
      }
      return this.success(back)
    }
  }
}
