const Base = require('../base.js');
const util = require('../../handle/util.js');
let fs = require('fs');
let moment = require('moment');
const upload = require('../../handle/uploadFile.js');
module.exports = class extends Base {
/**
 * showdoc
 * @catalog 互联网端资源加载
 * @title 获取轮播图
 * @description 获取轮播图接口
 * @method post
 * @url http://127.0.0.1:8360/online/load/getLunbo
 * @param type 必选 int 图片类型1app轮播，2互联网轮播，3微信轮播
 * @return {"errno": 0, "errmsg":"","data":[]}
 */
//获取轮播图
  async getLunboAction() {
    const param = this.post();
    let list = [];
    if (param.hasOwnProperty("type") && parseInt(param.type) === 1){
      //app端轮播图，不需要单位
      let res = await this.model('lunbo').field('url').where({"type":1}).select();
      res.forEach(function(it) {
        list.push(it.url);
      })
    }
    this.success(list);
  };
  /**
   * showdoc
   * @catalog 互联网端资源加载
   * @title 获取静态html
   * @description 获取静态html接口
   * @method post
   * @url http://127.0.0.1:8360/online/load/getHtml
   * @param type 必选 int 资源端1app，2互联网，3微信
   * @return {"errno": 0, "errmsg":"","data":[]}
   */
  // 获取静态html
  async getHtmlAction() {
    const param = this.post();
    let res;
    if (param.hasOwnProperty("type") && parseInt(param.type) === 1){
      //app端，不需要单位
      res = await this.model('html').where({"type":1}).select();
    }
    this.success(res);
  };
  /**
   * showdoc
   * @catalog 互联网端资源加载
   * @title 静态资源标题搜索
   * @description 静态资源标题搜索接口
   * @method post
   * @url http://127.0.0.1:8360/online/load/htmlTitleSearch
   * @param type 必选 int 资源端1app，2互联网，3微信
   * @param title 必选 string 标题关键字
   * @return {"errno": 0, "errmsg":"","data":[]}
   */
  // 静态资源标题搜索
  async htmlTitleSearchAction() {
    const param = this.post();
    let res;
    let where = {};
    if (param.hasOwnProperty("type") && parseInt(param.type) === 1){
      //app端，不需要单位
      where['type'] = 1;
      where['title'] = ['like', "%"+param.title+"%"];
      res = await this.model('html').where(where).select();
    }
    this.success(res);
  }
  /**
   * showdoc
   * @catalog 互联网端资源加载
   * @title 网上信访须知
   * @description 网上信访须知接口
   * @method get
   * @url http://127.0.0.1:8360/online/load/note
   * @return {"errno": 0, "errmsg":"","data":[]}
   */
  // 网上信访须知
  async noteAction(){
    const res = await this.model('html').field('title,content').where({"type":0}).find();
    return this.success(res)
  }
  /**
   * showdoc
   * @catalog 互联网端资源加载
   * @title app首页信息
   * @description app首页信息接口
   * @method post
   * @url http://127.0.0.1:8360/online/load/appHomePage
   * @return {"errno": 0, "errmsg":"","data":{"lunbo":[],"law":[],"fanwei":{}}}
   */
  // app首页信息 包括轮播图、受理范围、法律法规
  async appHomePageAction(){
    const data = this.post();
    let lunbo = []; // 轮播图url
    let law = []; // 法律法规
    let fanwei = {}; // 受理范围
    let list = await this.model('lunbo').field('url').where({"type":1}).select();
    list.forEach(function(it) {
      lunbo.push(it.url);
    });
    let res = await this.model('html').where({"type":["IN",[1,99]]}).select(); //1法律法规，99受理范围
    res.forEach(function(it) {
      if (it.type === 1){
        law.push(it);
      };
      if (it.type === 99){
        fanwei = it;
      }
    });
    return this.success({"lunbo":lunbo,"law":law,"fanwei":fanwei});
  }
};
