/* eslint-disable no-unused-vars */
const Base = require('./base.js');
const moment = require('moment');
const uuid = require('node-uuid');
const util = require('./../handle/util.js');
module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  /**
   * showdoc
   * @catalog 人员信息
   * @title 人员信息添加
   * @description 人员信息添加接口
   * @method post
   * @url http://127.0.0.1:8360/person/add
   * @param name 必选 string 姓名
   * @param xfType 必选 string 信访类型
   * @param xfTypeID 必选 string 信访类型ID
   * @param personID 必选 int 人员ID
   * @param activityID 必选 int 活动ID
   * @param family 必选 array 修改家庭关系
   * @param delFamily 必选 array 家庭关系ID
   * @param addFamily 必选 array 新增家庭关系
   * @param unit 选填 string 单位
   * @param position 选填 string 职位
   * @param grade 选填 string 层级
   * @param due 选填 string 届次
   * @param zone 选填 string 地区
   * @return {"errno": 0, "errmsg":"", "data":{"personID":,"familyID":,"activityID":}}
   */
  // 人员信息添加
  async addAction() {
    const data = this.post();
    let person;
    let family = [];
    let activity;
    // 判断是新增还是修改person
    if (typeof data.id === 'undefined') {
      // 新增person  return id
      let personAdd = data;
      personAdd["isAnonymous"] = (data.hasOwnProperty("isAnonymity") && data.isAnonymity === 1) ? 1 : 0; //判断1匿名，0实名。
      let userInfo = await this.getUserInfo(data.userId);
      personAdd['createPerson'] = userInfo.name;//创建人姓名
      personAdd['createAccount'] = userInfo.user_name;//创建人账号
      personAdd['createOrgID'] = userInfo.orgID;//创建机构ID
      personAdd['createOrg'] = userInfo.orgName;//创建机构

      // personAdd['id'] = uuid.v1();
      if (!data.hasOwnProperty("name") && data.isAnonymity !== 1){
        return this.fail("请输入姓名或者选择匿名！")
      }else if (data.isAnonymous ===1){
        // 匿名
        person = await this.model('person').add(personAdd);
      } else {
        // 只有当原先有身份证。与新增的身份证一致，才判断为重名，不需要导入，其他一律可以新增。
        let checkPersonWhere = {'name':data.name};
        if (data.hasOwnProperty('IDNumber') && (data.IDNumber !== ''|| data.IDNumber !== null )){
          checkPersonWhere['IDNumber'] = data.IDNumber;
          let checkPerson = await this.model('person').where(checkPersonWhere).find();
          if (!think.isEmpty(checkPerson)) {
            // 人员信息重复
            return this.fail("该人员已在信息系统中，请从系统中导入人员信息！")
          }else {
            person = await this.model('person').add(personAdd);
          }
        }else {
          person = await this.model('person').add(personAdd);
        }
      }
      // person = personAdd.id;
      if (data.addFamily.length > 0) {
        // 在家庭关系中插入personID
        data.addFamily.forEach(function(item) {
          item['personID'] = person;
        });
        // 新增family 家庭成员关系 return [id,id...]
        family = await this.model('family').addMany(data.addFamily);
      }
    } else {
      // 更新person  return 0失败 1成功
      data["isAnonymous"] = (data.hasOwnProperty("isAnonymity") && data.isAnonymity === 1) ? 1 : 0; //判断1匿名，0实名。
      const upPerson = await this.model('person').where({'id': data.id}).update(data);
      if (data.delFamily.length > 0) {
        // 删除部分家庭成员关系
        const delFamily = await this.model('family').where({'id': ['IN', data.delFamily]}).delete();
      }
      if (data.addFamily.length > 0) {
        // 在家庭关系中插入personID
        data.addFamily.forEach(function(item) {
          item['personID'] = data.id;
        });
        // 增加家庭成员 return [id,id...]
        family = await this.model('family').addMany(data.addFamily);
      }
      // 修改家庭成员
      if (data.family.length > 0) {
        const upFamily = await this.model('family').updateMany(data.family);
      }
    }
    // 更新personID
    const pushID = typeof data.id === 'undefined' ? person : data.id;
    // 判断主信访人标签
    if (data.mainPerson === 1) {
      let upDate ={'mainPerson': pushID};
      activity = await this.model('activity').where({'id': data.activityID}).update(upDate);
    }
    // let upDate = data.mainPerson === 1 ?
    // //   {'personID': ['exp', 'CONCAT_WS(",",personID,"' + pushID + '")'], 'mainPerson': pushID} :
    // // {'personID': ['exp', 'CONCAT_WS(",",personID,"' + pushID + '")']};
    //   {'personID': ['exp', 'IF(personID="",pushID,CONCAT_WS(",",personID,"'+pushID+'"))'], 'mainPerson': pushID} :
    //   {'personID': ['exp', 'IF(personID="",pushID,CONCAT_WS(",",personID,"'+pushID+'"))']};
    // activity = await this.model('activity').where({'id': data.activityID}).update(upDate);
    let upAdd = {
      'personID': (typeof person === 'undefined' ? data.id : person),
      'isMain': (data.mainPerson === 1 ? 1 : 0),
      'activityID':data.activityID,
      'isMainContact': data.isMainContact,
      'isSubject':data.isSubject,
      'subjectType':data.subjectType,
      'subjectTypeID':data.subjectTypeID,
      'relationWithSubject':data.relationWithSubject,
      'relationWithSubjectID':data.relationWithSubjectID,
      'objectName':data.objectName
    }
    // let upAdd = data.mainPerson === 1 ?
    //   {'personID': (typeof person === 'undefined' ? data.id : person), 'isMain':1, 'activityID':data.activityID, 'isMainContact': data.isMainContact} :
    //   {'personID': (typeof person === 'undefined' ? data.id : person), 'isMain':0, 'activityID':data.activityID, 'isMainContact': data.isMainContact};
    // 在人员活动表中是否命中条件，命中更新，未命中新增
    const person_activity = await this.model('person_activity').where({'personID': pushID,'activityID':data.activityID}).find();
    if (think.isEmpty(person_activity)) {
      // 未命中，新增
      await this.model('person_activity').add(upAdd);
      // 更新activity表中personID
      let personIDup = {'personID': ['exp', 'IF(personID="","'+pushID+'",CONCAT_WS(",",personID,"'+pushID+'"))']}
      activity = await this.model('activity').where({'id': data.activityID}).update(personIDup);
      if (data.isAnonymity === 0 && data.mainPerson === 1){
        // 如果是实名主信访人，进入大会判断
        await util.DH_window_add(data.activityID,upAdd.personID,data.userId);
      }
    } else {
      // 命中，更新
      await this.model('person_activity').where({'personID': pushID,'activityID':data.activityID}).update(upAdd)
    }
    //判断信访人是否大于或活动中的人数
    const personNumData = await util.getPersonNum(data.activityID);
    const editActXfNum = await util.perActMoreAct(personNumData, data.activityID);
    this.json({
      'errno': 0,
      'errmsg': '',
      'data': {
        'personID': typeof data.id === 'undefined' ? person : data.id,
        'familyID': family,
        'activityID': data.activityID === '' ? activity : data.activityID
      }
    });
  };
  // 人员信息列表
  async listAction() {
    const data = this.post();
    const back = await this.model('person').page(data.page, data.limit).order('createTime DESC').countSelect();// 时间倒序
    this.json({
      'errno': 0,
      'errmsg': '',
      'data': back
    });
  }
  // 人员信息详情
  async findAction() {
    const data = this.post();
    const back = await this.model('person').where({'id': data.id}).find();
    const family = await this.model('family').where({'personID': data.id}).select();
    if(data.activityID) {
      const isMainContact = await this.model('person_activity').field('isMainContact').where({personID: data.id,activityID:data.activityID}).find();
      if (!think.isEmpty(isMainContact)) {
        back['isMainContact'] = isMainContact['isMainContact'];
      }
    }
    back['family'] = family;
    this.json({
      'errno': 0,
      'errmsg': '',
      'data': back
    });
  }
  // 人员信息搜索
  async selectAction() {
    const data = this.post();
    let where;
    where['name'] = ['like', '%' + data.name + '%'];
    const back = await this.model('person').where(where).page(data.page, data.limit).order('createTime DESC').countSelect();
    return this.success(back);
  }
  async updateAction() {
    const data = this.post();
    const back = await this.model('person').updateMany(data);
    return this.success(back)
  }
  // 根据活动ID查询信访人
  async byActivityAction() {
    const data = this.post();
    let back = [];
    let where = {
      'activityID': data.activityID,
    };
    //如果传了isAll参数，且===1 则查询结果中剔除主信访人
    if (data.hasOwnProperty("isAll") && data.isAll === 1){
      let activity = await this.model('activity').setRelation(false).where({"id":data.activityID}).find();
      where['personID'] = ['!=',activity.mainPerson]
    }

    let person_activity = await this.model('person_activity').where(where).order('isMain DESC').page(data.page, data.limit).countSelect();
    let personID = [];
    person_activity.data.forEach(function(item) {
      personID.push(item.personID)
    });
    if (personID.length > 0){
      let personWhere = {
        "id":["IN",personID],
      };
      if (data.hasOwnProperty('name')){
        personWhere['name'] = ['LIKE','%' + data.name + '%']
      }
      if (data.hasOwnProperty('IDNumber')){
        personWhere['IDNumber'] = data.IDNumber
      }
      let person = await think.model('person').where(personWhere).setRelation('person_activity',false).select();
      person_activity.data.forEach(function(item) {
        person.forEach(function(items) {
          if (item.personID === items.id){
            item["person"] = items;
            back.push(item);
          }
        })
      })
    }
    person_activity.data = back;
    // person_activity.count = back.length;
    return this.success(person_activity);
  }

  //搜素信访人
  // name 姓名
  // IDNumber 证件号码
  // domicileID 户口所属地区
  // addressRegionID 现住址所属地区
  // address 现住址详细地址
  // identityID 信访人身份
  // politicalID 政治身份
  // phone 手机或固话号码(通过判断是否11位查询mobilePhone或telephone)
  // personLabel 重点人员标签 1代表(isRepresent) 2.贫困户(isPoor) 3.退役军人(isEXserviceman) 4.重点群体(isFocusGroup) 5.重点人员(isFocusPerson)
  // startTime/endTime 首次登记时间
  // createOrgID 首次登记单位(选
  // createPerson 首次登记人(输
  async searchPersonAction() {
    const param = this.post();
    let whereParam = {"isAnonymous":0};
    // 是否匿名，没传的话，默认不匿名
    if (param.hasOwnProperty('isAnonymous')) {
      whereParam.isAnonymous = param.isAnonymous;
    }
    //名称
    if (param.hasOwnProperty('name')) {
      whereParam.name = ['like', '%' + param.name + '%']
    }
    //身份证号
    if (param.hasOwnProperty('IDNumber')&& param.IDNumber !== '') {
      whereParam.IDNumber = param.IDNumber
    }
    //户籍所在地
    if (param.hasOwnProperty('domicileID')&& param.domicileID !== ''&& param.domicileID.length>0) {
      whereParam.domicileID = ["IN",param.domicileID]
    }
    //现住址所属地区
    if (param.hasOwnProperty('addressRegionID')&& param.addressRegionID !== ''&& param.addressRegionID.length>0) {
      whereParam.addressRegionID = ["IN",param.addressRegionID]
    }
    //现住址详细地址
    if (param.hasOwnProperty('address')) {
      whereParam.address = ['like', '%' + param.address + '%']
    }
    // 信访人身份
    if (param.hasOwnProperty('identityID')&& param.identityID !== ''&& param.identityID.length>0) {
      whereParam.identityID = ["IN",param.identityID]
    }
    // 政治身份
    if (param.hasOwnProperty('politicalID')&& param.politicalID !== '') {
      whereParam.politicalID = param.politicalID
    }
    //手机或固话号码
    if (param.hasOwnProperty('phone')) {
      if (param.phone.length === 11){
        whereParam.mobilePhone = param.mobilePhone
      } else {
        whereParam.telephone = param.telephone
      }
    }
    //重点人员标签
    if (param.hasOwnProperty('personLabel')) {
      switch (param.personLabel) {
        case 1: whereParam.isRepresent = 1;break;
        case 2: whereParam.isPoor = 1;break;
        case 3: whereParam.isEXserviceman = 1;break;
        case 4: whereParam.isFocusGroup = 1;break;
        case 5: whereParam.isFocusPerson = 1;break;
      }
    }
    // 时间
    if ((param.startTime === ''|| !param.hasOwnProperty("startTime")) && (param.endTime === ''|| !param.hasOwnProperty("startTime"))){
      whereParam['createTime'] = ['!=', null] //全选
      // 默认当天
    } else if (param.startTime === ''){
      // 未设定开始时间
      whereParam['createTime'] = ['between', '1900-01-01' + ',' + moment(param.endTime).add(1, 'day').format('YYYY-MM-DD')]
    } else if (param.endTime === ''){
      // 未设定结束时间
      whereParam['createTime'] = ['between', moment(param.startTime).format('YYYY-MM-DD') + ',' + '2099-01-01']
    } else {
      whereParam['createTime'] = ['between', moment(param.startTime).format('YYYY-MM-DD') + ',' + moment(param.endTime).add(1, 'day').format('YYYY-MM-DD')]
    }
    // 首次登记人
    if (param.hasOwnProperty('createPerson')) {
      whereParam.createPerson = ['like', '%' + param.createPerson + '%']
    }
    // 首次登记单位
    if (param.hasOwnProperty('createOrgID')&& param.createOrgID !== '') {
      whereParam.createOrgID = ["IN",param.createOrgID]
    }
    // 多次反映问题的信访人
    if (param.hasOwnProperty('visit') && param.visit === 0){
      let sql = 'SELECT COUNT(*),personID FROM person_activity GROUP BY personID HAVING COUNT(*) > 1'
      let pa = await this.model('person_activity').query(sql);
      if (pa.length > 0) {
        let personID = [];
        pa.forEach(function(item) {
          personID.push(item.personID);
        });
        if (personID.length > 0){
          whereParam.id = ['IN',personID];
        }
      }else {
        //因为是与条件，此处不满足，则返回空数据
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    // 领导代表
    if (param.hasOwnProperty('xfTypeID') && Array.isArray(param.xfTypeID) && param.xfTypeID.length > 0){
      let acWhere = {'a.xfTypeID':['IN',param.xfTypeID]};
      let leaderWhere = {};
      // 领导代表姓名
      if (param.hasOwnProperty('leaderName')) {
        leaderWhere["dl.name"] = ['like', '%' + param.leaderName + '%']
      }
      // 届次
      if (param.hasOwnProperty('due')) {
        leaderWhere["dl.due"] = ['like', '%' + param.due + '%']
      }
      // 层级
      if (param.hasOwnProperty('grade')) {
        leaderWhere["dl.grade"] = ['like', '%' + param.grade + '%']
      }
      // 地区编号
      if (param.hasOwnProperty('zoneID')) {
        leaderWhere["dl.zoneID"] = param.zoneID
      }
      let la = await this.model('activity_leading').alias('al').join('delegate_leading as dl on dl.id = al.leadingID').where(leaderWhere).select();
      if (!think.isEmpty('la')){
        let acID = [];
        la.forEach(function(item) {
          acID.push(item.activityID);
        });
        if (acID.length > 0){
          acWhere["a.id"] = ['IN',acID];
        }
      }
      let pa = await this.model('person_activity').alias('pa').join('activity as a on pa.activityID = a.id').where(acWhere).field('pa.personID').select();
      if (!think.isEmpty(pa)) {
        let personID = [];
        pa.forEach(function(item) {
          personID.push(item.personID);
        });
        if (personID.length > 0){
          if (whereParam.hasOwnProperty('id') && whereParam.id.length >0 ) {
            whereParam.id[1] = personID.concat(whereParam.id[1])
          }else {
            whereParam.id = ['IN',personID];
          }
        }
      }else {
        //因为是与条件，此处不满足，则返回空数据
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    // 信访人数 信访形式 异常状态
    if ((param.hasOwnProperty('xfNumber') && parseInt(param.xfNumber) > 0)
      || (param.hasOwnProperty('registerTypeID') && Array.isArray(param.registerTypeID) && param.registerTypeID.length > 0 )
      || (param.hasOwnProperty('abnormalID') && Array.isArray(param.abnormalID) && param.abnormalID.length > 0)){
      let whereA = {};
      if (param.hasOwnProperty('xfNumber') && parseInt(param.xfNumber) > 0) {
        whereA['a.xfNumber'] = ['>=',parseInt(param.xfNumber)];
      }
      if (param.hasOwnProperty('registerTypeID') && Array.isArray(param.registerTypeID) && param.registerTypeID.length > 0) {
        whereA['a.registerTypeID'] = ['IN',param.registerTypeID];
      }
      if (param.hasOwnProperty('abnormalID') && Array.isArray(param.abnormalID) && param.abnormalID.length > 0) {
        whereA['a.abnormalID'] = ['IN',param.abnormalID];
      }
      let pa = await this.model('person_activity').alias('pa').join('activity as a on pa.activityID = a.id').where(whereA).field('pa.personID').select();
      if (!think.isEmpty(pa)) {
        let personID = [];
        pa.forEach(function(item) {
          personID.push(item.personID);
        });
        if (personID.length > 0){
          if (whereParam.hasOwnProperty('id') && whereParam.id.length >0 ) {
            whereParam.id[1] = personID.concat(whereParam.id[1])
          }else {
            whereParam.id = ['IN',personID];
          }
        }
      }else {
        //因为是与条件，此处不满足，则返回空数据
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    // 诉求主体 事项属地 问题所属系统 摘要 三跨三分离 被反映人姓名
    if ((param.hasOwnProperty('objectName')  && param.objectName !== '')|| (param.hasOwnProperty('happenRegionID') && param.happenRegionID !== '')
      // || (param.hasOwnProperty('belongsID') && Array.isArray(param.belongsID) && param.belongsID.length > 0 )
      || (param.hasOwnProperty('belongsID') && param.belongsID.length > 0 )
      || (param.hasOwnProperty('abstract') && param.abstract !== '' ) || (param.hasOwnProperty('SKSFL') && Array.isArray(param.SKSFL) && param.SKSFL.length > 0 )
      || (param.hasOwnProperty('identityName') && param.identityName !== '')){
      let whereM = {};
      if (param.hasOwnProperty('objectName') && param.objectName !== '' ) {
        whereM['pa.objectName'] = ['LIKE','%' + param.objectName + '%'];
      }
      if (param.hasOwnProperty('happenRegionID') && param.happenRegionID !== '' ) {
        whereM['m.happenRegionID'] = param.happenRegionID;
      }
      if (param.hasOwnProperty('belongsID')  && param.belongsID.length > 0 ) {
        whereM['m.belongsID'] = ['IN',param.belongsID];
      }
      if (param.hasOwnProperty('abstract') && param.abstract !== '' ) {
        whereM['m.abstract'] = ['LIKE','%' + param.abstract + '%'];
      }
      if (param.hasOwnProperty('SKSFL') && Array.isArray(param.SKSFL) && param.SKSFL.length > 0 ) {
        whereM['m.SKSFL'] = ['IN',param.SKSFL];
      }
      if (param.hasOwnProperty('identityName') && param.identityName !== '' ) {
        whereM['m.identityName'] = ['LIKE','%' + param.identityName + '%'];
      }
      let mpa = await this.model('person_activity').alias('pa').join('activity as a on pa.activityID = a.id').join('matter as m on m.activityID = a.id').where(whereM).field('pa.personID').select();
      if (!think.isEmpty(mpa)) {
        let personID = [];
        mpa.forEach(function(item) {
          personID.push(item.personID);
        });
        if (personID.length > 0){
          if (whereParam.hasOwnProperty('id') && whereParam.id.length >0 ) {
            whereParam.id[1] = personID.concat(whereParam.id[1])
          }else {
            whereParam.id = ['IN',personID];
          }
        }
      }else {
        //因为是与条件，此处不满足，则返回空数据
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
    }
    const res = await this.model('person').where(whereParam).page(param.page, param.pageSize).order('id DESC').countSelect();
    for (let r of res.data){
      let matter = await this.model('matter').alias('m').join('person_activity as pa on pa.activityID = m.activityID')
        .where({'pa.personID':r.id}).select();
      r['matter'] = matter
    }
    return this.success(res)
  }
  // 获取同部门用户（指定角色）
  async getOrgUserAction(){
    // 传入当前用户userId，获取当前部门，
    // 传入需要查询的角色id  role_id，最终查询当前部门该角色的所有用户
    const data = this.post();
    const org = await this.model('sys_user').where({user_id: data.userId, del_flag: 1}).find();
    const account = await this.model('sys_user').field('name,sys_user.user_id,orgID')
      .where({"orgID":org.orgID}).select()
      // .join({table:'sys_user_role', join:'left', on:['user_id', 'user_id']}).where({"orgID":org.orgID,"sys_user_role.role_id":3}).select()
    return this.success(account)
  }
  // 获取信访人历史居住地址
  async addressHistoryAction(){
    // 传入信访人personID
    // 传入当前用户userId，获取当前部门 //用于本单位登记的历史记录查询
    const data = this.post();
    let history = await this.model("address_history").where({"personID":data.personID}).select();
    return this.success(history);
  }
  // 根据活动id获取告知人列表
  async informPersonAction(){
    const data = this.post();
    let person = await this.model("person").setRelation(false).join("person_activity on person_activity.personID = person.id")
      .where({"person_activity.activityID":data.activityID}).field("person.*").select();
    return this.success(person);
  }
  // 集体访联名信解绑
  async unboundAction(){
    //personID  activityID
    // 删除person_activity记录
    // 更新activity表personID
    // 如果这个人没有其他关联活动，删除这个人
    const data = this.post();
    let ac = await this.model('activity').setRelation(false).where({"id":data.activityID}).find();
    if (ac.mainPerson === data.personID) {
      // 主信访人不能是删除
      return this.fail("主信访人不能是删除");
    }else {
      Array.prototype.remove = function(val) {
        for (var i = 0; i < this.length; i++) {
          if (this[i] == val) this.splice(i, 1);
        }
      };
      let personList = ac.personID.split(',');
      personList.remove(data.personID);
      await this.model('activity').setRelation(false).where({"id":data.activityID}).update({"personID":personList.join(',')});
      let pac = await this.model('person_activity').where({"personID":data.personID}).select();
      if (pac.length === 1){
        // 没有其他绑定关系
        await this.model('person').setRelation(false).where({'id':data.personID}).delete();
        await this.model('family').setRelation(false).where({'personID':data.personID}).delete();
      }
      await this.model('person_activity').where({"personID":data.personID,"activityID":data.activityID}).delete();
      return this.success();
    }
  }

  // app集体访录入
  async appCollectiveAddAction(){
    const data = this.post();
    let activity = await this.model('activity').where({'id':data.activityID}).find();
    if (!think.isEmpty(activity)) {
      // 有活动
      let pa = await this.model('person_activity').where({'activityID':data.activityID}).select();
      if (pa.length < activity.xfNumber){
        // 可以继续绑
        if (data.hasOwnProperty("name") && data.name !== "" && data.hasOwnProperty("IDNumber") && data.IDNumber !== ""){
          let person = await this.model("person").where({"name":data.name,"IDNumber":data.IDNumber}).find();
          if (!think.isEmpty(person)){
            //已有信访人，直接绑定
            for (let item of pa){
              // 重复绑定
              if (parseInt(item.personID) === person.id){
                return this.fail("该信访人已录入，请勿重复！");
              }
            }
            let pa_Add = {
              "personID":add,
              "activityID":data.activityID,
              "isMain":0,
              "isMainContact":0,
              "isSubject":0,
            };
            let p = await this.model("person_activity").add(pa_Add);
            return this.success(person.id);
          } else {
            // 新增后绑定
            let personAdd = {
              "name":data.name,
              "sex":data.sex,
              "sexID":data.sex === "男" ? "111" : (data.sex === "女" ? "222" : ""),
              // "birthday":data.birthday === "" ? null : moment(data.birthday),
              "nation":data.nation,
              "nationID":data.nationID,
              "IDType": data.IDType,
              "IDTypeID": data.IDTypeID,
              "IDNumber": data.IDNumber,
              "idCardRegion": data.idCardRegion,
              "idCardRegionID": data.idCardRegionID,
              "idCardAddress": data.idCardAddress,
              "mobilePhone": data.mobilePhone,
              "domicile": data.domicile,
              "domicileID": data.domicileID,
              "addressRegion": data.addressRegion,
              "addressRegionID": data.addressRegionID,
              "address": data.address,
            };
            personAdd["isAnonymous"] = 0; //判断1匿名，0实名。
            let userInfo = await this.getUserInfo(data.userId);
            personAdd['createPerson'] = userInfo.name;//创建人姓名
            personAdd['createAccount'] = userInfo.user_name;//创建人账号
            personAdd['createOrgID'] = userInfo.orgID;//创建机构ID
            personAdd['createOrg'] = userInfo.orgName;//创建机构
            let add = await this.model('person').add(personAdd);
            // 绑定 person_activity
            let pa_Add = {
              "personID":add,
              "activityID":data.activityID,
              "isMain":0,
              "isMainContact":0,
              "isSubject":0,
            }
            let p = await this.model("person_activity").add(pa_Add);
            return this.success(add);
          }
        }else {
          return this.fail("信访人信息不全！")
        }
      }else {
        // 以达到信访人数
        return this.fail("以达到信访人数!");
      }
    }

  }

  // 人员库操作申请
  async applyAddAction(){
    const data = this.post();
    let userinfo = await this.getUserInfo(data.userId);
    let saveData = {
      "personID":data.personID,
      "other_person":data.other_person,
      "createUserId":data.userId,
      "createUserName":userinfo.user_name,
      "createOrgID":userinfo.orgID,
      "createOrg":userinfo.orgName,
      "type":data.type,//1修改，2合并，3删除
      "state":0,//0未审核，1通过，2不通过
      "jsonData":JSON.stringify(data.jsonData),
      "remark":data.remark
    };
    let back = await this.model('person_apply').add(saveData);
    // let back = await this.model('person_apply').where({"id":[8]}).select();
    // back.forEach(function(item) {
    //   item.jsonData = typeof JSON.parse(item.jsonData) === 'object' ? JSON.parse(item.jsonData) : {}
    // })
    return this.success(back);
  }
  // 人员库申请列表
  // 当前用户userId，当前部门orgID，审核状态state，申请类型type，时间区间
  async applyListAction(){
    const data = this.post();
    let where = {};
    if (data.hasOwnProperty('orgID') && data.orgID !== ""){
      where['createOrgID'] = data.orgID;//判断为管理员查询的列表
    }else {
      where['createUserId'] = data.userId;//判断为当前用户查询自己提交的列表
    }
    // 审核状态 0未提交 1通过 2不通过
    if (data.hasOwnProperty('state') && data.state !== ""){
      where['state'] = data.state;
    }else {
      where['state'] = 0;
    }
    // 申请类型 1修改 2合并 3删除
    if (data.hasOwnProperty('type') && data.type !== ""){
      where['type'] = data.type;
    }
    // 时间区间
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      where["createTime"] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      where["CreateTime"] = ['<',moment(data.endTime).add(1,'day').format('YYYY-MM-DD')];
    }
    let back = await this.model('person_apply').where(where).page(data.page, data.limit).order('createTime DESC').countSelect();
    back.data.forEach(function(item) {
      item.jsonData = typeof JSON.parse(item.jsonData) === 'object' ? JSON.parse(item.jsonData) : {}
    });
    return this.success(back);
  }

  // 人员库执行修改、合并、删除
  async applyDoneAction(){
    const data = this.post();
    let apply = await this.model('person_apply').where({"id":data.id}).find()
    if (think.isEmpty(apply) || apply.state !== 0){
      return this.fail("未找到该申请或者该申请已执行")
    } else {
      if (data.state === 1) { // 通过审批
        if (apply.type === 1){
          // type 1修改
          let update = JSON.parse(apply.jsonData);
          await this.model('person').setRelation(false).where({'id':apply.personID}).update(update);
        }else if (apply.type === 2){
          // type 2合并，修改person_activity、activity，删除多余包括family
          let update = JSON.parse(apply.jsonData);
          await this.model('person').setRelation(false).where({'id':apply.personID}).update(update);
          let pa = await this.model('person_activity').where({'personID':apply.other_person}).select();
          if (!think.isEmpty(pa)){
            let paID = [];
            let aID = [];
            pa.forEach(function(item) {
              paID.push({
                'id':item.id,
                'personID':apply.personID
              });
              aID.push(item.activityID);
            });
            // 更新 person_activity 变相删除 otherPersonID
            await this.model('person_activity').updateMany(paID);
            let activity = await this.model('activity').setRelation(false).where({'id':['IN',aID]}).select();
            for (let a of activity) {
              let list = a.personID.split(",").map(Number);
              list.splice(list.indexOf(parseInt(apply.other_person)),1);// 删除原数组中other_person
              let up = {
                "id":a.id,
                "personID":list
              };
              if (a.mainPerson === apply.other_person){
                up['mainPerson'] = apply.personID;
              }
            }
            await this.model('activity').setRelation(false).updateMany(up);// 更新activity
            await this.model('family').where({'personID':apply.other_person}).update({'personID':apply.personID});//更新家庭关系
          }
        }else if (apply.type === 3){
          // type 3验证是否可删，删除
          let pa = await this.model('person_activity').where({'personID':apply.other_person}).select();
          if (!think.isEmpty(pa)){
            return this.fail("该人员有关联活动，不可删除，建议合并！")
          }else {
            // 删除人员
            await this.model('person').setRelation(false).where({"id":apply.personID}).delete()
          }
        }
      }
      // 修改 person_apply
      let applyUp = {
        'state':data.state,
        'remark':data.remark,
        'applyUserId':data.userId,
        'applyTime':moment().format('YYYY-MM-DD HH:mm:ss')
      };
      await this.model('person_apply').where({"id":data.id}).update(applyUp);
      return this.success();
    }
  }
  async findPersonNameAction(){
    const data = this.post();
    let person = await this.model('person').setRelation(false).where({'name': ['like', '%' + data.name + '%'],'id':['!=',data.personID]})
      .page(data.page, data.limit).countSelect();
    for (let p of person.data){
      let matter = await this.model('matter').alias('m').join('person_activity as pa on pa.activityID = m.activityID')
        .where({'pa.personID':p.id}).select();
      p['matter'] = matter
    }
    return this.success(person);
  }

};
