const Base = require('./base.js');
const util = require('../handle/util.js')
module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  /**
   * showdoc
   * @catalog 系统管理/审核
   * @title 审核列表
   * @description 审核列表接口
   * @method get
   * @url http://127.0.0.1:8360/review/getReviewList
   * @return {"errno": 0, "errmsg":"", "data":[{"dictName":1,"dictID":1,"dictValue":10,"description":1,"shortDesc":"admin","parentValue":1,"isExistchild":0,"descSpell":"jash"}]}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param dictName  string 字典名称
   * @return_param dictID  string 字典类型
   * @return_param dictValue  string 字典值
   * @return_param description string 描述
   * @return_param shortDesc string 简述
   * @return_param parentValue string 父值
   * @return_param isExistchild int 是否存在下一级 0不存在，1存在
   * @return_param descSpell string 简拼
   */
  async getReviewListAction() {
    const param = this.get();
    let master = this.model('matter');
    let whereParam = {}
    if (param.status) {
      if (param.status == 1){
        whereParam.status = 1
        
      } else {
        whereParam.status = ['!=',1]
      }
    }
    let data = await master.where(whereParam).order(['createTime desc']).page(param.page,param.pageSize).countSelect().catch((err) => {
      console.log(err)
      return think.isError(err) ? err : new Error(err);  
    });
    if (think.isError(data)) {
      return this.fail(5001, 'Get reviewList failed');
    }
    return this.success(data)
  }

  async getReviewQeuryAction() {
    const param = this.get();
    let master = this.model('matter');
    let sql_param = {};
    if (param.keyword) {
      sql_param['m.contentClassify']=param.keyword
    }
    if (param.registerType) {
      sql_param['ac.registerType'] = param.registerType
    }
    if(param.status == 0) {
      sql_param['m.status'] =0;
    } else {
      sql_param['m.status']=['!=' ,0];
    }
    let data = await master.alias('m').join({table:'active',join:'left',as:'ac',on:['id','matter_id']}).where(sql_param).order(['createTime desc','isMain desc']).page(param.page,param.pageSize).countSelect().catch((err) => {
      return think.isError(err) ? err : new Error(err);  
    });
    if (think.isError(data)) {
      return this.fail(5002, 'Get review query fail');
    }
    return this.success(data);
  }

  async testAction() {
    // const param = {description:"安徽省", regionAdminNo:"340000"};
    // const res = await util.getNamespaceByNameRules(25,"001001001003");
    const res = await this.model('matter').field('contentClassifyID').where({id: ['in','3,6']}).select();
    console.log(res)

  }
};
