const Base = require('./../base.js');
//高级查询接口
module.exports = class extends Base {
  indexAction() {
    return this.display();
  }

  /**
   * showdoc
   * @catalog 高级查询的参数列表
   * @title 高级查询的参数列表
   * @description 高级查询的参数列表
   * @method post
   * @url http://127.0.0.1:8360/search/advance/paramlist
   * @return {"errno": 0, "errmsg":""}
   */
  async paramlistAction() {
    // const data = this.post();
    const back = await this.model('searchcondition').where('valid = 1').select();// 时间倒序
    const matter = [];
    const person = [];
    const activity = [];
    for (let count = 0; count < back.length; count++) {
      switch (back[count].tableName) {
        case 'matter':
          matter.push(back[count]);
          break;
        case 'person':
          person.push(back[count]);
          break;
        case 'activity':
          activity.push(back[count]);
          break;
      }
    }
    this.success({
      matter: matter,
      person: person,
      activity: activity
    });
  }

  /**
   * showdoc
   * @catalog 获取字典表接口
   * @title 获取字典表接口
   * @description 获取字典表接口
   * @method post
   * @param fieldstr 必选 string 举例：activity.isleapfrog,person.sexID,matter.contentClassifyID(内容分类，多层)
   * @url http://127.0.0.1:8360/search/advance/getDict
   * @return {"errno": 0, "errmsg":""}
   */
  async getDictAction() {
    const data = this.post();
    data.fieldstr = data.fieldstr === undefined ? '' : data.fieldstr;
    const back = await this.model('searchcondition').where('valid = 1 and concat(tableName,".",columnName) ="' + data.fieldstr + '"').select();// 时间倒序
    if (back.length !== 1) {
      this.fail();
    } else {
      const singleData = back[0];
      // console.log(singleData);
      if (singleData.hasDict !== 1 && singleData.hasDict !== 2) {
        this.fail();
      } else {
        switch (singleData.hasDict) {
          case 2:
            singleData.customDict = JSON.parse(singleData.customDict);
            for (let count = 0; count < singleData.customDict.length; count++) {
              singleData.customDict[count].value = singleData.customDict[count].k;
              singleData.customDict[count].label = singleData.customDict[count].v;
            }
            this.success(singleData.customDict);
            break;
          case 1:
            const back = await this.model(singleData.dictTable)
              .field(singleData.dictK + ' value,' + singleData.dictV + ' label,' + 'parentValue,dictValue')
              .where(singleData.dictWhere).order('IFNULL(orderNum, 9999) ASC').select();
            let tree = [];
            let data = {};
            for (const i in back) {
              const dataKey = back[i]['dictValue'];
              data[dataKey] = back[i];
              back[i].value = back[i].dictValue;
            }
            for (const j in back) {
              const bval = back[j];
              const dataP = data[bval['parentValue']];
              if (dataP) {
                if (!dataP.children) {
                  dataP.children = [];
                }
                dataP.children.push(bval);
              } else {
                tree.push(bval);
              }
            }
            this.success(tree);
            break;
        }
      }
    }
  }

  /**
   * showdoc
   * @catalog 高级查询的结果列表
   * @title 高级查询的结果列表
   * @description 高级查询的结果列表
   * @method post
   * @param userid 必选 string 登录人userid
   * @param page 必选 int 第几页
   * @param limit 必选 int 每页条数
   * @param params 必选 数组 查询条件，举例：[{fieldstr:'person.educationID',operator:'='，value:'12'}]
   * @param fields 必选 数组 表头，举例：['matter.contentClassifyID','matter.finalDisposalID']
   * @param export 可选 布尔值 默认false，true的话为导出
   * @url http://127.0.0.1:8360/search/advance/resultlist
   * @return {"errno": 0, "errmsg":""}
   */
  async resultlistAction() {
    // const data = this.post();
    // 1.获取人员信息，普通人员只能看经他处理的事件，领导能看经他单位处理的事件
    // 2.解析搜索条件
    // 3.进行搜索 返回数据
    const data = this.post();
    data.page = data.page === undefined ? 1 : data.page;
    data.limit = data.limit === undefined ? 10 : data.limit;
    data.params = data.params === undefined ? [] : data.params;
    data.fields = data.fields === undefined ? [] : data.fields;
    data.export = data.export === undefined ? false : data.export;
    if (data.export === true) {
      data.page = 1;
      data.limit = 10000000000;
    }
    const userInfo = await this.getUserInfo(data.userid || '');
    if (think.isEmpty(userInfo.user_name)) {
      return this.fail(1000, '查无此用户');
    }
    //登录名 用于matter表
    // console.log(userInfo.user_name);
    // 领导是1 其他为普通办事人员
    // console.log(userInfo.isLead);
    // console.log(userInfo.orgID);
    // console.log(userInfo.user_id);

    //首要条件 未进入流程，仅创建人可看
    let previlegeWhere = ' 1=1 and taskid is not null ';

    // if (userInfo.isLead === 1) {
    //   //该人为单位领导
    //   previlegeWhere = '((taskid is null and createAccount in (select user_name from sys_user where orgID = ' + userInfo.orgID + ')) or (taskid in (select c_task from fw_task_act where deptID_now = ' + userInfo.orgID + ')))';
    // } else {
    //   //该人为单位领导普通办事人员
    //   previlegeWhere = '((taskid is null and createAccount = "' + userInfo.user_name + '") or (taskid in (select c_task from fw_task_act where charger = "' + userInfo.user_id + '")))';
    // }
    let activityWhere = '';
    let matterWhere = '';
    let personWhere = '';
    for (let count = 0; count < data.params.length; count++) {
      const where = data.params[count];
      let extraWhere = '';
      // console.log(where);
      switch (where.operator) {
        case '=':
          extraWhere = ' and ' + where.fieldstr + where.operator + ' ' + '"' + where.value + '"';
          break;
        case '!=':
          extraWhere = ' and ' + where.fieldstr + where.operator + ' ' + '"' + where.value + '"';
          break;
        case 'like':
          extraWhere = ' and ' + where.fieldstr + ' ' + where.operator + ' ' + '"%' + where.value + '%"';
          break;
        case 'between':
          extraWhere = ' and ' + where.fieldstr + ' ' + where.operator + ' ' + '"' + where.value[0] + '" and "' + where.value[1] + '"';
          break;

      }

      switch (where.fieldstr.split('.')[0]) {
        case 'person':
          personWhere += extraWhere;
          break;
        case 'matter':
          matterWhere += extraWhere;
          break;
        case 'activity':
          activityWhere += extraWhere;
          break;
      }
      // console.log(extraWhere);
    }
    activityWhere = 'and activityID in (select id from activity where 1=1 ' + activityWhere + ')';
    personWhere = ' and activityID in (select activityID from person_activity where personID in (select id from person where 1=1 ' + personWhere + '))';

    let matterFields = [];
    let activityFields = [];
    for (let count = 0; count < data.fields.length; count++) {
      let field = data.fields[count];
      switch (field.split('.')[0]) {
        case 'matter':
          matterFields.push(field);
          if (field.endsWith('ID')) {
            // field = field.substr(field, field.length - 2) + ' ' + field.split('.')[1];
            matterFields.push(field.substr(field, field.length - 2));
          }
          break;
        case 'person':
          break;
        case 'activity':
          activityFields.push(field);
          if (field.endsWith('ID')) {
            // field = field.substr(field, field.length - 2) + ' ' + field.split('.')[1];
            activityFields.push(field.substr(field, field.length - 2));
          }
          break;
      }
    }
    // 自定义表头
    matterFields.push('id');
    matterFields.push('activityid');
    matterFields.push('taskid');
    activityFields.push('id actid');
    // activityFields.push('id');
    // data.fields.push('activity');

    const fields = matterFields.join(',');
    // 查询matter表
    const back = await this.model('matter').field(fields).setRelation(true).where(previlegeWhere + matterWhere + activityWhere + personWhere).page(data.page, data.limit).order('createTime DESC').countSelect();// 时间倒序

    if (back.length > 0) {
      // 自定义表头
      const activityQueryFields = activityFields.join(',');
      let activityid = [];
      for (let count = 0; count < back.data.length; count++) {
        activityid.push('"' + back.data[count].activityid + '"');
      }
      const activityids = activityid.join(',');
      const activityback = await this.model('activity').field(activityQueryFields).where('id in (' + activityids + ')').select();
      for (let count = 0; count < back.data.length; count++) {
        for (let count1 = 0; count1 < activityback.length; count1++) {
          if (back.data[count].activityid === activityback[count1].actid) {
            back.data[count] = Object.assign(back.data[count], activityback[count1]);
            break;
          }
        }
      }
      this.success(back);
    } else {
      this.success(back);
    }
  }

  /**
   * showdoc
   * @catalog 高级查询条件保存或更新
   * @title 高级查询条件保存或更新
   * @description 高级查询条件保存或更新
   * @method post
   * @param userid 必选 string 登录人userid
   * @param title 必选 string 查询条件名称
   * @param type 必选 int 条件类型 1 个人自定义查询 2 部门自定义查询
   * @param params 必选 数组 查询条件，举例：[{fieldstr:'person.educationID',operator:'='，value:'12'}]
   * @param fields 必选 数组 表头，举例：['matter.contentClassifyID','matter.finalDisposalID']
   * @url http://127.0.0.1:8360/search/advance/conditionSave
   * @return {"errno": 0, "errmsg":"",    "data": {"id": 1183}}
   */
  async conditionSaveAction() {
    let data = this.post();

    console.log(data);
    if (think.isEmpty(data.id)) {
      const userInfo = await this.getUserInfo(data.userid || '');
      data.orgID = userInfo.orgID === undefined ? 0 : userInfo.orgID;
      data.orgName = userInfo.orgName === undefined ? 0 : userInfo.orgName;
      data.creatorID = data.userid;
      data.creatorName = userInfo.name === undefined ? 0 : userInfo.name;
      data.params = JSON.stringify(data.params);
      data.fields = JSON.stringify(data.fields);
      //保存
      const res = await this.model('searchconditioncustomize').add(data);
      if (res) {
        this.success({id: res});
      } else {
        this.fail();
      }
    } else {
      data.params = JSON.stringify(data.params);
      data.fields = JSON.stringify(data.fields);
      //更新
      let res = await this.model('searchconditioncustomize').update(data);
      if (res) {
        this.success();
      } else {
        this.fail();
      }
    }
  }

  /**
   * showdoc
   * @catalog 高级查询的结果列表
   * @title 高级查询的结果列表
   * @description 高级查询的结果列表
   * @method post
   * @param id 必选 int 条件ID
   * @url http://127.0.0.1:8360/search/advance/conditionDel
   * @return {"errno": 0, "errmsg":""}
   */
  async conditionDelAction() {
    const post = this.post();
    const id = post.id;
    const affectedRows = await this.model('searchconditioncustomize').where({id: id}).update({del: 1});
    if (affectedRows === 0) {
      this.fail();
    } else {
      this.success();
    }
  }

  /**
   * showdoc
   * @catalog 高级查询的结果列表
   * @title 高级查询的结果列表
   * @description 高级查询的结果列表
   * @method post
   * @param userid 必选 string 登录人userid
   * @url http://127.0.0.1:8360/search/advance/conditionList
   * @return {"errno": 0, "errmsg":""}
   */
  async conditionListAction() {
    let data = this.post();
    data.type = data.type === undefined ? 0 : data.type;
    const userInfo = await this.getUserInfo(data.userid || '');
    data.orgID = userInfo.orgID === undefined ? 0 : userInfo.orgID;
    const where = 'del = 0 and (( type = 2 and orgID = "' + userInfo.orgID + '") or ( type = 1 and creatorID = "' + data.userid + '"))';

    const label = this.model('searchconditioncustomize'); // controller 里实例化模型
    const back = await label.field('id,title,updatetime').where(where).order('updatetime DESC').select();

    this.success(back);
  }

  /**
   * showdoc
   * @catalog 高级查询的某条查询条件的详情
   * @title 高级查询的某条查询条件的详情
   * @description 高级查询的某条查询条件的详情
   * @method post
   * @param id 必选 id
   * @param userid 必选 string 登录人userid
   * @url http://127.0.0.1:8360/search/advance/conditionDetail
   * @return {"errno": 0, "errmsg":""}
   */
  async conditionDetailAction() {
    let data = this.post();
    data.type = data.type === undefined ? 0 : data.type;
    const userInfo = await this.getUserInfo(data.userid || '');
    data.orgID = userInfo.orgID === undefined ? 0 : userInfo.orgID;
    const where = 'del = 0 and (( type = 2 and orgID = "' + userInfo.orgID + '") or ( type = 1 and creatorID = "' + data.userid + '")) and id = ' + data.id;

    const label = this.model('searchconditioncustomize'); // controller 里实例化模型
    const back = await label.field('id,title,updatetime,params,fields').where(where).order('updatetime DESC').select();
    if (back.length === 1) {
      back[0].params = JSON.parse(back[0].params);
      back[0].fields = JSON.parse(back[0].fields);
      this.success(back[0]);
    } else {
      this.fail();
    }

  }
};
