const Base = require('./../base.js');
//常用查询接口
const moment = require('moment');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  // 重复信访查询 建立在matter_relation绑定同源同诉的前提下
  async repeatAction(){
    const data = this.post();
    let where = {
      'm.taskid':['!=',null],
    };
    // let mrListNew = [...new Set(mrList)];// 去重

    // 时间区间
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      where["m.createTime"] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      where["m.CreateTime"] = ['<',moment(data.endTime).add(1,'day').format('YYYY-MM-DD')];
    }
    // 信访形式
    if (data.hasOwnProperty('registerTypeID') && Array.isArray(data.registerTypeID) && data.registerTypeID.length > 0){
      where["a.registerTypeID"] = ['IN',data.registerTypeID];
    }
    // 登记单位
    if (data.hasOwnProperty('orgID') && Array.isArray(data.orgID) && data.orgID.length > 0){
      where["m.createOrgID"] = ['IN',data.orgID];
    }
    // 最少重复次数
    if (data.hasOwnProperty('minNum') && data.minNum !== ''){
      let repeat = await this.model('matter_repeat').where({'count':['>=',parseInt(data.minNum)]}).select();
      let mID = [];
      repeat.forEach(function(item) {
        mID.push(...item.matter_list.split(","));
      });
      if (mID.length === 0){
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      } else {
        where['m.id'] = ['IN',mID];
      }
    }
    // 信访人姓名
    if (data.hasOwnProperty('name') && data.name !== ''){
      let person = await this.model('person').alias('p').setRelation(false).join('person_activity as pa on pa.personID = p.id')
        .where({'p.name':['LIKE','%' + data.name + '%']}).field("p.*,pa.activityID").select();
      if (think.isEmpty(person)){
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      } else {
        let acID = [];
        person.forEach(function(item) {
          acID.push(item.activityID);
        });
        if (acID.length > 0){
          where['a.id'] = ['IN',acID];
        }
      }
    }
    if (Object.keys(where).length === 1){
      // 没有选择好查询条件，直接查matter_repeat
      let matterRepeat = await this.model('matter_repeat').order('time Desc').page(data.page, data.pageSize).countSelect();
      matterRepeat.data.forEach(function(item) {
        item.matter_list = item.matter_list.split(",");
      });
      return this.success(matterRepeat);
    }
    let matter = await this.model('matter').alias('m').join('activity as a on a.id = m.activityID')
      .where(where).order('m.createTime Desc').field('m.*').select();
    let repeatList = []; //未去重的复合条件的matter_relation结果集
    for (let m of matter) {
      // 在所有符合条件的事项中，查找重复事项
      let find_sql = 'select * from matter_repeat where find_in_set("'+ m.id +'",matter_list)';
      let list = await this.model().query(find_sql);// count 数字不准
      repeatList.push(...list)
    }
    // repeatList 去重
    repeatList = JSON.parse(JSON.stringify(repeatList));
    function unique(arr) {
      var array = [];
      for(let i=0; i<arr.length; i++){
        let aStr = JSON.stringify(array)
        if(aStr.indexOf(JSON.stringify(arr[i])) === -1){
          array.push(arr[i])
        }
      }
      return array
    }
    let newList = unique(repeatList);    // 去重结束
    let count = newList.length; //查询结果总数
    // 如果分页，对newList处理
    if (data.hasOwnProperty('page') && data.hasOwnProperty('pageSize')){
      let page = parseInt(data.page);
      let pageSize = parseInt(data.pageSize);
      newList = newList.slice( (page-1) * pageSize, page * pageSize-1);
    }
    for (let nl of newList){
      // set一个matterID集合
      nl['matterList'] = [];
      for (let m of matter) {
        if (nl.matter_list.indexOf(m.id) >=  0){
          nl.matterList.push(m.id);
        }
      }
      // 给原数据的matter_list重新赋值
      nl.matter_list = nl.matterList// 方便前端取值
    }
    return this.success({
      "count": count,
      "totalPages": data.hasOwnProperty('pageSize') ? Math.ceil(count / parseInt(data.pageSize) ) : 1,
      "pageSize": data.hasOwnProperty('pageSize') ? data.pageSize : count,
      "currentPage": data.hasOwnProperty('page') ? data.page : 1,
      "data": newList
    });
  }
  // 具体重复事项
  async repeatFindAction() {
    const data = this.post();
    if (!data.hasOwnProperty('matterList') || !Array.isArray(data.matterList) || data.matterList.length === 0) {
      return this.fail('事项字段缺失')
    }
    let matter = await this.model('matter').where({'id':['IN',data.matterList]}).select();
    return this.success(matter);
  }
  // 重复访表头选择
  async repeatHeadAction(){
    let back = {
      "activity":a,
      "matter":m,
      "person":p
    }
    return this.success(back)
  }
  // 信访人所有信访事项
  async personAllAction(){
    let data = this.post();
    let where = {
      'a.submit':1
    };
    // 时间区间
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      where["a.createTime"] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      where["a.CreateTime"] = ['<',moment(data.endTime).add(1,'day').format('YYYY-MM-DD')];
    }
    // 信访形式
    if (data.hasOwnProperty('registerTypeID') && Array.isArray(data.registerTypeID) && data.registerTypeID.length > 0){
      where["a.registerTypeID"] = ['IN',data.registerTypeID];
    }
    // 登记单位
    if (data.hasOwnProperty('orgID') && Array.isArray(data.orgID) && data.orgID.length > 0){
      where["a.createOrgID"] = ['IN',data.orgID];
    }
    // 最少信访次数
    if (data.hasOwnProperty('minNum') && data.minNum !== ''){
      let sql = "SELECT personID,COUNT(*) AS a FROM person_activity GROUP BY personID HAVING a >= "+ parseInt(data.minNum);
      let num = await this.model().query(sql);
      if (think.isEmpty(num)) {
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }else {
        let acID = [];
        let pID = [];
        num.forEach(function(item) {
          pID.push(item.personID);
        });
        let p = await this.model('person_activity').setRelation(false).where({'personID':['IN',pID]}).select();
        p.forEach(function(items) {
          acID.push(items.activityID)
        });
        if (acID.length > 0){
          where['a.id'] = ['IN',acID];
        }
      }
    }
    // 信访人姓名
    if (data.hasOwnProperty('name') && data.name !== ''){
      let person = await this.model('person').alias('p').setRelation(false).join('person_activity as pa on pa.personID = p.id')
        .where({'p.name':['LIKE','%' + data.name + '%']}).field("p.*,pa.activityID").select();
      if (think.isEmpty(person)){
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      } else {
        let acID = [];
        person.forEach(function(item) {
          acID.push(item.activityID);
        });
        if (acID.length > 0){
          if (where.hasOwnProperty('a.id')){
            // 条件为与，应当为重复的a.id
            let c = [];
            let a = where['a.id'][1]
            acID.forEach(function(items) {
              if (a.indexOf(items) !== -1){
                c.push(items)
              }
            });
            where['a.id'][1] = c;
          } else {
            where['a.id'] = ['IN',acID];
          }
        }
      }
    }
    // let matter = await this.model('matter').alias('m').join('activity as a on a.id = m.activityID')
    //   .where(where).order('m.createTime Desc').field('m.*').page(data.page, data.pageSize).countSelect();
    let activity = await this.model('activity').alias('a').where(where).order('a.createTime Desc').page(data.page, data.pageSize).countSelect();
    return this.success(activity);
  }
  // 信访人所有信访事项表头选择
  async personAllHeadAction(){
    let back = {
      "activity":a,
      "matter":m,
      "person":p
    }
    return this.success(back)
  }
  // 领导代表查询
  async leaderAction(){
    let data = this.post();
    let where = {
      'm.taskid':['!=',null],
      // 'a.xfSourceID':['IN',['001002001','001002002','001003','002002001','002002002','002003','001004','002006']]
    };
    if (data.hasOwnProperty('type') && data.type !== ''){
      if (parseInt(data.type) === 1) { // 领导
        where["a.xfSourceID"] = ['IN',['001002001','001002002','002002001','002002002']]
      }
      if (parseInt(data.type) === 2) { // 代表
        where["a.xfSourceID"] = ['IN',['001003','002003','001004','002006']]
      }
      if (parseInt(data.type) === 3) { // 兼任
        where["a.dual_identity"] = ['!=',""];
        where["a.Dual_identity"] = ['!=',null];
      }
    }else {
      where["a.xfSourceID"] = ['IN',['001002001','001002002','001003','002002001','002002002','002003','001004','002006']]
    }
    // 时间区间
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      where["m.createTime"] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      where["m.CreateTime"] = ['<',moment(data.endTime).add(1,'day').format('YYYY-MM-DD')];
    }
    // 信访形式
    if (data.hasOwnProperty('xfSourceID') && Array.isArray(data.xfSourceID) && data.xfSourceID.length > 0){
      where["a.xfSourceID"] = ['IN',data.xfSourceID];
    }
    // 登记单位
    if (data.hasOwnProperty('orgID') && Array.isArray(data.orgID) && data.orgID.length > 0){
      where["m.createOrgID"] = ['IN',data.orgID];
    }
    // 领导代表相关
    if ((data.hasOwnProperty('name') && data.name !== '') || (data.hasOwnProperty('grade') && data.grade !== '') ||
      (data.hasOwnProperty('due') && data.due !== '') || (data.hasOwnProperty('zoneID') && data.zoneID !== '')){
      let whereL = {};
      // 领导代表姓名
      if (data.hasOwnProperty('name') && data.name !== '') {
        whereL['d.name'] = ['LIKE','%' + data.name + '%']
      }
      // 代表 层级
      if (data.hasOwnProperty('grade') && data.grade !== '') {
        whereL['d.grade'] = ['LIKE','%' + data.grade + '%']
      }
      // 代表 届次
      if (data.hasOwnProperty('due') && data.due !== '') {
        whereL['d.due'] = ['LIKE','%' + data.due + '%']
      }
      // 代表 地区
      if (data.hasOwnProperty('zoneID') && data.zoneID !== '') {
        whereL['d.zoneID'] = data.zoneID
      }
      if (Object.keys(whereL).length !== 0) {
        let leader = await this.model('delegate_leading').alias('d').join('activity_leading as al on al.leadingID = d.id').where(whereL).select();
        if (think.isEmpty(leader)){
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        } else {
          let aID = [];
          leader.forEach(function(item) {
            aID.push(item.activityID);
          });
          if (aID.length > 0){
            where['a.id'] = ['IN',aID]
          }
        }
      }
    }
    let activity = await this.model('activity').alias('a').join('matter as m on a.id = m.activityID').where(where)
      .order('a.createTime Desc').field('a.*').distinct('a.*').page(data.page, data.pageSize).countSelect();
    for (let item of activity.data) {
      let matter = await this.model('matter').setRelation(false).where({"activityID":item.id}).select();
      item['matter'] = matter;
    }
    return this.success(activity);

  }

  // 领导代表 表头选择
  async leaderHeadAction(){
    let back = {
      "activity":a,
      "matter":m,
      "person":p
    };
    return this.success(back)
  }

  // 集体访 联名反映查询
  async collectiveAction(){
    const data = this.post();
    let where = {
      'm.taskid':['!=',null],
    };
    // 时间区间
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      where["m.createTime"] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      where["m.CreateTime"] = ['<',moment(data.endTime).add(1,'day').format('YYYY-MM-DD')];
    }
    // 信访性质 FZ 只有联名信002002 集体访001002
    if (data.hasOwnProperty('xfTypeID') && data.xfTypeID !== ""){
      where["a.xfTypeID"] = ['IN',data.xfTypeID];
    }else {
      where["a.xfTypeID"] = ['IN',["001002","002002"]];//信访性质没有选的话，默认联名信和集体访
    }
    // 登记单位
    if (data.hasOwnProperty('orgID') && Array.isArray(data.orgID) && data.orgID.length > 0){
      where["m.createOrgID"] = ['IN',data.orgID];
    }
    // 最小来访人数 至少大于等于5
    if (data.hasOwnProperty('xfNumber') && data.xfNumber >= 5){
      where["a.xfNumber"] = ['>=',data.xfNumber];
    }
    // 诉求主体名称
    if (data.hasOwnProperty('objectName') && data.objectName !== ''){
      // where["pa.objectName"] = ['>=',data.objectName];
      let ac = await this.model('person_activity').where({'objectName':['LIKE','%' + data.objectName + '%']}).distinct('activityID').select();
      if (think.isEmpty(person)){
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      } else {
        let acID = [];
        ac.forEach(function(item) {
          acID.push(item.activityID);
        });
        if (acID.length > 0){
          where['a.id'] = ['IN',acID];
        }
      }
    }
    // 问题属地
    if (data.hasOwnProperty('happenRegionID') && Array.isArray(data.happenRegionID) && data.happenRegionID.length > 0){
      where["m.happenRegionID"] = ['IN',data.happenRegionID];
    }
    // 所属系统
    if (data.hasOwnProperty('belongsID') && Array.isArray(data.belongsID) && data.belongsID.length > 0){
      where["m.belongsID"] = ['IN',data.belongsID];
    }
    let activity = await this.model('activity').alias('a').join('matter as m on a.id = m.activityID')
      .where(where).order('a.createTime Desc').field('a.*').distinct('a.*').page(data.page, data.pageSize).countSelect();
    for (let item of activity.data) {
      let matter = await this.model('matter').setRelation(false).where({"activityID":item.id}).select();
      item['matter'] = matter;
    }
    return this.success(activity)
  }
  // 集体访联名 表头选择
  async collectiveHeadAction(){
    let back = {
      "activity":a,
      "matter":m,
      "person":p
    };
    return this.success(back)
  }
  // 被控检人查询查询
  async identityAction(){
    const data = this.post();
    let where = {
      'm.taskid':['!=',null]
    };
    // 时间区间
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      where["m.createTime"] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      where["m.CreateTime"] = ['<',moment(data.endTime).add(1,'day').format('YYYY-MM-DD')];
    }
    // 登记单位
    if (data.hasOwnProperty('orgID') && Array.isArray(data.orgID) && data.orgID.length > 0){
      where["m.createOrgID"] = ['IN',data.orgID];
    }
    // 信访形式
    if (data.hasOwnProperty('registerTypeID') && Array.isArray(data.registerTypeID) && data.registerTypeID.length > 0){
      where["a.registerTypeID"] = ['IN',data.registerTypeID];
    }
    // identityName 被控检人姓名 这个参数在 m.identityName和m.abstract摘要中查询 or
    if (data.hasOwnProperty('identityName') && data.identityName !== ""){
      where["_complex"] = {
          "m.identityName":['LIKE','%' + data.identityName + '%'],
        "m.abstract":['LIKE','%' + data.identityName + '%'],
        "_logic":"OR"
      };
    }
    let matter = await this.model('matter').alias('m').join('activity as a on a.id = m.activityID')
      .where(where).order('m.createTime Desc').field('m.*').page(data.page, data.pageSize).countSelect();
    return this.success(matter)
  }
  // 被控检人自定义表头
  async identityHeadAction(){
    let back = {
      "activity":a,
      "matter":m,
      "person":p
    };
    return this.success(back)
  }
  // 三跨三分离查询
  async sksflAction(){
    const data = this.post();
    let sql = "select *,a.id as aid,m.id as id from matter as m LEFT JOIN activity as a on m.activityID = a.id where m.taskid is not null and m.isSKSFL = 1"
    // 时间区间
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      let start = " and m.createTime > '" + moment(data.startTime).format('YYYY-MM-DD') +"'";
      sql += start;
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      let end = " and m.createTime < '" + moment(data.endTime).add(1,'day').format('YYYY-MM-DD') +"'";
      sql += end;
    }
    // 登记单位
    if (data.hasOwnProperty('orgID') && Array.isArray(data.orgID) && data.orgID.length > 0){
      let org = " and m.createOrgID in (" +data.orgID+")";
      sql += org;
    }
    // 信访形式
    if (data.hasOwnProperty('registerTypeID') && Array.isArray(data.registerTypeID) && data.registerTypeID.length > 0){
      let xfSource = " and a.registerTypeID in (" +data.registerTypeID+")";
      sql += xfSource;
    }
    // 三跨三分离情况 or
    if (data.hasOwnProperty('SKSFL') && Array.isArray(data.SKSFL) && data.SKSFL.length > 0){
      // 这里多选应该是 or 包含其中之一就是命中
      let str  = "";
      for (let i = 0; i < data.SKSFL.length; i++) {
        if (i === 0) {
          str = " and (FIND_IN_SET(" + data.SKSFL[i] + ",SKSFL)"
        }else {
          str += " or FIND_IN_SET(" + data.SKSFL[i] + ",SKSFL)"
        }
        // 最后补上这个括号
        if (i+1 === data.SKSFL.length) {
          str += ")"
        }
      }
      sql += str;
    }
    // 排序
    sql += " ORDER BY m.createTime Desc";

    // 总数
    let count = await this.model('matter').query(sql);
    // 分页
    if (data.hasOwnProperty('page') && data.page !== '' && data.hasOwnProperty('pageSize') && data.pageSize !== '') {
      sql += " LIMIT " + (data.page - 1) + "," + data.pageSize;
    }else {
      sql += " LIMIT 0,10";
    }
    let matter = await this.model('matter').query(sql);
    for (let item of matter) {
      let activity = await this.model('activity').where({'id':item.activityID}).find();
      item["activity"] = activity;
    }
    return this.success({
      "count": count.length,
      "totalPages": (data.hasOwnProperty('pageSize') && data.pageSize !== '') ? Math.ceil(count.length/data.pageSize) : Math.ceil(count.length/10),
      "pageSize": (data.hasOwnProperty('pageSize') && data.pageSize !== '') ? data.pageSize : 10,
      "currentPage": (data.hasOwnProperty('page') && data.page !== '') ? data.page : 1,// 当前页
      "data": matter
    })

  }
  // 三跨三分离 自定义表头
  async sksflHeadAction(){
    let back = {
      "activity":a,
      "matter":m,
      "person":p
    };
    return this.success(back)
  }

  // 异常查询 以活动为主
  async abnormalAction(){
    const data = this.post();
    let sql = "select * from activity where submit = 1 and isAbnormal = 1"
    // 时间区间
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      let start = " and createTime > '" + moment(data.startTime).format('YYYY-MM-DD') +"'";
      sql += start;
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      let end = " and createTime < '" + moment(data.endTime).add(1,'day').format('YYYY-MM-DD') +"'";
      sql += end;
    }
    // 登记单位
    if (data.hasOwnProperty('orgID') && Array.isArray(data.orgID) && data.orgID.length > 0){
      let org = " and createOrgID in (" +data.orgID+")";
      sql += org;
    }
    // 信访形式
    if (data.hasOwnProperty('registerTypeID') && Array.isArray(data.registerTypeID) && data.registerTypeID.length > 0){
      let registerTypeID = " and registerTypeID in (" +data.registerTypeID+")";
      sql += registerTypeID;
    }
    // 异常情况 or
    if (data.hasOwnProperty('abnormalID') && Array.isArray(data.abnormalID) && data.abnormalID.length > 0){
      // 这里多选应该是 or 包含其中之一就是命中
      let str  = "";
      for (let i = 0; i < data.abnormalID.length; i++) {
        if (i === 0) {
          str = " and (FIND_IN_SET(" + data.abnormalID[i] + ",abnormalID)"
        }else {
          str += " or FIND_IN_SET(" + data.abnormalID[i] + ",abnormalID)"
        }
        // 最后补上这个括号
        if (i+1 === data.abnormalID.length) {
          str += ")"
        }
      }
      sql += str;
    }
    // 排序
    sql += " ORDER BY createTime Desc";

    // 总数
    let count = await this.model('activity').query(sql);
    // 分页
    if (data.hasOwnProperty('page') && data.page !== '' && data.hasOwnProperty('pageSize') && data.pageSize !== '') {
      sql += " LIMIT " + (data.page - 1) + "," + data.pageSize;
    }else {
      sql += " LIMIT 0,10";
    }
    let activity = await this.model('activity').query(sql);
    for (let item of activity) {
      let matter = await this.model('matter').setRelation(false).where({'activityID':item.id}).select();
      item["matter"] = matter;
      // 所有信访人
      let personList = await this.model('person').setRelation(false).where({"id":['IN',item.mainPerson]}).select();
      item["personList"] = personList;
      // 找到主信访人
      for (let p of personList){
        if (p.id === parseInt(item.personID)){
          item['person'] = p;
          break;
        }
      }
    }
    return this.success({
      "count": count.length,
      "totalPages": (data.hasOwnProperty('pageSize') && data.pageSize !== '') ? Math.ceil(count.length/data.pageSize) : Math.ceil(count.length/10),
      "pageSize": (data.hasOwnProperty('pageSize') && data.pageSize !== '') ? data.pageSize : 10,
      "currentPage": (data.hasOwnProperty('page') && data.page !== '') ? data.page : 1,// 当前页
      "data": activity
    })
  }
  // 异常查询 自定义表头
  async abnormalHeadAction(){
    let back = {
      "activity":a,
      "matter":m,
      "person":p
    };
    return this.success(back)
  }
  // 函件查询并下载函件
  async letterAction(){
    const data = this.post();
    let where = {
      "n.businessID":4,// 加入这个条件后，就不查询老数据了
      "h.handleModelID": '002003001'
    };
    // let where = {};
    // 信访人姓名                    person.name
    if (data.hasOwnProperty('name') && data.name !== ''){
      let matter = await this.model('matter').alias('m').setRelation(false)
        .join('person_activity as pa on pa.activityID = m.activityID').join('person as p on p.id = pa.personID')
        .where({'p.name':['LIKE','%' + data.name + '%']}).field("m.id").distinct('m.id').select();
      if (think.isEmpty(matter)){
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      } else {
        let mID = [];
        matter.forEach(function(item) {
          mID.push(item.id);
        });
        if (mID.length > 0){
          where['m.id'] = ['IN',mID];
        }
      }
    }
    // 登记单位                      matter.createOrgID
    if (data.hasOwnProperty('orgID') && Array.isArray(data.orgID) && data.orgID.length > 0){
      where["m.createOrgID"] = ['IN',data.orgID];
    }
    // 函件字                        letters_num_query.letterNum
    if (data.hasOwnProperty('letterNum') && data.letterNum !== ""){
      where["n.info"] = ['LIKE','%' + data.letterNum + '%'];
    }
    // 去向单位   handle_log.handleModel='交办'  finalDisposalID
    if (data.hasOwnProperty('finalDisposal') && data.finalDisposal !== ""){
      where["_complex"] = {
        "l.finalDisposal":['LIKE','%' + data.finalDisposal + '%'],
        "_complex":{"h.finalDisposal":['LIKE','%' + data.finalDisposal + '%'],"h.handleModel":"交办"},
        "_logic":"or"
      }
    }
    // 交办人                        letters_num_query.createPerson
    if (data.hasOwnProperty('createPerson') && data.createPerson !== ""){
      where["l.createPerson"] = ['LIKE','%' + data.createPerson + '%'];
    }
    // 时间区间  指的是上传函件的时间 letters_num_query.createTime
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      where["l.createTime"] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      where["l.CreateTime"] = ['<',moment(data.endTime).add(1,'day').format('YYYY-MM-DD')];
    }
    let back = await this.model('letters_num_query').alias('l').join('matter AS m ON m.taskid = l.taskId')
      .join('handle_log AS h ON h.matterID = m.id').join('node_record AS n ON n.taskId = l.taskId')
      .where(where).order('l.createTime Desc')
      .distinct('l.*,m.id as matterID,m.activityID,n.taskId,h.finalDisposal as finalDisposal_h').page(data.page, data.pageSize).countSelect();
    for (let item of back.data){
      if (item.finalDisposal === "" || item.finalDisposal === null){
        item.finalDisposal = item.finalDisposal_h
      }
      if (item.fileUrl === "" || item.fileUrl === null) {
        // item['fileUrl'] = JSON.parse(item.info) === null ? "" : JSON.parse(item.info).letter;
        let letterWhere = {
          "taskId":item.taskId,
          "businessID":4
        };
        let letterUrl = await this.model('node_record').where(letterWhere).order('time DESC').select();
        for (let lu of letterUrl){
          let info = JSON.parse(lu.info);
          if (info.letterCode === item.letterNum ){
            item['fileUrl'] = info.letter;
            break;
          }else {
            item['fileUrl'] = "";
          }
        }
      }
      delete item.info;
      delete item.finalDisposal_h;
    }
    return this.success(back)
  }
  // 自定义查询
  async customizeAction(){
    const data = this.post();
    let userInfo = await this.getUserInfo(data.userId);
    let aID = [];//活动id
    let mID = [];//事项id
    let pID = [];//信访人id
    if (data.hasOwnProperty("activity") ) {
      let ac = data.activity;
      // 含活动查询条件
      let whereActivity = {
        "submit":1
      };
      // 时间区间
      if (ac.hasOwnProperty('startTime') && ac.startTime !== ''){
        whereActivity["createTime"] = ['>',moment(ac.startTime).format('YYYY-MM-DD')];
      }
      if (ac.hasOwnProperty('endTime') && ac.endTime !== ''){
        whereActivity["CreateTime"] = ['<',moment(ac.endTime).add(1,'day').format('YYYY-MM-DD')];
      }
      // 信访来源
      if (ac.hasOwnProperty('xfSourceID') && Array.isArray(ac.xfSourceID) && ac.xfSourceID.length > 0){
        whereActivity['xfSourceID'] = ['IN',ac.xfSourceID];
      }
      // 信访类型
      if (ac.hasOwnProperty('xfTypeID') && Array.isArray(ac.xfTypeID) && ac.xfTypeID.length > 0){
        whereActivity['xfTypeID'] = ['IN',ac.xfTypeID];
      }
      // 最小信访人数
      if (ac.hasOwnProperty('xfNumber') && ac.xfNumber > 0){
        whereActivity['xfNumber'] = ['>=',ac.xfNumber];
      }
      //信访登记类型
      if (ac.hasOwnProperty('registerTypeID') && Array.isArray(ac.registerTypeID) && ac.registerTypeID.length > 0){
        whereActivity['registerTypeID'] = ['IN',ac.registerTypeID];
      }
      //登记人姓名
      if (ac.hasOwnProperty('createPerson') && ac.createPerson !== ""){
        whereActivity['createPerson'] = ac.createPerson;
      }
      //活动编号
      if (ac.hasOwnProperty('activityNum') && ac.activityNum !== ""){
        whereActivity['activityNum'] =['LIKE','%'+ac.activityNum+'%'];
      }
      //登记单位
      if (ac.hasOwnProperty('createOrgID') && Array.isArray(ac.createOrgID) && ac.createOrgID.length > 0){
        whereActivity['createOrgID'] = ['IN',ac.createOrgID];
      }
      // else {
      //   whereActivity['createOrgID'] = userInfo.orgID;// 默认本单位
      // }
      let a = await this.model('activity').where(whereActivity).select();
      if (a.length === 0 ){
        // 活动未命中0，则结果应为空
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
      a.forEach(function(item) {
        aID.push(item.id);
      })
    }
    if (data.hasOwnProperty("matter") ) {
      // 含事项查询条件
      let m = data.matter;
      let whereMatter = {
        "taskid":['!=',null]
      };
      // 时间区间
      if (m.hasOwnProperty('startTime') && m.startTime !== ''){
        whereMatter["createTime"] = ['>',moment(m.startTime).format('YYYY-MM-DD')];
      }
      if (m.hasOwnProperty('endTime') && m.endTime !== ''){
        whereMatter["CreateTime"] = ['<',moment(m.endTime).add(1,'day').format('YYYY-MM-DD')];
      }
      //是否受理 0受理，1不受理
      if (m.hasOwnProperty('isAccept') && m.isAccept !== ""){
        whereMatter['isAccept'] = m.isAccept;
      }
      //被控检人
      if (m.hasOwnProperty('identityName') && m.identityName!== ""){
        whereMatter["_complex"] = {
          "identityName":['LIKE','%' + m.identityName + '%'],
          "abstract":['LIKE','%' + m.identityName + '%'],
          "_logic":"OR"
        };
      }
      // 来访原因
      if (m.hasOwnProperty('lfReasonID') && Array.isArray(m.lfReasonID) && m.lfReasonID.length > 0){
        whereMatter['lfReasonID'] = ['IN',m.lfReasonID];
      }
      // 所属内容分类
      if (m.hasOwnProperty('contentClassifyID') && m.contentClassifyID !=='' && m.contentClassifyID !== null) {//逐级查询，单选
        if (m.contentClassifyID.substr(0,3) === "003") {
          // 纪检监察类，只查主要问题
          whereMatter['_complex'] = {
            "contentClassifyID":["LIKE",m.contentClassifyID + '%'],
            "ContentClassifyID":["LIKE","%,"+ m.contentClassifyID + '%'],
          }
        }else {
          whereMatter['contentClassifyID'] = ['LIKE',m.contentClassifyID + '%']
        }
      }
      // 信访问题所属系统
      if (m.hasOwnProperty('belongsID') && Array.isArray(m.belongsID) && m.belongsID.length > 0){
        whereMatter['belongsID'] = ['IN',m.belongsID];
      }
      // 信访问题属地
      if (m.hasOwnProperty('happenRegionID') && Array.isArray(m.happenRegionID) && m.happenRegionID.length > 0){
        whereMatter['happenRegionID'] = ['IN',m.happenRegionID];
      }
      // 信访摘要
      if (m.hasOwnProperty('abstract') && m.abstract !== ''){
        whereMatter['abstract'] = ['LIKE','%' + m.abstract+ '%'];
      }
      // 热点问题标签 和 个人标签
      if ((m.hasOwnProperty('hotspot') && m.hotspot !== '') || (m.hasOwnProperty('personspot')  && m.personspot !== '')){
        // 两个标签都是单选
        if (m.hasOwnProperty('hotspot') && m.hotspot !== ''){
          let label = await this.model('label_count').where({'labelName':['LIKE',['%'+ data.hotspot + '%']],'type':1}).select();
          label.forEach(function(item) {
            mID.push(item.matterID);
          })
        }
        if (m.hasOwnProperty('personspot') && m.personspot !== ''){
          let label = await this.model('label_count').where({'labelName':['LIKE',['%'+ data.personspot + '%']],'type':2}).select();
          label.forEach(function(item) {
            mID.push(item.matterID);
          })
        }
        if (mID.length === 0 ){
          // 未命中，因为是and条件，此条件未命中，则结果应为空
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        }

      }
      // 是否三跨三分离1是0否
      if (m.hasOwnProperty('isSKSFL') && m.isSKSFL !== ''){
        whereMatter['isSKSFL'] = m.isSKSFL;
      }
      // 时间区间
      if (m.hasOwnProperty('startTime') && m.startTime !== ''){
        whereMatter["createTime"] = ['>',moment(m.startTime).format('YYYY-MM-DD')];
      }
      if (p.hasOwnProperty('endTime') && m.endTime !== ''){
        whereMatter["CreateTime"] = ['<',moment(m.endTime).add(1,'day').format('YYYY-MM-DD')];
      }
      // 登记人
      if (m.hasOwnProperty('createPerson') && m.createPerson !== ''){
        whereMatter['createPerson'] = m.createPerson;
      }
      // 登记单位
      if (m.hasOwnProperty('createOrgID') && Array.isArray(m.createOrgID) && m.createOrgID.length > 0){
        whereMatter['createOrgID'] = ['IN',m.createOrgID];
      }
      // else {
      //   whereMatter['createOrgID'] = userInfo.orgID;// 默认本单位
      // }
      // 办理方式
      if (m.hasOwnProperty('handleModelID') && Array.isArray(m.handleModelID) && m.handleModelID.length > 0){
        whereMatter['handleModelID'] = ['IN',m.handleModelID];
      }
      // 去向单位地区
      if (m.hasOwnProperty('finalZoneID') && Array.isArray(m.finalZoneID) && m.finalZoneID.length > 0){
        whereMatter['finalZoneID'] = ['IN',m.finalZoneID];
      }
      // 去向单位
      if (m.hasOwnProperty('finalDisposalID') && m.finalDisposalID !== "" && m.finalDisposalID.toString().length > 0){
        whereMatter['finalDisposalID'] = m.finalDisposalID;
      }
      //是否受理范围人工判断0受理，1不受理
      if (m.hasOwnProperty('isAcceptPerson') && m.isAcceptPerson !== ""){
        whereMatter['isAcceptPerson'] = m.isAcceptPerson;
      }
      //初重情况
      if (m.hasOwnProperty('visitID') && m.visitID !== ""){
        whereMatter['visitID'] = m.visitID;
      }
      // 是否需要反馈 1是0否
      if (m.hasOwnProperty('isAnswer') && m.isAnswer !== ''){
        whereMatter["isAnswer"] = m.isAnswer;
      }
      //事项名称
      if (m.hasOwnProperty('xfName') && m.xfName !== ""){
        whereMatter['xfName'] = ['LIKE','%' + m.xfName+ '%'];
      }
      //事项编号
      if (m.hasOwnProperty('matterNum') && m.matterNum !== ""){
        whereMatter['matterNum'] = ['LIKE','%' + m.matterNum+ '%'];
      }
      let matter = await this.model('matter').setRelation(false).where(whereMatter).select();
      if (matter.length === 0 ){
        // 事项命中0，则结果应为空
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
      matter.forEach(function(item) {
        mID.push(item.id);
      })
    }
    if (data.hasOwnProperty("person") ) {
      // 含信访人查询条件
      let p = data.person;
      let wherePerson = {
        "isAnonymous":['!=',null]
      };
      // 是否匿名 0非匿名，1匿名
      if (p.hasOwnProperty('isAnonymous') && p.isAnonymous !== ''){
        wherePerson["isAnonymous"] = p.isAnonymous;
      }
      // 初次录入系统时间区间
      if (p.hasOwnProperty('startTime') && p.startTime !== ''){
        wherePerson["createTime"] = ['>',moment(p.startTime).format('YYYY-MM-DD')];
      }
      if (p.hasOwnProperty('endTime') && p.endTime !== ''){
        wherePerson["CreateTime"] = ['<',moment(p.endTime).add(1,'day').format('YYYY-MM-DD')];
      }
      // 信访人名称
      if (p.hasOwnProperty('name') && p.name !== ""){
        wherePerson['name'] = ['LIKE','%' + p.name+ '%'];
      }
      // 证件类型
      if (p.hasOwnProperty('IDTypeID') && p.IDTypeID !== ""){
        wherePerson['IDTypeID'] = p.IDTypeID;
      }
      // 证件号码
      if (p.hasOwnProperty('IDNumber') && p.IDNumber !== ""){
        wherePerson['IDNumber'] = ['LIKE','%' + p.IDNumber+ '%'];
      }
      // 来访人身份
      if (p.hasOwnProperty('identityID') && p.identityID !== ""){
        wherePerson['identityID'] = p.identityID;
      }
      // 国家和地区
      if (p.hasOwnProperty('nationalityID') && p.nationalityID !== ""){
        wherePerson['nationalityID'] = p.nationalityID;
      }
      // 民族
      if (p.hasOwnProperty('nationID') && p.nationID !== ""){
        wherePerson['nationID'] = p.nationID;
      }
      // 身份证所属地区
      if (p.hasOwnProperty('idCardRegionID') && Array.isArray(p.idCardRegionID) && p.idCardRegionID.length > 0){
        wherePerson['idCardRegionID'] = ['IN',p.idCardRegionID];
      }
      // 户口所在地
      if (p.hasOwnProperty('domicileID') && Array.isArray(p.domicileID) && p.domicileID.length > 0){
        wherePerson['domicileID'] = ['IN',p.domicileID];
      }
      // 现住地址所属地区
        if (p.hasOwnProperty('addressRegionID') && Array.isArray(p.addressRegionID) && p.addressRegionID.length > 0){
        wherePerson['addressRegionID'] = ['IN',p.addressRegionID];
      }
      // 现住详细地址
      if (p.hasOwnProperty('address') && p.address !== ""){
        wherePerson['address'] = ['LIKE','%' + p.address+ '%'];
      }
      // 政治身份
      if (p.hasOwnProperty('politicalID') && p.politicalID !== ""){
        wherePerson['politicalID'] = p.politicalID;
      }
      // 学历
      if (p.hasOwnProperty('educationID') && p.educationID !== ""){
        wherePerson['educationID'] = p.educationID;
      }
      // 工作单位
      if (p.hasOwnProperty('company') && p.company !== ""){
        wherePerson['company'] = ['LIKE','%' + p.company+ '%'];
      }
      // 手机
      if (p.hasOwnProperty('mobilePhone') && p.mobilePhone !== ""){
        wherePerson['mobilePhone'] = ['LIKE','%' + p.mobilePhone+ '%'];
      }
      // 电话
      if (p.hasOwnProperty('telephone') && p.telephone !== ""){
        wherePerson['telephone'] = ['LIKE','%' + p.telephone+ '%'];
      }
      // 微信号
      if (p.hasOwnProperty('weChat') && p.weChat !== ""){
        wherePerson['weChat'] = ['LIKE','%' + p.weChat+ '%'];
      }
      // qq
      if (p.hasOwnProperty('qq') && p.qq !== ""){
        wherePerson['qq'] = ['LIKE','%' + p.qq+ '%'];
      }
      // 邮政编码
      if (p.hasOwnProperty('postCode') && p.postCode !== ""){
        wherePerson['postCode'] = ['LIKE','%' + p.postCode+ '%'];
      }
      // 邮箱地址
      if (p.hasOwnProperty('email') && p.email !== ""){
        wherePerson['email'] = ['LIKE','%' + p.email+ '%'];
      }
      // 通讯详细地址
      if (p.hasOwnProperty('postal') && p.postal !== ""){
        wherePerson['postal'] = ['LIKE','%' + p.postal+ '%'];
      }
      let person = await this.model('person').setRelation(false).where(wherePerson).select();
      if (person.length === 0 ){
        // 信访人命中0，则结果应为空
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      }
      person.forEach(function(item) {
        pID.push(item.id);
      })
    }

    // 根据查询主表返回
    if (data.type === 1){
      // 查询主表为活动
      let where = {};
      if (data.hasOwnProperty('activity')){
        if (aID.length > 0){
          where['a.id'] = ['IN',aID];
        }else {
          // 没有复合条件的
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        }
      }
      if (data.hasOwnProperty('matter')){
        if (mID.length > 0){
          where['m.id'] = ['IN',mID];
        }else {
          // 没有复合条件的
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        }
      }
      if (data.hasOwnProperty('person')){
        if (pID.length > 0){
          where['pa.personID'] = ['IN',pID];
        }else {
          // 没有复合条件的
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        }
      }

      let back = await this.model('activity').alias('a').join('person_activity as pa on pa.activityID = a.id')
        .join('matter as m on m.activityID = a.id').where(where).order('a.createTime DESC').distinct('a.*')
        .page(data.page, data.pageSize).countSelect();
      let counts = await this.model('activity').alias('a').join('person_activity as pa on pa.activityID = a.id')
        .join('matter as m on m.activityID = a.id').where(where).distinct('a.*').select();
      for (let item of back.data) {
        let ma = await this.model('matter').setRelation(false).where({'activityID':item.id}).select();
        item['matter'] = ma;
      }
      back.count = counts.length;
      return this.success(back);
    }
    if (data.type === 2){
      // 查询主表为事项
      if (pID.length > 0){
        let paID = []
        let pushA = await this.model('person_activity').where({'personID':['IN',pID]}).select();
        for (let a of pushA){
          paID.push(a.activityID);
        }
        let c = paID.filter(item => aID.some(ele => ele === item ));
        aID = c;//取重复部分的activityID ，因为要去范围小的
      }
      let where = {};
      if (data.hasOwnProperty('activity') || data.hasOwnProperty('person')) {
        if (aID.length > 0){
          where['m.activityID'] = ['IN',aID];
        }else {
          // 没有复合条件的activity
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        }
      }
      if (data.hasOwnProperty('matter')){
        if (mID.length > 0){
          where['m.id'] = ['IN',mID];
        }else {
          // 没有复合条件的matter
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        }
      }
      let back = await this.model('matter').alias('m').where(where).order('m.createTime DESC')
        .page(data.page, data.pageSize).countSelect();
      return this.success(back);
    }
    if (data.type === 3){
      // 查询主表为人
      let where = {};
      let maID = [];
      if (mID.length > 0) {
        let ma = await this.model('matter').setRelation(false).where({'id':['IN',mID]}).select();
        ma.forEach(function(item) {
          maID.push(item.activityID);
        });
        let c = maID.filter(item => aID.some(ele => ele === item ));
        aID = c;//取重复部分的activityID ，因为要去范围小的
      }
      if (data.hasOwnProperty('activity') || data.hasOwnProperty('matter')) {
        if (aID.length > 0){
          where['pa.activityID'] = ['IN',aID]
        }else {
          // 没有复合条件的
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        }
      }
      if (data.hasOwnProperty('person')) {
        if (pID.length > 0) {
          where['p.id'] = ['IN',pID];
        }else {
          // 没有复合条件的
          return this.success({
            "count": 0,
            "totalPages": 0,
            "pageSize": 10,
            "currentPage": 1,
            "data": []
          })
        }
      }
      let back = await this.model('person').alias("p").join("person_activity as pa on pa.personID = p.id")
        .where(where).order('p.createTime DESC').distinct('p.*').page(data.page, data.pageSize).countSelect();
      for (let b of back.data){
        let ac = await this.model('activity').alias('a').join("person_activity as pa on pa.activityID = a.id")
          .where({'pa.personID':b.id}).select();
        b["activity"] = ac;
        for (let a of b.activity){
          let m = await this.model('matter').setRelation(false).where({'activityID':a.id}).select();
          a["matter"] = m;
        }
      }
      return this.success(back);
    }
  }
  async customizeHeadAction(){
    let back = {
      "activity":a,
      "matter":m,
      "person":p
    }
    return this.success(back)
  }
  async customizeQueryAction(){
    let back = {
      "activity":[
        {"id":"time","name":"活动登记时间"},
        {"id":"xfSourceID","name":"信访来源"},
        {"id":"xfTypeID","name":"信访类型"},
        {"id":"xfNumber","name":"最小信访人数"},
        {"id":"registerTypeID","name":"信访登记类型"},
        {"id":"createPerson","name":"活动登记人姓名"},
        {"id":"activityNum","name":"活动编号"},
        {"id":"createOrgID","name":"活动登记单位"}
      ],
      "matter":[
        {"id":"time","name":"事项登记时间"},
        {"id":"isAccept","name":"是否受理"},
        {"id":"identityName","name":"被控检人"},
        {"id":"isAcceptPerson","name":"是否受理范围人工判断"},
        // {"id":"lfReasonID","name":"信访目的"},
        {"id":"contentClassifyID","name":"所属内容分类"},
        {"id":"belongsID","name":"信访问题所属系统"},
        {"id":"happenRegionID","name":"信访问题属地"},
        {"id":"hotspot","name":"热点问题标签"},
        {"id":"personspot","name":"个人标签"},
        {"id":"isSKSFL","name":"是否三跨三分离"},
        {"id":"createPerson","name":"事项登记人姓名"},
        {"id":"createOrgID","name":"事项登记单位"},
        {"id":"matterNum","name":"事项编号"},
        {"id":"xfName","name":"事项名称"},
        {"id":"handleModelID","name":"办理方式"},
        // {"id":"finalZoneID","name":"去向单位地区"},
        {"id":"finalDisposalID","name":"去向单位"},
        {"id":"visitID","name":"初重情况"},
        {"id":"isAnswer","name":"是否需要反馈"}
      ],
      "person":[
        {"id":"isAnonymous","name":"是否匿名"},
        {"id":"time","name":"初次录入系统时间区间"},
        {"id":"name","name":"信访人名称"},
        {"id":"IDTypeID","name":"证件类型"},
        {"id":"IDNumber","name":"证件号码"},
        {"id":"identityID","name":"来访人身份"},
        {"id":"nationalityID","name":"国家和地区"},
        {"id":"nationID","name":"民族"},
        {"id":"idCardRegionID","name":"身份证所属地区"},
        {"id":"domicileID","name":"户口所在地"},
        {"id":"addressRegionID","name":"现住地址所属地区"},
        {"id":"address","name":"现住详细地址"},
        {"id":"politicalID","name":"政治身份"},
        {"id":"educationID","name":"学历"},
        {"id":"company","name":"工作单位"},
        {"id":"mobilePhone","name":"手机"},
        {"id":"telephone","name":"电话"},
        {"id":"weChat","name":"微信号"},
        {"id":"qq","name":"qq"},
        {"id":"postCode","name":"邮政编码"},
        {"id":"email","name":"邮箱地址"},
        {"id":"postal","name":"通讯详细地址"}
      ]
    }
    return this.success(back)
  }
};
// Excel导出，自定义表头字段
// 活动表表头
var a = [
  {"id":"xfSource","name":"信访来源"},//信访来源
  // {"id":"xfNature","name":"信访性质"},//信访性质
  {"id":"xfType","name":"信访性质"},//信访类型
  {"id":"xfNumber","name":"信访人数"},//信访人数
  {"id":"registerType","name":"信访登记类型"},//信访登记类型
  {"id":"createTime","name":"登记时间"},//登记时间
  {"id":"createPerson","name":"登记人姓名"},//登记人姓名
  {"id":"createOrg","name":"登记单位"},//登记单位
  {"id":"mainPerson","name":"主信访人"},//主信访人id，需要连person表
  {"id":"activityNum","name":"活动编号"},//活动编号
  {"id":"registerPlace","name":"登记地点"},//登记地点
  {"id":"isMeeting","name":"是否大会"},//是否大会 0是1不是
  {"id":"meetingSession","name":"大会届次"}//大会届次
];
// 事项表表头
var m = [
  {"id":"isAccept","name":"是否受理"},//是否受理 0受理，1不受理
  {"id":"lfReason","name":"来访原因"},//来访原因
  {"id":"xfName","name":"事项名称"},//事项名称
  {"id":"contentClassify","name":"所属内容分类"},//所属内容分类
  // {"id":"contentClassifyID","name":"用于查询祖级"},//用于查询祖级
  {"id":"finalDisposal","name":"去向单位"},//去向单位
  {"id":"belongs","name":"信访问题所属系统"},//信访问题所属系统
  {"id":"happenRegion","name":"问题属地"},//问题属地
  {"id":"abstract","name":"信访摘要"},//信访摘要
  {"id":"hotspot","name":"热点问题标签"},//热点问题标签
  {"id":"personspot","name":"个人标签"},//个人标签
  {"id":"isSKSFL","name":"是否三跨三分离"},// 是否三跨三分离1是0否
  {"id":"createTime","name":"登记时间"},//登记时间
  {"id":"createPerson","name":"登记人"},//登记人
  {"id":"createOrg","name":"登记单位"},//登记单位
  {"id":"handleModel","name":"办理方式"},//办理方式
  {"id":"finalZone","name":"去向单位地区"},//去向单位地区
  {"id":"isAcceptPerson","name":"是否受理范围人工判断"},//是否受理范围人工判断0受理，1不受理
  {"id":"visit","name":"初重情况"},//初重情况
  {"id":"isMeeting","name":"是否大会"},//是否大会 0是1不是
  {"id":"isAnswer","name":"是否需要反馈"},//是否需要反馈 1是0不是
  {"id":"meetingSession","name":"大会届次"}//大会届次
];
// 信访人表头
var p = [
  {"id":"name","name":"姓名"},//姓名
  {"id":"sex","name":"性别"},//性别
  {"id":"birthday","name":"出生日期"},//出生日期
  {"id":"IDType","name":"证件类型"},//证件类型
  {"id":"IDNumber","name":"证件号码"},//证件号码
  {"id":"identity","name":"来访人身份"},//来访人身份
  {"id":"nationaty","name":"国家和地区"},//国家和地区
  {"id":"nation","name":"民族"},//民族
  {"id":"idCardRegion","name":"身份证所属地区"},//身份证所属地区
  {"id":"domicile","name":"户口所在地"},//户口所在地
  {"id":"addressRegion","name":"现住地址所属地区"},//现住地址所属地区
  {"id":"address","name":"现住详细地址"},//现住详细地址
  {"id":"political","name":"政治身份"},//政治身份
  {"id":"education","name":"学历"},//学历
  {"id":"profession","name":"职业"},//职业
  {"id":"company","name":"工作单位"},//工作单位
  {"id":"mobilePhone","name":"手机"},//手机
  {"id":"telephone","name":"电话"},//电话
  {"id":"weChat","name":"微信号"},//微信号
  {"id":"qq","name":"qq"},//qq
  {"id":"postCode","name":"邮政编码"},//邮政编码
  {"id":"email","name":"邮箱地址"},//邮箱地址
  {"id":"postalRegion","name":"通讯地址所属地区"},//通讯地址所属地区
  {"id":"postal","name":"通讯地址详细地址"}//通讯地址详细地址
];
