const Base = require('./../base.js');
module.exports = class extends Base {
  /**
   * showdoc
   * @catalog 系统管理/领导代表
   * @title 添加领导或代表信息
   * @description 添加领导或代表信息接口
   * @method post
   * @url http://127.0.0.1:8360/sys/delegateLead/addDelegateLead
   * @param name 必选 string  姓名
   * @param IDcard 必选 string 身份证号
   * @param sex 必选 array 性别
   * @param unit 选填 string 机构
   * @param orgID 选填 int 机构id
   * @param position 选填 string 职位
   * @param grade 选填 string 层级
   * @param due 选填 string 届次
   * @param zone 选填 string 地区
   * @param zoneID 选填 int 地区ID
   * @param isLeading 必填 int 0是代表，1是领导
   * @param serveStartTime 必填 date 任职开始时间
   * @param serveEndTime 必填 date 任职结束时间
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  async addDelegateLeadAction() {
    const param = this.post();
    delete param.id;
    const result = await this.model('delegate_leading').thenAdd(param,{IDcard:param.IDcard,serveStartTime: param.serveStartTime, serveEndTime: param.serveEndTime}).catch((e) => {
      return think.isError(e) ? e : new Error(e);
    })
    if (think.isError(result)) {
      return this.fail(5001, '添加代表或领导人信息失败');
    }
    return this.success()
  }

   /**
   * showdoc
   * @catalog 系统管理/领导代表
   * @title 修改领导或代表信息
   * @description 修改领导或代表信息接口
   * @method post
   * @url http://127.0.0.1:8360/sys/delegateLead/editDelegateLead
   * @param name 必选 string  姓名
   * @param IDcard 必选 string 身份证号
   * @param sex 必选 array 性别
   * @param id 必选 int 代表id
   * @param unit 选填 string 单位
   * @param position 选填 string 职位
   * @param grade 选填 string 层级
   * @param due 选填 string 届次
   * @param zone 选填 string 地区
   * @param isLeading 必填 int 0是代表，1是领导
   * @param serveStartTime 必填 date 任职开始时间
   * @param serveEndTime 必填 date 任职结束时间
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  async editDelegateLeadAction() {
    const param = this.post();
    const result = await this.model('delegate_leading').where({id:param.id}).update(param).catch((err) => {
      return think.isError(err) ? err : new Errror(err);
    });
    if (think.isError(result)) {
      return this.fail(5002, '修改失败');
    }
    return this.success();
  }

  /**
   * showdoc
   * @catalog 系统管理/领导代表
   * @title 删除领导或代表信息
   * @description 删除领导或代表信息接口
   * @method post
   * @url http://127.0.0.1:8360/sys/delegateLead/delDelegateLead
   * @param id 必选 int 代表id
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  async delDelegateLeadAction() {
    const param = this.post();
    const result = await this.model('delegate_leading').where({id:param.id}).delete().catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(result)) {
      return this.fail(5003, '删除失败');
    }
    return this.success();
  }

  /**
   * showdoc
   * @catalog 系统管理/领导代表
   * @title 获取领导或代表信息列表
   * @description 获取领导或代表信息列表接口
   * @method post
   * @url http://127.0.0.1:8360/delegateLead/getDelegateLeadList
   * @param page 必选 int 页码
   * @param pageSize 必选 int 每页显示条数
   * @param name 选填 string 名称
   * @param isLead 选填 int 名称
   * @return {"errno": 0, "errmsg":"", "data":{"count": 1,"totalPages": 1,"pageSize": 15,"currentPage": 1,"data":[{"name":"zhang","IDcard":"","sex":"男","activityID":1,"unit":"河北","position":"组长","grade":"","due":"","zone":"","isLeading":1,"serveStartTime":"2017-10-11", "serveEndTime": "2019-10-10"}]}}
   * @return_param count  int 总条数
   * @return_param totalPages  int 总页数
   * @return_param currentPage  int 当前页
   * @return_param name  string  姓名
   * @return_param IDcard string 身份证号
   * @return_param sex  string 性别
   * @return_param activityID int 活动ID
   * @return_param unit string 单位
   * @return_param position string 职位
   * @return_param grade string 层级
   * @return_param due string 届次
   * @return_param zone string 地区
   * @return_param isLeading int 0是代表，1是领导
   * @return_param serveStartTime string 任职开始时间
   * @return_param serveEndTime string 任职结束时间
   */
  async getDelegateLeadListAction() {
    const param = this.post();
    const nowTime = think.datetime(new Date()).split(' ')[0];
    let whereParam = {serveStartTime:['<=', nowTime], serveEndTime: ['>=', nowTime]};
    if(param.name) {
      whereParam.name = ['like','%' + param.name + '%'];
    }
    //判断是否为超级管理员，超级管理员全部展示，否在只展示本级
    const userRole = await this.model('sys_user_role').where({role_id:1,user_id:param.userId}).find();
    //为空不是超级管理员，需要登录者的地区
    if (think.isEmpty(userRole)) {
      const user = await this.model('sys/sys_user').where({user_id: param.userId}).find();
      whereParam.orgID = user.org.id
    }
    if (param.orgID) {
      whereParam.orgID = param.orgID;
    }
    if (param.hasOwnProperty("isLeading") && param.isLeading !== ""  )  {
      whereParam.isLeading = parseInt(param.isLeading)
    }
    const result = await this.model('sys/delegate_leading').where(whereParam).page(param.page, param.pageSize).countSelect().catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(result)) {
      return this.fail(5004, '获取列表失败');
    }
    return this.success(result)
  }

  async getZoneTreeAction() {
    let  res = await this.model('dictionary').field('dictID,dictValue,parentValue,description').where({dictID:'AB',dictValue:['NOTLIKE','%135%']}).select();

    if (!think.isEmpty(res)) {
      res = this.getDictTree(res,'dictValue', 'parentValue')
    }
    return this.success(res)
  }


  /**
   * showdoc
   * @catalog 系统管理/领导代表
   * @title 获取职位和层次信息列表
   * @description 获取职位和层次信息列表接口
   * @method post
   * @url http://127.0.0.1:8360/sys/delegateLead/getPositionGrade
   * @param page 必选 int 页码
   * @param pageSize 必选 int 每页显示条数
   * @param name 选填 string 名称
   * @return {"errno": 0, "errmsg":"", "data":{"count": 1,"totalPages": 1,"pageSize": 15,"currentPage": 1,"data":{"postion":["aa"],"grade":['bbb']}}}
   * @return_param postion  array 职位
   * @return_param grade  array 层级
   */
  async getPositionGradeAction() {
    const position = ["常委会主任、副主任","常委会秘书长","常委会副秘书长","常委会工作办事机构领导","其它领导"];
    const grade = ["全国人大代表","省人大代表","市人大代表","县人大代表"];
    this.success({position: position, grade: grade});
  }
}
