const Base = require('./../base.js');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }

  /**
   * showdoc
   * @catalog 系统管理/菜单管理
   * @title 添加菜单
   * @description 添加菜单接口
   * @method post
   * @url http://127.0.0.1:8360/sys/menu/addMenu
   * @param menu_name 必选 string 菜单名称
   * @param parent_id 必选 int 父级id
   * @param order_num 必选 int 菜单排序
   * @param menu_type 必选 int 菜单类型0目录，1菜单，2按钮
   * @param visible 必选 string 菜单状态，0显示，1隐藏
   * @param perms 必选 string api接口地址
   * @param path 必须 string 前端页面地址
   * @param remark 必选 string 备注
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async addMenuAction() {
    let param = this.post();
    console.log(param)
    let menu = this.model('sys_menu');
    menu._pk = "menu_id";
    // let add_return = await menu.thenAdd(param,{menu_name:param.menu_name}).catch((err) => {
    //   return think.isError(err) ? err : new Error(err);
    // });
    // let find = await menu.where({menu_name:param.menu_name}).find();
    // if (!think.isEmpty(find)){
    //   return this.fail(4000, 'Add menu failed:\n' + find.message);
    // }
    delete param.menu_id
    let add_return = await menu.add(param);
    // if (think.isError(add_return)) {
    //   return this.fail(4000, 'Add menu failed:\n' + add_return.message);
    // }
    //判断是否已存在该菜单名称
    if (add_return.type == 'exist') {
      return this.fail(4005, 'This menu_name existed'); //指定错误号和错误信息

    }
    return this.success();
  }

  /**
   * showdoc
   * @catalog 系统管理/菜单管理
   * @title 修改菜单
   * @description 修改菜单接口
   * @method post
   * @url http://127.0.0.1:8360/sys/menu/editMenu
   * @param menu_name 必选 string 菜单名称
   * @param menu_id 必选 int 菜单id
   * @param parent_id 必选 int 父级id
   * @param order_num 必选 int 菜单排序
   * @param menu_type 必选 int 菜单类型0目录，1菜单，2按钮
   * @param visible 必选 string 菜单状态，0显示，1隐藏
   * @param perms 必选 string api接口地址
   * @param path 必须 string 前端页面地址
   * @param remark 必选 string 备注
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  //修改菜单权限
  async editMenuAction() {
    let param = this.post();
    let edit_return = await this.model('sys_menu').where({menu_id:param.menu_id}).update(param).catch((err) => {
      console.log(err)
      return think.isError(err) ? err : new Error(err);
    })
    if (think.isError(edit_return)) {
      return this.fail(4001, 'Edit menu failed');
    }
    return this.success();
  }

  /**
   * showdoc
   * @catalog 系统管理/菜单管理
   * @title 删除菜单
   * @description 删除菜单接口
   * @method post
   * @url http://127.0.0.1:8360/sys/menu/delMenu
   * @param menu_id 必选 int 菜单id
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async delMenuAction() {
    let param = this.post();
    //proc_delete_menu 在mysql中创建存储过程，用来删除本级以及期子集
    let sql = "call proc_delete_menu(" + param.menu_id + ")";
    let del_return = await this.model('sys_menu').query(sql).catch((err) => {
      console.log(err)
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(del_return)) {
      return this.fail(4002, 'Delete menu failed');
    }
    return this.success();
  }


  /**
   * showdoc
   * @catalog 系统管理/菜单管理
   * @title 获取菜单列表
   * @description 获取菜单列表接口
   * @method get
   * @url http://127.0.0.1:8360/sys/menu/getMenuList
   * @param page 必选 int 当前页数
   * @param page_size 必选 int 每页显示条数
   * @return {"errno": 0, "errmsg":"", "data":{"count":1,"totalPages":1,"pageSize":10,"currentPage":1,"data":[{"menu_id":1,"menu_name":"admin","order_num":1,"perms":"sys/menu/getMenuQuery"}]}}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param count  int 总条数
   * @return_param totalPages  int 总页数
   * @return_param currentPage  int 当前页
   * @return_param menu_id 必选 int 菜单id
   * @return_param menu_name 必选 string 菜单名称
   * @return_param order_num 必选 string 菜单排序
   * @return_param perms 必选 string 菜单的接口地址
   */
  async getMenuListAction() {
    let param = this.get();
    let whereParam = {}
    if (param.menu_name) {
      whereParam.menu_name = ["like" , "%" + param.menu_name + "%"];
    }
    if (param.visible) {
      whereParam.visible = param.visible ;
    }
    let menu = this.model('sys_menu');
    menu._pk = "menu_id"
    let result = await menu.where(whereParam).select().catch(err => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(result)) {
      return this.fail(4004, 'Get menu list failed');
    }
    //j项数据树形结构化 this.getDictTree在extends中的controller.js文件中
    if (result) {
      let fina_res= this.getDictTree(result, 'menu_id', 'parent_id')
      return this.success(fina_res);
    }
    return this.success(result);

  }
  /**
   * showdoc
   * @catalog 系统管理/菜单管理
   * @title 获取菜单详细信息
   * @description 获取菜单详细信息接口
   * @method get
   * @url http://127.0.0.1:8360/sys/menu/getMenuDetail
   * @param menu_id 必选 int 菜单id
   * @return {"errno": 0, "errmsg":"", "data":[{"menu_id":1,"menu_name":"admin","order_num":1,"perms":"sys/menu/getMenuQuery","parent_id":null,"visible":0,"order_num":1,"menu_type":0,"remark":"admin"}]}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param menu_id 必选 int 菜单id
   * @return_param menu_name 必选 string 菜单名称
   * @return_param order_num 必选 string 菜单排序
   * @return_param perms 必选 string 菜单的接口地址
   * @return_param parent_id 必选 string 菜单父级id
   * @return_param visible 必选 string 菜单状态
   * @return_param menu_type 必选 string 菜单类型0目录，1菜单，2按钮
   * @return_param remark 必选 string 备注
   */
  async getMenuDetailAction() {
    const param = this.get();
    let data = await this.model('sys_menu').field('menu_id,parent_id,menu_name,order_num,visible,menu_type,perms,remark').where({menu_id:param.menu_id}).find().catch(err => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(result)) {
      return this.fail(4004, 'Get menu list failed');
    }
    return this.success(data)
  }

};
