const Base = require('../base.js');
const moment = require('moment');
const util = require('./../../handle/util.js');
module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  /**
   * showdoc
   * @catalog 站内新闻
   * @title 站内新闻添加
   * @description 站内新闻添加接口
   * @method post
   * @url http://127.0.0.1:8360/sys/news/add
   * @param title 必选 string 标题
   * @param subtitle 必选 string 副标题
   * @param content 必选 string 内容
   * @param picUrl 必选 array 图片地址,存成数组以便支持多图
   * @param htmlUrl 必选 array html文件地址
   * @param url 必选 array 其他附件地址
   * @param userId 必选 string 创建人员id
   * @param startTime 必选 string 发布日期YYYY-MM-DD HH:mm:ss
   * @param endTime 必选 string 结束日期YYYY-MM-DD HH:mm:ss
   * @param state 必选 int 消息状态 1删除，2正在发布，3未发布，4已发布
   * @param msgType 必选 int 消息类型 消息类型，1新闻，2通知
   * @param range 必选 int 作用范围，0全网，1本级，2本级及以下
   * @param sendType 必选 int 使用场景，0全部，1app，2互联网，3微信
   * @return {"errno": 0, "errmsg":"", "data":{}}
   */
  async addAction(){
    let data = this.post();
    let userInfo = await this.getUserInfo(data.userId);
    let addData = {
      'title':data.title,// 标题
      'subtitle':data.subtitle,// 副标题
      'content':data.content,// 内容
      'picUrl':!data.hasOwnProperty('picUrl') || !Array.isArray(data.picUrl) ? '' : data.picUrl.join(','),// 图片地址 存成数组以便支持多图
      'htmlUrl':!data.hasOwnProperty('htmlUrl') || !Array.isArray(data.htmlUrl) ? '' : data.htmlUrl.join(','),// html文件地址
      'url':!data.hasOwnProperty('url') || !Array.isArray(data.url) ? '' : data.url.join(','),// 其他附件地址
      'createUserID':data.userId,// 创建人员id
      'createUserName':userInfo.name,// 创建人员
      'createOrgID':userInfo.orgID,// 创建人员
      'createOrgName':userInfo.orgName,// 创建单位
      'startTime':moment(data.startTime).format('YYYY-MM-DD HH:mm:ss'),// 发布日期
      'endTime':moment(data.endTime).format('YYYY-MM-DD HH:mm:ss'),// 结束日期
      'state':data.state,// 消息状态 1删除，2正在发布，3未发布，4已发布
      'msgType':data.msgType,// 消息类型 消息类型，1新闻，2通知
      'range':data.range,// 作用范围，0全网，1本级，2本级及以下
      'sendType':data.sendType,// 使用场景，0全部，1app，2互联网，3微信
    };
    let save = await this.model('station_news').add(addData);
    return this.success(save);
  }
  /**
   * showdoc
   * @catalog 站内新闻
   * @title 站内新闻修改
   * @description 站内新闻修改接口
   * @method post
   * @url http://127.0.0.1:8360/sys/news/update
   * @param title 必选 string 标题
   * @param subtitle 必选 string 副标题
   * @param content 必选 string 内容
   * @param picUrl 必选 array 图片地址,存成数组以便支持多图
   * @param htmlUrl 必选 array html文件地址
   * @param url 必选 array 其他附件地址
   * @param userId 必选 string userId
   * @param startTime 必选 string 发布日期YYYY-MM-DD HH:mm:ss
   * @param endTime 必选 string 结束日期YYYY-MM-DD HH:mm:ss
   * @param state 必选 int 消息状态 1删除，2正在发布，3未发布，4已发布
   * @param msgType 必选 int 消息类型 消息类型，1新闻，2通知
   * @param range 必选 int 作用范围，0全网，1本级，2本级及以下
   * @param sendType 必选 int 使用场景，0全部，1app，2互联网，3微信
   * @return {"errno": 0, "errmsg":"", "data":{}}
   */
  async updateAction(){
    let data = this.post();
    let up = {};
    if (data.hasOwnProperty('title')) {
      up['title'] = data.title
    }
    if (data.hasOwnProperty('subtitle')) {
      up['subtitle'] = data.subtitle
    }
    if (data.hasOwnProperty('content')) {
      up['content'] = data.content
    }
    if (data.hasOwnProperty('picUrl') && Array.isArray(data.picUrl)) {
      up['picUrl'] = data.picUrl.join(',')
    }
    if (data.hasOwnProperty('htmlUrl') && Array.isArray(data.htmlUrl)) {
      up['htmlUrl'] = data.htmlUrl.join(',')
    }
    if (data.hasOwnProperty('url') && Array.isArray(data.url)) {
      up['url'] = data.url.join(',')
    }
    if (data.hasOwnProperty('startTime') && data.startTime !== '') {
      up['startTime'] = moment(data.startTime).format('YYYY-MM-DD HH:mm:ss')
    }
    if (data.hasOwnProperty('endTime') && data.startTime !== '') {
      up['endTime'] = moment(data.endTime).format('YYYY-MM-DD HH:mm:ss')
    }
    if (data.hasOwnProperty('state')) {
      up['state'] = data.state
    }
    if (data.hasOwnProperty('msgType')) {
      up['msgType'] = data.msgType
    }
    if (data.hasOwnProperty('range')) {
      up['range'] = data.range
    }
    if (data.hasOwnProperty('sendType')) {
      up['sendType'] = data.sendType
    }
    if (up === {}){
      return this.fail("empty!")
    }
    let back = await this.model('station_news').where({id:data.id}).update(up);
    return this.success(back);
  }
  /**
   * showdoc
   * @catalog 站内新闻
   * @title 站内新闻添加
   * @description 站内新闻添加接口
   * @method post
   * @url http://127.0.0.1:8360/sys/news/adminList
   * @param userId 必选 string 创建人员id
   * @param state 必选 int 消息状态 1删除，2正在发布，3未发布，4已发布
   * @param msgType 必选 int 消息类型 消息类型，1新闻，2通知
   * @param range 必选 int 作用范围，0全网，1本级，2本级及以下
   * @param sendType 必选 int 使用场景，0全部，1app，2互联网，3微信
   * @param page 必选 int 页码
   * @param limit 必选 int 每页条数
   * @return {"errno": 0, "errmsg":"", "data":{}}
   */
  // 后台管理列表
  async adminListAction(){
    let data = this.post();
    let userInfo = await this.getUserInfo(data.userId);
    let where = {
      'createOrgID': userInfo.orgID === 40 ? ['!=',null] : userInfo.orgID,// 省级管理员可以查看全部
      'msgType': data.hasOwnProperty('msgType') ? data.msgType :['!=',null],// 消息类型 消息类型，1新闻，2通知
      'state': data.hasOwnProperty('state') ? data.state :['!=',null],// 消息类型 1删除，2正在发布，3未发布，4已发布
      'sendType': data.hasOwnProperty('sendType') ? data.sendType :['!=',null],// 使用场景，0全部，1app，2互联网，3微信
      'range': data.hasOwnProperty('range') ? data.range :['!=',null],// 作用范围，0全网，1本级，2本级及以下
    };
    let list = await this.model('station_news').where(where).page(data.page, data.limit).order('createTime DESC').countSelect();
    return this.success(list);
  }
  /**
   * showdoc
   * @catalog 获取新闻列表
   * @title 获取新闻列表
   * @description 获取新闻列表接口
   * @method post
   * @url http://127.0.0.1:8360/sys/news/getNews
   * @param userId 必选 string userId
   * @param page 必选 int 页码
   * @param limit 必选 int 每页条数
   * @return {"errno": 0, "errmsg":"", "data":{}}
   */
  async getNewsAction(){
    let data = this.post();
    let userInfo = await this.getUserInfo(data.userId);
    let where = {};
    let lv = await this.model('sys_organization').alias('so').join('sys_dept as sd on so.deptID = sd.parentID')
      .where({'sd.id':userInfo.dictValue,'so.agent':1}).field('so.id').find();// 上级人大orgID
    if (!think.isEmpty(lv)){
      where = {
        '_complex':[
          {  // 上级单位发布，选择本级及以下可见
            'createOrgID': lv.id,
            'range': 2,
            'startTime':['<=',moment().format('YYYY-MM-DD')],
            'endTime':['>',moment().add(1,'days').format('YYYY-MM-DD')]
          },
          {  // 本级单位发布
            'createOrgID': userInfo.orgID,
            'startTime':['<=',moment().format('YYYY-MM-DD')],
            'endTime':['>',moment().add(1,'days').format('YYYY-MM-DD')]
          }
        ],
        '_logic':'or'
      };
    } else {
      where = {
        'createOrgID': userInfo.orgID,
        'startTime':['<=',moment().format('YYYY-MM-DD')],
        'endTime':['>',moment().add(1,'days').format('YYYY-MM-DD')],
      }
    }
    let list = await this.model('station_news').where(where).page(data.page, data.limit).order('createTime DESC').countSelect();
    return this.success(list);
  }
  /**
   * showdoc
   * @catalog 删除
   * @title 删除
   * @description 删除接口
   * @method post
   * @url http://127.0.0.1:8360/sys/news/del
   * @param userId 必选 string userId
   * @return {"errno": 0, "errmsg":"", "data":{}}
   */
  // 删除
  async delAction(){
    let data = this.psot();
    let back = await this.model('station_news').where({'id':data.id}).delete();
    if (think.isEmpty(back)){
      return this.fail()
    } else {
      return this.success(back);
    }
  }
};
