const Base = require('../base.js');

module.exports = class extends Base {
  /**
   * showdoc
   * @catalog 系统管理/组织机构管理
   * @title 组织机构列表
   * @description 组织机构列表接口
   * @method post
   * @url http://127.0.0.1:8360/sys/org/getOrgList
   * @param orgName 必选 string 机构名称
   * @param deptID 必选 int 地区id
   * @param deptName 必选 string 地区名称
   * @param isRenDa 必选 int 是否是人大机构，1是，0不是
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async getOrgListAction() {
    const param = this.post();
    const userRole = await this.model('sys_user_role').where({role_id:1,user_id:param.userId}).find();
    let whereParam = {}
    //为空不是超级管理员，需要登录者的地区
    if (think.isEmpty(userRole)) {
      const user = await this.model('sys/sys_user').where({user_id: param.userId}).find();
      whereParam['so.id'] = user.org.id
    }
    //机构名称
    if (param.orgName) {
      whereParam['so.orgName'] = ['like' + '%' + param.orgName + '%']
    }
    //地区id
    if (param.deptID) {
      whereParam['so.deptID'] = param.deptID;
    }
    //是否是人大机构
    if (param.isRenDa !== "" && typeof param.isRenDa !== 'undefined') {
      whereParam['so.isRenDa'] =  param.isRenDa;
    }
    console.log(whereParam)
    const org = await this.model('sys_organization').alias('so').field('so.*,sp.deptName').join({table:'sys_dept', join:'left', on:['deptID', 'id'],as:'sp'}).where(whereParam).page(param.page,param.pageSize).countSelect();
    return this.success(org);
  }
  //添加组织机构
  /**
   * showdoc
   * @catalog 系统管理/组织机构管理
   * @title 添加组织机构
   * @description 添加组织机构接口
   * @method post
   * @url http://127.0.0.1:8360/sys/org/addOrg
   * @param userId 必选 string 用户userId
   * @param orgName 必选 string 机构名称
   * @param deptID 必选 int 地区id
   * @param deptName 必选 string 地区名称
   * @param deptTitle 必选 string 函件头
   * @param searchPhone 必选 string 信访查询电话
   * @param passTitle 必选 string 转送单头
   * @param jc 必选 string 机构简称
   * @param agent 必选 int 人大常委会代理机构设置为1
   * @param isRenDa 必选 int 是否是人大机构，1是，0不是
   * @param isOnline 必选 int 是否开通网上信访，0是，1否
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async addOrgAction() {
    const param = this.post();
    delete param.userId;
    let add = {
      "orgName":param.orgName,
      "isRenDa":param.isRenDa,
      "deptID":param.deptID,
      "deptName":param.deptName,
      "jc":param.jc,//机构简称
      "createPerson":param.userId,
      // "agent":param.agent,
      "deptTitle":param.deptTitle,
      "isOnline":param.isOnline,
      "searchPhone":param.searchPhone,
      "passTitle":param.passTitle,
    }
    const res = await this.model('sys_organization').add(add);
    return this.success(res);
  }

  /**
   * showdoc
   * @catalog 系统管理/组织机构管理
   * @title 修改组织机构
   * @description 修改组织机构接口
   * @method post
   * @url http://127.0.0.1:8360/sys/org/editOrg
   * @param orgName 必选 string 机构名称
   * @param deptID 必选 int 地区id
   * @param id 必选 int 组织id
   * @param deptName 必选 string 地区名称
   * @param oldAgent 必选 int 原代理单位id
   * @param newAgent 必选 int 新代理单位id
   * @param isRenDa 必选 int 是否是人大机构，1是，0不是
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async editOrgAction() {
    const param = this.post();
    let data = {
      'orgName':param.orgName,
      'deptID':param.deptID,
      'id':param.id,
      'deptName':param.deptName,
      'isRenDa':param.isRenDa,
      'searchPhone':param.searchPhone,
      'deptTitle':param.deptTitle,
      'jc':param.jc,
      'agent':param.newAgent === param.id  ? 1 : param.agent // 设置为1人大常委会代理机构
    };
    const res = await this.model('sys_organization').where({id:param.id}).update(data);
    if (param.oldAgent !== ''){
      const up = await this.model('sys_organization').where({id:param.oldAgent}).update({'agent':0}); // 将原代理机构改为0
    }
    return this.success(res);
  }
  /**
   * showdoc
   * @catalog 系统管理/组织机构管理
   * @title 删除组织机构
   * @description 删除组织机构接口
   * @method post
   * @url http://127.0.0.1:8360/sys/org/delOrg
   * @param id 必选 int 组织id
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async delOrgAction() {
    const param = this.post();
    const res = await this.model('sys_organization').where({id: param.id}).delete();
    return this.success(res);
  }
  /**
   * showdoc
   * @catalog 系统管理/组织机构管理
   * @title 当前地区代理机构查询
   * @description 当前地区代理机构查询接口
   * @method post
   * @url http://127.0.0.1:8360/sys/org/getAgent
   * @param deptID 必选 int 地区id
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  // 当前地区代理机构查询
  async getAgentAction() {
    const param = this.post();
    const res = await this.model('sys_organization').where({deptID: param.deptID,agent:1,isRenDa:1}).find();
    return this.success(res);
  }
  /**
   * showdoc
   * @catalog 系统管理/获取所有组织机构
   * @title 获取所有组织机构
   * @description 获取所有组织机构
   * @method post
   * @url http://127.0.0.1:8360/sys/org/getOrgAll
   * @param id deptID
   * @return {"errno": 0, "errmsg":"", "data":""}
   */
  async getOrgAllAction(){
    const data = this.post();
    let where = {
      "deptID":data.id === "" || data.id === undefined ? ['!=',null] : data.id,
      "isRenDa":1
    }
    let org = await this.model('sys_organization').where(where).select();
    return this.success(org);
  }

  //
  async deptOrgAction(){
    let where = {
      "sd.type":['IN',[2,3,4]],
      "so.agent":1
    };
    let org = await this.model('sys_organization').alias('so').join('sys_dept as sd on sd.id = so.deptID')
      .where(where).field('so.id,so.deptID,so.orgName,sd.type,sd.parentID,sd.deptName').select();
    let back = {
      "deptName":"安徽省",
      "children":[
        {
          "orgName":"安徽省人大常委会",
          "orgID":40,
        },
        {
          "deptName":"省辖市级人大常委会",
          "children":[]
        },
        {
          "deptName":"省辖县级人大常委会",
          "children":[]
        }
      ]
    }
    org.forEach(function(item) {
      if (item.type === 3){
        back.children.push({
          "deptName":item.deptName,
          "deptID":item.deptID,
          // "orgName":item.orgName,
          // "orgID":item.id,
          "children":[
            {
              "orgName":item.orgName,
              "orgID":item.id,
            },
            {
              "deptName":"市辖县级人大常委会",
              "children":[]
            }
          ]
        })
      }
    });
    org.forEach(function(item) {
      if (item.type === 4){
        back.children[2].children.push({
          "orgName":item.orgName,
          "orgID":item.id,
        })
        back.children.forEach(function(items) {
          if (typeof items.deptID !== 'undefined'){
            if (items.deptID === item.parentID){
              items.children[1].children.push({
                "orgName":item.orgName,
                "orgID":item.id,
              })
            }

          }
        })
      };
      if (item.type === 3){
        back.children[1].children.push({
          "orgName":item.orgName,
          "orgID":item.id,
        })
      }
    })
    return this.success(back)
  }
  // 获取省市县所有人大常委会
  async getAgentAction(){
    let where = {
      "sd.type":['IN',[2,3,4]],
      "so.agent":1
    };
    let org = await this.model('sys_organization').alias('so').join('sys_dept as sd on sd.id = so.deptID')
      .where(where).field('so.id as orgID,so.deptID,so.orgName,sd.type,sd.id as deptID,sd.parentID,sd.deptName').select();
    let tree = [];
    let data = {};
    for (const i in org) {
      const dataKey = org[i]['deptID'];
      data[dataKey] = org[i];
    }
    for (const j in org) {
      const bval = org[j];
      const dataP = data[bval['parentID']];
      if (dataP) {
        if (!dataP.children) {
          dataP.children = [];
        }
        dataP.children.push(bval);
      } else {
        tree.push(bval);
      }
    }
    return this.success(tree)
  }
}
