const Base = require('../base.js');

module.exports = class extends Base {
  /**
   * showdoc
   * @catalog 系统管理/问题管理
   * @title 添加问题
   * @description 添加问题接口
   * @method post
   * @url http://127.0.0.1:8360/sys/question/addQuestion
   * @param title 必选 string 标题
   * @param content 必选 string 内容
   * @param isTop 必选 int 是否置顶，0不置顶，1置顶
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async addQuestionAction() {
    const param = this.post();
    delete param.id;
    const res = await this.model('question').add(param);
    return this.success(res);
  }

  /**
   * showdoc
   * @catalog 系统管理/问题管理
   * @title 修改问题
   * @description 修改问题接口
   * @method post
   * @url http://127.0.0.1:8360/sys/question/editQuestion
   * @param title 必选 string 标题
   * @param content 必选 string 内容
   * @param isTop 必选 int 是否置顶，0不置顶，1置顶
   * @param id 必选 int 文章id
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async editQuestionAction() {
    const param = this.post();
    const res = await this.model('question').where({id: param.id}).update(param);
    return this.success();
  }

  /**
   * showdoc
   * @catalog 系统管理/问题管理
   * @title 删除问题
   * @description 删除问题接口
   * @method post
   * @url http://127.0.0.1:8360/sys/question/delQuestion
   * @param title 必选 string 标题
   * @param content 必选 string 内容
   * @param isTop 必选 int 是否置顶，0不置顶，1置顶
   * @param id 必选 int 文章id
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  //
  async delQuestionAction() {
    const param = this.post();
    const res = await this.model('question').where({id: param.id}).delete();
    return this.success();
  }

  /**
   * showdoc
   * @catalog 系统管理/问题管理
   * @title 分页获取问题列表
   * @description 分页获取问题列表接口
   * @method post
   * @url http://127.0.0.1:8360/sys/question/getQuestionList
   * @param title 选填 string 标题
   * @param page 必选 int 页码
   * @param pageSize 必选 int 每页显示
   * @return {"errno": 0, "errmsg":"", "data":[{"title":"新问题", content:"ddssss", isTop:1, id:2}]}
   * @return_param title 必选 string 标题
   * @return_param content 必选 string 内容
   * @return_param isTop 必选 int 是否置顶，0不置顶，1置顶
   * @return_param id 必选 int 文章id
   */
  //
  async getQuestionListAction() {
    const param = this.post();
    let whereParam = {};
    if (param.title) {
      whereParam.title = ['like', '%' + param.title + '%'];
    }
    const res = await this.model('question').where(whereParam).page(param.page,param.pageSize).order(' isTop desc,createTime desc').countSelect();
    return this.success(res);
  }

}