const Base = require('./../base.js');
const moment = require('moment')

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }

  /**
   * showdoc
   * @catalog 系统管理/角色管理
   * @title 获取菜单权限
   * @description 获取菜单权限接口
   * @method get
   * @url http://127.0.0.1:8360/sys/role/getMenuTree
   * @return {"errno": 0, "errmsg":"", "data":[{"menu_id":1,"menu_name": "管理员管理","parent_id":null ,children:[]}]}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param menu_id  int 菜单主键id
   * @return_param menu_name  string 菜单名称
   * @return_param parent_id  string 父级id
   * @return_param children  array 子集
   */
  async getMenuTreeAction() {
    let menu_tree = await this.model('sys_menu').field('menu_id,menu_name,parent_id').order('order_num asc').select().catch((err) => {
        return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(menu_tree)) {
        return this.fail(2000, "Get menuTree fail");
    }
    let getMenuTree = () => {
      let menu = {};
      let tree = [];
      menu_tree.forEach((item) => {
        menu[item.menu_id] = item;
      })
      menu_tree.forEach((meT) => {
        const data = menu[meT['parent_id']];
        if (data) {
          (!data.chidren) && (data.chidren=[])
          data.chidren.push(meT)
        } else {
          tree.push(meT)
        }
      })
      return tree
    }
    const fin_data = getMenuTree();
    return this.success(fin_data);
  }

  /**
   * showdoc
   * @catalog 系统管理/角色管理
   * @title 添加角色
   * @description 添加角色接口
   * @method post
   * @url http://127.0.0.1:8360/sys/role/addRole
   * @param role_name 必选 string 角色名称
   * @param handle_name 必选 string 添加者
   * @param menu_ids 必选 array 菜单的id
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async addRoleAction() {
    let param = this.post();
    let add_return = await this.model('sys_role').thenAdd({role_name:param.role_name},{role_name:param.role_name}).catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(add_return)) {
      return this.fail(2001, "Add role fail");
    }
    if (add_return.type == 'exist') {
      return
       this.fail(2011, 'This role_name existed');
    }
    let role_menu_param =  [];
    param.menu_ids.forEach((item) => {
        role_menu_param.push({role_id:add_return.id,menu_id:item});
    })
    let add_role_menu_return = await this.model('sys_role_menu').addMany(role_menu_param).catch((err) => {
        return think.isError(err) ? err : new Error(err);
    })
    if (think.isError(add_role_menu_return)) {
      return this.fail(2002, "Add role-menu fail");
    }
    return this.success();
  }

  /**
   * showdoc
   * @catalog 系统管理/角色管理
   * @title 修改角色
   * @description 修改角色接口
   * @method post
   * @url http://127.0.0.1:8360/sys/role/editRole
   * @param role_name 必选 string 角色名称
   * @param update_name 必选 string 添加者
   * @param menu_ids 必选 array 菜单的id
   * @param role_id 必选 int 角色id
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async editRoleAction() {
    let param = this.post();
    //角色id为1，是不允许修改
    if (param.role_id === 1) {
      return this.fail(2010, "该角色为超级管理员角色，不允许修改")
    } else {
      // param.update_time = new Date().toLocaleString();
      param.update_time = moment().format('YYYY-MM-DD'); //修改时间
      let edit_return =  await this.model('sys_role').where({role_id:param.role_id}).update({role_name:param.role_name,update_time:param.update_time,update_name:param.update_name}).catch((err) => {
        console.log(err);
        return think.isError(err) ? err : new Error(err);
      });
      if (think.isError(edit_return)) {
        return this.fail(2003, "Edit role fail");
      }
      //删除角色权限表中的值
      let del_return = await this.model('sys_role_menu').where({role_id:param.role_id}).delete().catch((err) => {
        console.log(err);
        return think.isError(err) ? err : new Error(err);
      });
      if (think.isError(del_return)) {
        return this.fail(2004, "Delete role-menu fail");
      }
      //插入角色权限表中的参数
      let role_menu_param = [];
      param.menu_ids.forEach((item) => {
        role_menu_param.push({role_id:param.role_id, menu_id:item})
      });

      let edit_role_menu_return = await this.model('sys_role_menu').addMany(role_menu_param).catch((err) => {
        console.log(err);
        return think.isError(err) ? err : new Error(err);
      });
      if (think.isError(edit_role_menu_return)) {
        return this.fail(2002, "Add role-menu fail");
      }
      return this.success();
    }



  }

  /**
   * showdoc
   * @catalog 系统管理/角色管理
   * @title 删除角色
   * @description 删除角色接口
   * @method post
   * @url http://127.0.0.1:8360/sys/role/delRole
   * @param role_id 必选 int 角色id
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  //删除角色
  async delRoleAction() {
    let param = this.post();
    if (param.role_id === 1) {
      return this.fail(2010, "该角色为超级管理员角色，不允许删除")
    } else {
      let del_return = await this.model('sys_role').where({role_id:param.role_id}).delete().catch((err) => {
        return think.isError(err) ? err : new Error(err);
      });
      if (think.isError(del_return)) {
        return this.fail(2005, "Delete role fail");
      }
    }
    return this.success();
  }


  /**
   * showdoc
   * @catalog 系统管理/角色管理
   * @title 获取角色列表
   * @description 获取角色列表接口
   * @method get
   * @url http://127.0.0.1:8360/sys/role/getRoleList
   * @param page 必选 int 当前页数
   * @param page_size 必选 int 每页显示条数
   * @return {"errno": 0, "errmsg":"", "data":{"count":1,"totalPages":1,"pageSize":10,"currentPage":1,"data":[{"role_id":1,"role_name":"admin","role_status":1}]}}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param count  int 总条数
   * @return_param totalPages  int 总页数
   * @return_param currentPage  int 当前页
   * @return_param role_id 必选 int 角色id
   * @return_param role_name 必选 string 角色名称
   * @return_param role_status 必选 int 角色状态
   */
  async getRoleListAction() {
    const param = this.get();
    let role = this.model('sys_role');
    role._pk = 'role_id';
    let whereParam = {};
    if (param.role_name) {
      whereParam.role_name = param.role_name;
    }
    if (param.role_status) {
      whereParam.role_status = param.role_status;
    }
    let role_list = await role.field('role_id,role_name,role_status,handle_name').where(whereParam).page(parseInt(param.page),parseInt(param.pageSize)).countSelect().catch((err) => {
      console.log(err);
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(role_list)) {
      return this.fail(2007, "Get role list fail");
    }
    this.success(role_list);
  }

  // 获取角色的菜单权限，只获取最后一级权限
  async getRoleMenuAction() {
    const param = this.post();
    let sql = "SELECT m.menu_id,m.parent_id,m.menu_name FROM sys_menu m LEFT JOIN sys_role_menu rm  on  m.menu_id = rm.menu_id WHERE rm.role_id = "+ param.role_id + " and m.menu_id not in (SELECT parent_id from sys_menu a INNER JOIN sys_role_menu b on a.menu_id = b.menu_id WHERE b.role_id=" + param.role_id + ")";
    let menuList = await this.model('sys_role_menu').query(sql).catch((err) => {
      console.log(err);
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(menuList)) {
      return this.fail(2007, "Get role list fail");
    }
    return this.success(menuList);
  }


};
