const Base = require('../base.js');

module.exports = class extends Base {
  /**
   * showdoc
   * @catalog 系统管理/届次管理
   * @title 届次列表
   * @description 届次列表接口
   * @method post
   * @url http://127.0.0.1:8360/sys/sysSession/getSessionList
   * @param sysSession 选填 string 届次名称
   * @return {"errno": 0, "errmsg":"", "data":{"count":1,"totalPages":1,"pageSize":10,"currentPage":1,"data":[{"region":"合肥市","regionID":1,"deptName":"办公室","ddeptNameID":2,"type": 1}]}}
   * @return_param region  string 地区
   * @return_param id  int 届次id
   * @return_param regionID  int 地区id
   * @return_param deptName  string 机构名称
   * @return_param deptNameID  int 机构id
   * @return_param type  int 0代表，1领导
   */
  async getSessionListAction() {
    const param = this.post();
    const userRole = await this.model('sys_user_role').where({role_id:1,user_id:param.userId}).find();
    let whereParam = {}
    //为空不是超级管理员，需要登录者的地区
    if (think.isEmpty(userRole)) {
      const user = await this.model('sys/sys_user').where({user_id: param.userId}).find();
      whereParam.depetNameID = user.org.id
    }
    if (param.sysSession) {
      whereParam['session'] = ['like' + '%' + param.sysSession + '%']
    }
    const sysSession = await this.model('sys_session').where(whereParam).page(param.page,param.pageSize).countSelect();
    return this.success(sysSession);

  }  
  /**
   * showdoc
   * @catalog 系统管理/届次管理
   * @title 添加届次
   * @description 添加届次
   * @method post
   * @url http://127.0.0.1:8360/sys/sysSession/addSession
   * @param region 必选 string 地区
   * @param regionID 必选 int 地区id
   * @param deptName 必选 string 机构名称
   * @param deptNameID 必选 int 机构id
   * @param type 必选 int 0代表，1领导
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async addSessionAction() {
    const param = this.post();
    const res = await this.model('sys_session').add(param);
    return this.success(res);
  }

  /**
   * showdoc
   * @catalog 系统管理/届次管理
   * @title 修改届次
   * @description 修改届次
   * @method post
   * @url http://127.0.0.1:8360/sys/sysSession/editSession
   * @param region 必选 string 地区
   * @param regionID 必选 int 地区id
   * @param id 必选 int 届次id
   * @param deptName 必选 string 机构名称
   * @param deptNameID 必选 int 机构id
   * @param type 必选 int 0代表，1领导
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async editSessionAction() {
    const param = this.post();
    const res = await this.model('sys_session').where({id: param.id}).update(param);
    return this.success(res);
  }

  /**
   * showdoc
   * @catalog 系统管理/届次管理
   * @title 删除届次
   * @description 删除届次
   * @method post
   * @url http://127.0.0.1:8360/sys/sysSession/delSession
   * @param id 必选 int 届次id
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  async delSessionAction() {
    const param = this.post();
    const res = await this.model('sys_session').where({id: param.id}).delete();
    return this.success(res);
  }

}