const Base = require('./../base.js');
const Uid = require('node-uuid');
const moment = require('moment');
const util = require('./../../handle/util');
module.exports = class extends Base {
  indexAction() {
    return this.display();
  }



  /**
   * showdoc
   * @catalog 系统管理/用户管理
   * @title 获取角色树
   * @description 获取角色接口
   * @method get
   * @url http://127.0.0.1:8360/sys/user/getRoleTree
   * @return {"errno": 0, "errmsg":"", "data":[{"role_id":1,"role_name": "管理员管理"}]}
   */
  async getRoleTreeAction() {
    const result = await this.model('sys_role').field('role_id,role_name').where({
      role_status: 1
    }).select().catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(result)) {
      return this.fail(3000, "get roleTree failed")
    }
    return this.success(result)
  }

  /**
   * showdoc
   * @catalog 系统管理/用户管理
   * @title 获取部门
   * @description 获取部门接口
   * @method get
   * @url http://127.0.0.1:8360/sys/user/getDeptTree
   * @return {"errno": 0, "errmsg":"", "data":[{"dictValue":"001","parentValue": "000", "description": "安徽省"}]}
   * @return_param dictValue 部门id
   * @return_param parentValue 部门父级id
   * @return_param description 部门名称
   */
  async getDeptTreeAction() {
    const result = await this.model('dictionary').field('dictValue,parentValue,description').where({
      flag: 1,
      dictID: "DP"
    }).select().catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(result)) {
      return this.fail(3000, "get roleTree failed")
    }
    if (result) {
      const data = this.getDictTree(result, 'dictValue', 'parentValue')
      return this.success(data);
    }
    return this.success(result)
  }

  /**
   * showdoc
   * @catalog 系统管理/用户管理
   * @title 添加用户
   * @description 添加用户接口
   * @method post
   * @url http://127.0.0.1:8360/sys/user/addUser
   * @param user_name 必选 string 用户名
   * @param email 必选 string 邮箱
   * @param password 必选 string 密码
   * @param phone 必选 string 手机号
   * @param name 必选 string 真实姓名
   * @param remark 必选 string 备注
   * @param orgJc 必选 string 机构简称
   * @param deptName 必选 string 函件署名
   * @param deptTitle 必选 string 函件头
   * @param depJc 必选 string 地区简称
   * @param role_ids 必选 array 角色id
   * @param dictValue 必选 string 部门id
   * @param regionAdminNo 必选 string 地区行政编码,(6位)
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  //添加用户
  async addUserAction() {
    const param = this.post();
    param.password = think.md5("123456");
    param.password = "14e1b600b1fd579f47433b88e8d85291";
    param.user_id = think.uuid().split('-').join(''); //获取用户userid
    // //根据dictValue判断等级，type为2是省级，3是市级，4是县级
    let level = await this.model("sys_dept").where({"id":param.dictValue}).find()
    if (level.type) {
      if (level.type === 2) {
        param.deptLevel = 0;
      } else if (level.type === 3) {
        param.deptLevel = 1;
      } else {
        param.deptLevel = 2;
      }
    }
    //判断地区简称是否为空，为空就修改
    if (!think.isEmpty(param.depJc)) {
      const depRes = await this.model('sys_dept').field('jc').where({
        id: param.dictValue
      }).find();
      if (depRes.jc == "") {
        const addJc = await this.model('sys_dept').where({
          id: param.dictValue
        }).update({
          jc: param.depJc
        })
      }
      //删除参数中的地区简称
      delete param.depJc
    }
    //判断机构简称是否为空，为空就添加简称
    if (!think.isEmpty(param.orgJc)) {
      const orgRes = await this.model('sys_organization').field('jc').where({
        id: param.orgID
      }).find();
      if (orgRes.jc == "") {
        const upOrgJc = await this.model('sys_organization').where({
          id: param.orgID
        }).update({
          jc: param.orgJc,
          deptName: param.deptName,
          passTitle: param.passTitle,
          deptTitle: param.deptTitle
        })
      }else {
        // 机构简称不为空，只能设置函件头和函件署名
        const upOrg = await this.model('sys_organization').where({
          id: param.orgID
        }).update({
          // deptName: param.deptName,
          deptTitle: param.title
        })
      }
      //删除机构中的简称参数
      delete param.orgJc
    }
    //添加用户基本信息，用户名不能重复
    const result = await this.model('sys_user').thenAdd(param, {
      user_name: param.user_name
    }).catch(err => {
      console.log(err);
      return think.isError(err) ? err : new Error(err)
    });
    if (think.isError(result)) {
      return this.fail(3001, "Add user failed");
    }
    if (result.type == "exist") {
      return this.fail(3009, "This user_name existed");
    }
    //---------------------为用户添加角色---------------------
    let user_role_param = []; //添加角色参数
    if (param.role_ids.length > 0) {
      param.role_ids.forEach(function (item) {
        user_role_param.push({
          role_id: item,
          user_id: param.user_id
        })
      });
      let user_role_return_data = await this.model('sys_user_role').addMany(user_role_param).catch((err) => {
        console.log(err)
        return think.isError(err) ? err : new Error(err);
      })
      if (think.isError(user_role_return_data)) {
        return this.fail(3002, "Add user-role failed");
      }
    }
    return this.success();
  }

  /**
   * showdoc
   * @catalog 系统管理/用户管理
   * @title 修改用户
   * @description 修改用户接口
   * @method post
   * @url http://127.0.0.1:8360/sys/user/editUser
   * @param user_id 必选 string 用户名uuid
   * @param user_name 必选 string 用户名
   * @param email 必选 string 邮箱
   * @param password 必选 string 密码
   * @param phone 必选 string 手机号
   * @param name 必选 string 真实姓名
   * @param remark 必选 string 备注
   * @param role_ids 必选 array 角色id
   * @param dictValue 必选 string 部门id
   * @param orgJc 必选 string 机构简称
   * @param deptName 必选 string 函件署名
   * @param deptTitle 必选 string 函件头
   * @param depJc 必选 string 地区简称
   * @param regionAdminNo 必选 string 地区行政编码,(6位)
   * @return {"errno": 0, "errmsg":"", "data":[{"role_id":1,"role_name": "管理员管理"}]}
   * @return_param role_id 必选 int 角色id
   * @return_param role_name 必选 string 角色名
   */
  //修改用户
  async editUserAction() {
    let param = this.post();
    // param.update_time = new Date().toLocaleString(); //修改时间
    param.update_time = moment().format('YYYY-MM-DD'); //修改时间
    //根据dictValue判断等级，长度为2是省级，3是市级，4是县级
    let level = await this.model("sys_dept").where({"id":param.dictValue}).find()
    if (level.type) {
        if (level.type === 2) {
          param.deptLevel = 0;
        } else if (level.type === 3) {
          param.deptLevel = 1;
        } else {
          param.deptLevel = 2;
        }
    }
    //判断地区简称是否为空，为空就修改
    if (!think.isEmpty(param.depJc)) {
      const depRes = await this.model('sys_dept').field('jc').where({
        id: param.dictValue
      }).find();
      if (depRes.jc == "") {
        const addJc = await this.model('sys_dept').where({
          id: param.dictValue
        }).update({
          jc: param.depJc
        })
      }
      //删除参数中的地区简称
      delete param.depJc
    }
    //判断机构简称是否为空，为空就添加简称
    if (!think.isEmpty(param.orgJc)) {
      const orgRes = await this.model('sys_organization').field('jc').where({
        id: param.orgID
      }).find();
      if (orgRes.jc == "") {
        const upOrgJc = await this.model('sys_organization').where({
          id: param.orgID
        }).update({
          jc: param.orgJc,
          deptName: param.deptName,
          deptTitle: param.deptTitle
        })
      }else {
        // 机构简称不为空，只能设置函件头和函件署名
        const upOrg = await this.model('sys_organization').where({
          id: param.orgID
        }).update({
          // deptName: param.deptName,
          deptTitle: param.title
        })
      }
      //删除机构中的简称参数
      delete param.orgJc
    }
    //修改用户基本信息
    let result = await this.model('sys_user').where({
      user_id: param.user_id
    }).update(param).catch((err) => {
      console.log(err);
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(result)) {
      return this.fail(3003, 'Update user failed');
    }

    //--------修改用户角色之前先全部删除用户角色，然后重新添加--------------
    //删除用户角色
    let del_user_role_return = await this.model('sys_user_role').where({
      user_id: param.user_id
    }).delete().catch((err) => {
      console.log(err);
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(del_user_role_return)) {
      return this.fail(3004, 'Delete user-role failed');
    }
    if (param.role_ids.length > 0) {
      //添加用户角色
      let user_role_param = [];
      param.role_ids.forEach((item, i) => {
        user_role_param.push({
          user_id: param.user_id,
          role_id: item
        })
      });
      //添加用户角色
      let user_role_return = await this.model('sys_user_role').addMany(user_role_param).catch((err) => {
        console.log(err);
        return think.isError(err) ? err : new Error(err);
      })
      if (think.isError(user_role_return)) {
        return this.fail(3002, 'Add user-role failed');
      }
    }
    return this.success();
  }

  /**
   * showdoc
   * @catalog 系统管理/用户管理
   * @title 删除用户
   * @description 删除用户接口
   * @method post
   * @url http://127.0.0.1:8360/sys/user/delUser
   * @param user_id 必选 string 用户名uuid
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  //删除用户
  async delUserAction() {
    const param = this.post();
    let result = await this.model('sys_user').where({
      user_id: param.user_id
    }).update({
      del_flag: 2
    }).catch((err) => {
      console.log(err);
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(result)) {
      return this.fail(3005, 'Delete user failed');
    }
    return this.success();
  }


  /**
   * showdoc
   * @catalog 系统管理/用户管理
   * @title 获取用户列表
   * @description 获取用户列表接口
   * @method get
   * @url http://127.0.0.1:8360/sys/user/getUserList
   * @param page 必选 int 当前页数
   * @param page_size 必选 int 每页显示条数
   * @return {"errno": 0, "errmsg":"", "data":{"count":1,"totalPages":1,"pageSize":10,"currentPage":1,"data":[{"user_id":"qwedcvfffs2234c","user_name":"admin","email":"3435959119@qq.com","phone":"15031291309","remark": "admin"}]}}
   * @return_param errno  int 错误号，0代表成功
   * @return_param errmsg  string 错误信息
   * @return_param count  int 总条数
   * @return_param totalPages  int 总页数
   * @return_param currentPage  int 当前页
   * @return_param user_id 必选 string 用户名uuid
   * @return_param user_name 必选 string 用户名
   * @return_param email 必选 string 邮箱
   * @return_param password 必选 string 密码
   * @return_param phone 必选 string 手机号
   * @return_param name 必选 string 真实姓名
   * @return_param remark 必选 string 备注
   */
  //获取用户列表
  async getUserListAction() {
    let param = this.post();
    // const user = this.model('sys_user')
    let user = this.model('sys/sys_user');
    let whereParam = {
      del_flag: 1
    }
    if (param.hasOwnProperty("orgID") && param.orgID !== ""){
      whereParam.orgID = param.orgID
    }
    if (param.user_name) {
      whereParam.user_name = param.user_name
    }
    if (param.phone) {
      whereParam.phone = param.phone;
    }
    if (param.name) {
      whereParam.name = param.name;
    }
    if (param.email) {
      whereParam.email = param.email;
    }
    const result = await user.page(parseInt(param.page), parseInt(param.page_size)).where(whereParam).order('add_time desc').countSelect().catch(err => {
      console.log(err);
      return think.isError(err) ? err : new Error(err)
    });

    if (think.isError(result)) {
      return this.fail(3006, "User filter failed");
    }
    return this.success(result);
  }



  /**
   * showdoc
   * @catalog 系统管理/用户管理
   * @title 修改用户密码
   * @description 修改用户密码
   * @method post
   * @url http://127.0.0.1:8360/sys/user/editPw
   * @param user_id 必选 string 用户名uuid
   * @param password 必选 string 密码
   * @return {"errno": 0, "errmsg":"", "data":}
   */
  //修改密码
  async editPwAction() {
    let param = this.post();
    param.password = think.md5(param.password);
    let pw_return = this.model('sys_user').where({
      user_id: param.user_id
    }).update({
      password: param.password
    }).catch((err) => {
      console.log(err);
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(pw_return)) {
      return this.fail(3007, 'Edit user password failed');
    }
    return this.success();
  }

  /**
   * showdoc
   * @catalog 系统管理/用户管理
   * @title 获取某用户的角色
   * @description 获取某用户的角色接口
   * @method post
   * @url http://127.0.0.1:8360/sys/user/getUserRole
   * @param user_id 必选 string 用户名uuid
   * @return {"errno": 0, "errmsg":"", "data":[{"role_id":1, "role_name":"后台管理员"}]}
   * @return_param role_id 必选 int 角色id
   * @return_param role_name 必选 string 角色名称
   */
  async getUserRoleAction() {
    const param = this.post();
    let role_list = await this.model('sys_user_role').join('sys_role on sys_role.role_id= sys_user_role.role_id').field('sys_role.role_id,sys_role.role_name').where('sys_user_role.user_id="' + param.user_id + '" and sys_role.role_status=1').select().catch((err) => {
      console.log(err);
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(role_list)) {
      return this.fail(3009, 'Get user role failed');
    }
    return this.success(role_list);
  }

  // 当前用户身份证所属地区，用于统计下去信访人户籍
  async getIdCardRegionAction(){
    //取字典DQ，当前用户本级和下级
    const param = this.post();
    let user = await this.model("sys_user").join("sys_dept on sys_user.dictValue = sys_dept.id").field('sys_dept.type,sys_dept.deptName').where({"sys_user.user_id":param.userId}).select();
    let dict = await this.model('dictionary').where({"dictID":'DQ',"flag":1,"description":user[0].deptName}).select();
    // let where = "dictID = 'DQ' and flag = 1 and (LENGTH(dictValue) = "+user[0].type*3+" or LENGTH(dictValue) = "+(user[0].type+1)*3+")";
    let where = {"dictID":'DQ',"flag":1,_complex: {"dictValue": dict[0].dictValue,
      "parentValue": dict[0].dictValue,
      _logic: 'or'}};
    const back = await this.model('dictionary').where(where).order('IFNULL(orderNum, 9999) ASC').select();
    let tree = [];
    let data = {};
    for (const i in back) {
      const dataKey = back[i]['dictValue'];
      data[dataKey] = back[i];
    }
    for (const j in back) {
      const bval = back[j];
      const dataP = data[bval['parentValue']];
      if (dataP) {
        if (!dataP.children) {
          dataP.children = [];
        }
        dataP.children.push(bval);
      } else {
        tree.push(bval);
      }
    }
    return this.success(tree);
  }
  async getMailListAction(){
    let mail = await this.model("sys_user").join("sys_organization as so on sys_user.orgID = so.id")
      .where({"del_flag":1,"status":1,"orgId":["!=",null]}).field("name,phone,mobilePhone,orgID,so.orgName").order("so.id").select();
    let group = util.groupTreeByParam(mail,"orgName");
    return this.success(group)
  }

};
