const Base = require('../base.js');

module.exports = class extends Base {
  //行政区域列表
  async getAdminZoneListAction() {
    const param = this.post();
    let whereParam = {}
    if (param.adminName) {
      whereParam.deptName = ['like', '%' + param.adminName + '%'];
    }
    let res = await this.model('sys_dept').where(whereParam).select();
    let finaRes = []
    if (res.length > 0) {
      finaRes = this.getDictTree(res, 'id', 'parentID')
    }
    return this.success(finaRes);
  }

  async addAdminZoneAction() {
    let param = this.post();
    let ancestors = param.ancestors.split(',')
    param.type = ancestors.length;
    const res = this.model('sys_dept').add(param);
    return this.success(res);
  }

  async editAdminZoneAction() {
    let param = this.post();
    let ancestors = param.ancestors.split(',')
    param.type = ancestors.length;
    const res = this.model('sys_dept').where({
      id: param.id
    }).update(param);
    return this.success(res);
  }

  async delZoneAction() {
    const param = this.post();
    let res = await this.model('sys_dept').where({
      id: param.id
    }).delete();
    let sql = "select id from sys_dept where find_in_set('" + param.id.toString() + "', ancestors)"
    //查询要删除数据下的所有子集
    let delIds = await this.model('sys_dept').query(sql);
    if (delIds.length > 0) {
      let ids = []
      delIds.forEach((item) => {
        ids.push(item.id)
      })
      //删除所有子集
      let deptREs = await this.model('sys_dept').where({
        id: ['in', ids.join(',')]
      }).delete();
      //删除已删除地区的所有机构
      ids.push(param.id)
      let orgRes = await this.model('sys_organization').where({
        deptID: ['in', ids.join(',')]
      }).delete();
    }
    return this.success(res);
  }
  // 根据当前用户地区，
  // 如果当前是‘区’一级，本区
  // 如果当前是‘市’一级,‘本市’和本市下面的‘区’
  // 如果是‘省’一级，返回‘本省’，和省下面的‘市’
  async getZoneAction() {
    const param = this.get();
    const userId = param.user_id;
    //获取用户地区信息
    let return_data = await this.model('sys/sys_user').where({
      user_id: userId,
      del_flag: 1
    }).find();
    if (!return_data) {
      return this.fail(1029, '不存在该用户')
    }
    let data = {};
    let zone = return_data.zone;
    if (param.hasOwnProperty("isOut") && param.isOut==='1'){
      data = await this.model('sys_dept').where({"type": zone.type,"id":['!=',zone.id]}).select();
      return this.success(data)
    }
    // //判断地区是那个级别
    // if (zone.type === 4){// 县
    //   data = zone
    // } else {//省、市
    //   let children = await this.model('sys_dept').where({parentID: zone.id}).select();
    //   data = zone;
    //   data['children'] = children
    // }
      let children = await this.model('sys_dept').where({parentID: zone.id}).select();
      data = zone;
      data['children'] = children
    return this.success(data)

  }
  // 根据当前用户所在地区和所选地区比较
  // 相同，返回选中地区机构，不同，返回选中地区人大
  async getOrgAction() {
    let userId = this.get().user_id;
    let zone_id = parseInt(this.get().zone_id);
    //获取用户的地区
    let return_data = await this.model('sys/sys_user').where({
      user_id: userId,
      del_flag: 1
    }).find();
    if (!return_data) {
      return this.fail(1029, '不存在该用户')
    }
    if (this.get().hasOwnProperty("handleModelID") && this.get().handleModelID.substr(3,3) === "006"){//办理方式为 自办
      let org = await this.model('sys_organization').where({"id":return_data.orgID}).select()
      return this.success(org);
    }
    let zone = return_data.zone;
    let data = [];
    if (zone.id === zone_id) {//登记单位与当前操作单位地区相同
      data = await this.model('sys_organization').where({
        deptID: zone_id
      }).select();
    } else {
      let where = {
        deptID: zone_id,
        // orgName: ['like', '%人大常委会%']
        isRenDa: 1
      };
      if (this.get().hasOwnProperty("handleModelID") && this.get().handleModelID.substr(3,3) === "003") {// 转办
        where["agent"] = 1;
      }
      data = await this.model('sys_organization').where(where).select();
    }
    return this.success(data);
  }
  // 获取地区字典列表
  async getZoneListAction() {
    let where = {
      "type":this.post().isAll === 1 ? ["!=",null] : ["!=",5]//isAll 1全显示
    }
    let back = await this.model('sys_dept').where(where).order('IFNULL(orderNum, 99999) ASC').select();
    let tree = [];
    let data = {};
    for (const i in back) {
      const dataKey = back[i]['id'];
      data[dataKey] = back[i];
    }
    for (const j in back) {
      const bval = back[j];
      const dataP = data[bval['parentID']];
      if (dataP) {
        if (!dataP.children) {
          dataP.children = [];
        }
        dataP.children.push(bval);
      } else {
        tree.push(bval);
      }
    }
    return this.success(tree)
  }
  // 通过地区id获取地区详情
  async getZoneDetailAction() {
    const data = this.post();
    let back = await this.model('sys_dept').where({"id":data.id}).find();
    return this.success(back)
  }
  // 获取当前用户所辖地区
  async getJurisdictionAction(){
    let data = this.post();
    let userInfo = await this.getUserInfo(data.userid); // 获取用户信息
    let level = {};
    let back = {};
    if (userInfo.deptLevel === 0) {//省级
      let str = parseInt(Math.random()**(9999-1001) + 1000);// 生成一个4位随机数
      back = {
        'id':parseInt(str + userInfo.dictValue.toString()),
        'deptName':userInfo.deptName,
        'children':[],
      };
      let children1 = await this.model('sys_dept').where({'parentID':userInfo.dictValue}).order('IFNULL(orderNum, 99999) ASC').select();
      children1.forEach(function(item) {
        // push 市
        back.children.push({
          'id':parseInt(str + item.id.toString()),
          'deptName':item.deptName,
          'children':[
            {
              'id':item.id,
              'deptName':'仅'+item.deptName,
            }
          ]
        })
      });
      // 处理县
      for (let c of back.children) {
        if (c.children){
          let children2 = await this.model('sys_dept').where({'parentID':c.children[0].id}).order('IFNULL(orderNum, 99999) ASC').select();
          children2.forEach(function(items) {
            c.children.push({
              'id':items.id,
              'deptName':items.deptName,
            })
          })
        }
      }

      level['higherLevel'] = [];//  上级全国不表
      level['lowerLevel'] = back;// 下级
      level['sameLevel'] = {
        'id':userInfo.dictValue,
        'deptName':userInfo.deptName,
      };// 本级
    } else if (userInfo.deptLevel === 1){ //市级
      let str = parseInt(Math.random()**(9999-1001) + 1000);// 生成一个4位随机数
      back = {
        'id':parseInt(str + userInfo.dictValue.toString()),
        'deptName':userInfo.deptName,
        'children':[],
      };
      let children = await this.model('sys_dept').where({'parentID':userInfo.dictValue}).order('IFNULL(orderNum, 99999) ASC').select();
      children.forEach(function(item) {
        // push 县
        back.children.push({
          'id':item.id,
          'deptName':item.deptName,
        })
      });
      level['higherLevel'] = [{
        'id':2,
        'deptName':'安徽省',
      }];// 上级
      level['lowerLevel'] = back;// 下级
      level['sameLevel'] = {
        'id':userInfo.dictValue,
        'deptName':userInfo.deptName,
      };// 本级
    } else {
      // 只有本县
      let sql = 'SELECT * FROM sys_dept WHERE id = (SELECT parentID FROM sys_dept WHERE id = '+ userInfo.dictValue +')'
      let parent = await this.model('sys_dept').query(sql);
      // back = {
      //   'id':userInfo.dictValue,
      //   'deptName':userInfo.deptName,
      //   // 'children':[
      //   //   {
      //   //     'id':userInfo.dictValue,
      //   //     'deptName':'仅'+userInfo.deptName,
      //   //   }
      //   // ],
      // };
      level['higherLevel'] = [
        {
          'id':2,
          'deptName':'安徽省',
        },
        {
          'id':parent.id,
          'deptName':parent.deptName,
        }
      ];// 上级
      level['lowerLevel'] = {};// 没有下级
      level['sameLevel'] = {
        'id':userInfo.dictValue,
        'deptName':userInfo.deptName,
      };// 本级
    }
    return this.success(level)
  }
}
