const Base = require('./base.js');
const upload = require('./../handle/uploadFile');
const Check = require('./../handle/check');
const path = require('path');
const os = require('os');
const fs = require('fs');
const util = require('./../handle/util');
const Template = require('./../handle/template');
const moment = require('moment');

module.exports = class extends Base {
  indexAction() {
    return this.display();
  }
  /**
   * showdoc
   * @catalog 流程操作
   * @title 上传函件
   * @description 上传函件form-data接口
   * @method post
   * @url http://127.0.0.1:8360/taskFlow/uploadLetters
   * @param userId 必选 string userId
   * @param taskId 必选 string 流程id
   * @param file 必选 file 文件key为file
   * @param info 必选 object 业务json
   * @param letter 必选 string 函件地址字段
   * @param info.letterCode 必选 string 函件编号字段
   * @return {"errno": 0, "errmsg":""}
   */
  // 上传函件
  async uploadLettersAction(){
    const file = this.file().file; // file 文件
    const data = this.post(); // post其他参数
    // console.log(file)
    // console.log(data)
    // 上传文件
    //获取后缀
    let fileType = file.name.substr( file.name.lastIndexOf(".") + 1);
    // 认可的文件类型
    // let arr = ['doc','docx','jpg','png','jpeg','pdf','zip','rar','jpg'];
    // if(arr.toString().indexOf(fileType.toLowerCase()) === -1) { // 字符串转为小写比较
    let arr = ['application/msword',// doc
      'application/vnd.openxmlformats-officedocument.wordprocessingml.document',// docx
      'image/jpeg',// jpeg
      'image/png',//png
      'application/pdf',//pdf
      'application/zip',// zip
      'application/x-zip',// zip
      'application/x-zip-compressed',// zip
      'application/x-rar-compressed',// rar
      'application/octet-stream'// 其他不可识别
    ];
    if(arr.indexOf(file.type.toLowerCase()) === -1) { // 字符串转为小写比较
      return this.fail("文件类型不支持！")
    }
    if (file.size > 50*1024*1024) {
      return this.fail("文件大小超过限制！")
    }
    //创建路径
    // let filePath = path.join(think.ROOT_PATH, '/www/static', fileType);
    let filePath = path.join(think.ROOT_PATH, '/www/static', moment().format('YYYY年')+'/'+moment().format('M月')+'/'+fileType);
    upload.mkdirsSync(filePath);// 创建文件夹（如果需要）
    let fileName = Math.random().toString(16).substr(2) + '.' + fileType;// 文件名称
    let _uploadFilePath = path.join(filePath, fileName);
    let saveTo = path.join(_uploadFilePath);
    const reader = fs.createReadStream(file.path);// 读取文件
    // 文件保存到指定路径
    reader.pipe(fs.createWriteStream(saveTo));
    // 在文件上传日志中保存记录
    let userInfo = await this.getUserInfo(data.userId);
    let log = {
      // "name":file.name,
      "name":moment().format('YYYY年M月D日') + userInfo.orgName + ((data.businessID === 3 || data.businessID === 5) ? "交办函" : (data.businessID === 10 ? "劝返单" : "转交单")),
      "random":fileName,
      // "url":'/static/'+ fileType + '/' + fileName,
      "url":'/static/'+ moment().format('YYYY年')+'/'+moment().format('M月')+'/'+ fileType + '/' + fileName,
      "fileType":fileType,
      "userId":data.userId
    };
    await this.model('file_log').add(log);
    // 在matter中更新最新letter地址
    // await this.model('matter').where({'taskid':data.taskId}).update({"letter":'/static/'+ fileType + '/' + fileName});
    await this.model('matter').where({'taskid':data.taskId}).update({"letter":log.url});
    // return ('/static/'+ fileType + '/' + fileName) // 路径
    // 在函号查询表中，更新函件地址
    if (data.hasOwnProperty('code')) {
      await this.model('letters_num_query').where({"letterNum":data.code}).update({'fileUrl':log.url});
    }
    // // 推进流程
    // let param = {
    //   'userId':data.userId,
    //   'taskId':data.taskId
    // };
    // let nextActID =  await httpRequest('post','http://localhost:8360/flow/service/taskForward',param);
    // if (nextActID.errno !== 0 ){
    //   return this.fail(nextActID);
    // }
    // // 更新节点
    // const update = {
    //   'nextActID':nextActID.data.nextActid,
    //   'updateTime':moment().format('YYYY-MM-DD HH:mm:ss'),
    //   'info':data.info,// string 不用转
    // };
    // await this.model('node_record').where({'taskId':data.taskId,'nextActID':null}).update(update);
    // // 插入节点表 和历史表
    // let nodeAdd = {
    //   'taskId':data.taskId,
    //   'actID':nextActID.nextActid,
    //   'nextActID':null,
    //   'userId':data.userId,
    //   'time':moment().format('YYYY-MM-DD HH:mm:ss'),
    //   'account':userInfo.user_name,
    //   'deptName':userInfo.orgName,
    //   'deptID':userInfo.orgID,
    //   'info':data.info,// string 不用转
    // };
    // await this.model('node_record').add(nodeAdd);// 节点表
    // await this.model('history').add(nodeAdd);// 历史表
    // return this.success('/static/'+ fileType + '/' + fileName)
    return this.success(log.url)
  }
  /**
   * showdoc
   * @catalog 流程操作
   * @title 生成函件、转送单
   * @description 生成函件、转送单接口
   * @method post
   * @url http://127.0.0.1:8360/taskFlow/createLetters
   * @param userId 必选 string userId
   * @param taskId 必选 string 流程id
   * @param matterID 必选 string 事项id
   * @param isRD 必选 int 是否人大自办0否，1是
   * @param info 必选 object 业务json
   * @param info.letter 必选 string 函件地址字段
   * @param info.letterCode 必选 string 函件编号字段
   * @return {"errno": 0, "errmsg":""}
   */
  // 生成函件、转送单
  async createLettersAction(){
    const data = this.post();
    const matter = await this.model('matter').join('fw_task on fw_task.id = matter.taskid').where({'matter.id':data.matterID})
      .field('matter.*,fw_task.dealType_pre').find();
    const userInfo = await this.getUserInfo(data.userId);
    // if (matter.handleModelID.substr(3,6) === '003001'){
    if (matter.dealType_pre=== '交办'){
      // 获取函件模板 // isRD默认为0
      // const temp = await Template.getTemplateAndReplace(data.matterID,data.isRD,data.userId);
      let temp = {};
      let template = {
        'title': userInfo.deptTitle,// 自行设置的函件标题
        // 'finalDisposal': matter.finalZone + matter.finalDisposal,// 去向单位 地区+单位
        // 'host': userInfo.deptName + userInfo.orgName, // 署名
        'host':userInfo.orgName + "信访办公室", // 署名
        'letterCode': '',
        'time': moment().format('YYYY年M月D日'),
        'phone':userInfo.phone === null ? "" :userInfo.phone
      };
      if (matter.isMeeting === 0 && userInfo.orgID === 40){
        // 判断为大会版
        let jie = userInfo.meetingSession.substr(userInfo.meetingSession.indexOf('届')-2,2);
        let ci = userInfo.meetingSession.substr(userInfo.meetingSession.indexOf('次')-1,1);
        temp['titleColor'] = 'red';
        temp['finalDisposal'] = matter.finalDisposal;
        let dbx = '信访人'; // 信访人或代表
        let fkdb = '';// 反馈代表
        if (matter.activity.xfSourceID == '001003' || matter.activity.xfSourceID == "002003") { // 代表转信转访
          fkdb = '、反馈代表'
        }
        if (matter.activity.xfSourceID === "001004" || matter.activity.xfSourceID === "002006"){ //代表来信来访
          dbx = '代表';
        }
        temp['text'] = matter.activity.person.name + '来省' + jie + '届人大' + ci + '次会议上访（来信），反映' + matter.abstract +
          String.fromCharCode(10)+'经大会信访组研究并报领导批准，现将信访人反映的问题转贵单位，请按相关法律法规、政策规定办理。办理结果答复'
          + dbx + fkdb + '，并于'+ moment().add(60,'day').format('YYYY年M月D日') + '前函告我们。';
        temp['rider'] = '附：信访材料（含联系方式）';
        template.title = '安徽省第' + jie + '届人民代表大会第' + ci +'次会议信访处理函';
        template.host = '省' + jie +'届人大'+ ci +'次会议秘书处信访组';
      }else {
        // 重写后的模板调用
        temp = await Template.getLettersTemplate(data.matterID,data.isRD,data.userId);
      }
      // if (think.isEmpty(temp)){
      if (temp.hasOwnProperty('code') && temp.code === 1){
        // 获取模板失败
        template['titleColor'] = 'red';
        template['text'] = '（未匹配到可用函件模板，以下内容仅供参考！）' + temp.text;
        template['rider'] = '附件：信访材料（含联系方式）';
        template['finalDisposal'] = temp.finalDisposal;
        return this.success(template);
      } else {
        template['titleColor'] = temp.titleColor;
        template['finalDisposal'] = temp.finalDisposal;
        template['text'] = temp.text;
        template['rider'] = temp.rider;
        return this.success(template)
      }
    // }else if (matter.handleModel === '转送') {
    // }else if (matter.handleModelID.substr(3,6) === '003002') {
    }else if (matter.dealType_pre === '转送' || matter.dealType_pre === '转交') {
       // 生成转送单
      let temp;
      let template = {
        // 'title': userInfo.deptName + "人民代表大会常务委员会信访事项转送单",// 自行设置的函件标题
        'title': userInfo.passTitle,// 自行设置的函件标题
        // 'finalDisposal': matter.finalZone + matter.finalDisposal,// 去向单位 地区+单位
        // 'host': userInfo.deptName + userInfo.orgName, // 署名
        'host':userInfo.orgName + "信访办公室", // 署名
        'letterCode': '',
        'time': moment().format('YYYY年M月D日'),
        'phone':userInfo.phone === null ? "" :userInfo.phone
      }
      if (matter.isMeeting === 0 && userInfo.orgID === 40){
        // 判断为大会版 转送单
        let jie = userInfo.meetingSession.substr(userInfo.meetingSession.indexOf('届')-2,2);
        let ci = userInfo.meetingSession.substr(userInfo.meetingSession.indexOf('次')-1,1);
        temp = await Template.getDHPassTemplate(data.matterID);
        template.title = '安徽省第' + jie + '届人民代表大会第' + ci +'次会议信访事项转送单';
        template.host = '安徽省' + jie +'届人大'+ ci +'次会议秘书处信访组';
      } else {
        temp = await Template.getPassTemplate(data.matterID,data.isRD);
      }
      // const temp = await Template.getPassTemplate(data.matterID,data.isRD);
      // let template = {
      //   // 'title': userInfo.deptName + "人民代表大会常务委员会信访事项转送单",// 自行设置的函件标题
      //   'title': userInfo.passTitle,// 自行设置的函件标题
      //   // 'finalDisposal': matter.finalZone + matter.finalDisposal,// 去向单位 地区+单位
      //   // 'host': userInfo.deptName + userInfo.orgName, // 署名
      //   'host':userInfo.orgName + "信访办公室", // 署名
      //   'letterCode': '',
      //   'time': moment().format('YYYY年M月D日'),
      //   'phone':userInfo.phone
      // };

      // if (think.isEmpty(temp)){
      if (temp.hasOwnProperty('code') && temp.code === 1){
        // 模板获取失败
        template['titleColor'] = "black";
        template['text'] = '（未匹配到可用转送单模板，以下内容仅供参考！）' + temp.text;
        template['rider'] = '附件：信访材料（含联系方式）';
        template['finalDisposal'] = temp.finalDisposal;
        return this.success(template)
      }else {
        template['titleColor'] = temp.titleColor;
        template['text'] = temp.text;
        template['rider'] = temp.rider;
        template['finalDisposal'] = temp.finalDisposal;
        return this.success(template)
      }
    }else {
      return this.fail('办理方式不支持')
    }
  }
  /**
   * showdoc
   * @catalog 流程操作
   * @title 生成函件编号
   * @description 生成函件编号接口
   * @method post
   * @url http://127.0.0.1:8360/taskFlow/createNum
   * @param userId 必选 string userId
   * @param taskId 必选 string 流程id
   * @return {"errno": 0, "errmsg":""}
   */
  // 生成函件编号
  async createNumAction(){
    const data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    // 查询当前节点，函件有没有编号
    // 如果有，返回编号
    // 如果没有，生成编号，返回编号，并把编号保存到节点表
    // const record = await this.model('node_record').where({'taskId':data.taskId,'nextActID':null}).order('time DESC').limit(1).find();
    //******************************
    // const recordList = await this.model('node_record').where({'taskId':data.taskId,'nextActID':null}).order('time DESC').select();

    // nextActID只有最近的一条为null，应当去找最近有letterCode记录，判断是不是本单位函件
    const recordList = await this.model('node_record').where({'taskId':data.taskId}).order('time DESC').select();
    if (think.isEmpty(recordList)) {
      return this.fail("节点错误");
    }else {
      let record = recordList[0];// 默认取最近一条
      for (let r of recordList){
        let infoR = JSON.parse(r.info);
        if (infoR.hasOwnProperty("letterCode")) {
          //最近一条节点有编号
          record = r;//取最近一条有编号的，跳出
          break;
        }
      }
      let jcLength = (userInfo.depJc === null || typeof userInfo.depJc === 'undefined') ? 1 : userInfo.depJc.length;
      if (record.info === null ){
        return this.fail("节点错误");
      }else if ( JSON.parse(record.info).hasOwnProperty('letterCode') && JSON.parse(record.info).letterCode.substr(0,jcLength) === userInfo.depJc){
        // 有编号,且是本单位编号，返回编号
        this.success({'code':JSON.parse(record.info).letterCode});
      }else if ( !JSON.parse(record.info).hasOwnProperty('letterCode') || JSON.parse(record.info).letterCode.substr(0,jcLength) !== userInfo.depJc){
        // 没有编号或者编号不是本单位，生成新编号，并返回
        let code;
        let matter = await this.model('matter').where({'taskid':data.taskId,'isMeeting':0}).find();
        if (!think.isEmpty(matter) && userInfo.orgID === 40){
          // 大会版函件
          code = await util.letterNum(userInfo.depJc,userInfo.orgJc,'信字',userInfo.orgID);
          // 插入函件函号查询表
          await util.letterQuery(code,'信字',userInfo,data.taskId)
        } else {
          code = await util.letterNum(userInfo.depJc,userInfo.orgJc,'信函字',userInfo.orgID);
          // 插入函件函号查询表
          await util.letterQuery(code,'信函字',userInfo,data.taskId)
        }
        // const code = await util..(userInfo.depJc,userInfo.orgJc,'信函字');
        // 更新节点
        let info = JSON.parse(record.info);
        info['letterCode'] = code; // 给info赋letterCode
        const update = {
          'updateTime':moment().format('YYYY-MM-DD HH:mm:ss'),
          'info':JSON.stringify(info),
        };
        await this.model('node_record').where({'taskId':data.taskId,'nextActID':null}).update(update); // 更新节点
        this.success({'code':code});
      }else {
        return this.fail("节点错误");
      }
    }
    //******************************
    // if (think.isEmpty(record) || record.info === null ){
    //   return this.fail("节点错误");
    // }else if ( JSON.parse(record.info).hasOwnProperty('letterCode')){
    //   // 有编号，返回编号
    //   this.success({'code':JSON.parse(record.info).letterCode});
    // }else if ( !JSON.parse(record.info).hasOwnProperty('letterCode')){
    //   // 没有编号，生成新编号，并返回
    //   let code;
    //   let matter = await this.model('matter').where({'taskid':data.taskId,'isMeeting':0}).find();
    //   if (!think.isEmpty(matter) && userInfo.orgID === 40){
    //     // 大会版函件
    //     code = await util.letterNum(userInfo.depJc,userInfo.orgJc,'信字');
    //     // 插入函件函号查询表
    //     await util.letterQuery(code,'信字',userInfo,data.taskId)
    //   } else {
    //     code = await util.letterNum(userInfo.depJc,userInfo.orgJc,'信函字');
    //     // 插入函件函号查询表
    //     await util.letterQuery(code,'信函字',userInfo,data.taskId)
    //   }
    //   // const code = await util..(userInfo.depJc,userInfo.orgJc,'信函字');
    //   // 更新节点
    //   let info = JSON.parse(record.info);
    //   info['letterCode'] = code; // 给info赋letterCode
    //   const update = {
    //     'updateTime':moment().format('YYYY-MM-DD HH:mm:ss'),
    //     'info':JSON.stringify(info),
    //   };
    //   await this.model('node_record').where({'taskId':data.taskId,'nextActID':null}).update(update); // 更新节点
    //   this.success({'code':code});
    // }else {
    //   return this.fail("节点错误");
    // }
  }
  /**
   * showdoc
   * @catalog 流程操作
   * @title 推进节点
   * @description 推进节点接口
   * @method post
   * @url http://127.0.0.1:8360/taskFlow/forward
   * @param userId 必选 string userId
   * @param taskId 必选 string 流程id
   * @param forward 必选 int 前进0后退1
   * @param info 必选 object 业务json
   * @param dealType_pre 可选 string 预办理方式
   * @param deptID_pre 可选 string 预流转部门ID
   * @param deptName_pre 可选 string 预流转部门名称
   * @return {"errno": 0, "errmsg":""}
   */
  // 推进节点
  async forwardAction(){
    let data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    // 更新当前节点信息，插入下一节点，在历史表插入一条跟节点表一样的数据
    // regionLevel_pre预转送行政级别 通过deptID_pre预流转部门ID查询判断
    let param = {
      'userId':data.userId,
      'taskId':data.taskId
    };
    if (data.hasOwnProperty('businessID')){
      param['businessId'] = data.businessID;
      if (data.forward === 0) {
        // 在审批通过的情况下
        if (data.businessID === 2) {
          // 登记审批通过，去验证是否有异常情况，如果有，插入异常列表
          await util.abnormal(data.taskId);
        }
        switch (data.businessID) {
          case 2: //登记审批通过
          case 32://办理审批通过
          case 20://上级接回报审核通过
            // 发送短信
            let matter = await this.model('matter').setRelation(false).where({"taskid":data.taskId}).find();
            await httpRequest('post','http://localhost:8360/msg/msg/sendTellMsg',{"matterID":matter.id});
            break;
          case 37://自办审批
            let m = await this.model('matter').setRelation(false).where({"taskid":data.taskId}).find();
            if (m.createOrgID === userInfo.orgID){
              //本级自办，发送短信
              await httpRequest('post','http://localhost:8360/msg/msg/sendTellMsg',{"matterID":m.id});
            }
            break;
          //   // 3.15测试
          // case 32: //上级信访件待办理审批通过
          //   // 发送短信
          //   break;
          // case 16: //签收审批通过
          //   // 发送短信
          //   break;
          // case 20: //上级接回报审核通过
          //   // 发送短信
          //   break;
        }
      }
    }
    let nextActID;
    if (data.forward === 0){//前进
      if (data.businessID === 24 ) {//登记审核未通过修改
        // 如果改变去向单位
        let matter = await this.model('matter').setRelation(false).alias('m').field('m.*, sd.type as deptType')
          .join({table:'sys_dept', join:'left', on:['finalZoneID', 'id'],as:'sd'}).where({"m.taskid":data.taskId}).find();
        let task = await this.model('fw_task').where({"id":data.taskId}).find();
        if (matter.finalDisposalID !== task.deptID_pre){
          let taskUp = {
            "regionLevel_pre":matter.deptType === 2 ? '省级' : (matter.deptType === 3 ? '市级': '县级') , //预转送行政级别
            "deptID_pre":matter.finalDisposalID, //预流转部门ID
            "deptName_pre":matter.finalDisposal, //预流转部门名称
          }
          await this.model('fw_task').where({"id":data.taskId}).update(taskUp);
        }
      }
      if (data.businessID === 34){ // 接谈叫号
        // 判断同一活动的其他事项有没有被叫号或者在接谈中，因为不能同时叫同一个人
        let m = await this.model('matter').join('activity on activity.id = matter.activityID').where({'matter.taskid':data.taskId}).select();
        let fw_t = [];
        m.forEach(function(item) {
          if (item.taskid !== data.taskId) {
            fw_t.push(item.taskid);
          }
        });
        if (fw_t.length > 0){
          let fw = await this.model('fw_task').where({'id':['IN',fw_t],'businessID':35}).select();
          if (!think.isEmpty(fw)) {
            return this.fail('该信访人正在其他接谈室接谈，请稍后叫号！')
          }
        }
        // 一个接谈室最多只能同时接谈2个人，有2人时不能叫号
        let queueCount = await this.model('queue').join('matter on matter.id = queue.matterID')
          .join('fw_task on fw_task.id = matter.taskid').join('meeting_room on meeting_room.id = queue.roomID')
          .where({'fw_task.businessID':35,'meeting_room.roomOrgID':userInfo.orgID}).count();
        if (queueCount >= 2){
          return this.fail('请先完成当前接谈工作再叫号！')
        }
        // 大会初始化接谈处理单
        await util.addTalkingHandle(data.taskId,data.queueId);
      }
      if (data.businessID === 35){          // 接谈处理
        // 插入接谈记录单
        let matter = await this.model('matter').where({'taskid':data.taskId}).find()
        let recordAdd = {
          "userId":data.userId,
          "userName":userInfo.name,
          "meetingID":matter.meetingID,
          "activityID":matter.activityID,
          "matterID":matter.id,
          "deptID":data.deptID,
          "orgID":data.orgID,
          "orgName":data.orgName,
          "isAbnormal":data.isAbnormal,
          "abnormal":data.abnormal,
          "talkContent":data.talkContent,
          "beforeMood":data.beforeMood,
          "beforeMoodID":data.beforeMoodID,
          "beforeMoodState":data.beforeMoodState,
          "afterMood":data.afterMood,
          "afterMoodID":data.afterMoodID,
          "afterMoodState":data.afterMoodState,
          "talkingHandle":data.talkingHandle,
          "talkingHandleID":data.talkingHandleID,
          "queueID":data.queueId
        };
        let record = await think.model('talking_record').add(recordAdd);
        // 更新接谈处理单
        let up = {
          "endTalkingTime":moment().format('YYYY-MM-DD HH:mm:ss'),
          "talkingRecordID":record,
          "talkContent":data.talkContent,
          "talkingUserId":data.userId,
          "talkingUserName":userInfo.name,
          "talkingHandle":data.talkingHandle,
          "talkingHandleID":data.talkingHandleID
        };
        await this.model('talking_handle').where({'queueID':data.queueId}).update(up)
      }
      // 选定办理方式
      if (data.businessID === 21) {
        let matter = await this.model('matter').setRelation(false).where({'taskid':data.taskId}).find()
        let handleLog = {
          "matterID":matter.id,
          "belongs":data.belongs,
          "belongsID":data.belongsID,
          "finalDisposal":data.finalDisposal,
          "finalDisposalID":data.finalDisposalID,
          "createUserID":data.userId,
          "createUserName":userInfo.name,
          "createOrgID":userInfo.orgID,
          "createOrgName":userInfo.orgName,
          "finalZone":data.finalZone,
          "finalZoneID":data.finalZoneID,
          "handleModel":data.handleModel,
          "handleModelID":data.handleModelID,
          "departmentID":data.departmentID,
          "department":data.department,
          "deptZone":data.deptZone,
          "deptZoneID":data.deptZoneID,
          "deptLevel":data.deptLevel,
          "happenRegion":data.happenRegion,
          "happenRegionID":data.happenRegionID,
          "happenAddress":data.happenAddress,
          "isAccept":data.isAccept,
          "isAcceptPerson":data.isAcceptPerson,
          "isAnswer":data.isAnswer
        };
        //插入办理方式记录
        await this.model('handle_log').add(handleLog);
      }
      if (data.hasOwnProperty('deptID_pre') && data.deptID_pre !== "") {
        const regionLevel = await this.model('sys_organization').alias('so').field('sd.type as deptType, so.isRenDa as isRenDa')
          .join({table:'sys_dept', join:'left', on:['deptID', 'id'],as:'sd'}).where({'so.id':data.deptID_pre}).find();
        if (think.isEmpty(regionLevel)){
          return this.fail(1500,"预转送行政级别错误")
        }
        const regionLevel_pre = regionLevel.deptType === 2 ? '省级' : (regionLevel.deptType === 3 ? '市级': '县级'); //预转送行政级别
        if ((data.dealType_pre === "转送" ||data.handleModel === "转送")&& data.hasOwnProperty('isAnswer') && data.isAnswer === 1){
          param['dealType_pre'] = "转交";//预办理方式
        }else {
          param['dealType_pre'] = typeof data.dealType_pre === 'undefined' ? data.handleModel : data.dealType_pre;//预办理方式
        }
        param['deptID_pre'] = data.deptID_pre;//预流转部门ID
        param['deptName_pre'] = data.deptName_pre;//预流转部门名称
        param['regionLevel_pre'] = (data.businessID === 33 || (data.businessID === 36 && data.handleModel === '省直机关接谈'))? "大会" : regionLevel_pre;//预转送行政级别 // 大会版部分流程特殊处理
        // 向info中增加参数
        param['isRenDa'] = regionLevel.isRenDa;//是否人大机构 生成函件时用到
        data.info['param'] = param;
        if (data.businessID === 36){
          // 大会版 分类处理状态，去更新matter表
          //finalZone finalZoneID 去向单位地区 handleModel办理方式 finalDisposal去向单位
          // 当handleModel为‘省直机关接谈’handleModelID前端不会传
          let upMatter = {
            'finalZone': regionLevel.deptName,
            'finalZoneID': regionLevel.deptID,//去向单位地区
            'handleModel': data.handleModel,//办理离方式
            'handleModelID': typeof data.handleModelID === 'undefined' ? "005" : data.handleModelID,//省直机关接谈
            'finalDisposalID':data.deptID_pre, //去向单位ID
            'finalDisposal':data.deptName_pre //去向单位
          };
          if (data.hasOwnProperty('isAnswer') && data.isAnswer === 1){
            upMatter['handleModel'] = '转交';
            upMatter['isAnswer'] = 1
          }
          if (data.hasOwnProperty('isOut') && data.isOut === 1){
            upMatter['isOut'] = 1
          }
          // 更新matter表
          await this.model('matter').where({'taskid':data.taskId}).update(upMatter);
          if (typeof data.queueId !== 'undefined' && data.queueId !== null){
            // 在有接谈记录的情况下，更新接谈处理单
            let up = {
              'handleModel': data.handleModel,//办理离方式
              'handleModelID': typeof data.handleModelID === 'undefined' ? "005" : data.handleModelID,//省直机关接谈
              'finalDisposalID':data.deptID_pre, //去向单位ID
              'finalDisposal':data.deptName_pre, //去向单位
              'handleUserId':data.userId,
              'handleUserName':userInfo.name,
            };
            await this.model('talking_handle').where({'queueID':data.queueId}).update(up)
          }
          // 如果劝返
          // if (data.hasOwnProperty('persuade') && data.persuade === 1 && data.hasOwnProperty('persuadePerson')){
          if (data.hasOwnProperty('persuade') && data.persuade === 1){
            let personList = await this.model('matter').join('person_activity on person_activity.activityID = matter.activityID')
              .where({'matter.taskid':data.taskId}).field('person_activity.personID').select();
            if (!think.isEmpty(personList)){
              let upWhere = [];
              personList.forEach(function(item) {
                upWhere.push(item.personID);
              });
              await this.model('person').where({'id':['IN',upWhere]}).update({'persuade':1});//给所有信访人打上劝返标签
            }
          }
        }
        if ((data.businessID === 33 && data.dealType_pre === '省直机关接谈') ||
          (data.businessID === 36 && data.handleModel === '省直机关接谈')) {
          // 当这两种情况下，去生成接谈室排队号
          // 接谈单位id为 data.deptID_pre
          // let roomCodeNum = await util.getRoomCodeNum(data.deptID_pre);// 生成接谈室排号（接谈单位id
          // await util.saveQueue(roomCodeNum,data.taskId,data.deptID_pre);// 保存接谈排号单（接谈室排号，taskId，接谈单位id
          // 24-1-24修改生成排号与保存排号单一起进行
          await util.saveQueue(data.taskId,data.deptID_pre)
        }
      };
      if (data.businessID === 1 && typeof data.queueId !== 'undefined' && data.queueId !== null) {
        // 在有接谈记录的情况下，更新接谈处理单
        let up = {
          'examineContent': data.content,
          'examine':0,// 同意
          'examineTime':moment().format('YYYY-MM-DD HH:mm:ss'),
          'examineUserId':data.userId,
          'examineUserName':userInfo.name,
        };
        await this.model('talking_handle').where({'queueID':data.queueId}).update(up)
      }
      // 办结附件 和 办结说明
      if (data.hasOwnProperty('endingUrl') || data.hasOwnProperty('conclusion')) {
        data.info['endingUrl'] = data.endingUrl;
        data.info['conclusion'] = data.conclusion;
        let update = {
          "endingUrl":data.hasOwnProperty('endingUrl') ? data.endingUrl.join(",") : "",
          "conclusion":data.hasOwnProperty('conclusion') ? data.conclusion : ""
        }
        await this.model('matter').where({"id":data.matterID}).update(update);
      }
      if (data.hasOwnProperty('dealType_pre') && !data.hasOwnProperty('deptID_pre')){
        if (data.businessID === 2 && data.dealType_pre === '转送'){
          let matter = await this.model('matter').setRelation(false).where({'taskid':data.taskId}).find();//这里左连去查handle_log最后一条记录的isAnswer可行？
          if (matter.isAnswer === 1){
            param['dealType_pre'] = '转交';//需反馈
          }else {
            param['dealType_pre'] = '转送';//不需反馈
          }
        } else {
          param['dealType_pre'] = data.dealType_pre;//修改
        }
        // param['dealType_pre'] = data.dealType_pre;//修改
      }
      if (data.hasOwnProperty("charger")){ //登记审批或者办理审批 的交办
        param["charger"] = data.charger;
      } else {
        if (data.businessID===2||data.businessID===32){ // 登记审批或者办理审批 的转送
          const task = await this.model("fw_task").where({"id":data.taskId}).find();
          param["charger"] = task.charger;
        }
      }
      // 4办理信访件（每流转一次）
      // await Check.addPoints(4,data.userId);
      // 推进流程
      nextActID = await httpRequest('post','http://localhost:8360/flow/service/taskForward',param);
      if (nextActID.errno !== 0 ){
        return this.fail(nextActID)
      }
      // 插入历史表
    } else if (data.forward === 1){//后退
      // 后退流程
      nextActID = await httpRequest('post','http://localhost:8360/flow/service/taskBackward',param);
      if (nextActID.errno !== 0 ){
        return this.fail(nextActID)
      }
      if (data.businessID === 1 && typeof data.queueId !== 'undefined' && data.queueId !== null) {
        // 在有接谈记录的情况下，更新接谈处理单
        let up = {
          'examineContent': data.content,
          'examine':1,// 不同意
          'examineTime':moment().format('YYYY-MM-DD HH:mm:ss'),
          'examineUserId':data.userId,
          'examineUserName':userInfo.name,
        };
        await this.model('talking_handle').where({'queueID':data.queueId}).update(up)
      }
    } else {
      return this.fail("流程方向错误")
    }
    // 更新节点
    const update = {
      'nextActID':nextActID.data.nextActid,
      'updateTime':moment().format('YYYY-MM-DD HH:mm:ss'),
      'info':JSON.stringify(data.info),
      //更新操作人员和单位
      'userId':data.userId,
      'account':userInfo.user_name,
      'deptName':userInfo.orgName,
      'deptID':userInfo.orgID,
    };
    await this.model('node_record').where({'taskId':data.taskId,'nextActID':null}).update(update);
    // 插入新节点和历史表
    const add = {
      'taskId':data.taskId,
      'actID':nextActID.data.nextActid,
      'nextActID':null,
      'businessID':data.businessID,
      'userId':data.userId,
      'time':moment().format('YYYY-MM-DD HH:mm:ss'),
      'account':userInfo.user_name,
      'deptName':userInfo.orgName,
      'deptID':userInfo.orgID,
      'info':JSON.stringify(data.info),
      'solveCode':typeof data.solveCode === 'undefined' ? "" : data.solveCode, //反馈办结状态字典表FK
    };
    await this.model('node_record').add(add);// 节点表
    await this.model('history').add(add);// 历史表
    this.success('流程更新成功！')
  }
  // 节点已办理数据
  async handledAction(){
    const data = this.post();
    const userInfo = await this.getUserInfo(data.userId);
    let sql = 'select DISTINCT c_task from fw_task_act where actno in ' +
      '( select c_to from fw_act_path where c_from in ' +
      '( select id from fw_act where businessID = ' + data.businessID + '))' +
      ' and deptID_now = ' + userInfo.orgID;  // userInfo.orgID 当前部门ID
    const taskId = await this.model('fw_task_act').query(sql);
    let where = {
      "taskId":['IN',taskId],
      "userId":data.userId,
    };
    const node = await this.model('node_record').where(where).page(data.page, data.limit).order('id DESC').countSelect();
    return this.success(node)
  }
  // 流程节点信息
  async nodeHistoryAction(){
    const data = this.post();
    let node = await this.model('node_record').where({"taskId":data.taskId}).order("id DESC").select();
    if (!think.isEmpty(node)){
      let userId = [];
      let actID = [];
      node.forEach(function(item) {
        userId.push(item.userId);
        actID.push(item.actID);
        item.info = JSON.parse(item.info);
      });
      let userInfo = await this.model('sys_user').join('sys_organization on sys_organization.id = sys_user.orgID')
        .where({"user_id":['IN',userId]}).field('sys_organization.orgName,sys_user.*').select();
      let actInfo = await this.model('fw_task_act').where({"id":['IN',actID]}).select();
      for (let n of node){
        for (let user of userInfo){
          if (n.userId === user.user_id){
            n["userInfo"] = user;
            break;
          }
        };
        for (let act of actInfo){
          if (parseInt(n.actID) === act.id){
            n["actInfo"] = act;
            break;
          }
        }
      }
      // 查询提交登记审批信息
      let matter = await this.model('matter').setRelation(false).where({"taskid":data.taskId}).find();
      let user = await this.model('sys_user').join('sys_organization on sys_organization.id = sys_user.orgID')
        .where({"sys_user.user_name":matter.createAccount}).field('sys_user.*,sys_organization.orgName').find();
      node = JSON.parse(JSON.stringify(node));
      node.push({
        "actInfo":{
          "businessName":"提交登记审批",
        },
        "time":matter.createTime,
        "userInfo":user,
        "account":user.user_name,
        "deptName":user.orgName
      })
    }
    return this.success(node)
  }

  /**
   * showdoc
   * @catalog 流程操作
   * @title 退回修改保存历史记录
   * @description 退回修改保存历史记录
   * @method post
   * @url http://127.0.0.1:8360/taskFlow/modifyHistory
   * @param userId 必选 string userId
   * @param taskId 必选 string 流程id
   * @param history 必选 object 修改后数据json
   * @param matterID 可选 string 事项ID
   * @return {"errno": 0, "errmsg":""}
   */
  // 退回修改保存历史记录
  async modifyHistoryAction(){
    const data = this.post();
    let matter = await this.model('matter').where({"id":data.matterID}).find()
    if (think.isEmpty(matter)){
      return this.fail()
    } else {
      let actno = await this.model('fw_task').where({"id":data.taskId}).find();
      let history = data.history;
      history['contraband'] = history['contraband'] ? history['contraband'].join(',') : "";
      history['SKSFL'] = history['SKSFL'] ? history['SKSFL'].join(',') : "";
      history['hotspot'] = history['hotspot'] ? JSON.stringify(history['hotspot']) : ""; // 热点问题标签
      history['personspot'] = history['personspot'] ? JSON.stringify(history['personspot']) : ""; // 个人标签
      history['url'] = history['url'] ? history['url'].join(',') : "";
      history['contentClassify'] = history['contentClassify'].toString();
      history['contentClassifyID'] = history['contentClassifyID'].toString(); // 问题分类可能多选，多选的话是数组，所以转字符串，单选依旧是字符串
      let matterUp = await this.model('matter').where({"id":data.matterID}).update(history);
      let add = {
        "userId":data.userId,
        "history":JSON.stringify(matter),
        "taskid":data.taskId,
        "matterID":data.matterID,
        "actNum":actno.actno === undefined ? "" :actno.actno
      }
      let back = await this.model('modify_history').add(add);
      return this.success(back)
    }
  }

  // 在流程中显示各类型附件
  // 登记附件 matter表url
  // 待发送函件 history表6，28的letter   //6待发送
  // 待转交 history表7，25的letter   //9，27，30待发送
  // 回报材料 history表17  url
  async getAnnexAction(){
    const data = this.post();
    let jiaoban = [];// 交办材料集
    let huibao = [];// 回报材料集合
    let fujian = [];// 附件地址集
    let banjie = [];// 办结材料
    let node = [];
    let matterWhere = {};
    if (data.hasOwnProperty('matterID') && data.matterID !== ''){
      matterWhere['id'] = data.matterID;
    } else {
      matterWhere['taskid'] = data.taskId;
    }
    if (data.hasOwnProperty('activityID') && data.activityID !== '') {
      // 查询活动所含的事项的所有附件
      let matter = await this.model('matter').setRelation(false).where({'activityID':data.activityID}).select();
      if (think.isEmpty(matter)) {
        fujian = [];
        banjie = [];
      }
      let taskIdList = [];
      for (let m of matter){
        taskIdList.push(m.taskid);
        if (m.url !== null && m.url.length > 0){
          // fujian.push(m.url.split(','))
          fujian = fujian.concat(m.url.split(','))
        }
        if (m.endingUrl !== null && m.endingUrl.length > 0){
          // banjie.push(m.endingUrl.split(','))
          banjie = banjie.concat(m.endingUrl.split(','))
        }
      }
      if (taskIdList.length > 0){
        node = await this.model('history').where({"taskId":['IN',taskIdList],"businessID":['IN',[6,8,10,27,30,17]]}).select()// businessID 10劝返单
      }
    }else {
      // let matter = await this.model('matter').setRelation(false).where({"taskid":data.taskId}).find();
      let matter = await this.model('matter').setRelation(false).where(matterWhere).find();
      if (think.isEmpty(matter)){
        return this.fail('事项不存在！')
      }
      fujian = matter.url ? matter.url.split(',') : [];// 附件地址集
      banjie = matter.endingUrl ? matter.endingUrl.split(',') : [];// 办结材料
      // let node = await this.model('history').where({"taskId":data.taskId,"businessID":['IN',[6,7,25,28,17]]}).select();
      node = await this.model('history').where({"taskId":matter.taskid,"businessID":['IN',[6,8,10,27,30,17]]}).select();// businessID 10劝返单
    }
    // // let matter = await this.model('matter').setRelation(false).where({"taskid":data.taskId}).find();
    // let matter = await this.model('matter').setRelation(false).where(matterWhere).find();
    // if (think.isEmpty(matter)){
    //   return this.fail('事项不存在！')
    // }
    // fujian = matter.url ? matter.url.split(',') : [];// 附件地址集
    // banjie = matter.endingUrl ? matter.endingUrl.split(',') : [];// 办结材料
    // // let node = await this.model('history').where({"taskId":data.taskId,"businessID":['IN',[6,7,25,28,17]]}).select();
    // let node = await this.model('history').where({"taskId":matter.taskid,"businessID":['IN',[6,9,27,30,17]]}).select();
    node.forEach(function(item) {
      let info = JSON.parse(item.info);
      if (item.businessID === 17){
        // 回报材料
        huibao = huibao.concat(info.url ? info.url : [])
      }else {
        if (item.businessID === 10 && info.hasOwnProperty('transferLetter')){
          // 大会劝返单
          jiaoban = jiaoban.concat(info.transferLetter ? info.transferLetter.split(',') : [])
        }
        // 交办材料
        if (info.hasOwnProperty('letter')){
          jiaoban = jiaoban.concat(info.letter ? info.letter.split(',') : [])
        }
        // 交办材料照片
        if (info.hasOwnProperty('letterPic')){
          jiaoban = jiaoban.concat(info.letterPic ? info.letterPic.split(',') : [])
        }
      }
    });
    let url = [];
    url = url.concat(fujian);
    url = url.concat(huibao);
    url = url.concat(jiaoban);
    url = url.concat(banjie);
    let file = [];
    // console.log(url)
    if (url.length > 0){
      file = await this.model('file_log').join('sys_user on sys_user.user_id = file_log.userId')
        .join('sys_organization on sys_organization.id = sys_user.orgID').where({"file_log.url":['IN',url]})
        .field('file_log.*,sys_user.name as userName,sys_organization.orgName').order('file_log.createTime DESC').select();
      file.forEach(function(item) {
        if (JSON.stringify(fujian).indexOf(item.url) !== -1) {
          item["type"] = 1; // 附件地址
        }else if (JSON.stringify(jiaoban).indexOf(item.url) !== -1) {
          item["type"] = 2; // 交办材料
        }else if (JSON.stringify(huibao).indexOf(item.url) !== -1) {
          item["type"] = 3; // 回报材料
        }else if (JSON.stringify(banjie).indexOf(item.url) !== -1) {
          item["type"] = 4; // 办结材料
        }
      });
    }
    return this.success(file)
  }
  // 存信存件自办的 关闭说明
  async closeMatterAction(){
    const data = this.post();
    if (data.hasOwnProperty('url') && data.url !== ''){
      data.url = data.url.join();//数组转字符串，逗号分隔
    }
    let addData = {
      'matterID':data.matterID,
      'taskId':data.taskId,
      'userId':data.userId,
      'orgID':data.orgID,
      'orgName':data.orgName,
      'url':data.url,
      'remark':data.remark
    };
    await this.model('matter_close').add(addData);
    return this.success();
  }
  // 获取 受理告知书和处理意见书 模板
  async getTempAction(){
    const data = this.post();
    let userInfo = await this.getUserInfo(data.userId);
    let matter = await this.model('matter').alias('m').setRelation(false).where({'m.id':data.matterID})
      .join('history as h on h.taskId = m.taskid').field('m.*,h.time,h.businessID').select();
    let xfr = await this.model('person').alias('p').setRelation(false).join('activity as a on a.mainPerson = p.id')
      .where({'a.id':matter[0].activityID}).field("p.name").find();
    let time = moment(matter[0].createTime).add(60,'days').format('YYYY年M月D日');
    for (let item of matter){
      if (item.businessID === 2){
        time = moment(item.time).add(60,'days').format('YYYY年M月D日');
        break;
      }
    }
    if (data.type === 1){
      //受理告知书
      // 告知书正文
      let text = "您提出的信访事项,我们决定予以受理。按照《信访工作条例》第三十四条规定,将于"+ time +"(注:最长不超过受理后60日）前办结并书面答复您。在此期间，您以同一事实和理由提出同一信访事项,本级和上级机关（单位)不予受理。";
      let rider = "特此告知";// 告知书附文
      let title = "受理告知书";// 标题
      return this.success({
        'biaoti':title,
        'danwei':userInfo.orgName,
        'riqi':moment().format('YYYY年M月D日'),
        'xfr':xfr.name,
        'zhengwen1':text,
        'zhengwen2':rider,
      })
    }else {
      //处理意见书
      let text1 = "您于" + moment(matter[0].createTime).format('YYYY年M月D日') + "反映" + matter[0].xfName +
        "。我们于" + time + "受理，并发出受理告知书。";
      let text2 = "经调查，(以下内容为对信访人反映问题的认定、有关法律法规政策规定、调查情况和处理意见)。";
      let text3 = "如不服本处理意见，可自收到本处理意见书之日起 30日内向"+ userInfo.orgName +"提出复查申请。";
      let title = "信访事项处理意见书";// 标题
      return this.success({
        'biaoti':title,
        'danwei':userInfo.orgName,
        'qfr':userInfo.name,// 签发人
        'riqi':moment().format('YYYY年M月D日'),
        'xfr':xfr.name,
        'zhengwen1':text1,
        'zhengwen2':text2,
        'zhengwen3':text3,
      })
    }

  }
  // 获取 可生成受理告知书/处理意见书列表
  async getNoticeListAction(){
    const data = this.post();
    // 本单位登记的，人工选择受理的事项
    let userInfo = await this.getUserInfo(data.userId);
    let where = {
      'm.isAcceptPerson':0,// 是否受理范围人工判断
      'm.createOrgID':userInfo.orgID,
      'm.taskid':['!=',null]
    };
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      where['m.createTime'] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      where['m.CreateTime'] = ['<',moment(data.endTime).add(1,'days').format('YYYY-MM-DD')];
    }
    // 信访人姓名
    if (data.hasOwnProperty('name') && data.name !== ''){
      let person = await this.model('person').alias('p').setRelation(false).join('person_activity as pa on pa.personID = p.id')
        .where({'p.name':['LIKE','%' + data.name + '%']}).field("p.*,pa.activityID").select();
      if (think.isEmpty(person)){
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      } else {
        let acID = [];
        person.forEach(function(item) {
          acID.push(item.activityID);
        });
        if (acID.length > 0){
          where['a.id'] = ['IN',acID];
        }
      }
    }
    // 信访类型
    if (data.hasOwnProperty('xfSourceID') && Array.isArray(data.xfSourceID) && data.xfSourceID.length > 0){
      where["a.xfSourceID"] = ['IN',data.xfSourceID];
    }
    let matter = await this.model('matter').alias('m').where(where)
      .join('activity as a on a.id = m.activityID').order('m.createTime Desc')
      .page(data.page, data.pageSize).countSelect();
    return this.success(matter)
  }

  //上传受理告知书或处理意见书，并生成记录
  async upNoticeAction(){
    const file = this.file().file; // file 文件
    const data = this.post(); // post其他参数
    // 上传文件
    //获取后缀
    let fileType = file.name.substr( file.name.lastIndexOf(".") + 1);
    //创建路径
    // let filePath = path.join(think.ROOT_PATH, '/www/static', fileType);
    let filePath = path.join(think.ROOT_PATH, '/www/static', moment().format('YYYY年')+'/'+moment().format('M月')+'/'+fileType);
    upload.mkdirsSync(filePath);// 创建文件夹（如果需要）
    let fileName = Math.random().toString(16).substr(2) + '.' + fileType;// 文件名称
    let _uploadFilePath = path.join(filePath, fileName);
    let saveTo = path.join(_uploadFilePath);
    const reader = fs.createReadStream(file.path);// 读取文件
    // 文件保存到指定路径
    reader.pipe(fs.createWriteStream(saveTo));
    // 在文件上传日志中保存记录
    let userInfo = await this.getUserInfo(data.userId);

    let log = {
      "name":moment().format('YYYY年M月D日') + userInfo.orgName + ((data.type === 1 ) ? "受理告知书" : "处理意见书"),
      "random":fileName,
      "url":'/static/'+ moment().format('YYYY年')+'/'+moment().format('M月')+'/'+ fileType + '/' + fileName,
      "matterID":data.matterID,
      "userId":data.userId,
      "orgID":userInfo.orgID,
      "orgName":userInfo.orgName,
      "type":data.type,
    };
    await this.model('notice_log').add(log);
    return this.success(log.url)
  }
  //已生成受理告知书或处理意见书事项列表
  async getNoticeLogAction(){
    const data = this.post();
    let userInfo = await this.getUserInfo(data.userId);
    let where = {
      'm.createOrgID':userInfo.orgID,
      'n.type':data.type,
      'm.id':['!=', null]
    };
    if (data.hasOwnProperty('startTime') && data.startTime !== ''){
      where['m.createTime'] = ['>',moment(data.startTime).format('YYYY-MM-DD')];
    }
    if (data.hasOwnProperty('endTime') && data.endTime !== ''){
      where['m.CreateTime'] = ['<',moment(data.endTime).add(1,'days').format('YYYY-MM-DD')];
    }
    // 信访人姓名
    if (data.hasOwnProperty('name') && data.name !== ''){
      let person = await this.model('person').alias('p').setRelation(false).join('person_activity as pa on pa.personID = p.id')
        .where({'p.name':['LIKE','%' + data.name + '%']}).field("p.*,pa.activityID").select();
      if (think.isEmpty(person)){
        return this.success({
          "count": 0,
          "totalPages": 0,
          "pageSize": 10,
          "currentPage": 1,
          "data": []
        })
      } else {
        let acID = [];
        person.forEach(function(item) {
          acID.push(item.activityID);
        });
        if (acID.length > 0){
          where['m.activityID'] = ['IN',acID];
        }
      }
    }
    let matter = await this.model('matter').alias('m').join('notice_log as n on m.id = n.matterID')
    // let matter = await this.model('notice_log').alias('n').join('matter as m on m.id = n.matterID')
      .where(where).field('m.*,n.url as noticeURL,n.name as noticeName').order('m.createTime Desc')
      .page(data.page, data.pageSize).countSelect();
    return this.success(matter)
  }
};
