const jwt = require('jsonwebtoken');
const fs = require('fs')
const path = require('path')
const moment = require('moment')
const util = require('../handle/util')
module.exports = {
  authFail() {
    return this.fail('JWT 验证失败');
  },

  checkAuth(token) {
    let res;
    let cert = fs.readFileSync(path.join(think.ROOT_PATH, 'rsa_public_key.pem'));
    try {
      let result = jwt.verify(token, cert, {
        algorithms: ['RS256']
      }) || {};
      let {
        exp = 0
      } = result, current = Math.floor(Date.now() / 1000);
      if (current <= exp) {
        res = result.userId || {};
      }
    } catch (e) {
      res = 'err';
    }
    return res;

  },
  updateAuth(userId) {
    let created = Math.floor(Date.now() / 1000);
    let cert = fs.readFileSync(path.join(think.ROOT_PATH, 'rsa_private_key.pem')); //私钥 可以自己生成
    let token = jwt.sign({
      userId,
      exp: created + 3600 * 24,
    }, cert, {
      algorithm: 'RS256'
    });
    return token;
  },
  getDictTree(dictTree, sonName, parentName) {
    let menu = {};
    let tree = [];
    dictTree.forEach((item) => {
      item['text'] = item.description; // 测试,额外赋key
      menu[item[sonName]] = item;
    });
    dictTree.forEach((meT) => {
      meT['text'] = meT.description; // 测试,额外赋key
      const data = menu[meT[parentName]];
      if (data) {
        (!data.children) && (data.children = []);
        data.children.push(meT)
      } else {
        tree.push(meT)
      }
    });
    return tree
  },
  //获取用户信息
  // user_id: '4ae8f1800b0147bba674242fb074fd60',
  // deptLevel: 0, //0省级，1市级，2县级
  // user_name: 'zhangqing',
  // name: '张庆',
  // email: null,
  // phone: '17635317892',
  // mobilePhone: '17635317892',
  // ip: null,
  // last_login_time: '2020-08-07 01:17:46',
  // dictValue: 2, //sys_dept表id
  // regionAdminNo: '340000',
  // orgName: '人大常委会',  //sys_organization表 组织名称
  // deptName: '安徽省',   //sys_dept表deptName
  // deptTitle: '',  //sys_organization表 函件头
  // passTitle: '',  //sys_organization表 转交单头
  // agent: 0,  // sys_organization表 人大常委会代理机构设置为1 暂时弃用
  // isRenDa: 1, //sys_organization表 1是人大机构，0是职能单位
  // orgID: 6, //sys_organization表 id
  // isLead: null,  //1是领导，0不是
  // orgJc: '人常',  //sys_organization表 机构简称
  // isSuper: 0,  // 是否为超级管理员
  // isAdmin: 0,  // 0不具有后台管理功能，1具有后台管理功能
  // description: '安徽省',  //sys_dept 表 deptName
  // type: 2, //sys_dept 表 1全国2省3市4县
  // depJc: '皖',//sys_dept 表 jc 地区简称
  // deptValue: '001001',//sys_dept 表 dictValue 字典表value
  // meetingID: '001001',//sys_user 表 meetingID 大会届次
  // roleList: [ RowDataPacket { role_id: 3, role_name: '安徽人大信访系统测试员' } ]
  async getUserInfo(userId) {
    //其中的orgJc代表的是机构简称
    let userInfo = await this.model('sys_user').alias('su').field('su.isAdmin,su.meetingID,su.meetingSession,su.user_id,su.deptLevel,su.user_name,su.name,su.email,su.phone,su.mobilePhone,su.ip,su.last_login_time,su.dictValue,su.regionAdminNo,so.isOnline,so.orgName,so.deptName,so.deptTitle,so.passTitle,so.agent,so.isRenDa,su.orgID,su.isLead,so.jc as orgJc').join('sys_organization as so on so.id=su.orgID').setRelation(false).where('su.user_id="' + userId + '"').find().catch((err) => {
      console.log(err)
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(userInfo)) {
      return 0
    }
    //判断用户是否是超级管理员,就是是否含有角色为1
    let roleId = await this.model('sys_user_role').where({
      user_id: userId,
      role_id: 1
    }).find();
    if (think.isEmpty(roleId)) {
      userInfo.isSuper = 0;
    } else {
      userInfo.isSuper = 1;
    }
    //获取用户地区
    if (userInfo.dictValue) {
      const deptName = await this.model('sys_dept').field('deptName,type,jc,dictValue').where({
        'id': userInfo.dictValue
      }).find();
      //用户所在的地区
      userInfo.description = deptName.deptName
      userInfo.type = deptName.type
      //地区简称
      userInfo.depJc = deptName.jc
      // 地区value
      userInfo.deptValue = deptName.dictValue
    }
    //获取用户角色列表
    let role_list = await this.model('sys_user_role').field('sys_role.role_id,sys_role.role_name').join('sys_role on sys_role.role_id=sys_user_role.role_id').where({
      user_id: userId
    }).select().catch((err) => {
      return think.isError(err) ? err : new Error(err);
    });
    if (think.isError(role_list)) {
      return 0
    }
    userInfo.roleList = role_list;
    return userInfo;
  },
  // 提交登记审批
  async djSubmit(matterID, userId, mainPerson) {
    // 获取事项信息
    const matter = await this.model('matter').where({
      'id': matterID
    }).find();
    // 自动生成信访事项名称
    let xfname = await util.getNameRule(matter.activityID,matter.contentClassifyID,matter.identityTypeID,matter.departmentID,matter.createTime);
    // 更新信访事项名称 和 登记时间
    const upName = await this.model('matter').where({'id': matterID}).update({'xfName': xfname,'createTime':moment().format('YYYY-MM-DD HH:mm:ss')});
    //     // if (matter.contentClassifyID.toString().substring(0,3) === "003") {
    //   // 纪检监察 类  有额外的命名规则
    // }else {
    //   let xfname = await util.getNamespaceByNameRules(matter.activityID, matterID, matter.contentClassifyID);
    //   const upName = await this.model('matter').where({
    //     'id': matterID
    //   }).update({
    //     'xfName': xfname
    //   });
    // }

    // let userInfo = await this.getUserInfo(userId); // 获取用户信息
    // 在matter_state中插入新状态
    // const stateAdd = {
    //   'matterID': matterID,
    //   'activityID': matter.activityID,
    //   'mainPersonID': mainPerson, //主信访人
    //   'state': 2,
    //   'stateName': '登记待审批/已提交登记审批',
    //   'nextState': util.judgeState(matter.handleModelID).state, // 判断办理方式
    //   'nextStateName': util.judgeState(matter.handleModelID).stateName,
    //   'departmentID': userInfo.orgID,
    //   'department': userInfo.orgName, // 机构
    //   'description': userInfo.description, // 地区
    //   'dictValue': userInfo.dictValue,
    //   'handlePerson': userInfo.name,
    //   'handlePersonID': userInfo.user_name,
    //   'nextDepartment': userInfo.orgID, // 去向单位 （下一步操作还是本单位）
    //   'nextDepartmentID': userInfo.orgName
    // };
    // // 插入事件状态
    // const addState = await this.model('matter_state').add(stateAdd);
    // // 修改事件状态
    // const matterUp = await this.model('matter').where({
    //   'id': matterID
    // }).update({
    //   'state': 2
    // });
    // // 插入审批记录
    // const approval = await this.model('approval').add({
    //   'auditee': userInfo.name, //被审核人
    //   'auditeeAccount': userInfo.user_name,
    //   'createTime': moment().format('YYYY-MM-DD HH:mm:ss'), // 提交审核时间
    //   'eventID': matterID, // 提交审核时间
    //   'typeID': 1, // 审核类型编号 1登记 2修改 3拟函 4转交 5回报
    //   'state': 0,
    // })
    // // return this.success('提交成功！');
    return true
  },
  //获取用户是否是领导，是获取该领导管辖的所有工作人员账号，不是只返回本人账号
  async getUserJurisdiction(userId) {
    //获取用户信息
    const userInfo = await this.model('sys_user').field('user_name,isLead,orgID').where({
      user_id: userId,
      del_flag: 1
    }).find();
    let res = {
      isLead: 0, //0不是领导，1是领导
      selfAccount: "", //本人账号
      nextAccount: [], //下属账号
    }
    if (!think.isEmpty(userInfo)) {
      res.selfAccount = userInfo.user_name;
      if (userInfo.isLead === 1) { //是领导
        res.isLead = 1;
        //获取下属的账号
        const nextUser = await this.model('sys_user').field('user_name').where({
          orgID: userInfo.orgID,
          isLead: 0,
          del_flag: 1
        }).select();
        if (nextUser.length > 0) {
          nextUser.forEach((item) => {
            res.nextAccount.push(item.user_name);
          })
        }

      }
    }
    return res;
  }
}
