const moment = require('moment');
// var date1 = new Date();
// var date2 = new Date(date1);
// date2.setDate(date1.getDate() + 15);
var date2 = moment().add(60, 'days').format("YYYY年M月D日")
async function getMatterInfo(matterID,userID) {
  //获取事件信息
  let matter = await think.model('matter').where({
    id: matterID
  }).find();
  if (!think.isEmpty(matter)) {
    matter.activity = await think.model('activity').setRelation(false).where({
      id: matter.activityID
    }).find();
    matter.createPerson = await think.model('sys/sys_user').where({
      user_name: matter.createAccount
    }).find();
    //获取当前登录者地区
    let dictValue = await think.model('sys_user').where({
      user_id: userID
    }).find();
    matter.loginInfo = dictValue
  }
  return matter
}

//获取替换字段信息
async function getDetailInfo(matter) {
  //要替换的内容
  let repInfo = {
    xfName: "", //信访人姓名
    xfNumber: matter.activity.xfNumber, //信访人数
    grade: "", //代表层级
    deleName: "", //代表姓名
    upLevel: "", //上级人大常
    objectName: matter.objectName, //主体名称
    leader: "", //领导姓名
    // feedbackDate: think.datetime(date2).substr(0, 10)
    feedbackDate: date2

  }
  let leadWhere = {
    'al.activityID': matter.activity.id
  }
  //获取领导姓名
  const leader = await think.model('delegate_leading').alias('dl').join('activity_leading as al on al.leadingID=dl.id').where(leadWhere).find();
  if (!think.isEmpty(leader)) {
    repInfo.leader = leader.name
  }
  //获取主信访人信息
  const xfPerson = await think.model('person').where({
    id: matter.activity.mainPerson
  }).find();
  const whereparam = {}
  //获取代表信息
  whereparam['al.activityID'] = matter.activity.id
  const delegate = await think.model('delegate_leading').alias('dl').field('dl.*').join('left join activity_leading as al on al.leadingID=dl.id').where(whereparam).find();
  if (!think.isEmpty(xfPerson)) {
    repInfo.xfName = xfPerson.name
  }
  if (!think.isEmpty(delegate)) {
    repInfo.deleName = delegate.name
    repInfo.grade = delegate.grade
  }
  //不是同地区
  if (matter.loginInfo.dictValue !== matter.createPerson.dictValue) {
    repInfo.upLevel = matter.createPerson.zone.deptName + "人大常委会"
  }
  return repInfo;
}

async function judgeLetterSource(matter, isRD) {
  let whereParam = {};
  //判断是否是人大自办
  whereParam.isRD = parseInt(isRD);
  //获取事件去向单位
  const matterToDept = await think.model('sys_organization').where({
    id: matter.finalDisposalID
  }).find();
  //判断来访类型 如果登记人和操作人员是同地区
  if (matter.loginInfo.dictValue !== matter.createPerson.dictValue) {
    whereParam.sourceID = '5';//此判断为 由上级交 下级人大或同级一府两院
    if (matterToDept.isRenDa === 1) {
      whereParam.notCongressWhereID = '4'
    } else {
      whereParam.notCongressWhereID = '3'
    }
  } else {
    if (matterToDept.isRenDa === 1) {
      whereParam.notCongressWhereID = '2'
    } else {
      whereParam.notCongressWhereID = '1'
    }
  }
  //判断来访形式
  if (matter.contentClassifyID.substr(0,3) === '001') {
    whereParam.letterTypeID = "001" //反映建议
  } else if (matter.contentClassifyID.substr(0,3) === '002') {
    whereParam.letterTypeID = "002"; //行政诉求
  } else if (matter.contentClassifyID.substr(0,3) === '005') {
    whereParam.letterTypeID = "005"; //涉法涉诉
  }

  // 判断类型
  if (matter.activity.xfSourceID == "001001" || matter.activity.xfSourceID == "002001") {
    whereParam.isLeader = 0 //非领导
  } else if (matter.activity.xfSourceID.substr(0,6) === '002002') {
    whereParam.isLeader = 1 //领导阅批
  } else if (matter.activity.xfSourceID.substr(0,6) === '001002') {
    whereParam.isLeader = 2 //领导接访
  } else if (matter.activity.xfSourceID == "002006" || matter.activity.xfSourceID == "001004") {
    whereParam.isLeader = 3 //代表来信
    //判断代表是否多代表
    if (matter.activity.xfNumber > 1) {
      whereParam.isMany = 1
    } else {
      whereParam.isMany = 0
    }
  } else if (matter.activity.xfSourceID == '001003' || matter.activity.xfSourceID == "002003") {
    whereParam.isLeader = 4 //代表转信
    //判断代表是否多代表
    if (matter.activity.xfNumber > 1) {
      whereParam.isMany = 1
    } else {
      whereParam.isMany = 0
    }
  }
  return whereParam;
}

//获取模板
async function getTemplate(whereParam, repInfo) {
  let template = await think.model('template').where(whereParam).find();
  if (!think.isEmpty(template)) {
    // console.log(repInfo)
    template.text = template.text.replace('[信访人姓名]', repInfo.xfName);
    template.text = template.text.replace('[上一级人大常委会名称]', repInfo.upLevel);
    template.text = template.text.replace('[代表姓名]', repInfo.deleName);
    template.text = template.text.replace('[代表层级]', repInfo.grade);
    template.text = template.text.replace('[代表人数]', repInfo.xfNumber);
    template.text = template.text.replace('[领导阅批]', repInfo.leader + "批阅");
    template.text = template.text.replace('[领导接访]', repInfo.leader + "接访");
    template.text = template.text.replace('[反馈日期]', repInfo.feedbackDate);
  }
  return template;
}
//获取模板并替换模板内容
async function getTemplateAndReplace(matterID,isRD,userID) { // isRD 0非人大自办，1人大自办
  //1.获取事项信息，活动信息，人员信息
  const matter = await getMatterInfo(matterID, userID)
  //2.获取替换后的内容
  const repInfo = await getDetailInfo(matter);
  //3. 获取模板需要的参数
  const whereParam = await judgeLetterSource(matter, isRD);
  //4. 获取模板
  const template = await getTemplate(whereParam, repInfo);
  return template
}

// 函件模板重写
// 需要传参isRD 0非人大自办，1人大自办
// 需要传参matterID
// 需要传参userId
async function getLettersTemplate(matterID, isRD, userId){
  let matter = await think.model('matter').where({id: matterID}).find();
  let userInfo = await think.model('sys_user').where({user_id: userId}).find();
  let activity;
  let leader;//领导信息 leader.name
  let delegate;//获取代表信息 代表层级delegate.grade delegate.name
  let xfPerson;//获取主信访人信息
  let superior;//上级人大
  let finalDisposal;//去向单位
  let whereParam = {"isRD":parseInt(isRD)};//模板选择查询条件
  if (!think.isEmpty(matter)) {
    activity = await think.model('activity').setRelation(false).where({id: matter.activityID}).find();
    if (!think.isEmpty(activity)) {
      //获取领导姓名
      leader = await think.model('delegate_leading').alias('dl')
        .join('activity_leading as al on al.leadingID=dl.id').where({'al.activityID': activity.id}).find();
      //获取主信访人信息
      xfPerson = await think.model('person').where({id: activity.mainPerson}).find();
      //获取代表信息
      if (activity.xfSourceID === "001004" || activity.xfSourceID === "002006"){
        // 代表来访或者代表来信
        delegate = xfPerson;
      } else {
        delegate = await think.model('delegate_leading').alias('dl').field('dl.*')
          .join('left join activity_leading as al on al.leadingID=dl.id').where({'al.activityID':activity.id}).find();
      }
      // 判断类型
      if (activity.xfSourceID == "001001" || activity.xfSourceID == "002001" || activity.xfSourceID == "003001" || activity.xfSourceID == "004001" ) {
        whereParam["isLeader"] = 0 //非领导
      } else if (activity.xfSourceID.substr(0,6) === '002002') {
        whereParam["isLeader"] = 1 //领导阅批
      } else if (activity.xfSourceID.substr(0,6) === '001002') {
        whereParam["isLeader"] = 2 //领导接访
      } else if (activity.xfSourceID == "002006" || activity.xfSourceID == "001004") {
        whereParam["isLeader"] = 3 //代表来信
        //判断代表是否多代表
        whereParam["isMany"] = activity.xfNumber > 1 ? 1 : 0
      } else if (activity.xfSourceID == '001003' || activity.xfSourceID == "002003") {
        whereParam["isLeader"] = 4 //代表转信
        //判断代表是否多代表
        whereParam["isMany"] = activity.xfNumber > 1 ? 1 : 0
      }
    }
    let node_record = await think.model('history').where({"taskId":matter.taskid,"businessID":21}).order("id DESC").select();
    if (!think.isEmpty(node_record) && (JSON.parse(node_record[0]["info"])).hasOwnProperty("param")){
      // 获取最后一次办理方式
      finalDisposal = JSON.parse(node_record[0]["info"]).param.deptName_pre;
      whereParam["sourceID"] = '5'; // 有办理记录，则不是登记单位。判断为 由上级交 下级人大或同级一府两院一委
      whereParam["isLeader"] = 0; // 有办理记录，不区分领导代表
      whereParam["notCongressWhereID"] = JSON.parse(node_record[0]["info"]).param.isRenDa === 1 ? 4 : 3;
      // 经过办理，才有上级人大， 获取上级人大
      let sql = 'sys_dept where id = (select parentID from sys_dept where id = '+ userInfo.dictValue +')'
      let back = await think.model('sys_dept').table(sql).find();
      superior = back.deptName + "人大常委会";
    }else {
      // 没有进行过办理，直接从matter中获取
      finalDisposal = matter.finalDisposal;
      let isRenDa = await think.model('sys_organization').where({'id':matter.finalDisposalID}).find();
      whereParam["notCongressWhereID"] = (isRenDa.isRenDa === 1 ? 2 : 1);
    }
    //判断来访形式
    if (matter.contentClassifyID.substr(0,3) === '001') {
      whereParam["letterTypeID"] = "001" //反映建议
    } else if (matter.contentClassifyID.substr(0,3) === '002') {
      whereParam["letterTypeID"] = "002"; //行政诉求
    } else if (matter.contentClassifyID.substr(0,3) === '005') {
      whereParam["letterTypeID"] = "005"; //涉法涉诉
    }
  }
  // 查询模板
  let template = await think.model('template').where(whereParam).find();
  if (!think.isEmpty(template)) {
    template.text = template.text.replace('[信访人姓名]', xfPerson.name);
    template.text = template.text.replace('[上一级人大常委会名称]', superior);//superior
    template.text = template.text.replace('[代表姓名]', delegate.name);
    template.text = template.text.replace('[代表层级]', delegate.grade);
    template.text = template.text.replace('[代表人数]', activity.xfNumber);
    template.text = template.text.replace('[领导阅批]', leader.name + "批阅");
    template.text = template.text.replace('[领导接访]', leader.name + "接访");
    template.text = template.text.replace('[反馈日期]', date2);
    template["finalDisposal"] = finalDisposal;
  }else {
    template = {
      'code':1,// 获取模板失败
      'text':"依据《信访工作条例》相关规定，现将信访人所反映信访事项转给你们，请研究办理。办理结果答复信访人，并于"+date2+"前函告我单位。",
      'finalDisposal':finalDisposal
    }
  }
  return template
}



// *************************** 转交单模板
async function getPassTemplate(matterID,isRD){
  //isRD 0去向下级人大，1去向同级一府两院
  //isAnswer 0不需要反馈，1需要反馈
  let finalDisposal;// 去向单位
  let isAnswer;// 0不需要反馈，1需要反馈
  const matter = await think.model('matter').where({"id":matterID}).find();
  let fromID;
  switch (matter.activity.xfSourceID) {
    case "001001":
    case "002001":
    case "002004"://上级机关交转  信访主体默认为“信访人”
    case "003001":
    case "004001":
      fromID = 3;
      break;
    case "001004":
    case "002006":
      fromID = 1;
      break;
    case "001003":
    case "002003":
      fromID = 2;
      break;
    default:
      fromID = 0;//无效
  }
  // 查询是否有办理记录
  let node_record = await think.model('history').where({"taskId":matter.taskid,"businessID":21}).order("id DESC").select();
  if (!think.isEmpty(node_record) && (JSON.parse(node_record[0]["info"])).hasOwnProperty("param")) {
    // 获取最后一次办理方式
    finalDisposal = JSON.parse(node_record[0]["info"]).param.deptName_pre;
    isAnswer = typeof JSON.parse(node_record[0]["info"]).isAnswer === 'undefined' ? 1 : JSON.parse(node_record[0]["info"]).isAnswer;//默认反馈
  }else {
    // 没有进行过办理，直接从matter中获取
    finalDisposal = matter.finalDisposal;
    isAnswer = matter.isAnswer;
  }
  let template = await think.model('template_pass').where({'whereID':isRD,'fromID':fromID,"isAnswer":isAnswer}).find();
  if (!think.isEmpty(template)) {
    template.text = template.text.replace('[信访事项编号]', matter.matterNum);
    // template.text = template.text.replace('[反馈时间]', think.datetime(date2).substr(0, 10));
    template.text = template.text.replace('[反馈时间]', date2);
    template["finalDisposal"] = finalDisposal;
    return template
  }else {
    // 模板查询失败
    // return ""
    let back = {
      'code':1,
      'finalDisposal':finalDisposal,
      'text':"依据《信访工作条例》相关规定，现将 "+matter.matterNum+"信访事项转给你们，请按相关法律法规、政策规定办理。办理结果答复信访人，并将简要办理情况于"+date2+"前反馈我单位"
    };
    return back
  }
}
// 获取告知单模板
// type 类型1短信2告知单
// stage 信访阶段，1登记签收，2分类处理，4结案审核
// 通过userId查询发送单位是否开通网上信访 0开通，1未开通
// isRepresent  0发送给代表 1发送给信访人
// handleModel  办理方式，1交办转送，2接谈存信存件
// [信访事项编号] [查询码] [发送单位] [网址链接] [去向单位查询电话] [去向单位] [发送人电话] [地区] [地区层级单位]
async function getTellTemplate(type, stage, data){
  // 部分类型是在matter事件生成之前调取模板，故，注意传参可能没有matterID
  let where = {"type":type,"stage":stage};
  // let userInfo = await think.model('sys_user').alias('su').field('su.user_id,su.deptLevel,su.user_name,su.name,su.email,su.phone,su.ip,su.last_login_time,su.dictValue,su.regionAdminNo,so.orgName,so.deptName,so.deptTitle,so.agent,so.isRenDa,su.orgID,su.isLead,so.jc as orgJc').join('sys_organization as so on so.id=su.orgID').setRelation(false).where('su.user_id="' + data.userId + '"').find();
  let userInfo = await think.model('sys_user').alias('su').join('sys_organization as so on so.id=su.orgID')
    .setRelation(false).where({"user_id":data.userId}).field('su.phone,su.mobilePhone,so.*').find();
  // console.log(userInfo);
  if (stage === 1){// 1登记签收
    // 判断是否网上信访 0开通 1未开通
    where["isOnline"] = userInfo.isOnline === 0 ? ['IN',[0,3]] : ['IN',[1,3]];
    // let template = await think.model('template_tell').where(where).select();
    // template.forEach(function(item) {
    //   let times = item.content.split('[').length - 1; // 替换字符出现次数
    //   for (let i = 1;i<=times;i++){
    //     // item.content = item.content.replace('[信访事项编号]', "");
    //     item.content = item.content.replace('[查询码]', "");
    //     item.content = item.content.replace('[发送单位]', userInfo.orgName);
    //     item.content = item.content.replace('[[发送人电话]]', userInfo.phone);
    //     item.content = item.content.replace('[网址链接]', "");
    //     item.content = item.content.replace('[去向单位查询电话]', data.disposalPhone === "" ? "" :"("+data.disposalPhone+")");
    //     item.content = item.content.replace('[去向单位]', data.finalDisposal);
    //     item.content = item.content.replace('[地区]', userInfo.deptName);
    //     // item.content = item.content.replace('[地区层级单位]', "");
    //     if (item.content.split('[').length - 1 === 0){
    //       break;
    //     }
    //   }
    // });
    // return template;
  }else if (stage === 2){// 2分类处理
    where["isRepresent"] = typeof data.isRepresent === 'undefined'|| data.isRepresent === 1 ? 1 : 0;
    if (where.isRepresent === 0){// 发送给代表
      where["handleModel"] = data.handleModel;// 办理方式
      where["isAccept"] = data.handleModel === 2 ? 1 : data.isAccept;// 0受理，1不受理 此处存信存件属不受理范畴
    } else { // 发送给信访人
      // 判断是否开通网上信访
      where["isOnline"] = userInfo.isOnline === 0 ? ['IN',[0,3]] : ['IN',[1,3]];
      where["handleModel"] = data.handleModel;// 办理方式
      where["isAccept"] = data.handleModel === 2 ? 1 : data.isAccept;// 0受理，1不受理 此处存信存件属不受理范畴仅用于模板判断
    }
  }else if (stage === 4){// 4结案审核
    // 判断是否网上信访
    where["isOnline"] = userInfo.isOnline === 0 ? ['IN',[0,3]] : ['IN',[1,3]];
    where["isRepresent"] = typeof data.isRepresent === 'undefined'|| data.isRepresent === 1 ? 1 : 0;
  }else { // 其他 无
    return []
  }
  let template = await think.model('template_tell').where(where).select();
  template.forEach(function(item) {
    let times = item.content.split('[').length - 1; // 替换字符出现次数
    for (let i = 1;i<=times;i++){
      if(data.hasOwnProperty('matterID') && data.matterID !== ""){
        item.content = item.content.replace('[信访事项编号]', data.matterID);
      }
      // item.content = item.content.replace('[信访事项编号]', "");
      // item.content = item.content.replace('[查询码]', "");
      item.content = item.content.replace('[发送单位]', userInfo.orgName);
      item.content = item.content.replace('[[发送人电话]]', userInfo.phone);
      item.content = item.content.replace('[网址链接]', "");
      item.content = item.content.replace('[去向单位查询电话]', data.disposalPhone === "" ? "" :"("+data.disposalPhone+")");
      item.content = item.content.replace('[去向单位]', data.finalDisposal);
      item.content = item.content.replace('[地区]', userInfo.deptName);
      // item.content = item.content.replace('[地区层级单位]', "");
      if (item.content.split('[').length - 1 === 0){
        break;
      }
    }
  });
  return template;
}
// 大会版获取转送模板
async function getDHPassTemplate(matterID){
  const matter = await think.model('matter').where({"id":matterID}).find();
  let template = {
    'titleColor':"black",
    'text':"",
    'rider':"附：信访材料（含联系方式）",
    'finalDisposal':matter.finalDisposal
  };
  if (matter.isOut === 1){
    // 域外
    template.text = '现将信访人'+ matter.activity.person.name +'转贵单位，请酌情处理。'
  } else if (matter.isAnswer === 1){
    // 需要回复
    let dbx = '信访人';
    let fkdb = '';
    if (matter.activity.xfSourceID === "001004" || matter.activity.xfSourceID === "002006"){ //代表来信来访
      dbx = '代表';
    }
    if (matter.activity.xfSourceID == '001003' || matter.activity.xfSourceID == "002003") { // 代表转信转访
      fkdb = '代表及'
    }
    let org = await think.model('sys_organization').where({'id':matter.finalDisposalID}).find();
    if (org.isRenDa === 1){
      // 去向单位是人大
      template.text = '依据《信访工作条例》，现将' + matter.matterNum + '信访事项转给你们，请转相关部门依法依规办理。办理结果答复'+ dbx +
        '，并将简要办理情况于' + moment().add(60, 'days').format("YYYY年M月D日") + '前反馈'+ fkdb +'我们。'
    } else {
      //去向单位是一府两院
      template.text = '依据《信访工作条例》，现将' + matter.matterNum + '信访事项转给你们，请依法依规办理。办理结果答复'+ dbx + '，并将简要办理情况于' +
        moment().add(60, 'days').format("YYYY年M月D日") + '前反馈'+ fkdb +'我们。'
    }
  }else {
    // 不需要回复
    let org = await think.model('sys_organization').where({'id':matter.finalDisposalID}).find();
    if (org.isRenDa === 1) {
      // 去向单位是人大
      template.text = '依据《信访工作条例》，现将' + matter.matterNum + '信访事项转给你们，请转相关部门依法依规处理。'
    }else {
      //去向单位是省直机关
      template.text = '依据《信访工作条例》，现将' + matter.matterNum + '信访事项转给你们，请依法依规处理。'
    }
  }
  return template;
}
module.exports = {
  getTemplateAndReplace,
  getPassTemplate,
  getLettersTemplate,
  getTellTemplate,
  getDHPassTemplate
}
