const inspect = require('util').inspect
const path = require('path')
const os = require('os')
const fs = require('fs')


/**
 * 同步创建文件目录
 * @param  {string} dirname 目录绝对地址
 * @return {boolean}        创建目录结果
 */
function mkdirsSync(dirname) {
  if (fs.existsSync(dirname)) {
    return true
  } else {
    if (mkdirsSync(path.dirname(dirname))) {
      fs.mkdirSync(dirname)
      return true
    }
  }
}

/**
 * 获取上传文件的后缀名
 * @param  {string} fileName 获取上传文件的后缀名
 * @return {string}          文件后缀名
 */
function getSuffixName(fileName) {
  let nameList = fileName.split('.')
  return nameList[nameList.length - 1]
}

/**
 * 上传文件
 * @param  {object} ctx     koa上下文
 * @param  {object} options 文件上传参数 fileType文件类型，path文件存放路径
 * @return {promise}
 */
function uploadFile(ctx) {
  let req = ctx.req;
  let file = ctx.request.files.file
  //请求体格式不对 直接返回
  if (!/multipart\/form-data/i.test(req.headers['content-type'])) {
    return
  }
  // 获取类型
  let fileType = 'temp';
  //获取后缀
  fileType = file.name.substr( file.name.lastIndexOf(".") + 1);
  //创建路径
  let filePath = path.join(
    think.ROOT_PATH,
    '/www/static',
    fileType,
  );
  let mkdirResult = mkdirsSync(filePath)
  let fileName = Math.random().toString(16).substr(2) + '.' + getSuffixName(file.name)
  let _uploadFilePath = path.join(filePath, fileName)
  let saveTo = path.join(_uploadFilePath)
  const reader = fs.createReadStream(file.path);
  // 文件保存到指定路径
  reader.pipe(fs.createWriteStream(saveTo))
  // return saveTo
  return ('/static/'+ fileType + '/' + fileName)
}

/**
 * 蒋文件移动到指定位置
 * @param  {string} oldPath 文件地址
 * @return {string}          文件名
 */
function moveFile(oldPath) {
  //指定的地址
  let newPath = path.join(
    think.ROOT_PATH,
    '/www/static/upload'
  )
  //创建文件夹
  let mkdirRes =  mkdirsSync(newPath)
  let fileName  = oldPath.split("\\")
  //获取名字
  let savePath = path.join(newPath, fileName[fileName.length-1]);
  //移动
  fs.rename(oldPath, savePath,function(err){
    if (err) {
      throw(err)
    }
  })
  return fileName[fileName.length-1]
}

module.exports = {
  uploadFile,
  moveFile,
  mkdirsSync
}
